return {
  auth = {
    oauth2 = {
      scopes = {
        ["https://www.googleapis.com/auth/cloud-platform"] = {
          description = "See, edit, configure, and delete your Google Cloud data and see the email address for your Google Account.",
        },
        ["https://www.googleapis.com/auth/dialogflow"] = {
          description = "View, manage and query your Dialogflow agents",
        },
      },
    },
  },
  basePath = "",
  baseUrl = "https://dialogflow.googleapis.com/",
  batchPath = "batch",
  canonicalName = "Dialogflow",
  description = "Builds conversational interfaces (for example, chatbots, and voice-powered apps and devices).",
  discoveryVersion = "v1",
  documentationLink = "https://cloud.google.com/dialogflow/",
  fullyEncodeReservedExpansion = true,
  icons = {
    x16 = "http://www.google.com/images/icons/product/search-16.gif",
    x32 = "http://www.google.com/images/icons/product/search-32.gif",
  },
  id = "dialogflow:v2",
  kind = "discovery#restDescription",
  mtlsRootUrl = "https://dialogflow.mtls.googleapis.com/",
  name = "dialogflow",
  ownerDomain = "google.com",
  ownerName = "Google",
  parameters = {
    ["$.xgafv"] = {
      description = "V1 error format.",
      enum = {
        "1",
        "2",
      },
      enumDescriptions = {
        "v1 error format",
        "v2 error format",
      },
      location = "query",
      type = "string",
    },
    access_token = {
      description = "OAuth access token.",
      location = "query",
      type = "string",
    },
    alt = {
      default = "json",
      description = "Data format for response.",
      enum = {
        "json",
        "media",
        "proto",
      },
      enumDescriptions = {
        "Responses with Content-Type of application/json",
        "Media download with context-dependent Content-Type",
        "Responses with Content-Type of application/x-protobuf",
      },
      location = "query",
      type = "string",
    },
    callback = {
      description = "JSONP",
      location = "query",
      type = "string",
    },
    fields = {
      description = "Selector specifying which fields to include in a partial response.",
      location = "query",
      type = "string",
    },
    key = {
      description = "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.",
      location = "query",
      type = "string",
    },
    oauth_token = {
      description = "OAuth 2.0 token for the current user.",
      location = "query",
      type = "string",
    },
    prettyPrint = {
      default = "true",
      description = "Returns response with indentations and line breaks.",
      location = "query",
      type = "boolean",
    },
    quotaUser = {
      description = "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.",
      location = "query",
      type = "string",
    },
    uploadType = {
      description = "Legacy upload protocol for media (e.g. \"media\", \"multipart\").",
      location = "query",
      type = "string",
    },
    upload_protocol = {
      description = "Upload protocol for media (e.g. \"raw\", \"multipart\").",
      location = "query",
      type = "string",
    },
  },
  protocol = "rest",
  resources = {
    projects = {
      methods = {
        deleteAgent = {
          description = "Deletes the specified agent.",
          flatPath = "v2/projects/{projectsId}/agent",
          httpMethod = "DELETE",
          id = "dialogflow.projects.deleteAgent",
          parameterOrder = {
            "parent",
          },
          parameters = {
            parent = {
              description = "Required. The project that the agent to delete is associated with. Format: `projects/`.",
              location = "path",
              pattern = "^projects/[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v2/{+parent}/agent",
          response = {
            ["$ref"] = "GoogleProtobufEmpty",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/dialogflow",
          },
        },
        getAgent = {
          description = "Retrieves the specified agent.",
          flatPath = "v2/projects/{projectsId}/agent",
          httpMethod = "GET",
          id = "dialogflow.projects.getAgent",
          parameterOrder = {
            "parent",
          },
          parameters = {
            parent = {
              description = "Required. The project that the agent to fetch is associated with. Format: `projects/`.",
              location = "path",
              pattern = "^projects/[^/]+$",
              required = true,
              type = "string",
            },
          },
          path = "v2/{+parent}/agent",
          response = {
            ["$ref"] = "GoogleCloudDialogflowV2Agent",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/dialogflow",
          },
        },
        setAgent = {
          description = "Creates/updates the specified agent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
          flatPath = "v2/projects/{projectsId}/agent",
          httpMethod = "POST",
          id = "dialogflow.projects.setAgent",
          parameterOrder = {
            "parent",
          },
          parameters = {
            parent = {
              description = "Required. The project of this agent. Format: `projects/`.",
              location = "path",
              pattern = "^projects/[^/]+$",
              required = true,
              type = "string",
            },
            updateMask = {
              description = "Optional. The mask to control which fields get updated.",
              format = "google-fieldmask",
              location = "query",
              type = "string",
            },
          },
          path = "v2/{+parent}/agent",
          request = {
            ["$ref"] = "GoogleCloudDialogflowV2Agent",
          },
          response = {
            ["$ref"] = "GoogleCloudDialogflowV2Agent",
          },
          scopes = {
            "https://www.googleapis.com/auth/cloud-platform",
            "https://www.googleapis.com/auth/dialogflow",
          },
        },
      },
      resources = {
        agent = {
          methods = {
            export = {
              description = "Exports the specified agent to a ZIP file. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: ExportAgentResponse",
              flatPath = "v2/projects/{projectsId}/agent:export",
              httpMethod = "POST",
              id = "dialogflow.projects.agent.export",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project that the agent to export is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent:export",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ExportAgentRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            getFulfillment = {
              description = "Retrieves the fulfillment.",
              flatPath = "v2/projects/{projectsId}/agent/fulfillment",
              httpMethod = "GET",
              id = "dialogflow.projects.agent.getFulfillment",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The name of the fulfillment. Format: `projects//agent/fulfillment`.",
                  location = "path",
                  pattern = "^projects/[^/]+/agent/fulfillment$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            getValidationResult = {
              description = "Gets agent validation result. Agent validation is performed during training time and is updated automatically when training is completed.",
              flatPath = "v2/projects/{projectsId}/agent/validationResult",
              httpMethod = "GET",
              id = "dialogflow.projects.agent.getValidationResult",
              parameterOrder = {
                "parent",
              },
              parameters = {
                languageCode = {
                  description = "Optional. The language for which you want a validation result. If not specified, the agent's default language is used. [Many languages](https://cloud.google.com/dialogflow/docs/reference/language) are supported. Note: languages must be enabled in the agent before they can be used.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project that the agent is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent/validationResult",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ValidationResult",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            import = {
              description = "Imports the specified agent from a ZIP file. Uploads new intents and entity types without deleting the existing ones. Intents and entity types with the same name are replaced with the new versions from ImportAgentRequest. After the import, the imported draft agent will be trained automatically (unless disabled in agent settings). However, once the import is done, training may not be completed yet. Please call TrainAgent and wait for the operation it returns in order to train explicitly. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) The operation only tracks when importing is complete, not when it is done training. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
              flatPath = "v2/projects/{projectsId}/agent:import",
              httpMethod = "POST",
              id = "dialogflow.projects.agent.import",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project that the agent to import is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent:import",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ImportAgentRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            restore = {
              description = "Restores the specified agent from a ZIP file. Replaces the current agent version with a new one. All the intents and entity types in the older version are deleted. After the restore, the restored draft agent will be trained automatically (unless disabled in agent settings). However, once the restore is done, training may not be completed yet. Please call TrainAgent and wait for the operation it returns in order to train explicitly. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) The operation only tracks when restoring is complete, not when it is done training. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
              flatPath = "v2/projects/{projectsId}/agent:restore",
              httpMethod = "POST",
              id = "dialogflow.projects.agent.restore",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project that the agent to restore is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent:restore",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2RestoreAgentRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            search = {
              description = "Returns the list of agents. Since there is at most one conversational agent per project, this method is useful primarily for listing all agents across projects the caller has access to. One can achieve that with a wildcard project collection id \"-\". Refer to [List Sub-Collections](https://cloud.google.com/apis/design/design_patterns#list_sub-collections).",
              flatPath = "v2/projects/{projectsId}/agent:search",
              httpMethod = "GET",
              id = "dialogflow.projects.agent.search",
              parameterOrder = {
                "parent",
              },
              parameters = {
                pageSize = {
                  description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "The next_page_token value returned from a previous list request.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project to list agents from. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent:search",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2SearchAgentsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            train = {
              description = "Trains the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
              flatPath = "v2/projects/{projectsId}/agent:train",
              httpMethod = "POST",
              id = "dialogflow.projects.agent.train",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project that the agent to train is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent:train",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2TrainAgentRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            updateFulfillment = {
              description = "Updates the fulfillment.",
              flatPath = "v2/projects/{projectsId}/agent/fulfillment",
              httpMethod = "PATCH",
              id = "dialogflow.projects.agent.updateFulfillment",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The unique identifier of the fulfillment. Supported formats: - `projects//agent/fulfillment` - `projects//locations//agent/fulfillment` This field is not used for Fulfillment in an Environment.",
                  location = "path",
                  pattern = "^projects/[^/]+/agent/fulfillment$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields get updated. If the mask is not present, all fields will be updated.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+name}",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
          resources = {
            entityTypes = {
              methods = {
                batchDelete = {
                  description = "Deletes entity types in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes:batchDelete",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.entityTypes.batchDelete",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The name of the agent to delete all entities types for. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/entityTypes:batchDelete",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                batchUpdate = {
                  description = "Updates/Creates multiple entity types in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: BatchUpdateEntityTypesResponse Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes:batchUpdate",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.entityTypes.batchUpdate",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The name of the agent to update or create entity types in. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/entityTypes:batchUpdate",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                create = {
                  description = "Creates an entity type in the specified agent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.entityTypes.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to create a entity type for. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/entityTypes",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified entity type. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.agent.entityTypes.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the entity type to delete. Format: `projects//agent/entityTypes/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/entityTypes/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified entity type.",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.entityTypes.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    name = {
                      description = "Required. The name of the entity type. Format: `projects//agent/entityTypes/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/entityTypes/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all entity types in the specified agent.",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.entityTypes.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to list all entity types from. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/entityTypes",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListEntityTypesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified entity type. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.agent.entityTypes.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    name = {
                      description = "The unique identifier of the entity type. Required for EntityTypes.UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Format: `projects//agent/entityTypes/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/entityTypes/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Optional. The mask to control which fields get updated.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                entities = {
                  methods = {
                    batchCreate = {
                      description = "Creates multiple new entities in the specified entity type. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchCreate",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.entityTypes.entities.batchCreate",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the entity type to create entities in. Format: `projects//agent/entityTypes/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entities:batchCreate",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchCreateEntitiesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    batchDelete = {
                      description = "Deletes entities in the specified entity type. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchDelete",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.entityTypes.entities.batchDelete",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the entity type to delete entries for. Format: `projects//agent/entityTypes/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entities:batchDelete",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    batchUpdate = {
                      description = "Updates or creates multiple entities in the specified entity type. This method does not affect entities in the entity type that aren't explicitly specified in the request. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training). ",
                      flatPath = "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchUpdate",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.entityTypes.entities.batchUpdate",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the entity type to update or create entities in. Format: `projects//agent/entityTypes/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entities:batchUpdate",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            environments = {
              methods = {
                create = {
                  description = "Creates an agent environment.",
                  flatPath = "v2/projects/{projectsId}/agent/environments",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.environments.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    environmentId = {
                      description = "Required. The unique id of the new environment.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to create an environment for. Supported formats: - `projects//agent` - `projects//locations//agent`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/environments",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Environment",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Environment",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified agent environment.",
                  flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.agent.environments.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the environment to delete. / Format: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/environments/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified agent environment.",
                  flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.environments.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the environment. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/environments/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Environment",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                getHistory = {
                  description = "Gets the history of the specified environment.",
                  flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/history",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.environments.getHistory",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The name of the environment to retrieve history for. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/environments/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/history",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2EnvironmentHistory",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all non-default environments of the specified agent.",
                  flatPath = "v2/projects/{projectsId}/agent/environments",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.environments.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to list all environments from. Format: - `projects//agent` - `projects//locations//agent`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/environments",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListEnvironmentsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified agent environment. This method allows you to deploy new agent versions into the environment. When an environment is pointed to a new agent version by setting `environment.agent_version`, the environment is temporarily set to the `LOADING` state. During that time, the environment continues serving the previous version of the agent. After the new agent version is done loading, the environment is set back to the `RUNNING` state. You can use \"-\" as Environment ID in environment name to update an agent version in the default environment. WARNING: this will negate all recent changes to the draft agent and can't be undone. You may want to save the draft agent to a version before calling this method.",
                  flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.agent.environments.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    allowLoadToDraftAndDiscardChanges = {
                      description = "Optional. This field is used to prevent accidental overwrite of the default environment, which is an operation that cannot be undone. To confirm that the caller desires this overwrite, this field must be explicitly set to true when updating the default environment (environment ID = `-`).",
                      location = "query",
                      type = "boolean",
                    },
                    name = {
                      description = "Output only. The unique identifier of this agent environment. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/environments/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Required. The mask to control which fields get updated.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Environment",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Environment",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                intents = {
                  methods = {
                    list = {
                      description = "Returns the list of all intents in the specified agent.",
                      flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/intents",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.environments.intents.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        intentView = {
                          description = "Optional. The resource view to apply to the returned intent.",
                          enum = {
                            "INTENT_VIEW_UNSPECIFIED",
                            "INTENT_VIEW_FULL",
                          },
                          enumDescriptions = {
                            "Training phrases field is not populated in the response.",
                            "All fields are populated.",
                          },
                          location = "query",
                          type = "string",
                        },
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to list all intents from. Format: `projects//agent` or `projects//locations//agent`. Alternatively, you can specify the environment to list intents for. Format: `projects//agent/environments/` or `projects//locations//agent/environments/`. Note: training phrases of the intents will not be returned for non-draft environment.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/environments/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/intents",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListIntentsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
                users = {
                  resources = {
                    sessions = {
                      methods = {
                        deleteContexts = {
                          description = "Deletes all active contexts in the specified session.",
                          flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts",
                          httpMethod = "DELETE",
                          id = "dialogflow.projects.agent.environments.users.sessions.deleteContexts",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the session to delete all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/contexts",
                          response = {
                            ["$ref"] = "GoogleProtobufEmpty",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        detectIntent = {
                          description = "Processes a natural language query and returns structured, actionable data as a result. This method is not idempotent, because it may cause contexts and session entity types to be updated, which in turn might affect results of future queries. If you might use [Agent Assist](https://cloud.google.com/dialogflow/docs/#aa) or other CCAI products now or in the future, consider using AnalyzeContent instead of `DetectIntent`. `AnalyzeContent` has additional functionality for Agent Assist and other CCAI products. Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                          flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}:detectIntent",
                          httpMethod = "POST",
                          id = "dialogflow.projects.agent.environments.users.sessions.detectIntent",
                          parameterOrder = {
                            "session",
                          },
                          parameters = {
                            session = {
                              description = "Required. The name of the session this query is sent to. Format: `projects//agent/sessions/`, or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment (`Environment ID` might be referred to as environment name at some places). If `User ID` is not specified, we are using \"-\". It's up to the API caller to choose an appropriate `Session ID` and `User Id`. They can be a random number or some type of user and session identifiers (preferably hashed). The length of the `Session ID` and `User ID` must not exceed 36 characters. For more information, see the [API interactions guide](https://cloud.google.com/dialogflow/docs/api-overview). Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                              location = "path",
                              pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+session}:detectIntent",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2DetectIntentRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2DetectIntentResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                      },
                      resources = {
                        contexts = {
                          methods = {
                            create = {
                              description = "Creates a context. If the specified context already exists, overrides the context.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts",
                              httpMethod = "POST",
                              id = "dialogflow.projects.agent.environments.users.sessions.contexts.create",
                              parameterOrder = {
                                "parent",
                              },
                              parameters = {
                                parent = {
                                  description = "Required. The session to create a context for. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+parent}/contexts",
                              request = {
                                ["$ref"] = "GoogleCloudDialogflowV2Context",
                              },
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2Context",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            delete = {
                              description = "Deletes the specified context.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}",
                              httpMethod = "DELETE",
                              id = "dialogflow.projects.agent.environments.users.sessions.contexts.delete",
                              parameterOrder = {
                                "name",
                              },
                              parameters = {
                                name = {
                                  description = "Required. The name of the context to delete. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+name}",
                              response = {
                                ["$ref"] = "GoogleProtobufEmpty",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            get = {
                              description = "Retrieves the specified context.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}",
                              httpMethod = "GET",
                              id = "dialogflow.projects.agent.environments.users.sessions.contexts.get",
                              parameterOrder = {
                                "name",
                              },
                              parameters = {
                                name = {
                                  description = "Required. The name of the context. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+name}",
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2Context",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            list = {
                              description = "Returns the list of all contexts in the specified session.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts",
                              httpMethod = "GET",
                              id = "dialogflow.projects.agent.environments.users.sessions.contexts.list",
                              parameterOrder = {
                                "parent",
                              },
                              parameters = {
                                pageSize = {
                                  description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                                  format = "int32",
                                  location = "query",
                                  type = "integer",
                                },
                                pageToken = {
                                  description = "Optional. The next_page_token value returned from a previous list request.",
                                  location = "query",
                                  type = "string",
                                },
                                parent = {
                                  description = "Required. The session to list all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+parent}/contexts",
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2ListContextsResponse",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            patch = {
                              description = "Updates the specified context.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}",
                              httpMethod = "PATCH",
                              id = "dialogflow.projects.agent.environments.users.sessions.contexts.patch",
                              parameterOrder = {
                                "name",
                              },
                              parameters = {
                                name = {
                                  description = "Required. The unique identifier of the context. Format: `projects//agent/sessions//contexts/`, or `projects//agent/environments//users//sessions//contexts/`. The `Context ID` is always converted to lowercase, may only contain characters in a-zA-Z0-9_-% and may be at most 250 bytes long. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. The following context names are reserved for internal use by Dialogflow. You should not use these contexts or create contexts with these names: * `__system_counters__` * `*_id_dialog_context` * `*_dialog_params_size`",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                                updateMask = {
                                  description = "Optional. The mask to control which fields get updated.",
                                  format = "google-fieldmask",
                                  location = "query",
                                  type = "string",
                                },
                              },
                              path = "v2/{+name}",
                              request = {
                                ["$ref"] = "GoogleCloudDialogflowV2Context",
                              },
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2Context",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                          },
                        },
                        entityTypes = {
                          methods = {
                            create = {
                              description = "Creates a session entity type. If the specified session entity type already exists, overrides the session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes",
                              httpMethod = "POST",
                              id = "dialogflow.projects.agent.environments.users.sessions.entityTypes.create",
                              parameterOrder = {
                                "parent",
                              },
                              parameters = {
                                parent = {
                                  description = "Required. The session to create a session entity type for. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+parent}/entityTypes",
                              request = {
                                ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                              },
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            delete = {
                              description = "Deletes the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                              httpMethod = "DELETE",
                              id = "dialogflow.projects.agent.environments.users.sessions.entityTypes.delete",
                              parameterOrder = {
                                "name",
                              },
                              parameters = {
                                name = {
                                  description = "Required. The name of the entity type to delete. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+name}",
                              response = {
                                ["$ref"] = "GoogleProtobufEmpty",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            get = {
                              description = "Retrieves the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                              httpMethod = "GET",
                              id = "dialogflow.projects.agent.environments.users.sessions.entityTypes.get",
                              parameterOrder = {
                                "name",
                              },
                              parameters = {
                                name = {
                                  description = "Required. The name of the session entity type. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+name}",
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            list = {
                              description = "Returns the list of all session entity types in the specified session. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes",
                              httpMethod = "GET",
                              id = "dialogflow.projects.agent.environments.users.sessions.entityTypes.list",
                              parameterOrder = {
                                "parent",
                              },
                              parameters = {
                                pageSize = {
                                  description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                                  format = "int32",
                                  location = "query",
                                  type = "integer",
                                },
                                pageToken = {
                                  description = "Optional. The next_page_token value returned from a previous list request.",
                                  location = "query",
                                  type = "string",
                                },
                                parent = {
                                  description = "Required. The session to list all session entity types from. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+parent}/entityTypes",
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2ListSessionEntityTypesResponse",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            patch = {
                              description = "Updates the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                              flatPath = "v2/projects/{projectsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                              httpMethod = "PATCH",
                              id = "dialogflow.projects.agent.environments.users.sessions.entityTypes.patch",
                              parameterOrder = {
                                "name",
                              },
                              parameters = {
                                name = {
                                  description = "Required. The unique identifier of this session entity type. Format: `projects//agent/sessions//entityTypes/`, or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. `` must be the display name of an existing entity type in the same agent that will be overridden or supplemented.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                                updateMask = {
                                  description = "Optional. The mask to control which fields get updated.",
                                  format = "google-fieldmask",
                                  location = "query",
                                  type = "string",
                                },
                              },
                              path = "v2/{+name}",
                              request = {
                                ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                              },
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                          },
                        },
                      },
                    },
                  },
                },
              },
            },
            intents = {
              methods = {
                batchDelete = {
                  description = "Deletes intents in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/intents:batchDelete",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.intents.batchDelete",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The name of the agent to delete all entities types for. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/intents:batchDelete",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2BatchDeleteIntentsRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                batchUpdate = {
                  description = "Updates/Creates multiple intents in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: BatchUpdateIntentsResponse Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/intents:batchUpdate",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.intents.batchUpdate",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The name of the agent to update or create intents in. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/intents:batchUpdate",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2BatchUpdateIntentsRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                create = {
                  description = "Creates an intent in the specified agent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/intents",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.intents.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    intentView = {
                      description = "Optional. The resource view to apply to the returned intent.",
                      enum = {
                        "INTENT_VIEW_UNSPECIFIED",
                        "INTENT_VIEW_FULL",
                      },
                      enumDescriptions = {
                        "Training phrases field is not populated in the response.",
                        "All fields are populated.",
                      },
                      location = "query",
                      type = "string",
                    },
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to create a intent for. Format: `projects//agent`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/intents",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Intent",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Intent",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified intent and its direct or indirect followup intents. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/intents/{intentsId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.agent.intents.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the intent to delete. If this intent has direct or indirect followup intents, we also delete them. Format: `projects//agent/intents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/intents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified intent.",
                  flatPath = "v2/projects/{projectsId}/agent/intents/{intentsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.intents.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    intentView = {
                      description = "Optional. The resource view to apply to the returned intent.",
                      enum = {
                        "INTENT_VIEW_UNSPECIFIED",
                        "INTENT_VIEW_FULL",
                      },
                      enumDescriptions = {
                        "Training phrases field is not populated in the response.",
                        "All fields are populated.",
                      },
                      location = "query",
                      type = "string",
                    },
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    name = {
                      description = "Required. The name of the intent. Format: `projects//agent/intents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/intents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Intent",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all intents in the specified agent.",
                  flatPath = "v2/projects/{projectsId}/agent/intents",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.intents.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    intentView = {
                      description = "Optional. The resource view to apply to the returned intent.",
                      enum = {
                        "INTENT_VIEW_UNSPECIFIED",
                        "INTENT_VIEW_FULL",
                      },
                      enumDescriptions = {
                        "Training phrases field is not populated in the response.",
                        "All fields are populated.",
                      },
                      location = "query",
                      type = "string",
                    },
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to list all intents from. Format: `projects//agent` or `projects//locations//agent`. Alternatively, you can specify the environment to list intents for. Format: `projects//agent/environments/` or `projects//locations//agent/environments/`. Note: training phrases of the intents will not be returned for non-draft environment.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/intents",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListIntentsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified intent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/agent/intents/{intentsId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.agent.intents.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    intentView = {
                      description = "Optional. The resource view to apply to the returned intent.",
                      enum = {
                        "INTENT_VIEW_UNSPECIFIED",
                        "INTENT_VIEW_FULL",
                      },
                      enumDescriptions = {
                        "Training phrases field is not populated in the response.",
                        "All fields are populated.",
                      },
                      location = "query",
                      type = "string",
                    },
                    languageCode = {
                      description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                      location = "query",
                      type = "string",
                    },
                    name = {
                      description = "Optional. The unique identifier of this intent. Required for Intents.UpdateIntent and Intents.BatchUpdateIntents methods. Format: `projects//agent/intents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/intents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Optional. The mask to control which fields get updated.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Intent",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Intent",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
            knowledgeBases = {
              methods = {
                create = {
                  description = "Creates a knowledge base.",
                  flatPath = "v2/projects/{projectsId}/agent/knowledgeBases",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.knowledgeBases.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project to create a knowledge base for. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/knowledgeBases",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified knowledge base.",
                  flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.agent.knowledgeBases.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    force = {
                      description = "Optional. Force deletes the knowledge base. When set to true, any documents in the knowledge base are also deleted.",
                      location = "query",
                      type = "boolean",
                    },
                    name = {
                      description = "Required. The name of the knowledge base to delete. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified knowledge base.",
                  flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.knowledgeBases.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the knowledge base to retrieve. Format `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all knowledge bases of the specified agent.",
                  flatPath = "v2/projects/{projectsId}/agent/knowledgeBases",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.knowledgeBases.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    filter = {
                      description = "The filter expression used to filter knowledge bases returned by the list method. The expression has the following syntax: [AND ] ... The following fields and operators are supported: * display_name with has(:) operator * language_code with equals(=) operator Examples: * 'language_code=en-us' matches knowledge bases with en-us language code. * 'display_name:articles' matches knowledge bases whose display name contains \"articles\". * 'display_name:\"Best Articles\"' matches knowledge bases whose display name contains \"Best Articles\". * 'language_code=en-gb AND display_name=articles' matches all knowledge bases whose display name contains \"articles\" and whose language code is \"en-gb\". Note: An empty filter string (i.e. \"\") is a no-op and will result in no filtering. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "The maximum number of items to return in a single page. By default 10 and at most 100.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project to list of knowledge bases for. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/knowledgeBases",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListKnowledgeBasesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified knowledge base.",
                  flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.agent.knowledgeBases.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "The knowledge base resource name. The name must be empty when creating a knowledge base. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Optional. Not specified means `update all`. Currently, only `display_name` can be updated, an InvalidArgument will be returned for attempting to update other fields.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                documents = {
                  methods = {
                    create = {
                      description = "Creates a new document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                      flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.knowledgeBases.documents.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The knowledge base to create a document for. Format: `projects//locations//knowledgeBases/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/documents",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Document",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                      flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.agent.knowledgeBases.documents.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to delete. Format: `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified document.",
                      flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.knowledgeBases.documents.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to retrieve. Format `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Document",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all documents of the knowledge base.",
                      flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.knowledgeBases.documents.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        filter = {
                          description = "The filter expression used to filter documents returned by the list method. The expression has the following syntax: [AND ] ... The following fields and operators are supported: * knowledge_types with has(:) operator * display_name with has(:) operator * state with equals(=) operator Examples: * \"knowledge_types:FAQ\" matches documents with FAQ knowledge type. * \"display_name:customer\" matches documents whose display name contains \"customer\". * \"state=ACTIVE\" matches documents with ACTIVE state. * \"knowledge_types:FAQ AND state=ACTIVE\" matches all active FAQ documents. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "The maximum number of items to return in a single page. By default 10 and at most 100.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The knowledge base to list all documents for. Format: `projects//locations//knowledgeBases/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/documents",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListDocumentsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                      flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.agent.knowledgeBases.documents.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Optional. The document resource name. The name must be empty when creating a document. Format: `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Optional. Not specified means `update all`. Currently, only `display_name` can be updated, an InvalidArgument will be returned for attempting to update other fields.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Document",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    reload = {
                      description = "Reloads the specified document from its specified source, content_uri or content. The previously loaded content of the document will be deleted. Note: Even when the content of the document has not changed, there still may be side effects because of internal implementation changes. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document Note: The `projects.agent.knowledgeBases.documents` resource is deprecated; only use `projects.knowledgeBases.documents`.",
                      flatPath = "v2/projects/{projectsId}/agent/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:reload",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.knowledgeBases.documents.reload",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to reload. Format: `projects//locations//knowledgeBases//documents/`",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}:reload",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2ReloadDocumentRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            sessions = {
              methods = {
                deleteContexts = {
                  description = "Deletes all active contexts in the specified session.",
                  flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.agent.sessions.deleteContexts",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The name of the session to delete all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/sessions/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/contexts",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                detectIntent = {
                  description = "Processes a natural language query and returns structured, actionable data as a result. This method is not idempotent, because it may cause contexts and session entity types to be updated, which in turn might affect results of future queries. If you might use [Agent Assist](https://cloud.google.com/dialogflow/docs/#aa) or other CCAI products now or in the future, consider using AnalyzeContent instead of `DetectIntent`. `AnalyzeContent` has additional functionality for Agent Assist and other CCAI products. Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                  flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}:detectIntent",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.sessions.detectIntent",
                  parameterOrder = {
                    "session",
                  },
                  parameters = {
                    session = {
                      description = "Required. The name of the session this query is sent to. Format: `projects//agent/sessions/`, or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment (`Environment ID` might be referred to as environment name at some places). If `User ID` is not specified, we are using \"-\". It's up to the API caller to choose an appropriate `Session ID` and `User Id`. They can be a random number or some type of user and session identifiers (preferably hashed). The length of the `Session ID` and `User ID` must not exceed 36 characters. For more information, see the [API interactions guide](https://cloud.google.com/dialogflow/docs/api-overview). Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/sessions/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+session}:detectIntent",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2DetectIntentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2DetectIntentResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                contexts = {
                  methods = {
                    create = {
                      description = "Creates a context. If the specified context already exists, overrides the context.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.sessions.contexts.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The session to create a context for. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/contexts",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Context",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Context",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified context.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.agent.sessions.contexts.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the context to delete. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified context.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.sessions.contexts.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the context. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Context",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all contexts in the specified session.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.sessions.contexts.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The session to list all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/contexts",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListContextsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified context.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.agent.sessions.contexts.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The unique identifier of the context. Format: `projects//agent/sessions//contexts/`, or `projects//agent/environments//users//sessions//contexts/`. The `Context ID` is always converted to lowercase, may only contain characters in a-zA-Z0-9_-% and may be at most 250 bytes long. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. The following context names are reserved for internal use by Dialogflow. You should not use these contexts or create contexts with these names: * `__system_counters__` * `*_id_dialog_context` * `*_dialog_params_size`",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Optional. The mask to control which fields get updated.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Context",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Context",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
                entityTypes = {
                  methods = {
                    create = {
                      description = "Creates a session entity type. If the specified session entity type already exists, overrides the session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes",
                      httpMethod = "POST",
                      id = "dialogflow.projects.agent.sessions.entityTypes.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The session to create a session entity type for. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entityTypes",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.agent.sessions.entityTypes.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the entity type to delete. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.sessions.entityTypes.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the session entity type. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all session entity types in the specified session. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes",
                      httpMethod = "GET",
                      id = "dialogflow.projects.agent.sessions.entityTypes.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The session to list all session entity types from. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entityTypes",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListSessionEntityTypesResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                      flatPath = "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.agent.sessions.entityTypes.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The unique identifier of this session entity type. Format: `projects//agent/sessions//entityTypes/`, or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. `` must be the display name of an existing entity type in the same agent that will be overridden or supplemented.",
                          location = "path",
                          pattern = "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Optional. The mask to control which fields get updated.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            versions = {
              methods = {
                create = {
                  description = "Creates an agent version. The new version points to the agent instance in the \"default\" environment.",
                  flatPath = "v2/projects/{projectsId}/agent/versions",
                  httpMethod = "POST",
                  id = "dialogflow.projects.agent.versions.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The agent to create a version for. Supported formats: - `projects//agent` - `projects//locations//agent`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/versions",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Version",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Version",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Delete the specified agent version.",
                  flatPath = "v2/projects/{projectsId}/agent/versions/{versionsId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.agent.versions.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the version to delete. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/versions/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified agent version.",
                  flatPath = "v2/projects/{projectsId}/agent/versions/{versionsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.versions.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the version. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/versions/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Version",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all versions of the specified agent.",
                  flatPath = "v2/projects/{projectsId}/agent/versions",
                  httpMethod = "GET",
                  id = "dialogflow.projects.agent.versions.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The agent to list all versions from. Supported formats: - `projects//agent` - `projects//locations//agent`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/versions",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListVersionsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified agent version. Note that this method does not allow you to update the state of the agent the given version points to. It allows you to update only mutable properties of the version resource.",
                  flatPath = "v2/projects/{projectsId}/agent/versions/{versionsId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.agent.versions.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Output only. The unique identifier of this agent version. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
                      location = "path",
                      pattern = "^projects/[^/]+/agent/versions/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Required. The mask to control which fields get updated.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Version",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Version",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
          },
        },
        answerRecords = {
          methods = {
            list = {
              description = "Returns the list of all answer records in the specified project in reverse chronological order.",
              flatPath = "v2/projects/{projectsId}/answerRecords",
              httpMethod = "GET",
              id = "dialogflow.projects.answerRecords.list",
              parameterOrder = {
                "parent",
              },
              parameters = {
                filter = {
                  description = "Optional. Filters to restrict results to specific answer records. Marked deprecated as it hasn't been, and isn't currently, supported. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Optional. The maximum number of records to return in a single page. The server may return fewer records than this. If unspecified, we use 10. The maximum is 100.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "Optional. The ListAnswerRecordsResponse.next_page_token value returned from a previous list request used to continue listing on the next page.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project to list all answer records for in reverse chronological order. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/answerRecords",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ListAnswerRecordsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            patch = {
              description = "Updates the specified answer record.",
              flatPath = "v2/projects/{projectsId}/answerRecords/{answerRecordsId}",
              httpMethod = "PATCH",
              id = "dialogflow.projects.answerRecords.patch",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "The unique identifier of this answer record. Format: `projects//locations//answerRecords/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/answerRecords/[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields get updated.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+name}",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2AnswerRecord",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2AnswerRecord",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
        },
        conversationDatasets = {
          methods = {
            get = {
              description = "Retrieves the specified conversation dataset.",
              flatPath = "v2/projects/{projectsId}/conversationDatasets/{conversationDatasetsId}",
              httpMethod = "GET",
              id = "dialogflow.projects.conversationDatasets.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The conversation dataset to retrieve. Format: `projects//locations//conversationDatasets/`",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationDatasets/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationDataset",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            importConversationData = {
              description = "Import data into the specified conversation dataset. Note that it is not allowed to import data to a conversation dataset that already has data in it. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: ImportConversationDataOperationMetadata - `response`: ImportConversationDataOperationResponse",
              flatPath = "v2/projects/{projectsId}/conversationDatasets/{conversationDatasetsId}:importConversationData",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationDatasets.importConversationData",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. Dataset resource name. Format: `projects//locations//conversationDatasets/`",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationDatasets/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}:importConversationData",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ImportConversationDataRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Returns the list of all conversation datasets in the specified project and location.",
              flatPath = "v2/projects/{projectsId}/conversationDatasets",
              httpMethod = "GET",
              id = "dialogflow.projects.conversationDatasets.list",
              parameterOrder = {
                "parent",
              },
              parameters = {
                pageSize = {
                  description = "Optional. Maximum number of conversation datasets to return in a single page. By default 100 and at most 1000.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "Optional. The next_page_token value returned from a previous list request.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project and location name to list all conversation datasets for. Format: `projects//locations/`",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversationDatasets",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ListConversationDatasetsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
        },
        conversationModels = {
          methods = {
            create = {
              description = "Creates a model. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: CreateConversationModelOperationMetadata - `response`: ConversationModel",
              flatPath = "v2/projects/{projectsId}/conversationModels",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationModels.create",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "The project to create conversation model for. Format: `projects/`",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversationModels",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationModel",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            delete = {
              description = "Deletes a model. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: DeleteConversationModelOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
              flatPath = "v2/projects/{projectsId}/conversationModels/{conversationModelsId}",
              httpMethod = "DELETE",
              id = "dialogflow.projects.conversationModels.delete",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The conversation model to delete. Format: `projects//conversationModels/`",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationModels/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            deploy = {
              description = "Deploys a model. If a model is already deployed, deploying it has no effect. A model can only serve prediction requests after it gets deployed. For article suggestion, custom model will not be used unless it is deployed. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: DeployConversationModelOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
              flatPath = "v2/projects/{projectsId}/conversationModels/{conversationModelsId}:deploy",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationModels.deploy",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The conversation model to deploy. Format: `projects//conversationModels/`",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationModels/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}:deploy",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2DeployConversationModelRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            get = {
              description = "Gets conversation model.",
              flatPath = "v2/projects/{projectsId}/conversationModels/{conversationModelsId}",
              httpMethod = "GET",
              id = "dialogflow.projects.conversationModels.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The conversation model to retrieve. Format: `projects//conversationModels/`",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationModels/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationModel",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Lists conversation models.",
              flatPath = "v2/projects/{projectsId}/conversationModels",
              httpMethod = "GET",
              id = "dialogflow.projects.conversationModels.list",
              parameterOrder = {
                "parent",
              },
              parameters = {
                pageSize = {
                  description = "Optional. Maximum number of conversation models to return in a single page. By default 100 and at most 1000.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "Optional. The next_page_token value returned from a previous list request.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project to list all conversation models for. Format: `projects/`",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversationModels",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ListConversationModelsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            undeploy = {
              description = "Undeploys a model. If the model is not deployed this method has no effect. If the model is currently being used: - For article suggestion, article suggestion will fallback to the default model if model is undeployed. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: UndeployConversationModelOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
              flatPath = "v2/projects/{projectsId}/conversationModels/{conversationModelsId}:undeploy",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationModels.undeploy",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The conversation model to undeploy. Format: `projects//conversationModels/`",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationModels/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}:undeploy",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2UndeployConversationModelRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
          resources = {
            evaluations = {
              methods = {
                get = {
                  description = "Gets an evaluation of conversation model.",
                  flatPath = "v2/projects/{projectsId}/conversationModels/{conversationModelsId}/evaluations/{evaluationsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.conversationModels.evaluations.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation model evaluation resource name. Format: `projects//conversationModels//evaluations/`",
                      location = "path",
                      pattern = "^projects/[^/]+/conversationModels/[^/]+/evaluations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationModelEvaluation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Lists evaluations of a conversation model.",
                  flatPath = "v2/projects/{projectsId}/conversationModels/{conversationModelsId}/evaluations",
                  httpMethod = "GET",
                  id = "dialogflow.projects.conversationModels.evaluations.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. Maximum number of evaluations to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The conversation model resource name. Format: `projects//conversationModels/`",
                      location = "path",
                      pattern = "^projects/[^/]+/conversationModels/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/evaluations",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListConversationModelEvaluationsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
          },
        },
        conversationProfiles = {
          methods = {
            clearSuggestionFeatureConfig = {
              description = "Clears a suggestion feature from a conversation profile for the given participant role. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: ClearSuggestionFeatureConfigOperationMetadata - `response`: ConversationProfile",
              flatPath = "v2/projects/{projectsId}/conversationProfiles/{conversationProfilesId}:clearSuggestionFeatureConfig",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationProfiles.clearSuggestionFeatureConfig",
              parameterOrder = {
                "conversationProfile",
              },
              parameters = {
                conversationProfile = {
                  description = "Required. The Conversation Profile to add or update the suggestion feature config. Format: `projects//locations//conversationProfiles/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationProfiles/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+conversationProfile}:clearSuggestionFeatureConfig",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ClearSuggestionFeatureConfigRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            create = {
              description = "Creates a conversation profile in the specified project. ConversationProfile.CreateTime and ConversationProfile.UpdateTime aren't populated in the response. You can retrieve them via GetConversationProfile API.",
              flatPath = "v2/projects/{projectsId}/conversationProfiles",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationProfiles.create",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project to create a conversation profile for. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversationProfiles",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            delete = {
              description = "Deletes the specified conversation profile.",
              flatPath = "v2/projects/{projectsId}/conversationProfiles/{conversationProfilesId}",
              httpMethod = "DELETE",
              id = "dialogflow.projects.conversationProfiles.delete",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The name of the conversation profile to delete. Format: `projects//locations//conversationProfiles/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationProfiles/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleProtobufEmpty",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            get = {
              description = "Retrieves the specified conversation profile.",
              flatPath = "v2/projects/{projectsId}/conversationProfiles/{conversationProfilesId}",
              httpMethod = "GET",
              id = "dialogflow.projects.conversationProfiles.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The resource name of the conversation profile. Format: `projects//locations//conversationProfiles/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationProfiles/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Returns the list of all conversation profiles in the specified project.",
              flatPath = "v2/projects/{projectsId}/conversationProfiles",
              httpMethod = "GET",
              id = "dialogflow.projects.conversationProfiles.list",
              parameterOrder = {
                "parent",
              },
              parameters = {
                pageSize = {
                  description = "The maximum number of items to return in a single page. By default 100 and at most 1000.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "The next_page_token value returned from a previous list request.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project to list all conversation profiles from. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversationProfiles",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ListConversationProfilesResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            patch = {
              description = "Updates the specified conversation profile. ConversationProfile.CreateTime and ConversationProfile.UpdateTime aren't populated in the response. You can retrieve them via GetConversationProfile API.",
              flatPath = "v2/projects/{projectsId}/conversationProfiles/{conversationProfilesId}",
              httpMethod = "PATCH",
              id = "dialogflow.projects.conversationProfiles.patch",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "The unique identifier of this conversation profile. Format: `projects//locations//conversationProfiles/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationProfiles/[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Required. The mask to control which fields to update.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+name}",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            setSuggestionFeatureConfig = {
              description = "Adds or updates a suggestion feature in a conversation profile. If the conversation profile contains the type of suggestion feature for the participant role, it will update it. Otherwise it will insert the suggestion feature. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: SetSuggestionFeatureConfigOperationMetadata - `response`: ConversationProfile If a long running operation to add or update suggestion feature config for the same conversation profile, participant role and suggestion feature type exists, please cancel the existing long running operation before sending such request, otherwise the request will be rejected.",
              flatPath = "v2/projects/{projectsId}/conversationProfiles/{conversationProfilesId}:setSuggestionFeatureConfig",
              httpMethod = "POST",
              id = "dialogflow.projects.conversationProfiles.setSuggestionFeatureConfig",
              parameterOrder = {
                "conversationProfile",
              },
              parameters = {
                conversationProfile = {
                  description = "Required. The Conversation Profile to add or update the suggestion feature config. Format: `projects//locations//conversationProfiles/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversationProfiles/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+conversationProfile}:setSuggestionFeatureConfig",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2SetSuggestionFeatureConfigRequest",
              },
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
        },
        conversations = {
          methods = {
            complete = {
              description = "Completes the specified conversation. Finished conversations are purged from the database after 30 days.",
              flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}:complete",
              httpMethod = "POST",
              id = "dialogflow.projects.conversations.complete",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. Resource identifier of the conversation to close. Format: `projects//locations//conversations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}:complete",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2CompleteConversationRequest",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Conversation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            create = {
              description = "Creates a new conversation. Conversations are auto-completed after 24 hours. Conversation Lifecycle: There are two stages during a conversation: Automated Agent Stage and Assist Stage. For Automated Agent Stage, there will be a dialogflow agent responding to user queries. For Assist Stage, there's no dialogflow agent responding to user queries. But we will provide suggestions which are generated from conversation. If Conversation.conversation_profile is configured for a dialogflow agent, conversation will start from `Automated Agent Stage`, otherwise, it will start from `Assist Stage`. And during `Automated Agent Stage`, once an Intent with Intent.live_agent_handoff is triggered, conversation will transfer to Assist Stage.",
              flatPath = "v2/projects/{projectsId}/conversations",
              httpMethod = "POST",
              id = "dialogflow.projects.conversations.create",
              parameterOrder = {
                "parent",
              },
              parameters = {
                conversationId = {
                  description = "Optional. Identifier of the conversation. Generally it's auto generated by Google. Only set it if you cannot wait for the response to return a auto-generated one to you. The conversation ID must be compliant with the regression fomula \"a-zA-Z*\" with the characters length in range of [3,64]. If the field is provided, the caller is resposible for 1. the uniqueness of the ID, otherwise the request will be rejected. 2. the consistency for whether to use custom ID or not under a project to better ensure uniqueness.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. Resource identifier of the project creating the conversation. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversations",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2Conversation",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Conversation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            get = {
              description = "Retrieves the specific conversation.",
              flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}",
              httpMethod = "GET",
              id = "dialogflow.projects.conversations.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The name of the conversation. Format: `projects//locations//conversations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/conversations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Conversation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Returns the list of all conversations in the specified project.",
              flatPath = "v2/projects/{projectsId}/conversations",
              httpMethod = "GET",
              id = "dialogflow.projects.conversations.list",
              parameterOrder = {
                "parent",
              },
              parameters = {
                filter = {
                  description = "A filter expression that filters conversations listed in the response. In general, the expression must specify the field name, a comparison operator, and the value to use for filtering: - The value must be a string, a number, or a boolean. - The comparison operator must be either `=`,`!=`, `>`, or `<`. - To filter on multiple expressions, separate the expressions with `AND` or `OR` (omitting both implies `AND`). - For clarity, expressions can be enclosed in parentheses. Only `lifecycle_state` can be filtered on in this way. For example, the following expression only returns `COMPLETED` conversations: `lifecycle_state = \"COMPLETED\"` For more information about filtering, see [API Filtering](https://aip.dev/160).",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "Optional. The next_page_token value returned from a previous list request.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project from which to list all conversation. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/conversations",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ListConversationsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
          resources = {
            messages = {
              methods = {
                list = {
                  description = "Lists messages that belong to a given conversation. `messages` are ordered by `create_time` in descending order. To fetch updates without duplication, send request with filter `create_time_epoch_microseconds > [first item's create_time of previous request]` and empty page_token.",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/messages",
                  httpMethod = "GET",
                  id = "dialogflow.projects.conversations.messages.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    filter = {
                      description = "Optional. Filter on message fields. Currently predicates on `create_time` and `create_time_epoch_microseconds` are supported. `create_time` only support milliseconds accuracy. E.g., `create_time_epoch_microseconds > 1551790877964485` or `create_time > 2017-01-15T01:30:15.01Z`. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The name of the conversation to list messages for. Format: `projects//locations//conversations/`",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/messages",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListMessagesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
            participants = {
              methods = {
                analyzeContent = {
                  description = "Adds a text (chat, for example), or audio (phone recording, for example) message from a participant into the conversation. Note: Always use agent versions for production traffic sent to virtual agents. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants/{participantsId}:analyzeContent",
                  httpMethod = "POST",
                  id = "dialogflow.projects.conversations.participants.analyzeContent",
                  parameterOrder = {
                    "participant",
                  },
                  parameters = {
                    participant = {
                      description = "Required. The name of the participant this text comes from. Format: `projects//locations//conversations//participants/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+/participants/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+participant}:analyzeContent",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2AnalyzeContentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2AnalyzeContentResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                create = {
                  description = "Creates a new participant in a conversation.",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants",
                  httpMethod = "POST",
                  id = "dialogflow.projects.conversations.participants.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. Resource identifier of the conversation adding the participant. Format: `projects//locations//conversations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/participants",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Participant",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Participant",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves a conversation participant.",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants/{participantsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.conversations.participants.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the participant. Format: `projects//locations//conversations//participants/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+/participants/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Participant",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all participants in the specified conversation.",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants",
                  httpMethod = "GET",
                  id = "dialogflow.projects.conversations.participants.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The conversation to list all participants from. Format: `projects//locations//conversations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/participants",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListParticipantsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified participant.",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants/{participantsId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.conversations.participants.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Optional. The unique identifier of this participant. Format: `projects//locations//conversations//participants/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+/participants/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Required. The mask to specify which fields to update.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Participant",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Participant",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                suggestions = {
                  methods = {
                    suggestArticles = {
                      description = "Gets suggested articles for a participant based on specific historical messages.",
                      flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants/{participantsId}/suggestions:suggestArticles",
                      httpMethod = "POST",
                      id = "dialogflow.projects.conversations.participants.suggestions.suggestArticles",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the participant to fetch suggestion for. Format: `projects//locations//conversations//participants/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/conversations/[^/]+/participants/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/suggestions:suggestArticles",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestArticlesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestArticlesResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    suggestFaqAnswers = {
                      description = "Gets suggested faq answers for a participant based on specific historical messages.",
                      flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants/{participantsId}/suggestions:suggestFaqAnswers",
                      httpMethod = "POST",
                      id = "dialogflow.projects.conversations.participants.suggestions.suggestFaqAnswers",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the participant to fetch suggestion for. Format: `projects//locations//conversations//participants/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/conversations/[^/]+/participants/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/suggestions:suggestFaqAnswers",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestFaqAnswersRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestFaqAnswersResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    suggestSmartReplies = {
                      description = "Gets smart replies for a participant based on specific historical messages.",
                      flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/participants/{participantsId}/suggestions:suggestSmartReplies",
                      httpMethod = "POST",
                      id = "dialogflow.projects.conversations.participants.suggestions.suggestSmartReplies",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the participant to fetch suggestion for. Format: `projects//locations//conversations//participants/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/conversations/[^/]+/participants/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/suggestions:suggestSmartReplies",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestSmartRepliesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestSmartRepliesResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            suggestions = {
              methods = {
                suggestConversationSummary = {
                  description = "Suggests summary for a conversation based on specific historical messages. The range of the messages to be used for summary can be specified in the request.",
                  flatPath = "v2/projects/{projectsId}/conversations/{conversationsId}/suggestions:suggestConversationSummary",
                  httpMethod = "POST",
                  id = "dialogflow.projects.conversations.suggestions.suggestConversationSummary",
                  parameterOrder = {
                    "conversation",
                  },
                  parameters = {
                    conversation = {
                      description = "Required. The conversation to fetch suggestion for. Format: `projects//locations//conversations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/conversations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+conversation}/suggestions:suggestConversationSummary",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2SuggestConversationSummaryRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2SuggestConversationSummaryResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
          },
        },
        knowledgeBases = {
          methods = {
            create = {
              description = "Creates a knowledge base.",
              flatPath = "v2/projects/{projectsId}/knowledgeBases",
              httpMethod = "POST",
              id = "dialogflow.projects.knowledgeBases.create",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project to create a knowledge base for. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/knowledgeBases",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            delete = {
              description = "Deletes the specified knowledge base.",
              flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}",
              httpMethod = "DELETE",
              id = "dialogflow.projects.knowledgeBases.delete",
              parameterOrder = {
                "name",
              },
              parameters = {
                force = {
                  description = "Optional. Force deletes the knowledge base. When set to true, any documents in the knowledge base are also deleted.",
                  location = "query",
                  type = "boolean",
                },
                name = {
                  description = "Required. The name of the knowledge base to delete. Format: `projects//locations//knowledgeBases/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/knowledgeBases/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleProtobufEmpty",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            get = {
              description = "Retrieves the specified knowledge base.",
              flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}",
              httpMethod = "GET",
              id = "dialogflow.projects.knowledgeBases.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Required. The name of the knowledge base to retrieve. Format `projects//locations//knowledgeBases/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/knowledgeBases/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Returns the list of all knowledge bases of the specified agent.",
              flatPath = "v2/projects/{projectsId}/knowledgeBases",
              httpMethod = "GET",
              id = "dialogflow.projects.knowledgeBases.list",
              parameterOrder = {
                "parent",
              },
              parameters = {
                filter = {
                  description = "The filter expression used to filter knowledge bases returned by the list method. The expression has the following syntax: [AND ] ... The following fields and operators are supported: * display_name with has(:) operator * language_code with equals(=) operator Examples: * 'language_code=en-us' matches knowledge bases with en-us language code. * 'display_name:articles' matches knowledge bases whose display name contains \"articles\". * 'display_name:\"Best Articles\"' matches knowledge bases whose display name contains \"Best Articles\". * 'language_code=en-gb AND display_name=articles' matches all knowledge bases whose display name contains \"articles\" and whose language code is \"en-gb\". Note: An empty filter string (i.e. \"\") is a no-op and will result in no filtering. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                  location = "query",
                  type = "string",
                },
                pageSize = {
                  description = "The maximum number of items to return in a single page. By default 10 and at most 100.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "The next_page_token value returned from a previous list request.",
                  location = "query",
                  type = "string",
                },
                parent = {
                  description = "Required. The project to list of knowledge bases for. Format: `projects//locations/`.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/knowledgeBases",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2ListKnowledgeBasesResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            patch = {
              description = "Updates the specified knowledge base.",
              flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}",
              httpMethod = "PATCH",
              id = "dialogflow.projects.knowledgeBases.patch",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "The knowledge base resource name. The name must be empty when creating a knowledge base. Format: `projects//locations//knowledgeBases/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/knowledgeBases/[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Optional. Not specified means `update all`. Currently, only `display_name` can be updated, an InvalidArgument will be returned for attempting to update other fields.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+name}",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
          resources = {
            documents = {
              methods = {
                create = {
                  description = "Creates a new document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents",
                  httpMethod = "POST",
                  id = "dialogflow.projects.knowledgeBases.documents.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The knowledge base to create a document for. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/documents",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Document",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.knowledgeBases.documents.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the document to delete. Format: `projects//locations//knowledgeBases//documents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                export = {
                  description = "Exports a smart messaging candidate document into the specified destination. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:export",
                  httpMethod = "POST",
                  id = "dialogflow.projects.knowledgeBases.documents.export",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the document to export. Format: `projects//locations//knowledgeBases//documents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:export",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ExportDocumentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified document.",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.knowledgeBases.documents.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the document to retrieve. Format `projects//locations//knowledgeBases//documents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Document",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                import = {
                  description = "Creates documents by importing data from external sources. Dialogflow supports up to 350 documents in each request. If you try to import more, Dialogflow will return an error. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: ImportDocumentsResponse",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents:import",
                  httpMethod = "POST",
                  id = "dialogflow.projects.knowledgeBases.documents.import",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The knowledge base to import documents into. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/documents:import",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ImportDocumentsRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all documents of the knowledge base.",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents",
                  httpMethod = "GET",
                  id = "dialogflow.projects.knowledgeBases.documents.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    filter = {
                      description = "The filter expression used to filter documents returned by the list method. The expression has the following syntax: [AND ] ... The following fields and operators are supported: * knowledge_types with has(:) operator * display_name with has(:) operator * state with equals(=) operator Examples: * \"knowledge_types:FAQ\" matches documents with FAQ knowledge type. * \"display_name:customer\" matches documents whose display name contains \"customer\". * \"state=ACTIVE\" matches documents with ACTIVE state. * \"knowledge_types:FAQ AND state=ACTIVE\" matches all active FAQ documents. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "The maximum number of items to return in a single page. By default 10 and at most 100.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The knowledge base to list all documents for. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/documents",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListDocumentsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.knowledgeBases.documents.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Optional. The document resource name. The name must be empty when creating a document. Format: `projects//locations//knowledgeBases//documents/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Optional. Not specified means `update all`. Currently, only `display_name` can be updated, an InvalidArgument will be returned for attempting to update other fields.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Document",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                reload = {
                  description = "Reloads the specified document from its specified source, content_uri or content. The previously loaded content of the document will be deleted. Note: Even when the content of the document has not changed, there still may be side effects because of internal implementation changes. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document Note: The `projects.agent.knowledgeBases.documents` resource is deprecated; only use `projects.knowledgeBases.documents`.",
                  flatPath = "v2/projects/{projectsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:reload",
                  httpMethod = "POST",
                  id = "dialogflow.projects.knowledgeBases.documents.reload",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the document to reload. Format: `projects//locations//knowledgeBases//documents/`",
                      location = "path",
                      pattern = "^projects/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:reload",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ReloadDocumentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
          },
        },
        locations = {
          methods = {
            deleteAgent = {
              description = "Deletes the specified agent.",
              flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent",
              httpMethod = "DELETE",
              id = "dialogflow.projects.locations.deleteAgent",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project that the agent to delete is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/locations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent",
              response = {
                ["$ref"] = "GoogleProtobufEmpty",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            get = {
              description = "Gets information about a location.",
              flatPath = "v2/projects/{projectsId}/locations/{locationsId}",
              httpMethod = "GET",
              id = "dialogflow.projects.locations.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "Resource name for the location.",
                  location = "path",
                  pattern = "^projects/[^/]+/locations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleCloudLocationLocation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            getAgent = {
              description = "Retrieves the specified agent.",
              flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent",
              httpMethod = "GET",
              id = "dialogflow.projects.locations.getAgent",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project that the agent to fetch is associated with. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/locations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent",
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Agent",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Lists information about the supported locations for this service.",
              flatPath = "v2/projects/{projectsId}/locations",
              httpMethod = "GET",
              id = "dialogflow.projects.locations.list",
              parameterOrder = {
                "name",
              },
              parameters = {
                filter = {
                  description = "A filter to narrow down results to a preferred subset. The filtering language accepts strings like `\"displayName=tokyo\"`, and is documented in more detail in [AIP-160](https://google.aip.dev/160).",
                  location = "query",
                  type = "string",
                },
                name = {
                  description = "The resource that owns the locations collection, if applicable.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
                pageSize = {
                  description = "The maximum number of results to return. If not set, the service selects a default.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "A page token received from the `next_page_token` field in the response. Send that page token to receive the subsequent page.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+name}/locations",
              response = {
                ["$ref"] = "GoogleCloudLocationListLocationsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            setAgent = {
              description = "Creates/updates the specified agent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
              flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent",
              httpMethod = "POST",
              id = "dialogflow.projects.locations.setAgent",
              parameterOrder = {
                "parent",
              },
              parameters = {
                parent = {
                  description = "Required. The project of this agent. Format: `projects/`.",
                  location = "path",
                  pattern = "^projects/[^/]+/locations/[^/]+$",
                  required = true,
                  type = "string",
                },
                updateMask = {
                  description = "Optional. The mask to control which fields get updated.",
                  format = "google-fieldmask",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+parent}/agent",
              request = {
                ["$ref"] = "GoogleCloudDialogflowV2Agent",
              },
              response = {
                ["$ref"] = "GoogleCloudDialogflowV2Agent",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
          resources = {
            agent = {
              methods = {
                export = {
                  description = "Exports the specified agent to a ZIP file. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: ExportAgentResponse",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent:export",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.agent.export",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project that the agent to export is associated with. Format: `projects/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/agent:export",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ExportAgentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                getFulfillment = {
                  description = "Retrieves the fulfillment.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/fulfillment",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.agent.getFulfillment",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the fulfillment. Format: `projects//agent/fulfillment`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/agent/fulfillment$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                getValidationResult = {
                  description = "Gets agent validation result. Agent validation is performed during training time and is updated automatically when training is completed.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/validationResult",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.agent.getValidationResult",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    languageCode = {
                      description = "Optional. The language for which you want a validation result. If not specified, the agent's default language is used. [Many languages](https://cloud.google.com/dialogflow/docs/reference/language) are supported. Note: languages must be enabled in the agent before they can be used.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project that the agent is associated with. Format: `projects/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/agent/validationResult",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ValidationResult",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                import = {
                  description = "Imports the specified agent from a ZIP file. Uploads new intents and entity types without deleting the existing ones. Intents and entity types with the same name are replaced with the new versions from ImportAgentRequest. After the import, the imported draft agent will be trained automatically (unless disabled in agent settings). However, once the import is done, training may not be completed yet. Please call TrainAgent and wait for the operation it returns in order to train explicitly. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) The operation only tracks when importing is complete, not when it is done training. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent:import",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.agent.import",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project that the agent to import is associated with. Format: `projects/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/agent:import",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ImportAgentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                restore = {
                  description = "Restores the specified agent from a ZIP file. Replaces the current agent version with a new one. All the intents and entity types in the older version are deleted. After the restore, the restored draft agent will be trained automatically (unless disabled in agent settings). However, once the restore is done, training may not be completed yet. Please call TrainAgent and wait for the operation it returns in order to train explicitly. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) The operation only tracks when restoring is complete, not when it is done training. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent:restore",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.agent.restore",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project that the agent to restore is associated with. Format: `projects/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/agent:restore",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2RestoreAgentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                search = {
                  description = "Returns the list of agents. Since there is at most one conversational agent per project, this method is useful primarily for listing all agents across projects the caller has access to. One can achieve that with a wildcard project collection id \"-\". Refer to [List Sub-Collections](https://cloud.google.com/apis/design/design_patterns#list_sub-collections).",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent:search",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.agent.search",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project to list agents from. Format: `projects/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/agent:search",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2SearchAgentsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                train = {
                  description = "Trains the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent:train",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.agent.train",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project that the agent to train is associated with. Format: `projects/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/agent:train",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2TrainAgentRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                updateFulfillment = {
                  description = "Updates the fulfillment.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/fulfillment",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.locations.agent.updateFulfillment",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The unique identifier of the fulfillment. Supported formats: - `projects//agent/fulfillment` - `projects//locations//agent/fulfillment` This field is not used for Fulfillment in an Environment.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/agent/fulfillment$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Required. The mask to control which fields get updated. If the mask is not present, all fields will be updated.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                entityTypes = {
                  methods = {
                    batchDelete = {
                      description = "Deletes entity types in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes:batchDelete",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.entityTypes.batchDelete",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the agent to delete all entities types for. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entityTypes:batchDelete",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    batchUpdate = {
                      description = "Updates/Creates multiple entity types in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: BatchUpdateEntityTypesResponse Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes:batchUpdate",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.entityTypes.batchUpdate",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the agent to update or create entity types in. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entityTypes:batchUpdate",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    create = {
                      description = "Creates an entity type in the specified agent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.entityTypes.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to create a entity type for. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entityTypes",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified entity type. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes/{entityTypesId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.locations.agent.entityTypes.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the entity type to delete. Format: `projects//agent/entityTypes/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified entity type.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes/{entityTypesId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.entityTypes.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        name = {
                          description = "Required. The name of the entity type. Format: `projects//agent/entityTypes/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all entity types in the specified agent.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.entityTypes.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to list all entity types from. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/entityTypes",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListEntityTypesResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified entity type. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes/{entityTypesId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.locations.agent.entityTypes.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        name = {
                          description = "The unique identifier of the entity type. Required for EntityTypes.UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Format: `projects//agent/entityTypes/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/entityTypes/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Optional. The mask to control which fields get updated.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2EntityType",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                  resources = {
                    entities = {
                      methods = {
                        batchCreate = {
                          description = "Creates multiple new entities in the specified entity type. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes/{entityTypesId}/entities:batchCreate",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.agent.entityTypes.entities.batchCreate",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the entity type to create entities in. Format: `projects//agent/entityTypes/`.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/entityTypes/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/entities:batchCreate",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2BatchCreateEntitiesRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleLongrunningOperation",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        batchDelete = {
                          description = "Deletes entities in the specified entity type. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes/{entityTypesId}/entities:batchDelete",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.agent.entityTypes.entities.batchDelete",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the entity type to delete entries for. Format: `projects//agent/entityTypes/`.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/entityTypes/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/entities:batchDelete",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleLongrunningOperation",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        batchUpdate = {
                          description = "Updates or creates multiple entities in the specified entity type. This method does not affect entities in the entity type that aren't explicitly specified in the request. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training). ",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/entityTypes/{entityTypesId}/entities:batchUpdate",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.agent.entityTypes.entities.batchUpdate",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the entity type to update or create entities in. Format: `projects//agent/entityTypes/`.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/entityTypes/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/entities:batchUpdate",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleLongrunningOperation",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                      },
                    },
                  },
                },
                environments = {
                  methods = {
                    create = {
                      description = "Creates an agent environment.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.environments.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        environmentId = {
                          description = "Required. The unique id of the new environment.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to create an environment for. Supported formats: - `projects//agent` - `projects//locations//agent`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/environments",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Environment",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Environment",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified agent environment.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.locations.agent.environments.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the environment to delete. / Format: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified agent environment.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.environments.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the environment. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Environment",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    getHistory = {
                      description = "Gets the history of the specified environment.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/history",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.environments.getHistory",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The name of the environment to retrieve history for. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/history",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2EnvironmentHistory",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all non-default environments of the specified agent.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.environments.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to list all environments from. Format: - `projects//agent` - `projects//locations//agent`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/environments",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListEnvironmentsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified agent environment. This method allows you to deploy new agent versions into the environment. When an environment is pointed to a new agent version by setting `environment.agent_version`, the environment is temporarily set to the `LOADING` state. During that time, the environment continues serving the previous version of the agent. After the new agent version is done loading, the environment is set back to the `RUNNING` state. You can use \"-\" as Environment ID in environment name to update an agent version in the default environment. WARNING: this will negate all recent changes to the draft agent and can't be undone. You may want to save the draft agent to a version before calling this method.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.locations.agent.environments.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        allowLoadToDraftAndDiscardChanges = {
                          description = "Optional. This field is used to prevent accidental overwrite of the default environment, which is an operation that cannot be undone. To confirm that the caller desires this overwrite, this field must be explicitly set to true when updating the default environment (environment ID = `-`).",
                          location = "query",
                          type = "boolean",
                        },
                        name = {
                          description = "Output only. The unique identifier of this agent environment. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Required. The mask to control which fields get updated.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Environment",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Environment",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                  resources = {
                    intents = {
                      methods = {
                        list = {
                          description = "Returns the list of all intents in the specified agent.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/intents",
                          httpMethod = "GET",
                          id = "dialogflow.projects.locations.agent.environments.intents.list",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            intentView = {
                              description = "Optional. The resource view to apply to the returned intent.",
                              enum = {
                                "INTENT_VIEW_UNSPECIFIED",
                                "INTENT_VIEW_FULL",
                              },
                              enumDescriptions = {
                                "Training phrases field is not populated in the response.",
                                "All fields are populated.",
                              },
                              location = "query",
                              type = "string",
                            },
                            languageCode = {
                              description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                              location = "query",
                              type = "string",
                            },
                            pageSize = {
                              description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                              format = "int32",
                              location = "query",
                              type = "integer",
                            },
                            pageToken = {
                              description = "Optional. The next_page_token value returned from a previous list request.",
                              location = "query",
                              type = "string",
                            },
                            parent = {
                              description = "Required. The agent to list all intents from. Format: `projects//agent` or `projects//locations//agent`. Alternatively, you can specify the environment to list intents for. Format: `projects//agent/environments/` or `projects//locations//agent/environments/`. Note: training phrases of the intents will not be returned for non-draft environment.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/intents",
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2ListIntentsResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                      },
                    },
                    users = {
                      resources = {
                        sessions = {
                          methods = {
                            deleteContexts = {
                              description = "Deletes all active contexts in the specified session.",
                              flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts",
                              httpMethod = "DELETE",
                              id = "dialogflow.projects.locations.agent.environments.users.sessions.deleteContexts",
                              parameterOrder = {
                                "parent",
                              },
                              parameters = {
                                parent = {
                                  description = "Required. The name of the session to delete all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                  location = "path",
                                  pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+parent}/contexts",
                              response = {
                                ["$ref"] = "GoogleProtobufEmpty",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                            detectIntent = {
                              description = "Processes a natural language query and returns structured, actionable data as a result. This method is not idempotent, because it may cause contexts and session entity types to be updated, which in turn might affect results of future queries. If you might use [Agent Assist](https://cloud.google.com/dialogflow/docs/#aa) or other CCAI products now or in the future, consider using AnalyzeContent instead of `DetectIntent`. `AnalyzeContent` has additional functionality for Agent Assist and other CCAI products. Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                              flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}:detectIntent",
                              httpMethod = "POST",
                              id = "dialogflow.projects.locations.agent.environments.users.sessions.detectIntent",
                              parameterOrder = {
                                "session",
                              },
                              parameters = {
                                session = {
                                  description = "Required. The name of the session this query is sent to. Format: `projects//agent/sessions/`, or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment (`Environment ID` might be referred to as environment name at some places). If `User ID` is not specified, we are using \"-\". It's up to the API caller to choose an appropriate `Session ID` and `User Id`. They can be a random number or some type of user and session identifiers (preferably hashed). The length of the `Session ID` and `User ID` must not exceed 36 characters. For more information, see the [API interactions guide](https://cloud.google.com/dialogflow/docs/api-overview). Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                                  location = "path",
                                  pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                  required = true,
                                  type = "string",
                                },
                              },
                              path = "v2/{+session}:detectIntent",
                              request = {
                                ["$ref"] = "GoogleCloudDialogflowV2DetectIntentRequest",
                              },
                              response = {
                                ["$ref"] = "GoogleCloudDialogflowV2DetectIntentResponse",
                              },
                              scopes = {
                                "https://www.googleapis.com/auth/cloud-platform",
                                "https://www.googleapis.com/auth/dialogflow",
                              },
                            },
                          },
                          resources = {
                            contexts = {
                              methods = {
                                create = {
                                  description = "Creates a context. If the specified context already exists, overrides the context.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts",
                                  httpMethod = "POST",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.contexts.create",
                                  parameterOrder = {
                                    "parent",
                                  },
                                  parameters = {
                                    parent = {
                                      description = "Required. The session to create a context for. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+parent}/contexts",
                                  request = {
                                    ["$ref"] = "GoogleCloudDialogflowV2Context",
                                  },
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2Context",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                delete = {
                                  description = "Deletes the specified context.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}",
                                  httpMethod = "DELETE",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.contexts.delete",
                                  parameterOrder = {
                                    "name",
                                  },
                                  parameters = {
                                    name = {
                                      description = "Required. The name of the context to delete. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+name}",
                                  response = {
                                    ["$ref"] = "GoogleProtobufEmpty",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                get = {
                                  description = "Retrieves the specified context.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}",
                                  httpMethod = "GET",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.contexts.get",
                                  parameterOrder = {
                                    "name",
                                  },
                                  parameters = {
                                    name = {
                                      description = "Required. The name of the context. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+name}",
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2Context",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                list = {
                                  description = "Returns the list of all contexts in the specified session.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts",
                                  httpMethod = "GET",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.contexts.list",
                                  parameterOrder = {
                                    "parent",
                                  },
                                  parameters = {
                                    pageSize = {
                                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                                      format = "int32",
                                      location = "query",
                                      type = "integer",
                                    },
                                    pageToken = {
                                      description = "Optional. The next_page_token value returned from a previous list request.",
                                      location = "query",
                                      type = "string",
                                    },
                                    parent = {
                                      description = "Required. The session to list all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+parent}/contexts",
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2ListContextsResponse",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                patch = {
                                  description = "Updates the specified context.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/contexts/{contextsId}",
                                  httpMethod = "PATCH",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.contexts.patch",
                                  parameterOrder = {
                                    "name",
                                  },
                                  parameters = {
                                    name = {
                                      description = "Required. The unique identifier of the context. Format: `projects//agent/sessions//contexts/`, or `projects//agent/environments//users//sessions//contexts/`. The `Context ID` is always converted to lowercase, may only contain characters in a-zA-Z0-9_-% and may be at most 250 bytes long. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. The following context names are reserved for internal use by Dialogflow. You should not use these contexts or create contexts with these names: * `__system_counters__` * `*_id_dialog_context` * `*_dialog_params_size`",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/contexts/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                    updateMask = {
                                      description = "Optional. The mask to control which fields get updated.",
                                      format = "google-fieldmask",
                                      location = "query",
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+name}",
                                  request = {
                                    ["$ref"] = "GoogleCloudDialogflowV2Context",
                                  },
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2Context",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                              },
                            },
                            entityTypes = {
                              methods = {
                                create = {
                                  description = "Creates a session entity type. If the specified session entity type already exists, overrides the session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes",
                                  httpMethod = "POST",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.entityTypes.create",
                                  parameterOrder = {
                                    "parent",
                                  },
                                  parameters = {
                                    parent = {
                                      description = "Required. The session to create a session entity type for. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+parent}/entityTypes",
                                  request = {
                                    ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                                  },
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                delete = {
                                  description = "Deletes the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                                  httpMethod = "DELETE",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.entityTypes.delete",
                                  parameterOrder = {
                                    "name",
                                  },
                                  parameters = {
                                    name = {
                                      description = "Required. The name of the entity type to delete. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+name}",
                                  response = {
                                    ["$ref"] = "GoogleProtobufEmpty",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                get = {
                                  description = "Retrieves the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                                  httpMethod = "GET",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.entityTypes.get",
                                  parameterOrder = {
                                    "name",
                                  },
                                  parameters = {
                                    name = {
                                      description = "Required. The name of the session entity type. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+name}",
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                list = {
                                  description = "Returns the list of all session entity types in the specified session. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes",
                                  httpMethod = "GET",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.entityTypes.list",
                                  parameterOrder = {
                                    "parent",
                                  },
                                  parameters = {
                                    pageSize = {
                                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                                      format = "int32",
                                      location = "query",
                                      type = "integer",
                                    },
                                    pageToken = {
                                      description = "Optional. The next_page_token value returned from a previous list request.",
                                      location = "query",
                                      type = "string",
                                    },
                                    parent = {
                                      description = "Required. The session to list all session entity types from. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+parent}/entityTypes",
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2ListSessionEntityTypesResponse",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                                patch = {
                                  description = "Updates the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/environments/{environmentsId}/users/{usersId}/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                                  httpMethod = "PATCH",
                                  id = "dialogflow.projects.locations.agent.environments.users.sessions.entityTypes.patch",
                                  parameterOrder = {
                                    "name",
                                  },
                                  parameters = {
                                    name = {
                                      description = "Required. The unique identifier of this session entity type. Format: `projects//agent/sessions//entityTypes/`, or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. `` must be the display name of an existing entity type in the same agent that will be overridden or supplemented.",
                                      location = "path",
                                      pattern = "^projects/[^/]+/locations/[^/]+/agent/environments/[^/]+/users/[^/]+/sessions/[^/]+/entityTypes/[^/]+$",
                                      required = true,
                                      type = "string",
                                    },
                                    updateMask = {
                                      description = "Optional. The mask to control which fields get updated.",
                                      format = "google-fieldmask",
                                      location = "query",
                                      type = "string",
                                    },
                                  },
                                  path = "v2/{+name}",
                                  request = {
                                    ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                                  },
                                  response = {
                                    ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                                  },
                                  scopes = {
                                    "https://www.googleapis.com/auth/cloud-platform",
                                    "https://www.googleapis.com/auth/dialogflow",
                                  },
                                },
                              },
                            },
                          },
                        },
                      },
                    },
                  },
                },
                intents = {
                  methods = {
                    batchDelete = {
                      description = "Deletes intents in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty) Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents:batchDelete",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.intents.batchDelete",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the agent to delete all entities types for. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/intents:batchDelete",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchDeleteIntentsRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    batchUpdate = {
                      description = "Updates/Creates multiple intents in the specified agent. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: An empty [Struct message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#struct) - `response`: BatchUpdateIntentsResponse Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents:batchUpdate",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.intents.batchUpdate",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the agent to update or create intents in. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/intents:batchUpdate",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2BatchUpdateIntentsRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    create = {
                      description = "Creates an intent in the specified agent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.intents.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        intentView = {
                          description = "Optional. The resource view to apply to the returned intent.",
                          enum = {
                            "INTENT_VIEW_UNSPECIFIED",
                            "INTENT_VIEW_FULL",
                          },
                          enumDescriptions = {
                            "Training phrases field is not populated in the response.",
                            "All fields are populated.",
                          },
                          location = "query",
                          type = "string",
                        },
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to create a intent for. Format: `projects//agent`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/intents",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Intent",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Intent",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified intent and its direct or indirect followup intents. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents/{intentsId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.locations.agent.intents.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the intent to delete. If this intent has direct or indirect followup intents, we also delete them. Format: `projects//agent/intents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/intents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified intent.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents/{intentsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.intents.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        intentView = {
                          description = "Optional. The resource view to apply to the returned intent.",
                          enum = {
                            "INTENT_VIEW_UNSPECIFIED",
                            "INTENT_VIEW_FULL",
                          },
                          enumDescriptions = {
                            "Training phrases field is not populated in the response.",
                            "All fields are populated.",
                          },
                          location = "query",
                          type = "string",
                        },
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        name = {
                          description = "Required. The name of the intent. Format: `projects//agent/intents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/intents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Intent",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all intents in the specified agent.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.intents.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        intentView = {
                          description = "Optional. The resource view to apply to the returned intent.",
                          enum = {
                            "INTENT_VIEW_UNSPECIFIED",
                            "INTENT_VIEW_FULL",
                          },
                          enumDescriptions = {
                            "Training phrases field is not populated in the response.",
                            "All fields are populated.",
                          },
                          location = "query",
                          type = "string",
                        },
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to list all intents from. Format: `projects//agent` or `projects//locations//agent`. Alternatively, you can specify the environment to list intents for. Format: `projects//agent/environments/` or `projects//locations//agent/environments/`. Note: training phrases of the intents will not be returned for non-draft environment.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/intents",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListIntentsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified intent. Note: You should always train an agent prior to sending it queries. See the [training documentation](https://cloud.google.com/dialogflow/es/docs/training).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/intents/{intentsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.locations.agent.intents.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        intentView = {
                          description = "Optional. The resource view to apply to the returned intent.",
                          enum = {
                            "INTENT_VIEW_UNSPECIFIED",
                            "INTENT_VIEW_FULL",
                          },
                          enumDescriptions = {
                            "Training phrases field is not populated in the response.",
                            "All fields are populated.",
                          },
                          location = "query",
                          type = "string",
                        },
                        languageCode = {
                          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
                          location = "query",
                          type = "string",
                        },
                        name = {
                          description = "Optional. The unique identifier of this intent. Required for Intents.UpdateIntent and Intents.BatchUpdateIntents methods. Format: `projects//agent/intents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/intents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Optional. The mask to control which fields get updated.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Intent",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Intent",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
                sessions = {
                  methods = {
                    deleteContexts = {
                      description = "Deletes all active contexts in the specified session.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/contexts",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.locations.agent.sessions.deleteContexts",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The name of the session to delete all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/contexts",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    detectIntent = {
                      description = "Processes a natural language query and returns structured, actionable data as a result. This method is not idempotent, because it may cause contexts and session entity types to be updated, which in turn might affect results of future queries. If you might use [Agent Assist](https://cloud.google.com/dialogflow/docs/#aa) or other CCAI products now or in the future, consider using AnalyzeContent instead of `DetectIntent`. `AnalyzeContent` has additional functionality for Agent Assist and other CCAI products. Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}:detectIntent",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.sessions.detectIntent",
                      parameterOrder = {
                        "session",
                      },
                      parameters = {
                        session = {
                          description = "Required. The name of the session this query is sent to. Format: `projects//agent/sessions/`, or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment (`Environment ID` might be referred to as environment name at some places). If `User ID` is not specified, we are using \"-\". It's up to the API caller to choose an appropriate `Session ID` and `User Id`. They can be a random number or some type of user and session identifiers (preferably hashed). The length of the `Session ID` and `User ID` must not exceed 36 characters. For more information, see the [API interactions guide](https://cloud.google.com/dialogflow/docs/api-overview). Note: Always use agent versions for production traffic. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+session}:detectIntent",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2DetectIntentRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2DetectIntentResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                  resources = {
                    contexts = {
                      methods = {
                        create = {
                          description = "Creates a context. If the specified context already exists, overrides the context.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/contexts",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.agent.sessions.contexts.create",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The session to create a context for. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/contexts",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2Context",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2Context",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        delete = {
                          description = "Deletes the specified context.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/contexts/{contextsId}",
                          httpMethod = "DELETE",
                          id = "dialogflow.projects.locations.agent.sessions.contexts.delete",
                          parameterOrder = {
                            "name",
                          },
                          parameters = {
                            name = {
                              description = "Required. The name of the context to delete. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+name}",
                          response = {
                            ["$ref"] = "GoogleProtobufEmpty",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        get = {
                          description = "Retrieves the specified context.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/contexts/{contextsId}",
                          httpMethod = "GET",
                          id = "dialogflow.projects.locations.agent.sessions.contexts.get",
                          parameterOrder = {
                            "name",
                          },
                          parameters = {
                            name = {
                              description = "Required. The name of the context. Format: `projects//agent/sessions//contexts/` or `projects//agent/environments//users//sessions//contexts/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+name}",
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2Context",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        list = {
                          description = "Returns the list of all contexts in the specified session.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/contexts",
                          httpMethod = "GET",
                          id = "dialogflow.projects.locations.agent.sessions.contexts.list",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            pageSize = {
                              description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                              format = "int32",
                              location = "query",
                              type = "integer",
                            },
                            pageToken = {
                              description = "Optional. The next_page_token value returned from a previous list request.",
                              location = "query",
                              type = "string",
                            },
                            parent = {
                              description = "Required. The session to list all contexts from. Format: `projects//agent/sessions/` or `projects//agent/environments//users//sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/contexts",
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2ListContextsResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        patch = {
                          description = "Updates the specified context.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/contexts/{contextsId}",
                          httpMethod = "PATCH",
                          id = "dialogflow.projects.locations.agent.sessions.contexts.patch",
                          parameterOrder = {
                            "name",
                          },
                          parameters = {
                            name = {
                              description = "Required. The unique identifier of the context. Format: `projects//agent/sessions//contexts/`, or `projects//agent/environments//users//sessions//contexts/`. The `Context ID` is always converted to lowercase, may only contain characters in a-zA-Z0-9_-% and may be at most 250 bytes long. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. The following context names are reserved for internal use by Dialogflow. You should not use these contexts or create contexts with these names: * `__system_counters__` * `*_id_dialog_context` * `*_dialog_params_size`",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$",
                              required = true,
                              type = "string",
                            },
                            updateMask = {
                              description = "Optional. The mask to control which fields get updated.",
                              format = "google-fieldmask",
                              location = "query",
                              type = "string",
                            },
                          },
                          path = "v2/{+name}",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2Context",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2Context",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                      },
                    },
                    entityTypes = {
                      methods = {
                        create = {
                          description = "Creates a session entity type. If the specified session entity type already exists, overrides the session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/entityTypes",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.agent.sessions.entityTypes.create",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The session to create a session entity type for. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/entityTypes",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        delete = {
                          description = "Deletes the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                          httpMethod = "DELETE",
                          id = "dialogflow.projects.locations.agent.sessions.entityTypes.delete",
                          parameterOrder = {
                            "name",
                          },
                          parameters = {
                            name = {
                              description = "Required. The name of the entity type to delete. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+name}",
                          response = {
                            ["$ref"] = "GoogleProtobufEmpty",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        get = {
                          description = "Retrieves the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                          httpMethod = "GET",
                          id = "dialogflow.projects.locations.agent.sessions.entityTypes.get",
                          parameterOrder = {
                            "name",
                          },
                          parameters = {
                            name = {
                              description = "Required. The name of the session entity type. Format: `projects//agent/sessions//entityTypes/` or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+name}",
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        list = {
                          description = "Returns the list of all session entity types in the specified session. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/entityTypes",
                          httpMethod = "GET",
                          id = "dialogflow.projects.locations.agent.sessions.entityTypes.list",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            pageSize = {
                              description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                              format = "int32",
                              location = "query",
                              type = "integer",
                            },
                            pageToken = {
                              description = "Optional. The next_page_token value returned from a previous list request.",
                              location = "query",
                              type = "string",
                            },
                            parent = {
                              description = "Required. The session to list all session entity types from. Format: `projects//agent/sessions/` or `projects//agent/environments//users// sessions/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/entityTypes",
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2ListSessionEntityTypesResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        patch = {
                          description = "Updates the specified session entity type. This method doesn't work with Google Assistant integration. Contact Dialogflow support if you need to use session entities with Google Assistant integration.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}",
                          httpMethod = "PATCH",
                          id = "dialogflow.projects.locations.agent.sessions.entityTypes.patch",
                          parameterOrder = {
                            "name",
                          },
                          parameters = {
                            name = {
                              description = "Required. The unique identifier of this session entity type. Format: `projects//agent/sessions//entityTypes/`, or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. `` must be the display name of an existing entity type in the same agent that will be overridden or supplemented.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$",
                              required = true,
                              type = "string",
                            },
                            updateMask = {
                              description = "Optional. The mask to control which fields get updated.",
                              format = "google-fieldmask",
                              location = "query",
                              type = "string",
                            },
                          },
                          path = "v2/{+name}",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                      },
                    },
                  },
                },
                versions = {
                  methods = {
                    create = {
                      description = "Creates an agent version. The new version points to the agent instance in the \"default\" environment.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/versions",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.agent.versions.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The agent to create a version for. Supported formats: - `projects//agent` - `projects//locations//agent`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/versions",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Version",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Version",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Delete the specified agent version.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/versions/{versionsId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.locations.agent.versions.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the version to delete. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/versions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleProtobufEmpty",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified agent version.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/versions/{versionsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.versions.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the version. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/versions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Version",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all versions of the specified agent.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/versions",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.agent.versions.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The agent to list all versions from. Supported formats: - `projects//agent` - `projects//locations//agent`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/versions",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListVersionsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified agent version. Note that this method does not allow you to update the state of the agent the given version points to. It allows you to update only mutable properties of the version resource.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/agent/versions/{versionsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.locations.agent.versions.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Output only. The unique identifier of this agent version. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/agent/versions/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Required. The mask to control which fields get updated.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Version",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Version",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            answerRecords = {
              methods = {
                list = {
                  description = "Returns the list of all answer records in the specified project in reverse chronological order.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/answerRecords",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.answerRecords.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    filter = {
                      description = "Optional. Filters to restrict results to specific answer records. Marked deprecated as it hasn't been, and isn't currently, supported. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Optional. The maximum number of records to return in a single page. The server may return fewer records than this. If unspecified, we use 10. The maximum is 100.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The ListAnswerRecordsResponse.next_page_token value returned from a previous list request used to continue listing on the next page.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project to list all answer records for in reverse chronological order. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/answerRecords",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListAnswerRecordsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified answer record.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/answerRecords/{answerRecordsId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.locations.answerRecords.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "The unique identifier of this answer record. Format: `projects//locations//answerRecords/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/answerRecords/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Required. The mask to control which fields get updated.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2AnswerRecord",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2AnswerRecord",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
            conversationDatasets = {
              methods = {
                create = {
                  description = "Creates a new conversation dataset. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: CreateConversationDatasetOperationMetadata - `response`: ConversationDataset",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationDatasets",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationDatasets.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project to create conversation dataset for. Format: `projects//locations/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversationDatasets",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationDataset",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified conversation dataset. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: DeleteConversationDatasetOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationDatasets/{conversationDatasetsId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.locations.conversationDatasets.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation dataset to delete. Format: `projects//locations//conversationDatasets/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationDatasets/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified conversation dataset.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationDatasets/{conversationDatasetsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversationDatasets.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation dataset to retrieve. Format: `projects//locations//conversationDatasets/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationDatasets/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationDataset",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                importConversationData = {
                  description = "Import data into the specified conversation dataset. Note that it is not allowed to import data to a conversation dataset that already has data in it. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: ImportConversationDataOperationMetadata - `response`: ImportConversationDataOperationResponse",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationDatasets/{conversationDatasetsId}:importConversationData",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationDatasets.importConversationData",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. Dataset resource name. Format: `projects//locations//conversationDatasets/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationDatasets/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:importConversationData",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ImportConversationDataRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all conversation datasets in the specified project and location.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationDatasets",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversationDatasets.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. Maximum number of conversation datasets to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project and location name to list all conversation datasets for. Format: `projects//locations/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversationDatasets",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListConversationDatasetsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
            conversationModels = {
              methods = {
                create = {
                  description = "Creates a model. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: CreateConversationModelOperationMetadata - `response`: ConversationModel",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationModels.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "The project to create conversation model for. Format: `projects/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversationModels",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationModel",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes a model. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: DeleteConversationModelOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.locations.conversationModels.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation model to delete. Format: `projects//conversationModels/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                deploy = {
                  description = "Deploys a model. If a model is already deployed, deploying it has no effect. A model can only serve prediction requests after it gets deployed. For article suggestion, custom model will not be used unless it is deployed. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: DeployConversationModelOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}:deploy",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationModels.deploy",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation model to deploy. Format: `projects//conversationModels/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:deploy",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2DeployConversationModelRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Gets conversation model.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversationModels.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation model to retrieve. Format: `projects//conversationModels/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationModel",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Lists conversation models.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversationModels.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "Optional. Maximum number of conversation models to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project to list all conversation models for. Format: `projects/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversationModels",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListConversationModelsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                undeploy = {
                  description = "Undeploys a model. If the model is not deployed this method has no effect. If the model is currently being used: - For article suggestion, article suggestion will fallback to the default model if model is undeployed. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: UndeployConversationModelOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}:undeploy",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationModels.undeploy",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The conversation model to undeploy. Format: `projects//conversationModels/`",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:undeploy",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2UndeployConversationModelRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                evaluations = {
                  methods = {
                    create = {
                      description = "Creates evaluation of a conversation model.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}/evaluations",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.conversationModels.evaluations.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The conversation model resource name. Format: `projects//locations//conversationModels/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/evaluations",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2CreateConversationModelEvaluationRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Gets an evaluation of conversation model.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}/evaluations/{evaluationsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.conversationModels.evaluations.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The conversation model evaluation resource name. Format: `projects//conversationModels//evaluations/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+/evaluations/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ConversationModelEvaluation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Lists evaluations of a conversation model.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationModels/{conversationModelsId}/evaluations",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.conversationModels.evaluations.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. Maximum number of evaluations to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The conversation model resource name. Format: `projects//conversationModels/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversationModels/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/evaluations",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListConversationModelEvaluationsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            conversationProfiles = {
              methods = {
                clearSuggestionFeatureConfig = {
                  description = "Clears a suggestion feature from a conversation profile for the given participant role. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: ClearSuggestionFeatureConfigOperationMetadata - `response`: ConversationProfile",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles/{conversationProfilesId}:clearSuggestionFeatureConfig",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationProfiles.clearSuggestionFeatureConfig",
                  parameterOrder = {
                    "conversationProfile",
                  },
                  parameters = {
                    conversationProfile = {
                      description = "Required. The Conversation Profile to add or update the suggestion feature config. Format: `projects//locations//conversationProfiles/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationProfiles/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+conversationProfile}:clearSuggestionFeatureConfig",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ClearSuggestionFeatureConfigRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                create = {
                  description = "Creates a conversation profile in the specified project. ConversationProfile.CreateTime and ConversationProfile.UpdateTime aren't populated in the response. You can retrieve them via GetConversationProfile API.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationProfiles.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project to create a conversation profile for. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversationProfiles",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified conversation profile.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles/{conversationProfilesId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.locations.conversationProfiles.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the conversation profile to delete. Format: `projects//locations//conversationProfiles/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationProfiles/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified conversation profile.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles/{conversationProfilesId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversationProfiles.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The resource name of the conversation profile. Format: `projects//locations//conversationProfiles/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationProfiles/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all conversation profiles in the specified project.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversationProfiles.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    pageSize = {
                      description = "The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project to list all conversation profiles from. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversationProfiles",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListConversationProfilesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified conversation profile. ConversationProfile.CreateTime and ConversationProfile.UpdateTime aren't populated in the response. You can retrieve them via GetConversationProfile API.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles/{conversationProfilesId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.locations.conversationProfiles.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "The unique identifier of this conversation profile. Format: `projects//locations//conversationProfiles/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationProfiles/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Required. The mask to control which fields to update.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                setSuggestionFeatureConfig = {
                  description = "Adds or updates a suggestion feature in a conversation profile. If the conversation profile contains the type of suggestion feature for the participant role, it will update it. Otherwise it will insert the suggestion feature. This method is a [long-running operation](https://cloud.google.com/dialogflow/es/docs/how/long-running-operations). The returned `Operation` type has the following method-specific fields: - `metadata`: SetSuggestionFeatureConfigOperationMetadata - `response`: ConversationProfile If a long running operation to add or update suggestion feature config for the same conversation profile, participant role and suggestion feature type exists, please cancel the existing long running operation before sending such request, otherwise the request will be rejected.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversationProfiles/{conversationProfilesId}:setSuggestionFeatureConfig",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversationProfiles.setSuggestionFeatureConfig",
                  parameterOrder = {
                    "conversationProfile",
                  },
                  parameters = {
                    conversationProfile = {
                      description = "Required. The Conversation Profile to add or update the suggestion feature config. Format: `projects//locations//conversationProfiles/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversationProfiles/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+conversationProfile}:setSuggestionFeatureConfig",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2SetSuggestionFeatureConfigRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
            conversations = {
              methods = {
                complete = {
                  description = "Completes the specified conversation. Finished conversations are purged from the database after 30 days.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}:complete",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversations.complete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. Resource identifier of the conversation to close. Format: `projects//locations//conversations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:complete",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2CompleteConversationRequest",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Conversation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                create = {
                  description = "Creates a new conversation. Conversations are auto-completed after 24 hours. Conversation Lifecycle: There are two stages during a conversation: Automated Agent Stage and Assist Stage. For Automated Agent Stage, there will be a dialogflow agent responding to user queries. For Assist Stage, there's no dialogflow agent responding to user queries. But we will provide suggestions which are generated from conversation. If Conversation.conversation_profile is configured for a dialogflow agent, conversation will start from `Automated Agent Stage`, otherwise, it will start from `Assist Stage`. And during `Automated Agent Stage`, once an Intent with Intent.live_agent_handoff is triggered, conversation will transfer to Assist Stage.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.conversations.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    conversationId = {
                      description = "Optional. Identifier of the conversation. Generally it's auto generated by Google. Only set it if you cannot wait for the response to return a auto-generated one to you. The conversation ID must be compliant with the regression fomula \"a-zA-Z*\" with the characters length in range of [3,64]. If the field is provided, the caller is resposible for 1. the uniqueness of the ID, otherwise the request will be rejected. 2. the consistency for whether to use custom ID or not under a project to better ensure uniqueness.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. Resource identifier of the project creating the conversation. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversations",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2Conversation",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Conversation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specific conversation.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversations.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the conversation. Format: `projects//locations//conversations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2Conversation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all conversations in the specified project.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.conversations.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    filter = {
                      description = "A filter expression that filters conversations listed in the response. In general, the expression must specify the field name, a comparison operator, and the value to use for filtering: - The value must be a string, a number, or a boolean. - The comparison operator must be either `=`,`!=`, `>`, or `<`. - To filter on multiple expressions, separate the expressions with `AND` or `OR` (omitting both implies `AND`). - For clarity, expressions can be enclosed in parentheses. Only `lifecycle_state` can be filtered on in this way. For example, the following expression only returns `COMPLETED` conversations: `lifecycle_state = \"COMPLETED\"` For more information about filtering, see [API Filtering](https://aip.dev/160).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "Optional. The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project from which to list all conversation. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/conversations",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListConversationsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                messages = {
                  methods = {
                    list = {
                      description = "Lists messages that belong to a given conversation. `messages` are ordered by `create_time` in descending order. To fetch updates without duplication, send request with filter `create_time_epoch_microseconds > [first item's create_time of previous request]` and empty page_token.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/messages",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.conversations.messages.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        filter = {
                          description = "Optional. Filter on message fields. Currently predicates on `create_time` and `create_time_epoch_microseconds` are supported. `create_time` only support milliseconds accuracy. E.g., `create_time_epoch_microseconds > 1551790877964485` or `create_time > 2017-01-15T01:30:15.01Z`. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The name of the conversation to list messages for. Format: `projects//locations//conversations/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/messages",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListMessagesResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
                participants = {
                  methods = {
                    analyzeContent = {
                      description = "Adds a text (chat, for example), or audio (phone recording, for example) message from a participant into the conversation. Note: Always use agent versions for production traffic sent to virtual agents. See [Versions and environments](https://cloud.google.com/dialogflow/es/docs/agents-versions).",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants/{participantsId}:analyzeContent",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.conversations.participants.analyzeContent",
                      parameterOrder = {
                        "participant",
                      },
                      parameters = {
                        participant = {
                          description = "Required. The name of the participant this text comes from. Format: `projects//locations//conversations//participants/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+/participants/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+participant}:analyzeContent",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2AnalyzeContentRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2AnalyzeContentResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    create = {
                      description = "Creates a new participant in a conversation.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.conversations.participants.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. Resource identifier of the conversation adding the participant. Format: `projects//locations//conversations/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/participants",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Participant",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Participant",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves a conversation participant.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants/{participantsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.conversations.participants.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the participant. Format: `projects//locations//conversations//participants/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+/participants/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Participant",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all participants in the specified conversation.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.conversations.participants.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        pageSize = {
                          description = "Optional. The maximum number of items to return in a single page. By default 100 and at most 1000.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "Optional. The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The conversation to list all participants from. Format: `projects//locations//conversations/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/participants",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListParticipantsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified participant.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants/{participantsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.locations.conversations.participants.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Optional. The unique identifier of this participant. Format: `projects//locations//conversations//participants/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+/participants/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Required. The mask to specify which fields to update.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Participant",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Participant",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                  resources = {
                    suggestions = {
                      methods = {
                        suggestArticles = {
                          description = "Gets suggested articles for a participant based on specific historical messages.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants/{participantsId}/suggestions:suggestArticles",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.conversations.participants.suggestions.suggestArticles",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the participant to fetch suggestion for. Format: `projects//locations//conversations//participants/`.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+/participants/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/suggestions:suggestArticles",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2SuggestArticlesRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2SuggestArticlesResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        suggestFaqAnswers = {
                          description = "Gets suggested faq answers for a participant based on specific historical messages.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants/{participantsId}/suggestions:suggestFaqAnswers",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.conversations.participants.suggestions.suggestFaqAnswers",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the participant to fetch suggestion for. Format: `projects//locations//conversations//participants/`.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+/participants/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/suggestions:suggestFaqAnswers",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2SuggestFaqAnswersRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2SuggestFaqAnswersResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                        suggestSmartReplies = {
                          description = "Gets smart replies for a participant based on specific historical messages.",
                          flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/participants/{participantsId}/suggestions:suggestSmartReplies",
                          httpMethod = "POST",
                          id = "dialogflow.projects.locations.conversations.participants.suggestions.suggestSmartReplies",
                          parameterOrder = {
                            "parent",
                          },
                          parameters = {
                            parent = {
                              description = "Required. The name of the participant to fetch suggestion for. Format: `projects//locations//conversations//participants/`.",
                              location = "path",
                              pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+/participants/[^/]+$",
                              required = true,
                              type = "string",
                            },
                          },
                          path = "v2/{+parent}/suggestions:suggestSmartReplies",
                          request = {
                            ["$ref"] = "GoogleCloudDialogflowV2SuggestSmartRepliesRequest",
                          },
                          response = {
                            ["$ref"] = "GoogleCloudDialogflowV2SuggestSmartRepliesResponse",
                          },
                          scopes = {
                            "https://www.googleapis.com/auth/cloud-platform",
                            "https://www.googleapis.com/auth/dialogflow",
                          },
                        },
                      },
                    },
                  },
                },
                suggestions = {
                  methods = {
                    suggestConversationSummary = {
                      description = "Suggests summary for a conversation based on specific historical messages. The range of the messages to be used for summary can be specified in the request.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/conversations/{conversationsId}/suggestions:suggestConversationSummary",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.conversations.suggestions.suggestConversationSummary",
                      parameterOrder = {
                        "conversation",
                      },
                      parameters = {
                        conversation = {
                          description = "Required. The conversation to fetch suggestion for. Format: `projects//locations//conversations/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/conversations/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+conversation}/suggestions:suggestConversationSummary",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestConversationSummaryRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2SuggestConversationSummaryResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            knowledgeBases = {
              methods = {
                create = {
                  description = "Creates a knowledge base.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.knowledgeBases.create",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    parent = {
                      description = "Required. The project to create a knowledge base for. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/knowledgeBases",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                delete = {
                  description = "Deletes the specified knowledge base.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}",
                  httpMethod = "DELETE",
                  id = "dialogflow.projects.locations.knowledgeBases.delete",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    force = {
                      description = "Optional. Force deletes the knowledge base. When set to true, any documents in the knowledge base are also deleted.",
                      location = "query",
                      type = "boolean",
                    },
                    name = {
                      description = "Required. The name of the knowledge base to delete. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Retrieves the specified knowledge base.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.knowledgeBases.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "Required. The name of the knowledge base to retrieve. Format `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Returns the list of all knowledge bases of the specified agent.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.knowledgeBases.list",
                  parameterOrder = {
                    "parent",
                  },
                  parameters = {
                    filter = {
                      description = "The filter expression used to filter knowledge bases returned by the list method. The expression has the following syntax: [AND ] ... The following fields and operators are supported: * display_name with has(:) operator * language_code with equals(=) operator Examples: * 'language_code=en-us' matches knowledge bases with en-us language code. * 'display_name:articles' matches knowledge bases whose display name contains \"articles\". * 'display_name:\"Best Articles\"' matches knowledge bases whose display name contains \"Best Articles\". * 'language_code=en-gb AND display_name=articles' matches all knowledge bases whose display name contains \"articles\" and whose language code is \"en-gb\". Note: An empty filter string (i.e. \"\") is a no-op and will result in no filtering. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                      location = "query",
                      type = "string",
                    },
                    pageSize = {
                      description = "The maximum number of items to return in a single page. By default 10 and at most 100.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "The next_page_token value returned from a previous list request.",
                      location = "query",
                      type = "string",
                    },
                    parent = {
                      description = "Required. The project to list of knowledge bases for. Format: `projects//locations/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+parent}/knowledgeBases",
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2ListKnowledgeBasesResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                patch = {
                  description = "Updates the specified knowledge base.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}",
                  httpMethod = "PATCH",
                  id = "dialogflow.projects.locations.knowledgeBases.patch",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "The knowledge base resource name. The name must be empty when creating a knowledge base. Format: `projects//locations//knowledgeBases/`.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    updateMask = {
                      description = "Optional. Not specified means `update all`. Currently, only `display_name` can be updated, an InvalidArgument will be returned for attempting to update other fields.",
                      format = "google-fieldmask",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  request = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  response = {
                    ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
              resources = {
                documents = {
                  methods = {
                    create = {
                      description = "Creates a new document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.create",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The knowledge base to create a document for. Format: `projects//locations//knowledgeBases/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/documents",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Document",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    delete = {
                      description = "Deletes the specified document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: An [Empty message](https://developers.google.com/protocol-buffers/docs/reference/google.protobuf#empty)",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                      httpMethod = "DELETE",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.delete",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to delete. Format: `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    export = {
                      description = "Exports a smart messaging candidate document into the specified destination. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:export",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.export",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to export. Format: `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}:export",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2ExportDocumentRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    get = {
                      description = "Retrieves the specified document.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.get",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to retrieve. Format `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2Document",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    import = {
                      description = "Creates documents by importing data from external sources. Dialogflow supports up to 350 documents in each request. If you try to import more, Dialogflow will return an error. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: ImportDocumentsResponse",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents:import",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.import",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        parent = {
                          description = "Required. The knowledge base to import documents into. Format: `projects//locations//knowledgeBases/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/documents:import",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2ImportDocumentsRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    list = {
                      description = "Returns the list of all documents of the knowledge base.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents",
                      httpMethod = "GET",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.list",
                      parameterOrder = {
                        "parent",
                      },
                      parameters = {
                        filter = {
                          description = "The filter expression used to filter documents returned by the list method. The expression has the following syntax: [AND ] ... The following fields and operators are supported: * knowledge_types with has(:) operator * display_name with has(:) operator * state with equals(=) operator Examples: * \"knowledge_types:FAQ\" matches documents with FAQ knowledge type. * \"display_name:customer\" matches documents whose display name contains \"customer\". * \"state=ACTIVE\" matches documents with ACTIVE state. * \"knowledge_types:FAQ AND state=ACTIVE\" matches all active FAQ documents. For more information about filtering, see [API Filtering](https://aip.dev/160).",
                          location = "query",
                          type = "string",
                        },
                        pageSize = {
                          description = "The maximum number of items to return in a single page. By default 10 and at most 100.",
                          format = "int32",
                          location = "query",
                          type = "integer",
                        },
                        pageToken = {
                          description = "The next_page_token value returned from a previous list request.",
                          location = "query",
                          type = "string",
                        },
                        parent = {
                          description = "Required. The knowledge base to list all documents for. Format: `projects//locations//knowledgeBases/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+parent}/documents",
                      response = {
                        ["$ref"] = "GoogleCloudDialogflowV2ListDocumentsResponse",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    patch = {
                      description = "Updates the specified document. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}",
                      httpMethod = "PATCH",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.patch",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Optional. The document resource name. The name must be empty when creating a document. Format: `projects//locations//knowledgeBases//documents/`.",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                        updateMask = {
                          description = "Optional. Not specified means `update all`. Currently, only `display_name` can be updated, an InvalidArgument will be returned for attempting to update other fields.",
                          format = "google-fieldmask",
                          location = "query",
                          type = "string",
                        },
                      },
                      path = "v2/{+name}",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2Document",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                    reload = {
                      description = "Reloads the specified document from its specified source, content_uri or content. The previously loaded content of the document will be deleted. Note: Even when the content of the document has not changed, there still may be side effects because of internal implementation changes. This method is a [long-running operation](https://cloud.google.com/dialogflow/cx/docs/how/long-running-operation). The returned `Operation` type has the following method-specific fields: - `metadata`: KnowledgeOperationMetadata - `response`: Document Note: The `projects.agent.knowledgeBases.documents` resource is deprecated; only use `projects.knowledgeBases.documents`.",
                      flatPath = "v2/projects/{projectsId}/locations/{locationsId}/knowledgeBases/{knowledgeBasesId}/documents/{documentsId}:reload",
                      httpMethod = "POST",
                      id = "dialogflow.projects.locations.knowledgeBases.documents.reload",
                      parameterOrder = {
                        "name",
                      },
                      parameters = {
                        name = {
                          description = "Required. The name of the document to reload. Format: `projects//locations//knowledgeBases//documents/`",
                          location = "path",
                          pattern = "^projects/[^/]+/locations/[^/]+/knowledgeBases/[^/]+/documents/[^/]+$",
                          required = true,
                          type = "string",
                        },
                      },
                      path = "v2/{+name}:reload",
                      request = {
                        ["$ref"] = "GoogleCloudDialogflowV2ReloadDocumentRequest",
                      },
                      response = {
                        ["$ref"] = "GoogleLongrunningOperation",
                      },
                      scopes = {
                        "https://www.googleapis.com/auth/cloud-platform",
                        "https://www.googleapis.com/auth/dialogflow",
                      },
                    },
                  },
                },
              },
            },
            operations = {
              methods = {
                cancel = {
                  description = "Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}:cancel",
                  httpMethod = "POST",
                  id = "dialogflow.projects.locations.operations.cancel",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "The name of the operation resource to be cancelled.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/operations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}:cancel",
                  response = {
                    ["$ref"] = "GoogleProtobufEmpty",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                get = {
                  description = "Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/operations/{operationsId}",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.operations.get",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    name = {
                      description = "The name of the operation resource.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+/operations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                  },
                  path = "v2/{+name}",
                  response = {
                    ["$ref"] = "GoogleLongrunningOperation",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
                list = {
                  description = "Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`. NOTE: the `name` binding allows API services to override the binding to use different resource name schemes, such as `users/*/operations`. To override the binding, API services can add a binding such as `\"/v1/{name=users/*}/operations\"` to their service configuration. For backwards compatibility, the default name includes the operations collection id, however overriding users must ensure the name binding is the parent resource, without the operations collection id.",
                  flatPath = "v2/projects/{projectsId}/locations/{locationsId}/operations",
                  httpMethod = "GET",
                  id = "dialogflow.projects.locations.operations.list",
                  parameterOrder = {
                    "name",
                  },
                  parameters = {
                    filter = {
                      description = "The standard list filter.",
                      location = "query",
                      type = "string",
                    },
                    name = {
                      description = "The name of the operation's parent resource.",
                      location = "path",
                      pattern = "^projects/[^/]+/locations/[^/]+$",
                      required = true,
                      type = "string",
                    },
                    pageSize = {
                      description = "The standard list page size.",
                      format = "int32",
                      location = "query",
                      type = "integer",
                    },
                    pageToken = {
                      description = "The standard list page token.",
                      location = "query",
                      type = "string",
                    },
                  },
                  path = "v2/{+name}/operations",
                  response = {
                    ["$ref"] = "GoogleLongrunningListOperationsResponse",
                  },
                  scopes = {
                    "https://www.googleapis.com/auth/cloud-platform",
                    "https://www.googleapis.com/auth/dialogflow",
                  },
                },
              },
            },
          },
        },
        operations = {
          methods = {
            cancel = {
              description = "Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns `google.rpc.Code.UNIMPLEMENTED`. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to `Code.CANCELLED`.",
              flatPath = "v2/projects/{projectsId}/operations/{operationsId}:cancel",
              httpMethod = "POST",
              id = "dialogflow.projects.operations.cancel",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "The name of the operation resource to be cancelled.",
                  location = "path",
                  pattern = "^projects/[^/]+/operations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}:cancel",
              response = {
                ["$ref"] = "GoogleProtobufEmpty",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            get = {
              description = "Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.",
              flatPath = "v2/projects/{projectsId}/operations/{operationsId}",
              httpMethod = "GET",
              id = "dialogflow.projects.operations.get",
              parameterOrder = {
                "name",
              },
              parameters = {
                name = {
                  description = "The name of the operation resource.",
                  location = "path",
                  pattern = "^projects/[^/]+/operations/[^/]+$",
                  required = true,
                  type = "string",
                },
              },
              path = "v2/{+name}",
              response = {
                ["$ref"] = "GoogleLongrunningOperation",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
            list = {
              description = "Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns `UNIMPLEMENTED`. NOTE: the `name` binding allows API services to override the binding to use different resource name schemes, such as `users/*/operations`. To override the binding, API services can add a binding such as `\"/v1/{name=users/*}/operations\"` to their service configuration. For backwards compatibility, the default name includes the operations collection id, however overriding users must ensure the name binding is the parent resource, without the operations collection id.",
              flatPath = "v2/projects/{projectsId}/operations",
              httpMethod = "GET",
              id = "dialogflow.projects.operations.list",
              parameterOrder = {
                "name",
              },
              parameters = {
                filter = {
                  description = "The standard list filter.",
                  location = "query",
                  type = "string",
                },
                name = {
                  description = "The name of the operation's parent resource.",
                  location = "path",
                  pattern = "^projects/[^/]+$",
                  required = true,
                  type = "string",
                },
                pageSize = {
                  description = "The standard list page size.",
                  format = "int32",
                  location = "query",
                  type = "integer",
                },
                pageToken = {
                  description = "The standard list page token.",
                  location = "query",
                  type = "string",
                },
              },
              path = "v2/{+name}/operations",
              response = {
                ["$ref"] = "GoogleLongrunningListOperationsResponse",
              },
              scopes = {
                "https://www.googleapis.com/auth/cloud-platform",
                "https://www.googleapis.com/auth/dialogflow",
              },
            },
          },
        },
      },
    },
  },
  revision = "20230110",
  rootUrl = "https://dialogflow.googleapis.com/",
  schemas = {
    GoogleCloudDialogflowCxV3AudioInput = {
      description = "Represents the natural speech audio to be processed.",
      id = "GoogleCloudDialogflowCxV3AudioInput",
      properties = {
        audio = {
          description = "The natural language speech audio to be processed. A single request can contain up to 1 minute of speech audio data. The transcribed text cannot contain more than 256 bytes. For non-streaming audio detect intent, both `config` and `audio` must be provided. For streaming audio detect intent, `config` must be provided in the first request and `audio` must be provided in all following requests.",
          format = "byte",
          type = "string",
        },
        config = {
          ["$ref"] = "GoogleCloudDialogflowCxV3InputAudioConfig",
          description = "Required. Instructs the speech recognizer how to process the speech audio.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3BatchRunTestCasesMetadata = {
      description = "Metadata returned for the TestCases.BatchRunTestCases long running operation.",
      id = "GoogleCloudDialogflowCxV3BatchRunTestCasesMetadata",
      properties = {
        errors = {
          description = "The test errors.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TestError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3BatchRunTestCasesResponse = {
      description = "The response message for TestCases.BatchRunTestCases.",
      id = "GoogleCloudDialogflowCxV3BatchRunTestCasesResponse",
      properties = {
        results = {
          description = "The test case results. The detailed conversation turns are empty in this response.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TestCaseResult",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ContinuousTestResult = {
      description = "Represents a result from running a test case in an agent environment.",
      id = "GoogleCloudDialogflowCxV3ContinuousTestResult",
      properties = {
        name = {
          description = "The resource name for the continuous test result. Format: `projects//locations//agents//environments//continuousTestResults/`.",
          type = "string",
        },
        result = {
          description = "The result of this continuous test run, i.e. whether all the tests in this continuous test run pass or not.",
          enum = {
            "AGGREGATED_TEST_RESULT_UNSPECIFIED",
            "PASSED",
            "FAILED",
          },
          enumDescriptions = {
            "Not specified. Should never be used.",
            "All the tests passed.",
            "At least one test did not pass.",
          },
          type = "string",
        },
        runTime = {
          description = "Time when the continuous testing run starts.",
          format = "google-datetime",
          type = "string",
        },
        testCaseResults = {
          description = "A list of individual test case results names in this continuous test run.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ConversationSignals = {
      description = "This message is used to hold all the Conversation Signals data, which will be converted to JSON and exported to BigQuery.",
      id = "GoogleCloudDialogflowCxV3ConversationSignals",
      properties = {
        turnSignals = {
          ["$ref"] = "GoogleCloudDialogflowCxV3TurnSignals",
          description = "Required. Turn signals for the current turn.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ConversationTurn = {
      description = "One interaction between a human and virtual agent. The human provides some input and the virtual agent provides a response.",
      id = "GoogleCloudDialogflowCxV3ConversationTurn",
      properties = {
        userInput = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ConversationTurnUserInput",
          description = "The user input.",
        },
        virtualAgentOutput = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput",
          description = "The virtual agent output.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ConversationTurnUserInput = {
      description = "The input from the human user.",
      id = "GoogleCloudDialogflowCxV3ConversationTurnUserInput",
      properties = {
        enableSentimentAnalysis = {
          description = "Whether sentiment analysis is enabled.",
          type = "boolean",
        },
        injectedParameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Parameters that need to be injected into the conversation during intent detection.",
          type = "object",
        },
        input = {
          ["$ref"] = "GoogleCloudDialogflowCxV3QueryInput",
          description = "Supports text input, event input, dtmf input in the test case.",
        },
        isWebhookEnabled = {
          description = "If webhooks should be allowed to trigger in response to the user utterance. Often if parameters are injected, webhooks should not be enabled.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput = {
      description = "The output from the virtual agent.",
      id = "GoogleCloudDialogflowCxV3ConversationTurnVirtualAgentOutput",
      properties = {
        currentPage = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Page",
          description = "The Page on which the utterance was spoken. Only name and displayName will be set.",
        },
        diagnosticInfo = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Required. Input only. The diagnostic info output for the turn. Required to calculate the testing coverage.",
          type = "object",
        },
        differences = {
          description = "Output only. If this is part of a result conversation turn, the list of differences between the original run and the replay for this output, if any.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TestRunDifference",
          },
          readOnly = true,
          type = "array",
        },
        sessionParameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "The session parameters available to the bot at this point.",
          type = "object",
        },
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "Response error from the agent in the test result. If set, other output is empty.",
        },
        textResponses = {
          description = "The text responses from the agent for the turn.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageText",
          },
          type = "array",
        },
        triggeredIntent = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Intent",
          description = "The Intent that triggered the response. Only name and displayName will be set.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3CreateDocumentOperationMetadata = {
      description = "Metadata for CreateDocument operation.",
      id = "GoogleCloudDialogflowCxV3CreateDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3CreateVersionOperationMetadata = {
      description = "Metadata associated with the long running operation for Versions.CreateVersion.",
      id = "GoogleCloudDialogflowCxV3CreateVersionOperationMetadata",
      properties = {
        version = {
          description = "Name of the created version. Format: `projects//locations//agents//flows//versions/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3DeleteDocumentOperationMetadata = {
      description = "Metadata for DeleteDocument operation.",
      id = "GoogleCloudDialogflowCxV3DeleteDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3DeployFlowMetadata = {
      description = "Metadata returned for the Environments.DeployFlow long running operation.",
      id = "GoogleCloudDialogflowCxV3DeployFlowMetadata",
      properties = {
        testErrors = {
          description = "Errors of running deployment tests.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TestError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3DeployFlowResponse = {
      description = "The response message for Environments.DeployFlow.",
      id = "GoogleCloudDialogflowCxV3DeployFlowResponse",
      properties = {
        deployment = {
          description = "The name of the flow version Deployment. Format: `projects//locations//agents// environments//deployments/`.",
          type = "string",
        },
        environment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Environment",
          description = "The updated environment where the flow is deployed.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3DtmfInput = {
      description = "Represents the input for dtmf event.",
      id = "GoogleCloudDialogflowCxV3DtmfInput",
      properties = {
        digits = {
          description = "The dtmf digits.",
          type = "string",
        },
        finishDigit = {
          description = "The finish digit (if any).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3Environment = {
      description = "Represents an environment for an agent. You can create multiple versions of your agent and publish them to separate environments. When you edit an agent, you are editing the draft agent. At any point, you can save the draft agent as an agent version, which is an immutable snapshot of your agent. When you save the draft agent, it is published to the default environment. When you create agent versions, you can publish them to custom environments. You can create a variety of custom environments for testing, development, production, etc.",
      id = "GoogleCloudDialogflowCxV3Environment",
      properties = {
        description = {
          description = "The human-readable description of the environment. The maximum length is 500 characters. If exceeded, the request is rejected.",
          type = "string",
        },
        displayName = {
          description = "Required. The human-readable name of the environment (unique in an agent). Limit of 64 characters.",
          type = "string",
        },
        name = {
          description = "The name of the environment. Format: `projects//locations//agents//environments/`.",
          type = "string",
        },
        testCasesConfig = {
          ["$ref"] = "GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig",
          description = "The test cases config for continuous tests of this environment.",
        },
        updateTime = {
          description = "Output only. Update time of this environment.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        versionConfigs = {
          description = "Required. A list of configurations for flow versions. You should include version configs for all flows that are reachable from `Start Flow` in the agent. Otherwise, an error will be returned.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3EnvironmentVersionConfig",
          },
          type = "array",
        },
        webhookConfig = {
          ["$ref"] = "GoogleCloudDialogflowCxV3EnvironmentWebhookConfig",
          description = "The webhook configuration for this environment.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig = {
      description = "The configuration for continuous tests.",
      id = "GoogleCloudDialogflowCxV3EnvironmentTestCasesConfig",
      properties = {
        enableContinuousRun = {
          description = "Whether to run test cases in TestCasesConfig.test_cases periodically. Default false. If set to true, run once a day.",
          type = "boolean",
        },
        enablePredeploymentRun = {
          description = "Whether to run test cases in TestCasesConfig.test_cases before deploying a flow version to the environment. Default false.",
          type = "boolean",
        },
        testCases = {
          description = "A list of test case names to run. They should be under the same agent. Format of each test case name: `projects//locations/ /agents//testCases/`",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3EnvironmentVersionConfig = {
      description = "Configuration for the version.",
      id = "GoogleCloudDialogflowCxV3EnvironmentVersionConfig",
      properties = {
        version = {
          description = "Required. Format: projects//locations//agents//flows//versions/.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3EnvironmentWebhookConfig = {
      description = "Configuration for webhooks.",
      id = "GoogleCloudDialogflowCxV3EnvironmentWebhookConfig",
      properties = {
        webhookOverrides = {
          description = "The list of webhooks to override for the agent environment. The webhook must exist in the agent. You can override fields in `generic_web_service` and `service_directory`.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3Webhook",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3EventHandler = {
      description = "An event handler specifies an event that can be handled during a session. When the specified event happens, the following actions are taken in order: * If there is a `trigger_fulfillment` associated with the event, it will be called. * If there is a `target_page` associated with the event, the session will transition into the specified page. * If there is a `target_flow` associated with the event, the session will transition into the specified flow.",
      id = "GoogleCloudDialogflowCxV3EventHandler",
      properties = {
        event = {
          description = "Required. The name of the event to handle.",
          type = "string",
        },
        name = {
          description = "Output only. The unique identifier of this event handler.",
          readOnly = true,
          type = "string",
        },
        targetFlow = {
          description = "The target flow to transition to. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
        targetPage = {
          description = "The target page to transition to. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        triggerFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Fulfillment",
          description = "The fulfillment to call when the event occurs. Handling webhook errors with a fulfillment enabled with webhook could cause infinite loop. It is invalid to specify such fulfillment for a handler handling webhooks.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3EventInput = {
      description = "Represents the event to trigger.",
      id = "GoogleCloudDialogflowCxV3EventInput",
      properties = {
        event = {
          description = "Name of the event.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ExportAgentResponse = {
      description = "The response message for Agents.ExportAgent.",
      id = "GoogleCloudDialogflowCxV3ExportAgentResponse",
      properties = {
        agentContent = {
          description = "Uncompressed raw byte content for agent.",
          format = "byte",
          type = "string",
        },
        agentUri = {
          description = "The URI to a file containing the exported agent. This field is populated only if `agent_uri` is specified in ExportAgentRequest.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ExportFlowResponse = {
      description = "The response message for Flows.ExportFlow.",
      id = "GoogleCloudDialogflowCxV3ExportFlowResponse",
      properties = {
        flowContent = {
          description = "Uncompressed raw byte content for flow.",
          format = "byte",
          type = "string",
        },
        flowUri = {
          description = "The URI to a file containing the exported flow. This field is populated only if `flow_uri` is specified in ExportFlowRequest.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ExportTestCasesMetadata = {
      description = "Metadata returned for the TestCases.ExportTestCases long running operation. This message currently has no fields.",
      id = "GoogleCloudDialogflowCxV3ExportTestCasesMetadata",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowCxV3ExportTestCasesResponse = {
      description = "The response message for TestCases.ExportTestCases.",
      id = "GoogleCloudDialogflowCxV3ExportTestCasesResponse",
      properties = {
        content = {
          description = "Uncompressed raw byte content for test cases.",
          format = "byte",
          type = "string",
        },
        gcsUri = {
          description = "The URI to a file containing the exported test cases. This field is populated only if `gcs_uri` is specified in ExportTestCasesRequest.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3Form = {
      description = "A form is a data model that groups related parameters that can be collected from the user. The process in which the agent prompts the user and collects parameter values from the user is called form filling. A form can be added to a page. When form filling is done, the filled parameters will be written to the session.",
      id = "GoogleCloudDialogflowCxV3Form",
      properties = {
        parameters = {
          description = "Parameters to collect from the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3FormParameter",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3FormParameter = {
      description = "Represents a form parameter.",
      id = "GoogleCloudDialogflowCxV3FormParameter",
      properties = {
        defaultValue = {
          description = "The default value of an optional parameter. If the parameter is required, the default value will be ignored.",
          type = "any",
        },
        displayName = {
          description = "Required. The human-readable name of the parameter, unique within the form.",
          type = "string",
        },
        entityType = {
          description = "Required. The entity type of the parameter. Format: `projects/-/locations/-/agents/-/entityTypes/` for system entity types (for example, `projects/-/locations/-/agents/-/entityTypes/sys.date`), or `projects//locations//agents//entityTypes/` for developer entity types.",
          type = "string",
        },
        fillBehavior = {
          ["$ref"] = "GoogleCloudDialogflowCxV3FormParameterFillBehavior",
          description = "Required. Defines fill behavior for the parameter.",
        },
        isList = {
          description = "Indicates whether the parameter represents a list of values.",
          type = "boolean",
        },
        redact = {
          description = "Indicates whether the parameter content should be redacted in log. If redaction is enabled, the parameter content will be replaced by parameter name during logging. Note: the parameter content is subject to redaction if either parameter level redaction or entity type level redaction is enabled.",
          type = "boolean",
        },
        required = {
          description = "Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3FormParameterFillBehavior = {
      description = "Configuration for how the filling of a parameter should be handled.",
      id = "GoogleCloudDialogflowCxV3FormParameterFillBehavior",
      properties = {
        initialPromptFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Fulfillment",
          description = "Required. The fulfillment to provide the initial prompt that the agent can present to the user in order to fill the parameter.",
        },
        repromptEventHandlers = {
          description = "The handlers for parameter-level events, used to provide reprompt for the parameter or transition to a different page/flow. The supported events are: * `sys.no-match-`, where N can be from 1 to 6 * `sys.no-match-default` * `sys.no-input-`, where N can be from 1 to 6 * `sys.no-input-default` * `sys.invalid-parameter` `initial_prompt_fulfillment` provides the first prompt for the parameter. If the user's response does not fill the parameter, a no-match/no-input event will be triggered, and the fulfillment associated with the `sys.no-match-1`/`sys.no-input-1` handler (if defined) will be called to provide a prompt. The `sys.no-match-2`/`sys.no-input-2` handler (if defined) will respond to the next no-match/no-input event, and so on. A `sys.no-match-default` or `sys.no-input-default` handler will be used to handle all following no-match/no-input events after all numbered no-match/no-input handlers for the parameter are consumed. A `sys.invalid-parameter` handler can be defined to handle the case where the parameter values have been `invalidated` by webhook. For example, if the user's response fill the parameter, however the parameter was invalidated by webhook, the fulfillment associated with the `sys.invalid-parameter` handler (if defined) will be called to provide a prompt. If the event handler for the corresponding event can't be found on the parameter, `initial_prompt_fulfillment` will be re-prompted.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3EventHandler",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3Fulfillment = {
      description = "A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses. * Set parameter values. * Call the webhook. Fulfillments can be called at various stages in the Page or Form lifecycle. For example, when a DetectIntentRequest drives a session to enter a new page, the page's entry fulfillment can add a static response to the QueryResult in the returning DetectIntentResponse, call the webhook (for example, to load user data from a database), or both.",
      id = "GoogleCloudDialogflowCxV3Fulfillment",
      properties = {
        conditionalCases = {
          description = "Conditional cases for this fulfillment.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3FulfillmentConditionalCases",
          },
          type = "array",
        },
        messages = {
          description = "The list of rich message responses to present to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessage",
          },
          type = "array",
        },
        returnPartialResponses = {
          description = "Whether Dialogflow should return currently queued fulfillment response messages in streaming APIs. If a webhook is specified, it happens before Dialogflow invokes webhook. Warning: 1) This flag only affects streaming API. Responses are still queued and returned once in non-streaming API. 2) The flag can be enabled in any fulfillment but only the first 3 partial responses will be returned. You may only want to apply it to fulfillments that have slow webhooks.",
          type = "boolean",
        },
        setParameterActions = {
          description = "Set parameter values before executing the webhook.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3FulfillmentSetParameterAction",
          },
          type = "array",
        },
        tag = {
          description = "The value of this field will be populated in the WebhookRequest `fulfillmentInfo.tag` field by Dialogflow when the associated webhook is called. The tag is typically used by the webhook service to identify which fulfillment is being called, but it could be used for other purposes. This field is required if `webhook` is specified.",
          type = "string",
        },
        webhook = {
          description = "The webhook to call. Format: `projects//locations//agents//webhooks/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3FulfillmentConditionalCases = {
      description = "A list of cascading if-else conditions. Cases are mutually exclusive. The first one with a matching condition is selected, all the rest ignored.",
      id = "GoogleCloudDialogflowCxV3FulfillmentConditionalCases",
      properties = {
        cases = {
          description = "A list of cascading if-else conditions.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase = {
      description = "Each case has a Boolean condition. When it is evaluated to be True, the corresponding messages will be selected and evaluated recursively.",
      id = "GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCase",
      properties = {
        caseContent = {
          description = "A list of case content.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent",
          },
          type = "array",
        },
        condition = {
          description = "The condition to activate and select this case. Empty means the condition is always true. The condition is evaluated against form parameters or session parameters. See the [conditions reference](https://cloud.google.com/dialogflow/cx/docs/reference/condition).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent = {
      description = "The list of messages or conditional cases to activate for this case.",
      id = "GoogleCloudDialogflowCxV3FulfillmentConditionalCasesCaseCaseContent",
      properties = {
        additionalCases = {
          ["$ref"] = "GoogleCloudDialogflowCxV3FulfillmentConditionalCases",
          description = "Additional cases to be evaluated.",
        },
        message = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessage",
          description = "Returned message.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3FulfillmentSetParameterAction = {
      description = "Setting a parameter value.",
      id = "GoogleCloudDialogflowCxV3FulfillmentSetParameterAction",
      properties = {
        parameter = {
          description = "Display name of the parameter.",
          type = "string",
        },
        value = {
          description = "The new value of the parameter. A null value clears the parameter.",
          type = "any",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata = {
      description = "Metadata in google::longrunning::Operation for Knowledge operations.",
      id = "GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata",
      properties = {
        state = {
          description = "Required. Output only. The current state of this operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "PENDING",
            "RUNNING",
            "DONE",
          },
          enumDescriptions = {
            "State unspecified.",
            "The operation has been created.",
            "The operation is currently running.",
            "The operation is done, either cancelled or completed.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ImportDocumentsOperationMetadata = {
      description = "Metadata for ImportDocuments operation.",
      id = "GoogleCloudDialogflowCxV3ImportDocumentsOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ImportDocumentsResponse = {
      description = "Response message for Documents.ImportDocuments.",
      id = "GoogleCloudDialogflowCxV3ImportDocumentsResponse",
      properties = {
        warnings = {
          description = "Includes details about skipped documents or any other warnings.",
          items = {
            ["$ref"] = "GoogleRpcStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ImportFlowResponse = {
      description = "The response message for Flows.ImportFlow.",
      id = "GoogleCloudDialogflowCxV3ImportFlowResponse",
      properties = {
        flow = {
          description = "The unique identifier of the new flow. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ImportTestCasesMetadata = {
      description = "Metadata returned for the TestCases.ImportTestCases long running operation.",
      id = "GoogleCloudDialogflowCxV3ImportTestCasesMetadata",
      properties = {
        errors = {
          description = "Errors for failed test cases.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TestCaseError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ImportTestCasesResponse = {
      description = "The response message for TestCases.ImportTestCases.",
      id = "GoogleCloudDialogflowCxV3ImportTestCasesResponse",
      properties = {
        names = {
          description = "The unique identifiers of the new test cases. Format: `projects//locations//agents//testCases/`.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3InputAudioConfig = {
      description = "Instructs the speech recognizer on how to process the audio content.",
      id = "GoogleCloudDialogflowCxV3InputAudioConfig",
      properties = {
        audioEncoding = {
          description = "Required. Audio encoding of the audio content to process.",
          enum = {
            "AUDIO_ENCODING_UNSPECIFIED",
            "AUDIO_ENCODING_LINEAR_16",
            "AUDIO_ENCODING_FLAC",
            "AUDIO_ENCODING_MULAW",
            "AUDIO_ENCODING_AMR",
            "AUDIO_ENCODING_AMR_WB",
            "AUDIO_ENCODING_OGG_OPUS",
            "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE",
          },
          enumDescriptions = {
            "Not specified.",
            "Uncompressed 16-bit signed little-endian samples (Linear PCM).",
            "[`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio Codec) is the recommended encoding because it is lossless (therefore recognition is not compromised) and requires only about half the bandwidth of `LINEAR16`. `FLAC` stream encoding supports 16-bit and 24-bit samples, however, not all fields in `STREAMINFO` are supported.",
            "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.",
            "Adaptive Multi-Rate Narrowband codec. `sample_rate_hertz` must be 8000.",
            "Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.",
            "Opus encoded audio frames in Ogg container ([OggOpus](https://wiki.xiph.org/OggOpus)). `sample_rate_hertz` must be 16000.",
            "Although the use of lossy encodings is not recommended, if a very low bitrate encoding is required, `OGG_OPUS` is highly preferred over Speex encoding. The [Speex](https://speex.org/) encoding supported by Dialogflow API has a header byte in each block, as in MIME type `audio/x-speex-with-header-byte`. It is a variant of the RTP Speex encoding defined in [RFC 5574](https://tools.ietf.org/html/rfc5574). The stream is a sequence of blocks, one block per RTP packet. Each block starts with a byte containing the length of the block, in bytes, followed by one or more frames of Speex data, padded to an integral number of bytes (octets) as specified in RFC 5574. In other words, each RTP header is replaced with a single byte containing the block length. Only Speex wideband is supported. `sample_rate_hertz` must be 16000.",
          },
          type = "string",
        },
        enableWordInfo = {
          description = "Optional. If `true`, Dialogflow returns SpeechWordInfo in StreamingRecognitionResult with information about the recognized speech words, e.g. start and end time offsets. If false or unspecified, Speech doesn't return any word-level information.",
          type = "boolean",
        },
        model = {
          description = "Optional. Which Speech model to select for the given request. Select the model best suited to your domain to get best results. If a model is not explicitly specified, then we auto-select a model based on the parameters in the InputAudioConfig. If enhanced speech model is enabled for the agent and an enhanced version of the specified model for the language does not exist, then the speech is recognized using the standard version of the specified model. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics#select-model) for more details.",
          type = "string",
        },
        modelVariant = {
          description = "Optional. Which variant of the Speech model to use.",
          enum = {
            "SPEECH_MODEL_VARIANT_UNSPECIFIED",
            "USE_BEST_AVAILABLE",
            "USE_STANDARD",
            "USE_ENHANCED",
          },
          enumDescriptions = {
            "No model variant specified. In this case Dialogflow defaults to USE_BEST_AVAILABLE.",
            "Use the best available variant of the Speech model that the caller is eligible for. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible for enhanced models.",
            "Use standard model variant even if an enhanced model is available. See the [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) for details about enhanced models.",
            "Use an enhanced model variant: * If an enhanced variant does not exist for the given model and request language, Dialogflow falls back to the standard variant. The [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) describes which models have enhanced variants. * If the API caller isn't eligible for enhanced models, Dialogflow returns an error. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible.",
          },
          type = "string",
        },
        phraseHints = {
          description = "Optional. A list of strings containing words and phrases that the speech recognizer should recognize with higher likelihood. See [the Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints) for more details.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sampleRateHertz = {
          description = "Sample rate (in Hertz) of the audio content sent in the query. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics) for more details.",
          format = "int32",
          type = "integer",
        },
        singleUtterance = {
          description = "Optional. If `false` (default), recognition does not cease until the client closes the stream. If `true`, the recognizer will detect a single spoken utterance in input audio. Recognition ceases when it detects the audio's voice has stopped or paused. In this case, once a detected intent is received, the client should close the stream and start a new request with a new stream as needed. Note: This setting is relevant only for streaming methods.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3Intent = {
      description = "An intent represents a user's intent to interact with a conversational agent. You can provide information for the Dialogflow API to use to match user input to an intent by adding training phrases (i.e., examples of user input) to your intent.",
      id = "GoogleCloudDialogflowCxV3Intent",
      properties = {
        description = {
          description = "Human readable description for better understanding an intent like its scope, content, result etc. Maximum character limit: 140 characters.",
          type = "string",
        },
        displayName = {
          description = "Required. The human-readable name of the intent, unique within the agent.",
          type = "string",
        },
        isFallback = {
          description = "Indicates whether this is a fallback intent. Currently only default fallback intent is allowed in the agent, which is added upon agent creation. Adding training phrases to fallback intent is useful in the case of requests that are mistakenly matched, since training phrases assigned to fallback intents act as negative examples that triggers no-match event.",
          type = "boolean",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "The key/value metadata to label an intent. Labels can contain lowercase letters, digits and the symbols '-' and '_'. International characters are allowed, including letters from unicase alphabets. Keys must start with a letter. Keys and values can be no longer than 63 characters and no more than 128 bytes. Prefix \"sys-\" is reserved for Dialogflow defined labels. Currently allowed Dialogflow defined labels include: * sys-head * sys-contextual The above labels do not require value. \"sys-head\" means the intent is a head intent. \"sys.contextual\" means the intent is a contextual intent.",
          type = "object",
        },
        name = {
          description = "The unique identifier of the intent. Required for the Intents.UpdateIntent method. Intents.CreateIntent populates the name automatically. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
        parameters = {
          description = "The collection of parameters associated with the intent.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3IntentParameter",
          },
          type = "array",
        },
        priority = {
          description = "The priority of this intent. Higher numbers represent higher priorities. - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds to the `Normal` priority in the console. - If the supplied value is negative, the intent is ignored in runtime detect intent requests.",
          format = "int32",
          type = "integer",
        },
        trainingPhrases = {
          description = "The collection of training phrases the agent is trained on to identify the intent.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3IntentTrainingPhrase",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3IntentInput = {
      description = "Represents the intent to trigger programmatically rather than as a result of natural language processing.",
      id = "GoogleCloudDialogflowCxV3IntentInput",
      properties = {
        intent = {
          description = "Required. The unique identifier of the intent. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3IntentParameter = {
      description = "Represents an intent parameter.",
      id = "GoogleCloudDialogflowCxV3IntentParameter",
      properties = {
        entityType = {
          description = "Required. The entity type of the parameter. Format: `projects/-/locations/-/agents/-/entityTypes/` for system entity types (for example, `projects/-/locations/-/agents/-/entityTypes/sys.date`), or `projects//locations//agents//entityTypes/` for developer entity types.",
          type = "string",
        },
        id = {
          description = "Required. The unique identifier of the parameter. This field is used by training phrases to annotate their parts.",
          type = "string",
        },
        isList = {
          description = "Indicates whether the parameter represents a list of values.",
          type = "boolean",
        },
        redact = {
          description = "Indicates whether the parameter content should be redacted in log. If redaction is enabled, the parameter content will be replaced by parameter name during logging. Note: the parameter content is subject to redaction if either parameter level redaction or entity type level redaction is enabled.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3IntentTrainingPhrase = {
      description = "Represents an example that the agent is trained on to identify the intent.",
      id = "GoogleCloudDialogflowCxV3IntentTrainingPhrase",
      properties = {
        id = {
          description = "Output only. The unique identifier of the training phrase.",
          type = "string",
        },
        parts = {
          description = "Required. The ordered list of training phrase parts. The parts are concatenated in order to form the training phrase. Note: The API does not automatically annotate training phrases like the Dialogflow Console does. Note: Do not forget to include whitespace at part boundaries, so the training phrase is well formatted when the parts are concatenated. If the training phrase does not need to be annotated with parameters, you just need a single part with only the Part.text field set. If you want to annotate the training phrase, you must create multiple parts, where the fields of each part are populated in one of two ways: - `Part.text` is set to a part of the phrase that has no parameters. - `Part.text` is set to a part of the phrase that you want to annotate, and the `parameter_id` field is set.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3IntentTrainingPhrasePart",
          },
          type = "array",
        },
        repeatCount = {
          description = "Indicates how many times this example was added to the intent.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3IntentTrainingPhrasePart = {
      description = "Represents a part of a training phrase.",
      id = "GoogleCloudDialogflowCxV3IntentTrainingPhrasePart",
      properties = {
        parameterId = {
          description = "The parameter used to annotate this part of the training phrase. This field is required for annotated parts of the training phrase.",
          type = "string",
        },
        text = {
          description = "Required. The text for this part.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3Page = {
      description = "A Dialogflow CX conversation (session) can be described and visualized as a state machine. The states of a CX session are represented by pages. For each flow, you define many pages, where your combined pages can handle a complete conversation on the topics the flow is designed for. At any given moment, exactly one page is the current page, the current page is considered active, and the flow associated with that page is considered active. Every flow has a special start page. When a flow initially becomes active, the start page page becomes the current page. For each conversational turn, the current page will either stay the same or transition to another page. You configure each page to collect information from the end-user that is relevant for the conversational state represented by the page. For more information, see the [Page guide](https://cloud.google.com/dialogflow/cx/docs/concept/page).",
      id = "GoogleCloudDialogflowCxV3Page",
      properties = {
        displayName = {
          description = "Required. The human-readable name of the page, unique within the flow.",
          type = "string",
        },
        entryFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Fulfillment",
          description = "The fulfillment to call when the session is entering the page.",
        },
        eventHandlers = {
          description = "Handlers associated with the page to handle events such as webhook errors, no match or no input.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3EventHandler",
          },
          type = "array",
        },
        form = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Form",
          description = "The form associated with the page, used for collecting parameters relevant to the page.",
        },
        name = {
          description = "The unique identifier of the page. Required for the Pages.UpdatePage method. Pages.CreatePage populates the name automatically. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        transitionRouteGroups = {
          description = "Ordered list of `TransitionRouteGroups` associated with the page. Transition route groups must be unique within a page. * If multiple transition routes within a page scope refer to the same intent, then the precedence order is: page's transition route -> page's transition route group -> flow's transition routes. * If multiple transition route groups within a page contain the same intent, then the first group in the ordered list takes precedence. Format:`projects//locations//agents//flows//transitionRouteGroups/`.",
          items = {
            type = "string",
          },
          type = "array",
        },
        transitionRoutes = {
          description = "A list of transitions for the transition rules of this page. They route the conversation to another page in the same flow, or another flow. When we are in a certain page, the TransitionRoutes are evalauted in the following order: * TransitionRoutes defined in the page with intent specified. * TransitionRoutes defined in the transition route groups with intent specified. * TransitionRoutes defined in flow with intent specified. * TransitionRoutes defined in the transition route groups with intent specified. * TransitionRoutes defined in the page with only condition specified. * TransitionRoutes defined in the transition route groups with only condition specified.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TransitionRoute",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3PageInfo = {
      description = "Represents page information communicated to and from the webhook.",
      id = "GoogleCloudDialogflowCxV3PageInfo",
      properties = {
        currentPage = {
          description = "Always present for WebhookRequest. Ignored for WebhookResponse. The unique identifier of the current page. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        displayName = {
          description = "Always present for WebhookRequest. Ignored for WebhookResponse. The display name of the current page.",
          type = "string",
        },
        formInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3PageInfoFormInfo",
          description = "Optional for both WebhookRequest and WebhookResponse. Information about the form.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3PageInfoFormInfo = {
      description = "Represents form information.",
      id = "GoogleCloudDialogflowCxV3PageInfoFormInfo",
      properties = {
        parameterInfo = {
          description = "Optional for both WebhookRequest and WebhookResponse. The parameters contained in the form. Note that the webhook cannot add or remove any form parameter.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo = {
      description = "Represents parameter information.",
      id = "GoogleCloudDialogflowCxV3PageInfoFormInfoParameterInfo",
      properties = {
        displayName = {
          description = "Always present for WebhookRequest. Required for WebhookResponse. The human-readable name of the parameter, unique within the form. This field cannot be modified by the webhook.",
          type = "string",
        },
        justCollected = {
          description = "Optional for WebhookRequest. Ignored for WebhookResponse. Indicates if the parameter value was just collected on the last conversation turn.",
          type = "boolean",
        },
        required = {
          description = "Optional for both WebhookRequest and WebhookResponse. Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes.",
          type = "boolean",
        },
        state = {
          description = "Always present for WebhookRequest. Required for WebhookResponse. The state of the parameter. This field can be set to INVALID by the webhook to invalidate the parameter; other values set by the webhook will be ignored.",
          enum = {
            "PARAMETER_STATE_UNSPECIFIED",
            "EMPTY",
            "INVALID",
            "FILLED",
          },
          enumDescriptions = {
            "Not specified. This value should be never used.",
            "Indicates that the parameter does not have a value.",
            "Indicates that the parameter value is invalid. This field can be used by the webhook to invalidate the parameter and ask the server to collect it from the user again.",
            "Indicates that the parameter has a value.",
          },
          type = "string",
        },
        value = {
          description = "Optional for both WebhookRequest and WebhookResponse. The value of the parameter. This field can be set by the webhook to change the parameter value.",
          type = "any",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3QueryInput = {
      description = "Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger. 3. Natural language speech audio to be processed. 4. An event to be triggered. ",
      id = "GoogleCloudDialogflowCxV3QueryInput",
      properties = {
        audio = {
          ["$ref"] = "GoogleCloudDialogflowCxV3AudioInput",
          description = "The natural language speech audio to be processed.",
        },
        dtmf = {
          ["$ref"] = "GoogleCloudDialogflowCxV3DtmfInput",
          description = "The DTMF event to be handled.",
        },
        event = {
          ["$ref"] = "GoogleCloudDialogflowCxV3EventInput",
          description = "The event to be triggered.",
        },
        intent = {
          ["$ref"] = "GoogleCloudDialogflowCxV3IntentInput",
          description = "The intent to be triggered.",
        },
        languageCode = {
          description = "Required. The language of the input. See [Language Support](https://cloud.google.com/dialogflow/cx/docs/reference/language) for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.",
          type = "string",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowCxV3TextInput",
          description = "The natural language text to be processed.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ReloadDocumentOperationMetadata = {
      description = "Metadata for ReloadDocument operation.",
      id = "GoogleCloudDialogflowCxV3ReloadDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessage = {
      description = "Represents a response message that can be returned by a conversational agent. Response messages are also used for output audio synthesis. The approach is as follows: * If at least one OutputAudioText response is present, then all OutputAudioText responses are linearly concatenated, and the result is used for output audio synthesis. * If the OutputAudioText responses are a mixture of text and SSML, then the concatenated result is treated as SSML; otherwise, the result is treated as either text or SSML as appropriate. The agent designer should ideally use either text or SSML consistently throughout the bot design. * Otherwise, all Text responses are linearly concatenated, and the result is used for output audio synthesis. This approach allows for more sophisticated user experience scenarios, where the text displayed to the user may differ from what is heard.",
      id = "GoogleCloudDialogflowCxV3ResponseMessage",
      properties = {
        channel = {
          description = "The channel which the response is associated with. Clients can specify the channel via QueryParameters.channel, and only associated channel response will be returned.",
          type = "string",
        },
        conversationSuccess = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess",
          description = "Indicates that the conversation succeeded.",
        },
        endInteraction = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageEndInteraction",
          description = "Output only. A signal that indicates the interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only when the conversation reaches `END_SESSION` page. It is not supposed to be defined by the user. It's guaranteed that there is at most one such message in each response.",
          readOnly = true,
        },
        liveAgentHandoff = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff",
          description = "Hands off conversation to a human agent.",
        },
        mixedAudio = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageMixedAudio",
          description = "Output only. An audio response message composed of both the synthesized Dialogflow agent responses and responses defined via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.",
          readOnly = true,
        },
        outputAudioText = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText",
          description = "A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Returns a response containing a custom, platform-specific payload.",
          type = "object",
        },
        playAudio = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessagePlayAudio",
          description = "Signal that the client should play an audio clip hosted at a client-specific URI. Dialogflow uses this to construct mixed_audio. However, Dialogflow itself does not try to read or process the URI in any way.",
        },
        telephonyTransferCall = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall",
          description = "A signal that the client should transfer the phone call connected to this agent to a third-party endpoint.",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageText",
          description = "Returns a text response.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess = {
      description = "Indicates that the conversation succeeded, i.e., the bot handled the issue that the customer talked to it about. Dialogflow only uses this to determine which conversations should be counted as successful and doesn't process the metadata in this message in any way. Note that Dialogflow also considers conversations that get to the conversation end page as successful even if they don't return ConversationSuccess. You may set this, for example: * In the entry_fulfillment of a Page if entering the page indicates that the conversation succeeded. * In a webhook response when you determine that you handled the customer issue.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageConversationSuccess",
      properties = {
        metadata = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Custom metadata. Dialogflow doesn't impose any structure on this.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageEndInteraction = {
      description = "Indicates that interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only and not supposed to be defined by the user.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageEndInteraction",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff = {
      description = "Indicates that the conversation should be handed off to a live agent. Dialogflow only uses this to determine which conversations were handed off to a human agent for measurement purposes. What else to do with this signal is up to you and your handoff procedures. You may set this, for example: * In the entry_fulfillment of a Page if entering the page indicates something went extremely wrong in the conversation. * In a webhook response when you determine that the customer issue can only be handled by a human.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageLiveAgentHandoff",
      properties = {
        metadata = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Custom metadata for your handoff procedure. Dialogflow doesn't impose any structure on this.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageMixedAudio = {
      description = "Represents an audio message that is composed of both segments synthesized from the Dialogflow agent prompts and ones hosted externally at the specified URIs. The external URIs are specified via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageMixedAudio",
      properties = {
        segments = {
          description = "Segments this audio response is composed of.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment = {
      description = "Represents one segment of audio.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageMixedAudioSegment",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this segment can be interrupted by the end user's speech and the client should then start the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        audio = {
          description = "Raw audio synthesized from the Dialogflow agent's response using the output config specified in the request.",
          format = "byte",
          type = "string",
        },
        uri = {
          description = "Client-specific URI that points to an audio clip accessible to the client. Dialogflow does not impose any validation on it.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText = {
      description = "A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageOutputAudioText",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        ssml = {
          description = "The SSML text to be synthesized. For more information, see [SSML](/speech/text-to-speech/docs/ssml).",
          type = "string",
        },
        text = {
          description = "The raw text to be synthesized.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessagePlayAudio = {
      description = "Specifies an audio clip to be played by the client as part of the response.",
      id = "GoogleCloudDialogflowCxV3ResponseMessagePlayAudio",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        audioUri = {
          description = "Required. URI of the audio clip. Dialogflow does not impose any validation on this value. It is specific to the client that reads it.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall = {
      description = "Represents the signal that telles the client to transfer the phone call connected to the agent to a third-party endpoint.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageTelephonyTransferCall",
      properties = {
        phoneNumber = {
          description = "Transfer the call to a phone number in [E.164 format](https://en.wikipedia.org/wiki/E.164).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3ResponseMessageText = {
      description = "The text response message.",
      id = "GoogleCloudDialogflowCxV3ResponseMessageText",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        text = {
          description = "Required. A collection of text responses.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3RunContinuousTestMetadata = {
      description = "Metadata returned for the Environments.RunContinuousTest long running operation.",
      id = "GoogleCloudDialogflowCxV3RunContinuousTestMetadata",
      properties = {
        errors = {
          description = "The test errors.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3TestError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3RunContinuousTestResponse = {
      description = "The response message for Environments.RunContinuousTest.",
      id = "GoogleCloudDialogflowCxV3RunContinuousTestResponse",
      properties = {
        continuousTestResult = {
          ["$ref"] = "GoogleCloudDialogflowCxV3ContinuousTestResult",
          description = "The result for a continuous test run.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3RunTestCaseMetadata = {
      description = "Metadata returned for the TestCases.RunTestCase long running operation. This message currently has no fields.",
      id = "GoogleCloudDialogflowCxV3RunTestCaseMetadata",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowCxV3RunTestCaseResponse = {
      description = "The response message for TestCases.RunTestCase.",
      id = "GoogleCloudDialogflowCxV3RunTestCaseResponse",
      properties = {
        result = {
          ["$ref"] = "GoogleCloudDialogflowCxV3TestCaseResult",
          description = "The result.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3SessionInfo = {
      description = "Represents session information communicated to and from the webhook.",
      id = "GoogleCloudDialogflowCxV3SessionInfo",
      properties = {
        parameters = {
          additionalProperties = {
            type = "any",
          },
          description = "Optional for WebhookRequest. Optional for WebhookResponse. All parameters collected from forms and intents during the session. Parameters can be created, updated, or removed by the webhook. To remove a parameter from the session, the webhook should explicitly set the parameter value to null in WebhookResponse. The map is keyed by parameters' display names.",
          type = "object",
        },
        session = {
          description = "Always present for WebhookRequest. Ignored for WebhookResponse. The unique identifier of the session. This field can be used by the webhook to identify a session. Format: `projects//locations//agents//sessions/` or `projects//locations//agents//environments//sessions/` if environment is specified.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TestCase = {
      description = "Represents a test case.",
      id = "GoogleCloudDialogflowCxV3TestCase",
      properties = {
        creationTime = {
          description = "Output only. When the test was created.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Required. The human-readable name of the test case, unique within the agent. Limit of 200 characters.",
          type = "string",
        },
        lastTestResult = {
          ["$ref"] = "GoogleCloudDialogflowCxV3TestCaseResult",
          description = "The latest test result.",
        },
        name = {
          description = "The unique identifier of the test case. TestCases.CreateTestCase will populate the name automatically. Otherwise use format: `projects//locations//agents/ /testCases/`.",
          type = "string",
        },
        notes = {
          description = "Additional freeform notes about the test case. Limit of 400 characters.",
          type = "string",
        },
        tags = {
          description = "Tags are short descriptions that users may apply to test cases for organizational and filtering purposes. Each tag should start with \"#\" and has a limit of 30 characters.",
          items = {
            type = "string",
          },
          type = "array",
        },
        testCaseConversationTurns = {
          description = "The conversation turns uttered when the test case was created, in chronological order. These include the canonical set of agent utterances that should occur when the agent is working properly.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ConversationTurn",
          },
          type = "array",
        },
        testConfig = {
          ["$ref"] = "GoogleCloudDialogflowCxV3TestConfig",
          description = "Config for the test case.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TestCaseError = {
      description = "Error info for importing a test.",
      id = "GoogleCloudDialogflowCxV3TestCaseError",
      properties = {
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "The status associated with the test case.",
        },
        testCase = {
          ["$ref"] = "GoogleCloudDialogflowCxV3TestCase",
          description = "The test case.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TestCaseResult = {
      description = "Represents a result from running a test case in an agent environment.",
      id = "GoogleCloudDialogflowCxV3TestCaseResult",
      properties = {
        conversationTurns = {
          description = "The conversation turns uttered during the test case replay in chronological order.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ConversationTurn",
          },
          type = "array",
        },
        environment = {
          description = "Environment where the test was run. If not set, it indicates the draft environment.",
          type = "string",
        },
        name = {
          description = "The resource name for the test case result. Format: `projects//locations//agents//testCases/ /results/`.",
          type = "string",
        },
        testResult = {
          description = "Whether the test case passed in the agent environment.",
          enum = {
            "TEST_RESULT_UNSPECIFIED",
            "PASSED",
            "FAILED",
          },
          enumDescriptions = {
            "Not specified. Should never be used.",
            "The test passed.",
            "The test did not pass.",
          },
          type = "string",
        },
        testTime = {
          description = "The time that the test was run.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TestConfig = {
      description = "Represents configurations for a test case.",
      id = "GoogleCloudDialogflowCxV3TestConfig",
      properties = {
        flow = {
          description = "Flow name to start the test case with. Format: `projects//locations//agents//flows/`. Only one of `flow` and `page` should be set to indicate the starting point of the test case. If both are set, `page` takes precedence over `flow`. If neither is set, the test case will start with start page on the default start flow.",
          type = "string",
        },
        page = {
          description = "The page to start the test case with. Format: `projects//locations//agents//flows//pages/`. Only one of `flow` and `page` should be set to indicate the starting point of the test case. If both are set, `page` takes precedence over `flow`. If neither is set, the test case will start with start page on the default start flow.",
          type = "string",
        },
        trackingParameters = {
          description = "Session parameters to be compared when calculating differences.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TestError = {
      description = "Error info for running a test.",
      id = "GoogleCloudDialogflowCxV3TestError",
      properties = {
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "The status associated with the test.",
        },
        testCase = {
          description = "The test case resource name.",
          type = "string",
        },
        testTime = {
          description = "The timestamp when the test was completed.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TestRunDifference = {
      description = "The description of differences between original and replayed agent output.",
      id = "GoogleCloudDialogflowCxV3TestRunDifference",
      properties = {
        description = {
          description = "A description of the diff, showing the actual output vs expected output.",
          type = "string",
        },
        type = {
          description = "The type of diff.",
          enum = {
            "DIFF_TYPE_UNSPECIFIED",
            "INTENT",
            "PAGE",
            "PARAMETERS",
            "UTTERANCE",
          },
          enumDescriptions = {
            "Should never be used.",
            "The intent.",
            "The page.",
            "The parameters.",
            "The message utterance.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TextInput = {
      description = "Represents the natural language text to be processed.",
      id = "GoogleCloudDialogflowCxV3TextInput",
      properties = {
        text = {
          description = "Required. The UTF-8 encoded natural language text to be processed. Text length must not exceed 256 characters.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TransitionRoute = {
      description = "A transition route specifies a intent that can be matched and/or a data condition that can be evaluated during a session. When a specified transition is matched, the following actions are taken in order: * If there is a `trigger_fulfillment` associated with the transition, it will be called. * If there is a `target_page` associated with the transition, the session will transition into the specified page. * If there is a `target_flow` associated with the transition, the session will transition into the specified flow.",
      id = "GoogleCloudDialogflowCxV3TransitionRoute",
      properties = {
        condition = {
          description = "The condition to evaluate against form parameters or session parameters. See the [conditions reference](https://cloud.google.com/dialogflow/cx/docs/reference/condition). At least one of `intent` or `condition` must be specified. When both `intent` and `condition` are specified, the transition can only happen when both are fulfilled.",
          type = "string",
        },
        intent = {
          description = "The unique identifier of an Intent. Format: `projects//locations//agents//intents/`. Indicates that the transition can only happen when the given intent is matched. At least one of `intent` or `condition` must be specified. When both `intent` and `condition` are specified, the transition can only happen when both are fulfilled.",
          type = "string",
        },
        name = {
          description = "Output only. The unique identifier of this transition route.",
          readOnly = true,
          type = "string",
        },
        targetFlow = {
          description = "The target flow to transition to. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
        targetPage = {
          description = "The target page to transition to. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        triggerFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3Fulfillment",
          description = "The fulfillment to call when the condition is satisfied. At least one of `trigger_fulfillment` and `target` must be specified. When both are defined, `trigger_fulfillment` is executed first.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3TurnSignals = {
      description = "Collection of all signals that were extracted for a single turn of the conversation.",
      id = "GoogleCloudDialogflowCxV3TurnSignals",
      properties = {
        agentEscalated = {
          description = "Whether agent responded with LiveAgentHandoff fulfillment.",
          type = "boolean",
        },
        dtmfUsed = {
          description = "Whether user was using DTMF input.",
          type = "boolean",
        },
        failureReasons = {
          description = "Failure reasons of the turn.",
          items = {
            enum = {
              "FAILURE_REASON_UNSPECIFIED",
              "FAILED_INTENT",
              "FAILED_WEBHOOK",
            },
            enumDescriptions = {
              "Failure reason is not assigned.",
              "Whether NLU failed to recognize user intent.",
              "Whether webhook failed during the turn.",
            },
            type = "string",
          },
          type = "array",
        },
        noMatch = {
          description = "Whether NLU predicted NO_MATCH.",
          type = "boolean",
        },
        noUserInput = {
          description = "Whether user provided no input.",
          type = "boolean",
        },
        reachedEndPage = {
          description = "Whether turn resulted in End Session page.",
          type = "boolean",
        },
        userEscalated = {
          description = "Whether user was specifically asking for a live agent.",
          type = "boolean",
        },
        webhookStatuses = {
          description = "Human-readable statuses of the webhooks triggered during this turn.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3UpdateDocumentOperationMetadata = {
      description = "Metadata for UpdateDocument operation.",
      id = "GoogleCloudDialogflowCxV3UpdateDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3Webhook = {
      description = "Webhooks host the developer's business logic. During a session, webhooks allow the developer to use the data extracted by Dialogflow's natural language processing to generate dynamic responses, validate collected data, or trigger actions on the backend.",
      id = "GoogleCloudDialogflowCxV3Webhook",
      properties = {
        disabled = {
          description = "Indicates whether the webhook is disabled.",
          type = "boolean",
        },
        displayName = {
          description = "Required. The human-readable name of the webhook, unique within the agent.",
          type = "string",
        },
        genericWebService = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookGenericWebService",
          description = "Configuration for a generic web service.",
        },
        name = {
          description = "The unique identifier of the webhook. Required for the Webhooks.UpdateWebhook method. Webhooks.CreateWebhook populates the name automatically. Format: `projects//locations//agents//webhooks/`.",
          type = "string",
        },
        serviceDirectory = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig",
          description = "Configuration for a [Service Directory](https://cloud.google.com/service-directory) service.",
        },
        timeout = {
          description = "Webhook execution timeout. Execution is considered failed if Dialogflow doesn't receive a response from webhook at the end of the timeout period. Defaults to 5 seconds, maximum allowed timeout is 30 seconds.",
          format = "google-duration",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookGenericWebService = {
      description = "Represents configuration for a generic web service.",
      id = "GoogleCloudDialogflowCxV3WebhookGenericWebService",
      properties = {
        allowedCaCerts = {
          description = "Optional. Specifies a list of allowed custom CA certificates (in DER format) for HTTPS verification. This overrides the default SSL trust store. If this is empty or unspecified, Dialogflow will use Google's default trust store to verify certificates. N.B. Make sure the HTTPS server certificates are signed with \"subject alt name\". For instance a certificate can be self-signed using the following command, ``` openssl x509 -req -days 200 -in example.com.csr \\ -signkey example.com.key \\ -out example.com.crt \\ -extfile <(printf \"\\nsubjectAltName='DNS:www.example.com'\") ```",
          items = {
            format = "byte",
            type = "string",
          },
          type = "array",
        },
        password = {
          description = "The password for HTTP Basic authentication.",
          type = "string",
        },
        requestHeaders = {
          additionalProperties = {
            type = "string",
          },
          description = "The HTTP request headers to send together with webhook requests.",
          type = "object",
        },
        uri = {
          description = "Required. The webhook URI for receiving POST requests. It must use https protocol.",
          type = "string",
        },
        username = {
          description = "The user name for HTTP Basic authentication.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookRequest = {
      description = "The request message for a webhook call. The request is sent as a JSON object and the field names will be presented in camel cases. You may see undocumented fields in an actual request. These fields are used internally by Dialogflow and should be ignored.",
      id = "GoogleCloudDialogflowCxV3WebhookRequest",
      properties = {
        detectIntentResponseId = {
          description = "Always present. The unique identifier of the DetectIntentResponse that will be returned to the API caller.",
          type = "string",
        },
        fulfillmentInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo",
          description = "Always present. Information about the fulfillment that triggered this webhook call.",
        },
        intentInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookRequestIntentInfo",
          description = "Information about the last matched intent.",
        },
        languageCode = {
          description = "The language code specified in the original request.",
          type = "string",
        },
        messages = {
          description = "The list of rich message responses to present to the user. Webhook can choose to append or replace this list in WebhookResponse.fulfillment_response;",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessage",
          },
          type = "array",
        },
        pageInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3PageInfo",
          description = "Information about page status.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Custom data set in QueryParameters.payload.",
          type = "object",
        },
        sentimentAnalysisResult = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookRequestSentimentAnalysisResult",
          description = "The sentiment analysis result of the current user request. The field is filled when sentiment analysis is configured to be enabled for the request.",
        },
        sessionInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3SessionInfo",
          description = "Information about session status.",
        },
        text = {
          description = "If natural language text was provided as input, this field will contain a copy of the text.",
          type = "string",
        },
        transcript = {
          description = "If natural language speech audio was provided as input, this field will contain the transcript for the audio.",
          type = "string",
        },
        triggerEvent = {
          description = "If an event was provided as input, this field will contain the name of the event.",
          type = "string",
        },
        triggerIntent = {
          description = "If an intent was provided as input, this field will contain a copy of the intent identifier. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo = {
      description = "Represents fulfillment information communicated to the webhook.",
      id = "GoogleCloudDialogflowCxV3WebhookRequestFulfillmentInfo",
      properties = {
        tag = {
          description = "Always present. The value of the Fulfillment.tag field will be populated in this field by Dialogflow when the associated webhook is called. The tag is typically used by the webhook service to identify which fulfillment is being called, but it could be used for other purposes.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookRequestIntentInfo = {
      description = "Represents intent information communicated to the webhook.",
      id = "GoogleCloudDialogflowCxV3WebhookRequestIntentInfo",
      properties = {
        confidence = {
          description = "The confidence of the matched intent. Values range from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        displayName = {
          description = "Always present. The display name of the last matched intent.",
          type = "string",
        },
        lastMatchedIntent = {
          description = "Always present. The unique identifier of the last matched intent. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
        parameters = {
          additionalProperties = {
            ["$ref"] = "GoogleCloudDialogflowCxV3WebhookRequestIntentInfoIntentParameterValue",
          },
          description = "Parameters identified as a result of intent matching. This is a map of the name of the identified parameter to the value of the parameter identified from the user's utterance. All parameters defined in the matched intent that are identified will be surfaced here.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookRequestIntentInfoIntentParameterValue = {
      description = "Represents a value for an intent parameter.",
      id = "GoogleCloudDialogflowCxV3WebhookRequestIntentInfoIntentParameterValue",
      properties = {
        originalValue = {
          description = "Always present. Original text value extracted from user utterance.",
          type = "string",
        },
        resolvedValue = {
          description = "Always present. Structured value for the parameter extracted from user utterance.",
          type = "any",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookRequestSentimentAnalysisResult = {
      description = "Represents the result of sentiment analysis.",
      id = "GoogleCloudDialogflowCxV3WebhookRequestSentimentAnalysisResult",
      properties = {
        magnitude = {
          description = "A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).",
          format = "float",
          type = "number",
        },
        score = {
          description = "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookResponse = {
      description = "The response message for a webhook call.",
      id = "GoogleCloudDialogflowCxV3WebhookResponse",
      properties = {
        fulfillmentResponse = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse",
          description = "The fulfillment response to send to the user. This field can be omitted by the webhook if it does not intend to send any response to the user.",
        },
        pageInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3PageInfo",
          description = "Information about page status. This field can be omitted by the webhook if it does not intend to modify page status.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Value to append directly to QueryResult.webhook_payloads.",
          type = "object",
        },
        sessionInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3SessionInfo",
          description = "Information about session status. This field can be omitted by the webhook if it does not intend to modify session status.",
        },
        targetFlow = {
          description = "The target flow to transition to. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
        targetPage = {
          description = "The target page to transition to. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse = {
      description = "Represents a fulfillment response to the user.",
      id = "GoogleCloudDialogflowCxV3WebhookResponseFulfillmentResponse",
      properties = {
        mergeBehavior = {
          description = "Merge behavior for `messages`.",
          enum = {
            "MERGE_BEHAVIOR_UNSPECIFIED",
            "APPEND",
            "REPLACE",
          },
          enumDescriptions = {
            "Not specified. `APPEND` will be used.",
            "`messages` will be appended to the list of messages waiting to be sent to the user.",
            "`messages` will replace the list of messages waiting to be sent to the user.",
          },
          type = "string",
        },
        messages = {
          description = "The list of rich message responses to present to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3ResponseMessage",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig = {
      description = "Represents configuration for a [Service Directory](https://cloud.google.com/service-directory) service.",
      id = "GoogleCloudDialogflowCxV3WebhookServiceDirectoryConfig",
      properties = {
        genericWebService = {
          ["$ref"] = "GoogleCloudDialogflowCxV3WebhookGenericWebService",
          description = "Generic Service configuration of this webhook.",
        },
        service = {
          description = "Required. The name of [Service Directory](https://cloud.google.com/service-directory) service. Format: `projects//locations//namespaces//services/`. `Location ID` of the service directory must be the same as the location of the agent.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1AudioInput = {
      description = "Represents the natural speech audio to be processed.",
      id = "GoogleCloudDialogflowCxV3beta1AudioInput",
      properties = {
        audio = {
          description = "The natural language speech audio to be processed. A single request can contain up to 1 minute of speech audio data. The transcribed text cannot contain more than 256 bytes. For non-streaming audio detect intent, both `config` and `audio` must be provided. For streaming audio detect intent, `config` must be provided in the first request and `audio` must be provided in all following requests.",
          format = "byte",
          type = "string",
        },
        config = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1InputAudioConfig",
          description = "Required. Instructs the speech recognizer how to process the speech audio.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1BatchRunTestCasesMetadata = {
      description = "Metadata returned for the TestCases.BatchRunTestCases long running operation.",
      id = "GoogleCloudDialogflowCxV3beta1BatchRunTestCasesMetadata",
      properties = {
        errors = {
          description = "The test errors.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1BatchRunTestCasesResponse = {
      description = "The response message for TestCases.BatchRunTestCases.",
      id = "GoogleCloudDialogflowCxV3beta1BatchRunTestCasesResponse",
      properties = {
        results = {
          description = "The test case results. The detailed conversation turns are empty in this response.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestCaseResult",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ContinuousTestResult = {
      description = "Represents a result from running a test case in an agent environment.",
      id = "GoogleCloudDialogflowCxV3beta1ContinuousTestResult",
      properties = {
        name = {
          description = "The resource name for the continuous test result. Format: `projects//locations//agents//environments//continuousTestResults/`.",
          type = "string",
        },
        result = {
          description = "The result of this continuous test run, i.e. whether all the tests in this continuous test run pass or not.",
          enum = {
            "AGGREGATED_TEST_RESULT_UNSPECIFIED",
            "PASSED",
            "FAILED",
          },
          enumDescriptions = {
            "Not specified. Should never be used.",
            "All the tests passed.",
            "At least one test did not pass.",
          },
          type = "string",
        },
        runTime = {
          description = "Time when the continuous testing run starts.",
          format = "google-datetime",
          type = "string",
        },
        testCaseResults = {
          description = "A list of individual test case results names in this continuous test run.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ConversationSignals = {
      description = "This message is used to hold all the Conversation Signals data, which will be converted to JSON and exported to BigQuery.",
      id = "GoogleCloudDialogflowCxV3beta1ConversationSignals",
      properties = {
        turnSignals = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1TurnSignals",
          description = "Required. Turn signals for the current turn.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ConversationTurn = {
      description = "One interaction between a human and virtual agent. The human provides some input and the virtual agent provides a response.",
      id = "GoogleCloudDialogflowCxV3beta1ConversationTurn",
      properties = {
        userInput = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput",
          description = "The user input.",
        },
        virtualAgentOutput = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput",
          description = "The virtual agent output.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput = {
      description = "The input from the human user.",
      id = "GoogleCloudDialogflowCxV3beta1ConversationTurnUserInput",
      properties = {
        enableSentimentAnalysis = {
          description = "Whether sentiment analysis is enabled.",
          type = "boolean",
        },
        injectedParameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Parameters that need to be injected into the conversation during intent detection.",
          type = "object",
        },
        input = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1QueryInput",
          description = "Supports text input, event input, dtmf input in the test case.",
        },
        isWebhookEnabled = {
          description = "If webhooks should be allowed to trigger in response to the user utterance. Often if parameters are injected, webhooks should not be enabled.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput = {
      description = "The output from the virtual agent.",
      id = "GoogleCloudDialogflowCxV3beta1ConversationTurnVirtualAgentOutput",
      properties = {
        currentPage = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Page",
          description = "The Page on which the utterance was spoken. Only name and displayName will be set.",
        },
        diagnosticInfo = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Required. Input only. The diagnostic info output for the turn. Required to calculate the testing coverage.",
          type = "object",
        },
        differences = {
          description = "Output only. If this is part of a result conversation turn, the list of differences between the original run and the replay for this output, if any.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestRunDifference",
          },
          readOnly = true,
          type = "array",
        },
        sessionParameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "The session parameters available to the bot at this point.",
          type = "object",
        },
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "Response error from the agent in the test result. If set, other output is empty.",
        },
        textResponses = {
          description = "The text responses from the agent for the turn.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageText",
          },
          type = "array",
        },
        triggeredIntent = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Intent",
          description = "The Intent that triggered the response. Only name and displayName will be set.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1CreateDocumentOperationMetadata = {
      description = "Metadata for CreateDocument operation.",
      id = "GoogleCloudDialogflowCxV3beta1CreateDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1CreateVersionOperationMetadata = {
      description = "Metadata associated with the long running operation for Versions.CreateVersion.",
      id = "GoogleCloudDialogflowCxV3beta1CreateVersionOperationMetadata",
      properties = {
        version = {
          description = "Name of the created version. Format: `projects//locations//agents//flows//versions/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1DeleteDocumentOperationMetadata = {
      description = "Metadata for DeleteDocument operation.",
      id = "GoogleCloudDialogflowCxV3beta1DeleteDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1DeployFlowMetadata = {
      description = "Metadata returned for the Environments.DeployFlow long running operation.",
      id = "GoogleCloudDialogflowCxV3beta1DeployFlowMetadata",
      properties = {
        testErrors = {
          description = "Errors of running deployment tests.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1DeployFlowResponse = {
      description = "The response message for Environments.DeployFlow.",
      id = "GoogleCloudDialogflowCxV3beta1DeployFlowResponse",
      properties = {
        deployment = {
          description = "The name of the flow version deployment. Format: `projects//locations//agents// environments//deployments/`.",
          type = "string",
        },
        environment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Environment",
          description = "The updated environment where the flow is deployed.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1DtmfInput = {
      description = "Represents the input for dtmf event.",
      id = "GoogleCloudDialogflowCxV3beta1DtmfInput",
      properties = {
        digits = {
          description = "The dtmf digits.",
          type = "string",
        },
        finishDigit = {
          description = "The finish digit (if any).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1Environment = {
      description = "Represents an environment for an agent. You can create multiple versions of your agent and publish them to separate environments. When you edit an agent, you are editing the draft agent. At any point, you can save the draft agent as an agent version, which is an immutable snapshot of your agent. When you save the draft agent, it is published to the default environment. When you create agent versions, you can publish them to custom environments. You can create a variety of custom environments for testing, development, production, etc.",
      id = "GoogleCloudDialogflowCxV3beta1Environment",
      properties = {
        description = {
          description = "The human-readable description of the environment. The maximum length is 500 characters. If exceeded, the request is rejected.",
          type = "string",
        },
        displayName = {
          description = "Required. The human-readable name of the environment (unique in an agent). Limit of 64 characters.",
          type = "string",
        },
        name = {
          description = "The name of the environment. Format: `projects//locations//agents//environments/`.",
          type = "string",
        },
        testCasesConfig = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1EnvironmentTestCasesConfig",
          description = "The test cases config for continuous tests of this environment.",
        },
        updateTime = {
          description = "Output only. Update time of this environment.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        versionConfigs = {
          description = "Required. A list of configurations for flow versions. You should include version configs for all flows that are reachable from `Start Flow` in the agent. Otherwise, an error will be returned.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1EnvironmentVersionConfig",
          },
          type = "array",
        },
        webhookConfig = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1EnvironmentWebhookConfig",
          description = "The webhook configuration for this environment.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1EnvironmentTestCasesConfig = {
      description = "The configuration for continuous tests.",
      id = "GoogleCloudDialogflowCxV3beta1EnvironmentTestCasesConfig",
      properties = {
        enableContinuousRun = {
          description = "Whether to run test cases in TestCasesConfig.test_cases periodically. Default false. If set to true, run once a day.",
          type = "boolean",
        },
        enablePredeploymentRun = {
          description = "Whether to run test cases in TestCasesConfig.test_cases before deploying a flow version to the environment. Default false.",
          type = "boolean",
        },
        testCases = {
          description = "A list of test case names to run. They should be under the same agent. Format of each test case name: `projects//locations/ /agents//testCases/`",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1EnvironmentVersionConfig = {
      description = "Configuration for the version.",
      id = "GoogleCloudDialogflowCxV3beta1EnvironmentVersionConfig",
      properties = {
        version = {
          description = "Required. Format: projects//locations//agents//flows//versions/.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1EnvironmentWebhookConfig = {
      description = "Configuration for webhooks.",
      id = "GoogleCloudDialogflowCxV3beta1EnvironmentWebhookConfig",
      properties = {
        webhookOverrides = {
          description = "The list of webhooks to override for the agent environment. The webhook must exist in the agent. You can override fields in `generic_web_service` and `service_directory`.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1Webhook",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1EventHandler = {
      description = "An event handler specifies an event that can be handled during a session. When the specified event happens, the following actions are taken in order: * If there is a `trigger_fulfillment` associated with the event, it will be called. * If there is a `target_page` associated with the event, the session will transition into the specified page. * If there is a `target_flow` associated with the event, the session will transition into the specified flow.",
      id = "GoogleCloudDialogflowCxV3beta1EventHandler",
      properties = {
        event = {
          description = "Required. The name of the event to handle.",
          type = "string",
        },
        name = {
          description = "Output only. The unique identifier of this event handler.",
          readOnly = true,
          type = "string",
        },
        targetFlow = {
          description = "The target flow to transition to. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
        targetPage = {
          description = "The target page to transition to. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        triggerFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Fulfillment",
          description = "The fulfillment to call when the event occurs. Handling webhook errors with a fulfillment enabled with webhook could cause infinite loop. It is invalid to specify such fulfillment for a handler handling webhooks.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1EventInput = {
      description = "Represents the event to trigger.",
      id = "GoogleCloudDialogflowCxV3beta1EventInput",
      properties = {
        event = {
          description = "Name of the event.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ExportAgentResponse = {
      description = "The response message for Agents.ExportAgent.",
      id = "GoogleCloudDialogflowCxV3beta1ExportAgentResponse",
      properties = {
        agentContent = {
          description = "Uncompressed raw byte content for agent.",
          format = "byte",
          type = "string",
        },
        agentUri = {
          description = "The URI to a file containing the exported agent. This field is populated only if `agent_uri` is specified in ExportAgentRequest.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ExportFlowResponse = {
      description = "The response message for Flows.ExportFlow.",
      id = "GoogleCloudDialogflowCxV3beta1ExportFlowResponse",
      properties = {
        flowContent = {
          description = "Uncompressed raw byte content for flow.",
          format = "byte",
          type = "string",
        },
        flowUri = {
          description = "The URI to a file containing the exported flow. This field is populated only if `flow_uri` is specified in ExportFlowRequest.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ExportTestCasesMetadata = {
      description = "Metadata returned for the TestCases.ExportTestCases long running operation. This message currently has no fields.",
      id = "GoogleCloudDialogflowCxV3beta1ExportTestCasesMetadata",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ExportTestCasesResponse = {
      description = "The response message for TestCases.ExportTestCases.",
      id = "GoogleCloudDialogflowCxV3beta1ExportTestCasesResponse",
      properties = {
        content = {
          description = "Uncompressed raw byte content for test cases.",
          format = "byte",
          type = "string",
        },
        gcsUri = {
          description = "The URI to a file containing the exported test cases. This field is populated only if `gcs_uri` is specified in ExportTestCasesRequest.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1Form = {
      description = "A form is a data model that groups related parameters that can be collected from the user. The process in which the agent prompts the user and collects parameter values from the user is called form filling. A form can be added to a page. When form filling is done, the filled parameters will be written to the session.",
      id = "GoogleCloudDialogflowCxV3beta1Form",
      properties = {
        parameters = {
          description = "Parameters to collect from the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1FormParameter",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1FormParameter = {
      description = "Represents a form parameter.",
      id = "GoogleCloudDialogflowCxV3beta1FormParameter",
      properties = {
        defaultValue = {
          description = "The default value of an optional parameter. If the parameter is required, the default value will be ignored.",
          type = "any",
        },
        displayName = {
          description = "Required. The human-readable name of the parameter, unique within the form.",
          type = "string",
        },
        entityType = {
          description = "Required. The entity type of the parameter. Format: `projects/-/locations/-/agents/-/entityTypes/` for system entity types (for example, `projects/-/locations/-/agents/-/entityTypes/sys.date`), or `projects//locations//agents//entityTypes/` for developer entity types.",
          type = "string",
        },
        fillBehavior = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior",
          description = "Required. Defines fill behavior for the parameter.",
        },
        isList = {
          description = "Indicates whether the parameter represents a list of values.",
          type = "boolean",
        },
        redact = {
          description = "Indicates whether the parameter content should be redacted in log. If redaction is enabled, the parameter content will be replaced by parameter name during logging. Note: the parameter content is subject to redaction if either parameter level redaction or entity type level redaction is enabled.",
          type = "boolean",
        },
        required = {
          description = "Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior = {
      description = "Configuration for how the filling of a parameter should be handled.",
      id = "GoogleCloudDialogflowCxV3beta1FormParameterFillBehavior",
      properties = {
        initialPromptFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Fulfillment",
          description = "Required. The fulfillment to provide the initial prompt that the agent can present to the user in order to fill the parameter.",
        },
        repromptEventHandlers = {
          description = "The handlers for parameter-level events, used to provide reprompt for the parameter or transition to a different page/flow. The supported events are: * `sys.no-match-`, where N can be from 1 to 6 * `sys.no-match-default` * `sys.no-input-`, where N can be from 1 to 6 * `sys.no-input-default` * `sys.invalid-parameter` `initial_prompt_fulfillment` provides the first prompt for the parameter. If the user's response does not fill the parameter, a no-match/no-input event will be triggered, and the fulfillment associated with the `sys.no-match-1`/`sys.no-input-1` handler (if defined) will be called to provide a prompt. The `sys.no-match-2`/`sys.no-input-2` handler (if defined) will respond to the next no-match/no-input event, and so on. A `sys.no-match-default` or `sys.no-input-default` handler will be used to handle all following no-match/no-input events after all numbered no-match/no-input handlers for the parameter are consumed. A `sys.invalid-parameter` handler can be defined to handle the case where the parameter values have been `invalidated` by webhook. For example, if the user's response fill the parameter, however the parameter was invalidated by webhook, the fulfillment associated with the `sys.invalid-parameter` handler (if defined) will be called to provide a prompt. If the event handler for the corresponding event can't be found on the parameter, `initial_prompt_fulfillment` will be re-prompted.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1EventHandler",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1Fulfillment = {
      description = "A fulfillment can do one or more of the following actions at the same time: * Generate rich message responses. * Set parameter values. * Call the webhook. Fulfillments can be called at various stages in the Page or Form lifecycle. For example, when a DetectIntentRequest drives a session to enter a new page, the page's entry fulfillment can add a static response to the QueryResult in the returning DetectIntentResponse, call the webhook (for example, to load user data from a database), or both.",
      id = "GoogleCloudDialogflowCxV3beta1Fulfillment",
      properties = {
        conditionalCases = {
          description = "Conditional cases for this fulfillment.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases",
          },
          type = "array",
        },
        messages = {
          description = "The list of rich message responses to present to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessage",
          },
          type = "array",
        },
        returnPartialResponses = {
          description = "Whether Dialogflow should return currently queued fulfillment response messages in streaming APIs. If a webhook is specified, it happens before Dialogflow invokes webhook. Warning: 1) This flag only affects streaming API. Responses are still queued and returned once in non-streaming API. 2) The flag can be enabled in any fulfillment but only the first 3 partial responses will be returned. You may only want to apply it to fulfillments that have slow webhooks.",
          type = "boolean",
        },
        setParameterActions = {
          description = "Set parameter values before executing the webhook.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction",
          },
          type = "array",
        },
        tag = {
          description = "The value of this field will be populated in the WebhookRequest `fulfillmentInfo.tag` field by Dialogflow when the associated webhook is called. The tag is typically used by the webhook service to identify which fulfillment is being called, but it could be used for other purposes. This field is required if `webhook` is specified.",
          type = "string",
        },
        webhook = {
          description = "The webhook to call. Format: `projects//locations//agents//webhooks/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases = {
      description = "A list of cascading if-else conditions. Cases are mutually exclusive. The first one with a matching condition is selected, all the rest ignored.",
      id = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases",
      properties = {
        cases = {
          description = "A list of cascading if-else conditions.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase = {
      description = "Each case has a Boolean condition. When it is evaluated to be True, the corresponding messages will be selected and evaluated recursively.",
      id = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCase",
      properties = {
        caseContent = {
          description = "A list of case content.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent",
          },
          type = "array",
        },
        condition = {
          description = "The condition to activate and select this case. Empty means the condition is always true. The condition is evaluated against form parameters or session parameters. See the [conditions reference](https://cloud.google.com/dialogflow/cx/docs/reference/condition).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent = {
      description = "The list of messages or conditional cases to activate for this case.",
      id = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCasesCaseCaseContent",
      properties = {
        additionalCases = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1FulfillmentConditionalCases",
          description = "Additional cases to be evaluated.",
        },
        message = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessage",
          description = "Returned message.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction = {
      description = "Setting a parameter value.",
      id = "GoogleCloudDialogflowCxV3beta1FulfillmentSetParameterAction",
      properties = {
        parameter = {
          description = "Display name of the parameter.",
          type = "string",
        },
        value = {
          description = "The new value of the parameter. A null value clears the parameter.",
          type = "any",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata = {
      description = "Metadata in google::longrunning::Operation for Knowledge operations.",
      id = "GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata",
      properties = {
        state = {
          description = "Required. Output only. The current state of this operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "PENDING",
            "RUNNING",
            "DONE",
          },
          enumDescriptions = {
            "State unspecified.",
            "The operation has been created.",
            "The operation is currently running.",
            "The operation is done, either cancelled or completed.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ImportDocumentsOperationMetadata = {
      description = "Metadata for ImportDocuments operation.",
      id = "GoogleCloudDialogflowCxV3beta1ImportDocumentsOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ImportDocumentsResponse = {
      description = "Response message for Documents.ImportDocuments.",
      id = "GoogleCloudDialogflowCxV3beta1ImportDocumentsResponse",
      properties = {
        warnings = {
          description = "Includes details about skipped documents or any other warnings.",
          items = {
            ["$ref"] = "GoogleRpcStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ImportFlowResponse = {
      description = "The response message for Flows.ImportFlow.",
      id = "GoogleCloudDialogflowCxV3beta1ImportFlowResponse",
      properties = {
        flow = {
          description = "The unique identifier of the new flow. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ImportTestCasesMetadata = {
      description = "Metadata returned for the TestCases.ImportTestCases long running operation.",
      id = "GoogleCloudDialogflowCxV3beta1ImportTestCasesMetadata",
      properties = {
        errors = {
          description = "Errors for failed test cases.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestCaseError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ImportTestCasesResponse = {
      description = "The response message for TestCases.ImportTestCases.",
      id = "GoogleCloudDialogflowCxV3beta1ImportTestCasesResponse",
      properties = {
        names = {
          description = "The unique identifiers of the new test cases. Format: `projects//locations//agents//testCases/`.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1InputAudioConfig = {
      description = "Instructs the speech recognizer on how to process the audio content.",
      id = "GoogleCloudDialogflowCxV3beta1InputAudioConfig",
      properties = {
        audioEncoding = {
          description = "Required. Audio encoding of the audio content to process.",
          enum = {
            "AUDIO_ENCODING_UNSPECIFIED",
            "AUDIO_ENCODING_LINEAR_16",
            "AUDIO_ENCODING_FLAC",
            "AUDIO_ENCODING_MULAW",
            "AUDIO_ENCODING_AMR",
            "AUDIO_ENCODING_AMR_WB",
            "AUDIO_ENCODING_OGG_OPUS",
            "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE",
          },
          enumDescriptions = {
            "Not specified.",
            "Uncompressed 16-bit signed little-endian samples (Linear PCM).",
            "[`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio Codec) is the recommended encoding because it is lossless (therefore recognition is not compromised) and requires only about half the bandwidth of `LINEAR16`. `FLAC` stream encoding supports 16-bit and 24-bit samples, however, not all fields in `STREAMINFO` are supported.",
            "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.",
            "Adaptive Multi-Rate Narrowband codec. `sample_rate_hertz` must be 8000.",
            "Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.",
            "Opus encoded audio frames in Ogg container ([OggOpus](https://wiki.xiph.org/OggOpus)). `sample_rate_hertz` must be 16000.",
            "Although the use of lossy encodings is not recommended, if a very low bitrate encoding is required, `OGG_OPUS` is highly preferred over Speex encoding. The [Speex](https://speex.org/) encoding supported by Dialogflow API has a header byte in each block, as in MIME type `audio/x-speex-with-header-byte`. It is a variant of the RTP Speex encoding defined in [RFC 5574](https://tools.ietf.org/html/rfc5574). The stream is a sequence of blocks, one block per RTP packet. Each block starts with a byte containing the length of the block, in bytes, followed by one or more frames of Speex data, padded to an integral number of bytes (octets) as specified in RFC 5574. In other words, each RTP header is replaced with a single byte containing the block length. Only Speex wideband is supported. `sample_rate_hertz` must be 16000.",
          },
          type = "string",
        },
        enableWordInfo = {
          description = "Optional. If `true`, Dialogflow returns SpeechWordInfo in StreamingRecognitionResult with information about the recognized speech words, e.g. start and end time offsets. If false or unspecified, Speech doesn't return any word-level information.",
          type = "boolean",
        },
        model = {
          description = "Optional. Which Speech model to select for the given request. Select the model best suited to your domain to get best results. If a model is not explicitly specified, then we auto-select a model based on the parameters in the InputAudioConfig. If enhanced speech model is enabled for the agent and an enhanced version of the specified model for the language does not exist, then the speech is recognized using the standard version of the specified model. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics#select-model) for more details.",
          type = "string",
        },
        modelVariant = {
          description = "Optional. Which variant of the Speech model to use.",
          enum = {
            "SPEECH_MODEL_VARIANT_UNSPECIFIED",
            "USE_BEST_AVAILABLE",
            "USE_STANDARD",
            "USE_ENHANCED",
          },
          enumDescriptions = {
            "No model variant specified. In this case Dialogflow defaults to USE_BEST_AVAILABLE.",
            "Use the best available variant of the Speech model that the caller is eligible for. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible for enhanced models.",
            "Use standard model variant even if an enhanced model is available. See the [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) for details about enhanced models.",
            "Use an enhanced model variant: * If an enhanced variant does not exist for the given model and request language, Dialogflow falls back to the standard variant. The [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) describes which models have enhanced variants. * If the API caller isn't eligible for enhanced models, Dialogflow returns an error. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible.",
          },
          type = "string",
        },
        phraseHints = {
          description = "Optional. A list of strings containing words and phrases that the speech recognizer should recognize with higher likelihood. See [the Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints) for more details.",
          items = {
            type = "string",
          },
          type = "array",
        },
        sampleRateHertz = {
          description = "Sample rate (in Hertz) of the audio content sent in the query. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics) for more details.",
          format = "int32",
          type = "integer",
        },
        singleUtterance = {
          description = "Optional. If `false` (default), recognition does not cease until the client closes the stream. If `true`, the recognizer will detect a single spoken utterance in input audio. Recognition ceases when it detects the audio's voice has stopped or paused. In this case, once a detected intent is received, the client should close the stream and start a new request with a new stream as needed. Note: This setting is relevant only for streaming methods.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1Intent = {
      description = "An intent represents a user's intent to interact with a conversational agent. You can provide information for the Dialogflow API to use to match user input to an intent by adding training phrases (i.e., examples of user input) to your intent.",
      id = "GoogleCloudDialogflowCxV3beta1Intent",
      properties = {
        description = {
          description = "Human readable description for better understanding an intent like its scope, content, result etc. Maximum character limit: 140 characters.",
          type = "string",
        },
        displayName = {
          description = "Required. The human-readable name of the intent, unique within the agent.",
          type = "string",
        },
        isFallback = {
          description = "Indicates whether this is a fallback intent. Currently only default fallback intent is allowed in the agent, which is added upon agent creation. Adding training phrases to fallback intent is useful in the case of requests that are mistakenly matched, since training phrases assigned to fallback intents act as negative examples that triggers no-match event.",
          type = "boolean",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "The key/value metadata to label an intent. Labels can contain lowercase letters, digits and the symbols '-' and '_'. International characters are allowed, including letters from unicase alphabets. Keys must start with a letter. Keys and values can be no longer than 63 characters and no more than 128 bytes. Prefix \"sys-\" is reserved for Dialogflow defined labels. Currently allowed Dialogflow defined labels include: * sys-head * sys-contextual The above labels do not require value. \"sys-head\" means the intent is a head intent. \"sys-contextual\" means the intent is a contextual intent.",
          type = "object",
        },
        name = {
          description = "The unique identifier of the intent. Required for the Intents.UpdateIntent method. Intents.CreateIntent populates the name automatically. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
        parameters = {
          description = "The collection of parameters associated with the intent.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1IntentParameter",
          },
          type = "array",
        },
        priority = {
          description = "The priority of this intent. Higher numbers represent higher priorities. - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds to the `Normal` priority in the console. - If the supplied value is negative, the intent is ignored in runtime detect intent requests.",
          format = "int32",
          type = "integer",
        },
        trainingPhrases = {
          description = "The collection of training phrases the agent is trained on to identify the intent.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1IntentInput = {
      description = "Represents the intent to trigger programmatically rather than as a result of natural language processing.",
      id = "GoogleCloudDialogflowCxV3beta1IntentInput",
      properties = {
        intent = {
          description = "Required. The unique identifier of the intent. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1IntentParameter = {
      description = "Represents an intent parameter.",
      id = "GoogleCloudDialogflowCxV3beta1IntentParameter",
      properties = {
        entityType = {
          description = "Required. The entity type of the parameter. Format: `projects/-/locations/-/agents/-/entityTypes/` for system entity types (for example, `projects/-/locations/-/agents/-/entityTypes/sys.date`), or `projects//locations//agents//entityTypes/` for developer entity types.",
          type = "string",
        },
        id = {
          description = "Required. The unique identifier of the parameter. This field is used by training phrases to annotate their parts.",
          type = "string",
        },
        isList = {
          description = "Indicates whether the parameter represents a list of values.",
          type = "boolean",
        },
        redact = {
          description = "Indicates whether the parameter content should be redacted in log. If redaction is enabled, the parameter content will be replaced by parameter name during logging. Note: the parameter content is subject to redaction if either parameter level redaction or entity type level redaction is enabled.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase = {
      description = "Represents an example that the agent is trained on to identify the intent.",
      id = "GoogleCloudDialogflowCxV3beta1IntentTrainingPhrase",
      properties = {
        id = {
          description = "Output only. The unique identifier of the training phrase.",
          type = "string",
        },
        parts = {
          description = "Required. The ordered list of training phrase parts. The parts are concatenated in order to form the training phrase. Note: The API does not automatically annotate training phrases like the Dialogflow Console does. Note: Do not forget to include whitespace at part boundaries, so the training phrase is well formatted when the parts are concatenated. If the training phrase does not need to be annotated with parameters, you just need a single part with only the Part.text field set. If you want to annotate the training phrase, you must create multiple parts, where the fields of each part are populated in one of two ways: - `Part.text` is set to a part of the phrase that has no parameters. - `Part.text` is set to a part of the phrase that you want to annotate, and the `parameter_id` field is set.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart",
          },
          type = "array",
        },
        repeatCount = {
          description = "Indicates how many times this example was added to the intent.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart = {
      description = "Represents a part of a training phrase.",
      id = "GoogleCloudDialogflowCxV3beta1IntentTrainingPhrasePart",
      properties = {
        parameterId = {
          description = "The parameter used to annotate this part of the training phrase. This field is required for annotated parts of the training phrase.",
          type = "string",
        },
        text = {
          description = "Required. The text for this part.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1Page = {
      description = "A Dialogflow CX conversation (session) can be described and visualized as a state machine. The states of a CX session are represented by pages. For each flow, you define many pages, where your combined pages can handle a complete conversation on the topics the flow is designed for. At any given moment, exactly one page is the current page, the current page is considered active, and the flow associated with that page is considered active. Every flow has a special start page. When a flow initially becomes active, the start page page becomes the current page. For each conversational turn, the current page will either stay the same or transition to another page. You configure each page to collect information from the end-user that is relevant for the conversational state represented by the page. For more information, see the [Page guide](https://cloud.google.com/dialogflow/cx/docs/concept/page).",
      id = "GoogleCloudDialogflowCxV3beta1Page",
      properties = {
        displayName = {
          description = "Required. The human-readable name of the page, unique within the flow.",
          type = "string",
        },
        entryFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Fulfillment",
          description = "The fulfillment to call when the session is entering the page.",
        },
        eventHandlers = {
          description = "Handlers associated with the page to handle events such as webhook errors, no match or no input.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1EventHandler",
          },
          type = "array",
        },
        form = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Form",
          description = "The form associated with the page, used for collecting parameters relevant to the page.",
        },
        name = {
          description = "The unique identifier of the page. Required for the Pages.UpdatePage method. Pages.CreatePage populates the name automatically. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        transitionRouteGroups = {
          description = "Ordered list of `TransitionRouteGroups` associated with the page. Transition route groups must be unique within a page. * If multiple transition routes within a page scope refer to the same intent, then the precedence order is: page's transition route -> page's transition route group -> flow's transition routes. * If multiple transition route groups within a page contain the same intent, then the first group in the ordered list takes precedence. Format:`projects//locations//agents//flows//transitionRouteGroups/`.",
          items = {
            type = "string",
          },
          type = "array",
        },
        transitionRoutes = {
          description = "A list of transitions for the transition rules of this page. They route the conversation to another page in the same flow, or another flow. When we are in a certain page, the TransitionRoutes are evalauted in the following order: * TransitionRoutes defined in the page with intent specified. * TransitionRoutes defined in the transition route groups with intent specified. * TransitionRoutes defined in flow with intent specified. * TransitionRoutes defined in the transition route groups with intent specified. * TransitionRoutes defined in the page with only condition specified. * TransitionRoutes defined in the transition route groups with only condition specified.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TransitionRoute",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1PageInfo = {
      description = "Represents page information communicated to and from the webhook.",
      id = "GoogleCloudDialogflowCxV3beta1PageInfo",
      properties = {
        currentPage = {
          description = "Always present for WebhookRequest. Ignored for WebhookResponse. The unique identifier of the current page. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        displayName = {
          description = "Always present for WebhookRequest. Ignored for WebhookResponse. The display name of the current page.",
          type = "string",
        },
        formInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1PageInfoFormInfo",
          description = "Optional for both WebhookRequest and WebhookResponse. Information about the form.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1PageInfoFormInfo = {
      description = "Represents form information.",
      id = "GoogleCloudDialogflowCxV3beta1PageInfoFormInfo",
      properties = {
        parameterInfo = {
          description = "Optional for both WebhookRequest and WebhookResponse. The parameters contained in the form. Note that the webhook cannot add or remove any form parameter.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo = {
      description = "Represents parameter information.",
      id = "GoogleCloudDialogflowCxV3beta1PageInfoFormInfoParameterInfo",
      properties = {
        displayName = {
          description = "Always present for WebhookRequest. Required for WebhookResponse. The human-readable name of the parameter, unique within the form. This field cannot be modified by the webhook.",
          type = "string",
        },
        justCollected = {
          description = "Optional for WebhookRequest. Ignored for WebhookResponse. Indicates if the parameter value was just collected on the last conversation turn.",
          type = "boolean",
        },
        required = {
          description = "Optional for both WebhookRequest and WebhookResponse. Indicates whether the parameter is required. Optional parameters will not trigger prompts; however, they are filled if the user specifies them. Required parameters must be filled before form filling concludes.",
          type = "boolean",
        },
        state = {
          description = "Always present for WebhookRequest. Required for WebhookResponse. The state of the parameter. This field can be set to INVALID by the webhook to invalidate the parameter; other values set by the webhook will be ignored.",
          enum = {
            "PARAMETER_STATE_UNSPECIFIED",
            "EMPTY",
            "INVALID",
            "FILLED",
          },
          enumDescriptions = {
            "Not specified. This value should be never used.",
            "Indicates that the parameter does not have a value.",
            "Indicates that the parameter value is invalid. This field can be used by the webhook to invalidate the parameter and ask the server to collect it from the user again.",
            "Indicates that the parameter has a value.",
          },
          type = "string",
        },
        value = {
          description = "Optional for both WebhookRequest and WebhookResponse. The value of the parameter. This field can be set by the webhook to change the parameter value.",
          type = "any",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1QueryInput = {
      description = "Represents the query input. It can contain one of: 1. A conversational query in the form of text. 2. An intent query that specifies which intent to trigger. 3. Natural language speech audio to be processed. 4. An event to be triggered. ",
      id = "GoogleCloudDialogflowCxV3beta1QueryInput",
      properties = {
        audio = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1AudioInput",
          description = "The natural language speech audio to be processed.",
        },
        dtmf = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1DtmfInput",
          description = "The DTMF event to be handled.",
        },
        event = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1EventInput",
          description = "The event to be triggered.",
        },
        intent = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1IntentInput",
          description = "The intent to be triggered.",
        },
        languageCode = {
          description = "Required. The language of the input. See [Language Support](https://cloud.google.com/dialogflow/cx/docs/reference/language) for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.",
          type = "string",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1TextInput",
          description = "The natural language text to be processed.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ReloadDocumentOperationMetadata = {
      description = "Metadata for ReloadDocument operation.",
      id = "GoogleCloudDialogflowCxV3beta1ReloadDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessage = {
      description = "Represents a response message that can be returned by a conversational agent. Response messages are also used for output audio synthesis. The approach is as follows: * If at least one OutputAudioText response is present, then all OutputAudioText responses are linearly concatenated, and the result is used for output audio synthesis. * If the OutputAudioText responses are a mixture of text and SSML, then the concatenated result is treated as SSML; otherwise, the result is treated as either text or SSML as appropriate. The agent designer should ideally use either text or SSML consistently throughout the bot design. * Otherwise, all Text responses are linearly concatenated, and the result is used for output audio synthesis. This approach allows for more sophisticated user experience scenarios, where the text displayed to the user may differ from what is heard.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessage",
      properties = {
        channel = {
          description = "The channel which the response is associated with. Clients can specify the channel via QueryParameters.channel, and only associated channel response will be returned.",
          type = "string",
        },
        conversationSuccess = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageConversationSuccess",
          description = "Indicates that the conversation succeeded.",
        },
        endInteraction = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction",
          description = "Output only. A signal that indicates the interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only when the conversation reaches `END_SESSION` page. It is not supposed to be defined by the user. It's guaranteed that there is at most one such message in each response.",
          readOnly = true,
        },
        liveAgentHandoff = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageLiveAgentHandoff",
          description = "Hands off conversation to a human agent.",
        },
        mixedAudio = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio",
          description = "Output only. An audio response message composed of both the synthesized Dialogflow agent responses and responses defined via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.",
          readOnly = true,
        },
        outputAudioText = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText",
          description = "A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Returns a response containing a custom, platform-specific payload.",
          type = "object",
        },
        playAudio = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio",
          description = "Signal that the client should play an audio clip hosted at a client-specific URI. Dialogflow uses this to construct mixed_audio. However, Dialogflow itself does not try to read or process the URI in any way.",
        },
        telephonyTransferCall = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageTelephonyTransferCall",
          description = "A signal that the client should transfer the phone call connected to this agent to a third-party endpoint.",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageText",
          description = "Returns a text response.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageConversationSuccess = {
      description = "Indicates that the conversation succeeded, i.e., the bot handled the issue that the customer talked to it about. Dialogflow only uses this to determine which conversations should be counted as successful and doesn't process the metadata in this message in any way. Note that Dialogflow also considers conversations that get to the conversation end page as successful even if they don't return ConversationSuccess. You may set this, for example: * In the entry_fulfillment of a Page if entering the page indicates that the conversation succeeded. * In a webhook response when you determine that you handled the customer issue.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageConversationSuccess",
      properties = {
        metadata = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Custom metadata. Dialogflow doesn't impose any structure on this.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction = {
      description = "Indicates that interaction with the Dialogflow agent has ended. This message is generated by Dialogflow only and not supposed to be defined by the user.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageEndInteraction",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageLiveAgentHandoff = {
      description = "Indicates that the conversation should be handed off to a live agent. Dialogflow only uses this to determine which conversations were handed off to a human agent for measurement purposes. What else to do with this signal is up to you and your handoff procedures. You may set this, for example: * In the entry_fulfillment of a Page if entering the page indicates something went extremely wrong in the conversation. * In a webhook response when you determine that the customer issue can only be handled by a human.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageLiveAgentHandoff",
      properties = {
        metadata = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Custom metadata for your handoff procedure. Dialogflow doesn't impose any structure on this.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio = {
      description = "Represents an audio message that is composed of both segments synthesized from the Dialogflow agent prompts and ones hosted externally at the specified URIs. The external URIs are specified via play_audio. This message is generated by Dialogflow only and not supposed to be defined by the user.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudio",
      properties = {
        segments = {
          description = "Segments this audio response is composed of.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment = {
      description = "Represents one segment of audio.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageMixedAudioSegment",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this segment can be interrupted by the end user's speech and the client should then start the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        audio = {
          description = "Raw audio synthesized from the Dialogflow agent's response using the output config specified in the request.",
          format = "byte",
          type = "string",
        },
        uri = {
          description = "Client-specific URI that points to an audio clip accessible to the client. Dialogflow does not impose any validation on it.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText = {
      description = "A text or ssml response that is preferentially used for TTS output audio synthesis, as described in the comment on the ResponseMessage message.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageOutputAudioText",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        ssml = {
          description = "The SSML text to be synthesized. For more information, see [SSML](/speech/text-to-speech/docs/ssml).",
          type = "string",
        },
        text = {
          description = "The raw text to be synthesized.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio = {
      description = "Specifies an audio clip to be played by the client as part of the response.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessagePlayAudio",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        audioUri = {
          description = "Required. URI of the audio clip. Dialogflow does not impose any validation on this value. It is specific to the client that reads it.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageTelephonyTransferCall = {
      description = "Represents the signal that telles the client to transfer the phone call connected to the agent to a third-party endpoint.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageTelephonyTransferCall",
      properties = {
        phoneNumber = {
          description = "Transfer the call to a phone number in [E.164 format](https://en.wikipedia.org/wiki/E.164).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1ResponseMessageText = {
      description = "The text response message.",
      id = "GoogleCloudDialogflowCxV3beta1ResponseMessageText",
      properties = {
        allowPlaybackInterruption = {
          description = "Output only. Whether the playback of this message can be interrupted by the end user's speech and the client can then starts the next Dialogflow request.",
          readOnly = true,
          type = "boolean",
        },
        text = {
          description = "Required. A collection of text responses.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1RunContinuousTestMetadata = {
      description = "Metadata returned for the Environments.RunContinuousTest long running operation.",
      id = "GoogleCloudDialogflowCxV3beta1RunContinuousTestMetadata",
      properties = {
        errors = {
          description = "The test errors.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1RunContinuousTestResponse = {
      description = "The response message for Environments.RunContinuousTest.",
      id = "GoogleCloudDialogflowCxV3beta1RunContinuousTestResponse",
      properties = {
        continuousTestResult = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1ContinuousTestResult",
          description = "The result for a continuous test run.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1RunTestCaseMetadata = {
      description = "Metadata returned for the TestCases.RunTestCase long running operation. This message currently has no fields.",
      id = "GoogleCloudDialogflowCxV3beta1RunTestCaseMetadata",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1RunTestCaseResponse = {
      description = "The response message for TestCases.RunTestCase.",
      id = "GoogleCloudDialogflowCxV3beta1RunTestCaseResponse",
      properties = {
        result = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestCaseResult",
          description = "The result.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1SessionInfo = {
      description = "Represents session information communicated to and from the webhook.",
      id = "GoogleCloudDialogflowCxV3beta1SessionInfo",
      properties = {
        parameters = {
          additionalProperties = {
            type = "any",
          },
          description = "Optional for WebhookRequest. Optional for WebhookResponse. All parameters collected from forms and intents during the session. Parameters can be created, updated, or removed by the webhook. To remove a parameter from the session, the webhook should explicitly set the parameter value to null in WebhookResponse. The map is keyed by parameters' display names.",
          type = "object",
        },
        session = {
          description = "Always present for WebhookRequest. Ignored for WebhookResponse. The unique identifier of the session. This field can be used by the webhook to identify a session. Format: `projects//locations//agents//sessions/` or `projects//locations//agents//environments//sessions/` if environment is specified.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TestCase = {
      description = "Represents a test case.",
      id = "GoogleCloudDialogflowCxV3beta1TestCase",
      properties = {
        creationTime = {
          description = "Output only. When the test was created.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Required. The human-readable name of the test case, unique within the agent. Limit of 200 characters.",
          type = "string",
        },
        lastTestResult = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestCaseResult",
          description = "The latest test result.",
        },
        name = {
          description = "The unique identifier of the test case. TestCases.CreateTestCase will populate the name automatically. Otherwise use format: `projects//locations//agents/ /testCases/`.",
          type = "string",
        },
        notes = {
          description = "Additional freeform notes about the test case. Limit of 400 characters.",
          type = "string",
        },
        tags = {
          description = "Tags are short descriptions that users may apply to test cases for organizational and filtering purposes. Each tag should start with \"#\" and has a limit of 30 characters.",
          items = {
            type = "string",
          },
          type = "array",
        },
        testCaseConversationTurns = {
          description = "The conversation turns uttered when the test case was created, in chronological order. These include the canonical set of agent utterances that should occur when the agent is working properly.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ConversationTurn",
          },
          type = "array",
        },
        testConfig = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestConfig",
          description = "Config for the test case.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TestCaseError = {
      description = "Error info for importing a test.",
      id = "GoogleCloudDialogflowCxV3beta1TestCaseError",
      properties = {
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "The status associated with the test case.",
        },
        testCase = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1TestCase",
          description = "The test case.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TestCaseResult = {
      description = "Represents a result from running a test case in an agent environment.",
      id = "GoogleCloudDialogflowCxV3beta1TestCaseResult",
      properties = {
        conversationTurns = {
          description = "The conversation turns uttered during the test case replay in chronological order.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ConversationTurn",
          },
          type = "array",
        },
        environment = {
          description = "Environment where the test was run. If not set, it indicates the draft environment.",
          type = "string",
        },
        name = {
          description = "The resource name for the test case result. Format: `projects//locations//agents//testCases/ /results/`.",
          type = "string",
        },
        testResult = {
          description = "Whether the test case passed in the agent environment.",
          enum = {
            "TEST_RESULT_UNSPECIFIED",
            "PASSED",
            "FAILED",
          },
          enumDescriptions = {
            "Not specified. Should never be used.",
            "The test passed.",
            "The test did not pass.",
          },
          type = "string",
        },
        testTime = {
          description = "The time that the test was run.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TestConfig = {
      description = "Represents configurations for a test case.",
      id = "GoogleCloudDialogflowCxV3beta1TestConfig",
      properties = {
        flow = {
          description = "Flow name to start the test case with. Format: `projects//locations//agents//flows/`. Only one of `flow` and `page` should be set to indicate the starting point of the test case. If both are set, `page` takes precedence over `flow`. If neither is set, the test case will start with start page on the default start flow.",
          type = "string",
        },
        page = {
          description = "The page to start the test case with. Format: `projects//locations//agents//flows//pages/`. Only one of `flow` and `page` should be set to indicate the starting point of the test case. If both are set, `page` takes precedence over `flow`. If neither is set, the test case will start with start page on the default start flow.",
          type = "string",
        },
        trackingParameters = {
          description = "Session parameters to be compared when calculating differences.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TestError = {
      description = "Error info for running a test.",
      id = "GoogleCloudDialogflowCxV3beta1TestError",
      properties = {
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "The status associated with the test.",
        },
        testCase = {
          description = "The test case resource name.",
          type = "string",
        },
        testTime = {
          description = "The timestamp when the test was completed.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TestRunDifference = {
      description = "The description of differences between original and replayed agent output.",
      id = "GoogleCloudDialogflowCxV3beta1TestRunDifference",
      properties = {
        description = {
          description = "A description of the diff, showing the actual output vs expected output.",
          type = "string",
        },
        type = {
          description = "The type of diff.",
          enum = {
            "DIFF_TYPE_UNSPECIFIED",
            "INTENT",
            "PAGE",
            "PARAMETERS",
            "UTTERANCE",
          },
          enumDescriptions = {
            "Should never be used.",
            "The intent.",
            "The page.",
            "The parameters.",
            "The message utterance.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TextInput = {
      description = "Represents the natural language text to be processed.",
      id = "GoogleCloudDialogflowCxV3beta1TextInput",
      properties = {
        text = {
          description = "Required. The UTF-8 encoded natural language text to be processed. Text length must not exceed 256 characters.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TransitionRoute = {
      description = "A transition route specifies a intent that can be matched and/or a data condition that can be evaluated during a session. When a specified transition is matched, the following actions are taken in order: * If there is a `trigger_fulfillment` associated with the transition, it will be called. * If there is a `target_page` associated with the transition, the session will transition into the specified page. * If there is a `target_flow` associated with the transition, the session will transition into the specified flow.",
      id = "GoogleCloudDialogflowCxV3beta1TransitionRoute",
      properties = {
        condition = {
          description = "The condition to evaluate against form parameters or session parameters. See the [conditions reference](https://cloud.google.com/dialogflow/cx/docs/reference/condition). At least one of `intent` or `condition` must be specified. When both `intent` and `condition` are specified, the transition can only happen when both are fulfilled.",
          type = "string",
        },
        intent = {
          description = "The unique identifier of an Intent. Format: `projects//locations//agents//intents/`. Indicates that the transition can only happen when the given intent is matched. At least one of `intent` or `condition` must be specified. When both `intent` and `condition` are specified, the transition can only happen when both are fulfilled.",
          type = "string",
        },
        name = {
          description = "Output only. The unique identifier of this transition route.",
          readOnly = true,
          type = "string",
        },
        targetFlow = {
          description = "The target flow to transition to. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
        targetPage = {
          description = "The target page to transition to. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        triggerFulfillment = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1Fulfillment",
          description = "The fulfillment to call when the condition is satisfied. At least one of `trigger_fulfillment` and `target` must be specified. When both are defined, `trigger_fulfillment` is executed first.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1TurnSignals = {
      description = "Collection of all signals that were extracted for a single turn of the conversation.",
      id = "GoogleCloudDialogflowCxV3beta1TurnSignals",
      properties = {
        agentEscalated = {
          description = "Whether agent responded with LiveAgentHandoff fulfillment.",
          type = "boolean",
        },
        dtmfUsed = {
          description = "Whether user was using DTMF input.",
          type = "boolean",
        },
        failureReasons = {
          description = "Failure reasons of the turn.",
          items = {
            enum = {
              "FAILURE_REASON_UNSPECIFIED",
              "FAILED_INTENT",
              "FAILED_WEBHOOK",
            },
            enumDescriptions = {
              "Failure reason is not assigned.",
              "Whether NLU failed to recognize user intent.",
              "Whether webhook failed during the turn.",
            },
            type = "string",
          },
          type = "array",
        },
        noMatch = {
          description = "Whether NLU predicted NO_MATCH.",
          type = "boolean",
        },
        noUserInput = {
          description = "Whether user provided no input.",
          type = "boolean",
        },
        reachedEndPage = {
          description = "Whether turn resulted in End Session page.",
          type = "boolean",
        },
        userEscalated = {
          description = "Whether user was specifically asking for a live agent.",
          type = "boolean",
        },
        webhookStatuses = {
          description = "Human-readable statuses of the webhooks triggered during this turn.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1UpdateDocumentOperationMetadata = {
      description = "Metadata for UpdateDocument operation.",
      id = "GoogleCloudDialogflowCxV3beta1UpdateDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1Webhook = {
      description = "Webhooks host the developer's business logic. During a session, webhooks allow the developer to use the data extracted by Dialogflow's natural language processing to generate dynamic responses, validate collected data, or trigger actions on the backend.",
      id = "GoogleCloudDialogflowCxV3beta1Webhook",
      properties = {
        disabled = {
          description = "Indicates whether the webhook is disabled.",
          type = "boolean",
        },
        displayName = {
          description = "Required. The human-readable name of the webhook, unique within the agent.",
          type = "string",
        },
        genericWebService = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookGenericWebService",
          description = "Configuration for a generic web service.",
        },
        name = {
          description = "The unique identifier of the webhook. Required for the Webhooks.UpdateWebhook method. Webhooks.CreateWebhook populates the name automatically. Format: `projects//locations//agents//webhooks/`.",
          type = "string",
        },
        serviceDirectory = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookServiceDirectoryConfig",
          description = "Configuration for a [Service Directory](https://cloud.google.com/service-directory) service.",
        },
        timeout = {
          description = "Webhook execution timeout. Execution is considered failed if Dialogflow doesn't receive a response from webhook at the end of the timeout period. Defaults to 5 seconds, maximum allowed timeout is 30 seconds.",
          format = "google-duration",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookGenericWebService = {
      description = "Represents configuration for a generic web service.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookGenericWebService",
      properties = {
        allowedCaCerts = {
          description = "Optional. Specifies a list of allowed custom CA certificates (in DER format) for HTTPS verification. This overrides the default SSL trust store. If this is empty or unspecified, Dialogflow will use Google's default trust store to verify certificates. N.B. Make sure the HTTPS server certificates are signed with \"subject alt name\". For instance a certificate can be self-signed using the following command, ``` openssl x509 -req -days 200 -in example.com.csr \\ -signkey example.com.key \\ -out example.com.crt \\ -extfile <(printf \"\\nsubjectAltName='DNS:www.example.com'\") ```",
          items = {
            format = "byte",
            type = "string",
          },
          type = "array",
        },
        password = {
          description = "The password for HTTP Basic authentication.",
          type = "string",
        },
        requestHeaders = {
          additionalProperties = {
            type = "string",
          },
          description = "The HTTP request headers to send together with webhook requests.",
          type = "object",
        },
        uri = {
          description = "Required. The webhook URI for receiving POST requests. It must use https protocol.",
          type = "string",
        },
        username = {
          description = "The user name for HTTP Basic authentication.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookRequest = {
      description = "The request message for a webhook call. The request is sent as a JSON object and the field names will be presented in camel cases. You may see undocumented fields in an actual request. These fields are used internally by Dialogflow and should be ignored.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookRequest",
      properties = {
        detectIntentResponseId = {
          description = "Always present. The unique identifier of the DetectIntentResponse that will be returned to the API caller.",
          type = "string",
        },
        fulfillmentInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo",
          description = "Always present. Information about the fulfillment that triggered this webhook call.",
        },
        intentInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo",
          description = "Information about the last matched intent.",
        },
        languageCode = {
          description = "The language code specified in the original request.",
          type = "string",
        },
        messages = {
          description = "The list of rich message responses to present to the user. Webhook can choose to append or replace this list in WebhookResponse.fulfillment_response;",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessage",
          },
          type = "array",
        },
        pageInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1PageInfo",
          description = "Information about page status.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Custom data set in QueryParameters.payload.",
          type = "object",
        },
        sentimentAnalysisResult = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookRequestSentimentAnalysisResult",
          description = "The sentiment analysis result of the current user request. The field is filled when sentiment analysis is configured to be enabled for the request.",
        },
        sessionInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1SessionInfo",
          description = "Information about session status.",
        },
        text = {
          description = "If natural language text was provided as input, this field will contain a copy of the text.",
          type = "string",
        },
        transcript = {
          description = "If natural language speech audio was provided as input, this field will contain the transcript for the audio.",
          type = "string",
        },
        triggerEvent = {
          description = "If an event was provided as input, this field will contain the name of the event.",
          type = "string",
        },
        triggerIntent = {
          description = "If an intent was provided as input, this field will contain a copy of the intent identifier. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo = {
      description = "Represents fulfillment information communicated to the webhook.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookRequestFulfillmentInfo",
      properties = {
        tag = {
          description = "Always present. The value of the Fulfillment.tag field will be populated in this field by Dialogflow when the associated webhook is called. The tag is typically used by the webhook service to identify which fulfillment is being called, but it could be used for other purposes.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo = {
      description = "Represents intent information communicated to the webhook.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfo",
      properties = {
        confidence = {
          description = "The confidence of the matched intent. Values range from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        displayName = {
          description = "Always present. The display name of the last matched intent.",
          type = "string",
        },
        lastMatchedIntent = {
          description = "Always present. The unique identifier of the last matched intent. Format: `projects//locations//agents//intents/`.",
          type = "string",
        },
        parameters = {
          additionalProperties = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue",
          },
          description = "Parameters identified as a result of intent matching. This is a map of the name of the identified parameter to the value of the parameter identified from the user's utterance. All parameters defined in the matched intent that are identified will be surfaced here.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue = {
      description = "Represents a value for an intent parameter.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookRequestIntentInfoIntentParameterValue",
      properties = {
        originalValue = {
          description = "Always present. Original text value extracted from user utterance.",
          type = "string",
        },
        resolvedValue = {
          description = "Always present. Structured value for the parameter extracted from user utterance.",
          type = "any",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookRequestSentimentAnalysisResult = {
      description = "Represents the result of sentiment analysis.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookRequestSentimentAnalysisResult",
      properties = {
        magnitude = {
          description = "A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).",
          format = "float",
          type = "number",
        },
        score = {
          description = "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookResponse = {
      description = "The response message for a webhook call.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookResponse",
      properties = {
        fulfillmentResponse = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookResponseFulfillmentResponse",
          description = "The fulfillment response to send to the user. This field can be omitted by the webhook if it does not intend to send any response to the user.",
        },
        pageInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1PageInfo",
          description = "Information about page status. This field can be omitted by the webhook if it does not intend to modify page status.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Value to append directly to QueryResult.webhook_payloads.",
          type = "object",
        },
        sessionInfo = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1SessionInfo",
          description = "Information about session status. This field can be omitted by the webhook if it does not intend to modify session status.",
        },
        targetFlow = {
          description = "The target flow to transition to. Format: `projects//locations//agents//flows/`.",
          type = "string",
        },
        targetPage = {
          description = "The target page to transition to. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookResponseFulfillmentResponse = {
      description = "Represents a fulfillment response to the user.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookResponseFulfillmentResponse",
      properties = {
        mergeBehavior = {
          description = "Merge behavior for `messages`.",
          enum = {
            "MERGE_BEHAVIOR_UNSPECIFIED",
            "APPEND",
            "REPLACE",
          },
          enumDescriptions = {
            "Not specified. `APPEND` will be used.",
            "`messages` will be appended to the list of messages waiting to be sent to the user.",
            "`messages` will replace the list of messages waiting to be sent to the user.",
          },
          type = "string",
        },
        messages = {
          description = "The list of rich message responses to present to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowCxV3beta1ResponseMessage",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowCxV3beta1WebhookServiceDirectoryConfig = {
      description = "Represents configuration for a [Service Directory](https://cloud.google.com/service-directory) service.",
      id = "GoogleCloudDialogflowCxV3beta1WebhookServiceDirectoryConfig",
      properties = {
        genericWebService = {
          ["$ref"] = "GoogleCloudDialogflowCxV3beta1WebhookGenericWebService",
          description = "Generic Service configuration of this webhook.",
        },
        service = {
          description = "Required. The name of [Service Directory](https://cloud.google.com/service-directory) service. Format: `projects//locations//namespaces//services/`. `Location ID` of the service directory must be the same as the location of the agent.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Agent = {
      description = "A Dialogflow agent is a virtual agent that handles conversations with your end-users. It is a natural language understanding module that understands the nuances of human language. Dialogflow translates end-user text or audio during a conversation to structured data that your apps and services can understand. You design and build a Dialogflow agent to handle the types of conversations required for your system. For more information about agents, see the [Agent guide](https://cloud.google.com/dialogflow/docs/agents-overview). ",
      id = "GoogleCloudDialogflowV2Agent",
      properties = {
        apiVersion = {
          description = "Optional. API version displayed in Dialogflow console. If not specified, V2 API is assumed. Clients are free to query different service endpoints for different API versions. However, bots connectors and webhook calls will follow the specified API version.",
          enum = {
            "API_VERSION_UNSPECIFIED",
            "API_VERSION_V1",
            "API_VERSION_V2",
            "API_VERSION_V2_BETA_1",
          },
          enumDescriptions = {
            "Not specified.",
            "Legacy V1 API.",
            "V2 API.",
            "V2beta1 API.",
          },
          type = "string",
        },
        avatarUri = {
          description = "Optional. The URI of the agent's avatar. Avatars are used throughout the Dialogflow console and in the self-hosted [Web Demo](https://cloud.google.com/dialogflow/docs/integrations/web-demo) integration.",
          type = "string",
        },
        classificationThreshold = {
          description = "Optional. To filter out false positive results and still get variety in matched natural language inputs for your agent, you can tune the machine learning classification threshold. If the returned score value is less than the threshold value, then a fallback intent will be triggered or, if there are no fallback intents defined, no intent will be triggered. The score values range from 0.0 (completely uncertain) to 1.0 (completely certain). If set to 0.0, the default of 0.3 is used.",
          format = "float",
          type = "number",
        },
        defaultLanguageCode = {
          description = "Required. The default language of the agent as a language tag. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes. This field cannot be set by the `Update` method.",
          type = "string",
        },
        description = {
          description = "Optional. The description of this agent. The maximum length is 500 characters. If exceeded, the request is rejected.",
          type = "string",
        },
        displayName = {
          description = "Required. The name of this agent.",
          type = "string",
        },
        enableLogging = {
          description = "Optional. Determines whether this agent should log conversation queries.",
          type = "boolean",
        },
        matchMode = {
          description = "Optional. Determines how intents are detected from user queries.",
          enum = {
            "MATCH_MODE_UNSPECIFIED",
            "MATCH_MODE_HYBRID",
            "MATCH_MODE_ML_ONLY",
          },
          enumDescriptions = {
            "Not specified.",
            "Best for agents with a small number of examples in intents and/or wide use of templates syntax and composite entities.",
            "Can be used for agents with a large number of examples in intents, especially the ones using @sys.any or very large custom entities.",
          },
          type = "string",
        },
        parent = {
          description = "Required. The project of this agent. Format: `projects/`.",
          type = "string",
        },
        supportedLanguageCodes = {
          description = "Optional. The list of all languages supported by this agent (except for the `default_language_code`).",
          items = {
            type = "string",
          },
          type = "array",
        },
        tier = {
          description = "Optional. The agent tier. If not specified, TIER_STANDARD is assumed.",
          enum = {
            "TIER_UNSPECIFIED",
            "TIER_STANDARD",
            "TIER_ENTERPRISE",
            "TIER_ENTERPRISE_PLUS",
          },
          enumDescriptions = {
            "Not specified. This value should never be used.",
            "Trial Edition, previously known as Standard Edition.",
            "Essentials Edition, previously known as Enterprise Essential Edition.",
            "Essentials Edition (same as TIER_ENTERPRISE), previously known as Enterprise Plus Edition.",
          },
          type = "string",
        },
        timeZone = {
          description = "Required. The time zone of this agent from the [time zone database](https://www.iana.org/time-zones), e.g., America/New_York, Europe/Paris.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AgentAssistantFeedback = {
      description = "Detail feedback of Agent Assist result.",
      id = "GoogleCloudDialogflowV2AgentAssistantFeedback",
      properties = {
        answerRelevance = {
          description = "Optional. Whether or not the suggested answer is relevant. For example: * Query: \"Can I change my mailing address?\" * Suggested document says: \"Items must be returned/exchanged within 60 days of the purchase date.\" * answer_relevance: AnswerRelevance.IRRELEVANT",
          enum = {
            "ANSWER_RELEVANCE_UNSPECIFIED",
            "IRRELEVANT",
            "RELEVANT",
          },
          enumDescriptions = {
            "Answer relevance unspecified.",
            "Answer is irrelevant to query.",
            "Answer is relevant to query.",
          },
          type = "string",
        },
        documentCorrectness = {
          description = "Optional. Whether or not the information in the document is correct. For example: * Query: \"Can I return the package in 2 days once received?\" * Suggested document says: \"Items must be returned/exchanged within 60 days of the purchase date.\" * Ground truth: \"No return or exchange is allowed.\" * [document_correctness]: INCORRECT",
          enum = {
            "DOCUMENT_CORRECTNESS_UNSPECIFIED",
            "INCORRECT",
            "CORRECT",
          },
          enumDescriptions = {
            "Document correctness unspecified.",
            "Information in document is incorrect.",
            "Information in document is correct.",
          },
          type = "string",
        },
        documentEfficiency = {
          description = "Optional. Whether or not the suggested document is efficient. For example, if the document is poorly written, hard to understand, hard to use or too long to find useful information, document_efficiency is DocumentEfficiency.INEFFICIENT.",
          enum = {
            "DOCUMENT_EFFICIENCY_UNSPECIFIED",
            "INEFFICIENT",
            "EFFICIENT",
          },
          enumDescriptions = {
            "Document efficiency unspecified.",
            "Document is inefficient.",
            "Document is efficient.",
          },
          type = "string",
        },
        summarizationFeedback = {
          ["$ref"] = "GoogleCloudDialogflowV2AgentAssistantFeedbackSummarizationFeedback",
          description = "Optional. Feedback for conversation summarization.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AgentAssistantFeedbackSummarizationFeedback = {
      description = "Feedback for conversation summarization.",
      id = "GoogleCloudDialogflowV2AgentAssistantFeedbackSummarizationFeedback",
      properties = {
        startTime = {
          description = "Timestamp when composing of the summary starts.",
          format = "google-datetime",
          type = "string",
        },
        submitTime = {
          description = "Timestamp when the summary was submitted.",
          format = "google-datetime",
          type = "string",
        },
        summaryText = {
          description = "Text of actual submitted summary.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AgentAssistantRecord = {
      description = "Represents a record of a human agent assist answer.",
      id = "GoogleCloudDialogflowV2AgentAssistantRecord",
      properties = {
        articleSuggestionAnswer = {
          ["$ref"] = "GoogleCloudDialogflowV2ArticleAnswer",
          description = "Output only. The article suggestion answer.",
          readOnly = true,
        },
        faqAnswer = {
          ["$ref"] = "GoogleCloudDialogflowV2FaqAnswer",
          description = "Output only. The FAQ answer.",
          readOnly = true,
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AnalyzeContentRequest = {
      description = "The request message for Participants.AnalyzeContent.",
      id = "GoogleCloudDialogflowV2AnalyzeContentRequest",
      properties = {
        assistQueryParams = {
          ["$ref"] = "GoogleCloudDialogflowV2AssistQueryParameters",
          description = "Parameters for a human assist query.",
        },
        cxParameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Additional parameters to be put into Dialogflow CX session parameters. To remove a parameter from the session, clients should explicitly set the parameter value to null. Note: this field should only be used if you are connecting to a Dialogflow CX agent.",
          type = "object",
        },
        eventInput = {
          ["$ref"] = "GoogleCloudDialogflowV2EventInput",
          description = "An input event to send to Dialogflow.",
        },
        queryParams = {
          ["$ref"] = "GoogleCloudDialogflowV2QueryParameters",
          description = "Parameters for a Dialogflow virtual-agent query.",
        },
        replyAudioConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2OutputAudioConfig",
          description = "Speech synthesis configuration. The speech synthesis settings for a virtual agent that may be configured for the associated conversation profile are not used when calling AnalyzeContent. If this configuration is not supplied, speech synthesis is disabled.",
        },
        requestId = {
          description = "A unique identifier for this request. Restricted to 36 ASCII characters. A random UUID is recommended. This request is only idempotent if a `request_id` is provided.",
          type = "string",
        },
        textInput = {
          ["$ref"] = "GoogleCloudDialogflowV2TextInput",
          description = "The natural language text to be processed.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AnalyzeContentResponse = {
      description = "The response message for Participants.AnalyzeContent.",
      id = "GoogleCloudDialogflowV2AnalyzeContentResponse",
      properties = {
        automatedAgentReply = {
          ["$ref"] = "GoogleCloudDialogflowV2AutomatedAgentReply",
          description = "Only set if a Dialogflow automated agent has responded. Note that: AutomatedAgentReply.detect_intent_response.output_audio and AutomatedAgentReply.detect_intent_response.output_audio_config are always empty, use reply_audio instead.",
        },
        dtmfParameters = {
          ["$ref"] = "GoogleCloudDialogflowV2DtmfParameters",
          description = "Indicates the parameters of DTMF.",
        },
        endUserSuggestionResults = {
          description = "The suggestions for end user. The order is the same as HumanAgentAssistantConfig.SuggestionConfig.feature_configs of HumanAgentAssistantConfig.end_user_suggestion_config. Same as human_agent_suggestion_results, any failure of Agent Assist features will not lead to the overall failure of an AnalyzeContent API call. Instead, the features will fail silently with the error field set in the corresponding SuggestionResult.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SuggestionResult",
          },
          type = "array",
        },
        humanAgentSuggestionResults = {
          description = "The suggestions for most recent human agent. The order is the same as HumanAgentAssistantConfig.SuggestionConfig.feature_configs of HumanAgentAssistantConfig.human_agent_suggestion_config. Note that any failure of Agent Assist features will not lead to the overall failure of an AnalyzeContent API call. Instead, the features will fail silently with the error field set in the corresponding SuggestionResult.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SuggestionResult",
          },
          type = "array",
        },
        message = {
          ["$ref"] = "GoogleCloudDialogflowV2Message",
          description = "Message analyzed by CCAI.",
        },
        replyAudio = {
          ["$ref"] = "GoogleCloudDialogflowV2OutputAudio",
          description = "The audio data bytes encoded as specified in the request. This field is set if: - `reply_audio_config` was specified in the request, or - The automated agent responded with audio to play to the user. In such case, `reply_audio.config` contains settings used to synthesize the speech. In some scenarios, multiple output audio fields may be present in the response structure. In these cases, only the top-most-level audio output has content.",
        },
        replyText = {
          description = "The output text content. This field is set if the automated agent responded with text to show to the user.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AnnotatedMessagePart = {
      description = "Represents a part of a message possibly annotated with an entity. The part can be an entity or purely a part of the message between two entities or message start/end.",
      id = "GoogleCloudDialogflowV2AnnotatedMessagePart",
      properties = {
        entityType = {
          description = "The [Dialogflow system entity type](https://cloud.google.com/dialogflow/docs/reference/system-entities) of this message part. If this is empty, Dialogflow could not annotate the phrase part with a system entity.",
          type = "string",
        },
        formattedValue = {
          description = "The [Dialogflow system entity formatted value ](https://cloud.google.com/dialogflow/docs/reference/system-entities) of this message part. For example for a system entity of type `@sys.unit-currency`, this may contain: { \"amount\": 5, \"currency\": \"USD\" } ",
          type = "any",
        },
        text = {
          description = "A part of a message possibly annotated with an entity.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AnswerFeedback = {
      description = "Represents feedback the customer has about the quality & correctness of a certain answer in a conversation.",
      id = "GoogleCloudDialogflowV2AnswerFeedback",
      properties = {
        agentAssistantDetailFeedback = {
          ["$ref"] = "GoogleCloudDialogflowV2AgentAssistantFeedback",
          description = "Detail feedback of agent assist suggestions.",
        },
        clickTime = {
          description = "Time when the answer/item was clicked.",
          format = "google-datetime",
          type = "string",
        },
        clicked = {
          description = "Indicates whether the answer/item was clicked by the human agent or not. Default to false.",
          type = "boolean",
        },
        correctnessLevel = {
          description = "The correctness level of the specific answer.",
          enum = {
            "CORRECTNESS_LEVEL_UNSPECIFIED",
            "NOT_CORRECT",
            "PARTIALLY_CORRECT",
            "FULLY_CORRECT",
          },
          enumDescriptions = {
            "Correctness level unspecified.",
            "Answer is totally wrong.",
            "Answer is partially correct.",
            "Answer is fully correct.",
          },
          type = "string",
        },
        displayTime = {
          description = "Time when the answer/item was displayed.",
          format = "google-datetime",
          type = "string",
        },
        displayed = {
          description = "Indicates whether the answer/item was displayed to the human agent in the agent desktop UI. Default to false.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AnswerRecord = {
      description = "Answer records are records to manage answer history and feedbacks for Dialogflow. Currently, answer record includes: - human agent assistant article suggestion - human agent assistant faq article It doesn't include: - `DetectIntent` intent matching - `DetectIntent` knowledge Answer records are not related to the conversation history in the Dialogflow Console. A Record is generated even when the end-user disables conversation history in the console. Records are created when there's a human agent assistant suggestion generated. A typical workflow for customers provide feedback to an answer is: 1. For human agent assistant, customers get suggestion via ListSuggestions API. Together with the answers, AnswerRecord.name are returned to the customers. 2. The customer uses the AnswerRecord.name to call the UpdateAnswerRecord method to send feedback about a specific answer that they believe is wrong.",
      id = "GoogleCloudDialogflowV2AnswerRecord",
      properties = {
        agentAssistantRecord = {
          ["$ref"] = "GoogleCloudDialogflowV2AgentAssistantRecord",
          description = "Output only. The record for human agent assistant.",
          readOnly = true,
        },
        answerFeedback = {
          ["$ref"] = "GoogleCloudDialogflowV2AnswerFeedback",
          description = "Required. The AnswerFeedback for this record. You can set this with AnswerRecords.UpdateAnswerRecord in order to give us feedback about this answer.",
        },
        name = {
          description = "The unique identifier of this answer record. Format: `projects//locations//answerRecords/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ArticleAnswer = {
      description = "Represents article answer.",
      id = "GoogleCloudDialogflowV2ArticleAnswer",
      properties = {
        answerRecord = {
          description = "The name of answer record, in the format of \"projects//locations//answerRecords/\"",
          type = "string",
        },
        confidence = {
          description = "Article match confidence. The system's confidence score that this article is a good match for this conversation, as a value from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "A map that contains metadata about the answer and the document from which it originates.",
          type = "object",
        },
        snippets = {
          description = "Article snippets.",
          items = {
            type = "string",
          },
          type = "array",
        },
        title = {
          description = "The article title.",
          type = "string",
        },
        uri = {
          description = "The article URI.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ArticleSuggestionModelMetadata = {
      description = "Metadata for article suggestion models.",
      id = "GoogleCloudDialogflowV2ArticleSuggestionModelMetadata",
      properties = {
        trainingModelType = {
          description = "Optional. Type of the article suggestion model. If not provided, model_type is used.",
          enum = {
            "MODEL_TYPE_UNSPECIFIED",
            "SMART_REPLY_DUAL_ENCODER_MODEL",
            "SMART_REPLY_BERT_MODEL",
          },
          enumDescriptions = {
            "ModelType unspecified.",
            "ModelType smart reply dual encoder model.",
            "ModelType smart reply bert model.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AssistQueryParameters = {
      description = "Represents the parameters of human assist query.",
      id = "GoogleCloudDialogflowV2AssistQueryParameters",
      properties = {
        documentsMetadataFilters = {
          additionalProperties = {
            type = "string",
          },
          description = "Key-value filters on the metadata of documents returned by article suggestion. If specified, article suggestion only returns suggested documents that match all filters in their Document.metadata. Multiple values for a metadata key should be concatenated by comma. For example, filters to match all documents that have 'US' or 'CA' in their market metadata values and 'agent' in their user metadata values will be ``` documents_metadata_filters { key: \"market\" value: \"US,CA\" } documents_metadata_filters { key: \"user\" value: \"agent\" } ```",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AutomatedAgentConfig = {
      description = "Defines the Automated Agent to connect to a conversation.",
      id = "GoogleCloudDialogflowV2AutomatedAgentConfig",
      properties = {
        agent = {
          description = "Required. ID of the Dialogflow agent environment to use. This project needs to either be the same project as the conversation or you need to grant `service-@gcp-sa-dialogflow.iam.gserviceaccount.com` the `Dialogflow API Service Agent` role in this project. - For ES agents, use format: `projects//locations//agent/environments/`. If environment is not specified, the default `draft` environment is used. Refer to [DetectIntentRequest](/dialogflow/docs/reference/rpc/google.cloud.dialogflow.v2#google.cloud.dialogflow.v2.DetectIntentRequest) for more details. - For CX agents, use format `projects//locations//agents//environments/`. If environment is not specified, the default `draft` environment is used.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2AutomatedAgentReply = {
      description = "Represents a response from an automated agent.",
      id = "GoogleCloudDialogflowV2AutomatedAgentReply",
      properties = {
        allowCancellation = {
          description = "Indicates whether the partial automated agent reply is interruptible when a later reply message arrives. e.g. if the agent specified some music as partial response, it can be cancelled.",
          type = "boolean",
        },
        automatedAgentReplyType = {
          description = "AutomatedAgentReply type.",
          enum = {
            "AUTOMATED_AGENT_REPLY_TYPE_UNSPECIFIED",
            "PARTIAL",
            "FINAL",
          },
          enumDescriptions = {
            "Not specified. This should never happen.",
            "Partial reply. e.g. Aggregated responses in a `Fulfillment` that enables `return_partial_response` can be returned as partial reply. WARNING: partial reply is not eligible for barge-in.",
            "Final reply.",
          },
          type = "string",
        },
        cxCurrentPage = {
          description = "The unique identifier of the current Dialogflow CX conversation page. Format: `projects//locations//agents//flows//pages/`.",
          type = "string",
        },
        detectIntentResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2DetectIntentResponse",
          description = "Response of the Dialogflow Sessions.DetectIntent call.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchCreateEntitiesRequest = {
      description = "The request message for EntityTypes.BatchCreateEntities.",
      id = "GoogleCloudDialogflowV2BatchCreateEntitiesRequest",
      properties = {
        entities = {
          description = "Required. The entities to create.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityTypeEntity",
          },
          type = "array",
        },
        languageCode = {
          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchDeleteEntitiesRequest = {
      description = "The request message for EntityTypes.BatchDeleteEntities.",
      id = "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest",
      properties = {
        entityValues = {
          description = "Required. The reference `values` of the entities to delete. Note that these are not fully-qualified names, i.e. they don't start with `projects/`.",
          items = {
            type = "string",
          },
          type = "array",
        },
        languageCode = {
          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest = {
      description = "The request message for EntityTypes.BatchDeleteEntityTypes.",
      id = "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest",
      properties = {
        entityTypeNames = {
          description = "Required. The names entity types to delete. All names must point to the same agent as `parent`.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchDeleteIntentsRequest = {
      description = "The request message for Intents.BatchDeleteIntents.",
      id = "GoogleCloudDialogflowV2BatchDeleteIntentsRequest",
      properties = {
        intents = {
          description = "Required. The collection of intents to delete. Only intent `name` must be filled in.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Intent",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchUpdateEntitiesRequest = {
      description = "The request message for EntityTypes.BatchUpdateEntities.",
      id = "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest",
      properties = {
        entities = {
          description = "Required. The entities to update or create.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityTypeEntity",
          },
          type = "array",
        },
        languageCode = {
          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
          type = "string",
        },
        updateMask = {
          description = "Optional. The mask to control which fields get updated.",
          format = "google-fieldmask",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest = {
      description = "The request message for EntityTypes.BatchUpdateEntityTypes.",
      id = "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest",
      properties = {
        entityTypeBatchInline = {
          ["$ref"] = "GoogleCloudDialogflowV2EntityTypeBatch",
          description = "The collection of entity types to update or create.",
        },
        entityTypeBatchUri = {
          description = "The URI to a Google Cloud Storage file containing entity types to update or create. The file format can either be a serialized proto (of EntityBatch type) or a JSON object. Note: The URI must start with \"gs://\".",
          type = "string",
        },
        languageCode = {
          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
          type = "string",
        },
        updateMask = {
          description = "Optional. The mask to control which fields get updated.",
          format = "google-fieldmask",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse = {
      description = "The response message for EntityTypes.BatchUpdateEntityTypes.",
      id = "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse",
      properties = {
        entityTypes = {
          description = "The collection of updated or created entity types.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityType",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchUpdateIntentsRequest = {
      id = "GoogleCloudDialogflowV2BatchUpdateIntentsRequest",
      properties = {
        intentBatchInline = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentBatch",
          description = "The collection of intents to update or create.",
        },
        intentBatchUri = {
          description = "The URI to a Google Cloud Storage file containing intents to update or create. The file format can either be a serialized proto (of IntentBatch type) or JSON object. Note: The URI must start with \"gs://\".",
          type = "string",
        },
        intentView = {
          description = "Optional. The resource view to apply to the returned intent.",
          enum = {
            "INTENT_VIEW_UNSPECIFIED",
            "INTENT_VIEW_FULL",
          },
          enumDescriptions = {
            "Training phrases field is not populated in the response.",
            "All fields are populated.",
          },
          type = "string",
        },
        languageCode = {
          description = "Optional. The language used to access language-specific data. If not specified, the agent's default language is used. For more information, see [Multilingual intent and entity data](https://cloud.google.com/dialogflow/docs/agents-multilingual#intent-entity).",
          type = "string",
        },
        updateMask = {
          description = "Optional. The mask to control which fields get updated.",
          format = "google-fieldmask",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2BatchUpdateIntentsResponse = {
      description = "The response message for Intents.BatchUpdateIntents.",
      id = "GoogleCloudDialogflowV2BatchUpdateIntentsResponse",
      properties = {
        intents = {
          description = "The collection of updated or created intents.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Intent",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ClearSuggestionFeatureConfigOperationMetadata = {
      description = "Metadata for a ConversationProfile.ClearSuggestionFeatureConfig operation.",
      id = "GoogleCloudDialogflowV2ClearSuggestionFeatureConfigOperationMetadata",
      properties = {
        conversationProfile = {
          description = "The resource name of the conversation profile. Format: `projects//locations//conversationProfiles/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp whe the request was created. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        participantRole = {
          description = "Required. The participant role to remove the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        suggestionFeatureType = {
          description = "Required. The type of the suggestion feature to remove.",
          enum = {
            "TYPE_UNSPECIFIED",
            "ARTICLE_SUGGESTION",
            "FAQ",
            "SMART_REPLY",
          },
          enumDescriptions = {
            "Unspecified feature type.",
            "Run article suggestion model for chat.",
            "Run FAQ model for chat.",
            "Run smart reply model for chat.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ClearSuggestionFeatureConfigRequest = {
      description = "The request message for ConversationProfiles.ClearFeature.",
      id = "GoogleCloudDialogflowV2ClearSuggestionFeatureConfigRequest",
      properties = {
        participantRole = {
          description = "Required. The participant role to remove the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        suggestionFeatureType = {
          description = "Required. The type of the suggestion feature to remove.",
          enum = {
            "TYPE_UNSPECIFIED",
            "ARTICLE_SUGGESTION",
            "FAQ",
            "SMART_REPLY",
          },
          enumDescriptions = {
            "Unspecified feature type.",
            "Run article suggestion model for chat.",
            "Run FAQ model for chat.",
            "Run smart reply model for chat.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2CompleteConversationRequest = {
      description = "The request message for Conversations.CompleteConversation.",
      id = "GoogleCloudDialogflowV2CompleteConversationRequest",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowV2Context = {
      description = "Dialogflow contexts are similar to natural language context. If a person says to you \"they are orange\", you need context in order to understand what \"they\" is referring to. Similarly, for Dialogflow to handle an end-user expression like that, it needs to be provided with context in order to correctly match an intent. Using contexts, you can control the flow of a conversation. You can configure contexts for an intent by setting input and output contexts, which are identified by string names. When an intent is matched, any configured output contexts for that intent become active. While any contexts are active, Dialogflow is more likely to match intents that are configured with input contexts that correspond to the currently active contexts. For more information about context, see the [Contexts guide](https://cloud.google.com/dialogflow/docs/contexts-overview).",
      id = "GoogleCloudDialogflowV2Context",
      properties = {
        lifespanCount = {
          description = "Optional. The number of conversational query requests after which the context expires. The default is `0`. If set to `0`, the context expires immediately. Contexts expire automatically after 20 minutes if there are no matching queries.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "Required. The unique identifier of the context. Format: `projects//agent/sessions//contexts/`, or `projects//agent/environments//users//sessions//contexts/`. The `Context ID` is always converted to lowercase, may only contain characters in a-zA-Z0-9_-% and may be at most 250 bytes long. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. The following context names are reserved for internal use by Dialogflow. You should not use these contexts or create contexts with these names: * `__system_counters__` * `*_id_dialog_context` * `*_dialog_params_size`",
          type = "string",
        },
        parameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Optional. The collection of parameters associated with this context. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: - MapKey type: string - MapKey value: parameter name - MapValue type: - If parameter's entity type is a composite entity: map - Else: depending on parameter value type, could be one of string, number, boolean, null, list or map - MapValue value: - If parameter's entity type is a composite entity: map from composite entity property names to property values - Else: parameter value",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Conversation = {
      description = "Represents a conversation. A conversation is an interaction between an agent, including live agents and Dialogflow agents, and a support customer. Conversations can include phone calls and text-based chat sessions.",
      id = "GoogleCloudDialogflowV2Conversation",
      properties = {
        conversationProfile = {
          description = "Required. The Conversation Profile to be used to configure this Conversation. This field cannot be updated. Format: `projects//locations//conversationProfiles/`.",
          type = "string",
        },
        conversationStage = {
          description = "The stage of a conversation. It indicates whether the virtual agent or a human agent is handling the conversation. If the conversation is created with the conversation profile that has Dialogflow config set, defaults to ConversationStage.VIRTUAL_AGENT_STAGE; Otherwise, defaults to ConversationStage.HUMAN_ASSIST_STAGE. If the conversation is created with the conversation profile that has Dialogflow config set but explicitly sets conversation_stage to ConversationStage.HUMAN_ASSIST_STAGE, it skips ConversationStage.VIRTUAL_AGENT_STAGE stage and directly goes to ConversationStage.HUMAN_ASSIST_STAGE.",
          enum = {
            "CONVERSATION_STAGE_UNSPECIFIED",
            "VIRTUAL_AGENT_STAGE",
            "HUMAN_ASSIST_STAGE",
          },
          enumDescriptions = {
            "Unknown. Should never be used after a conversation is successfully created.",
            "The conversation should return virtual agent responses into the conversation.",
            "The conversation should not provide responses, just listen and provide suggestions.",
          },
          type = "string",
        },
        endTime = {
          description = "Output only. The time the conversation was finished.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        lifecycleState = {
          description = "Output only. The current state of the Conversation.",
          enum = {
            "LIFECYCLE_STATE_UNSPECIFIED",
            "IN_PROGRESS",
            "COMPLETED",
          },
          enumDescriptions = {
            "Unknown.",
            "Conversation is currently open for media analysis.",
            "Conversation has been completed.",
          },
          readOnly = true,
          type = "string",
        },
        name = {
          description = "Output only. The unique identifier of this conversation. Format: `projects//locations//conversations/`.",
          readOnly = true,
          type = "string",
        },
        phoneNumber = {
          ["$ref"] = "GoogleCloudDialogflowV2ConversationPhoneNumber",
          description = "Output only. It will not be empty if the conversation is to be connected over telephony.",
          readOnly = true,
        },
        startTime = {
          description = "Output only. The time the conversation was started.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationDataset = {
      description = "Represents a conversation dataset that a user imports raw data into. The data inside ConversationDataset can not be changed after ImportConversationData finishes (and calling ImportConversationData on a dataset that already has data is not allowed).",
      id = "GoogleCloudDialogflowV2ConversationDataset",
      properties = {
        conversationCount = {
          description = "Output only. The number of conversations this conversation dataset contains.",
          format = "int64",
          readOnly = true,
          type = "string",
        },
        conversationInfo = {
          ["$ref"] = "GoogleCloudDialogflowV2ConversationInfo",
          description = "Output only. Metadata set during conversation data import.",
          readOnly = true,
        },
        createTime = {
          description = "Output only. Creation time of this dataset.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        description = {
          description = "Optional. The description of the dataset. Maximum of 10000 bytes.",
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the dataset. Maximum of 64 bytes.",
          type = "string",
        },
        inputConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2InputConfig",
          description = "Output only. Input configurations set during conversation data import.",
          readOnly = true,
        },
        name = {
          description = "Output only. ConversationDataset resource name. Format: `projects//locations//conversationDatasets/`",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationEvent = {
      description = "Represents a notification sent to Pub/Sub subscribers for conversation lifecycle events.",
      id = "GoogleCloudDialogflowV2ConversationEvent",
      properties = {
        conversation = {
          description = "The unique identifier of the conversation this notification refers to. Format: `projects//conversations/`.",
          type = "string",
        },
        errorStatus = {
          ["$ref"] = "GoogleRpcStatus",
          description = "More detailed information about an error. Only set for type UNRECOVERABLE_ERROR_IN_PHONE_CALL.",
        },
        newMessagePayload = {
          ["$ref"] = "GoogleCloudDialogflowV2Message",
          description = "Payload of NEW_MESSAGE event.",
        },
        type = {
          description = "The type of the event that this notification refers to.",
          enum = {
            "TYPE_UNSPECIFIED",
            "CONVERSATION_STARTED",
            "CONVERSATION_FINISHED",
            "HUMAN_INTERVENTION_NEEDED",
            "NEW_MESSAGE",
            "UNRECOVERABLE_ERROR",
          },
          enumDescriptions = {
            "Type not set.",
            "A new conversation has been opened. This is fired when a telephone call is answered, or a conversation is created via the API.",
            "An existing conversation has closed. This is fired when a telephone call is terminated, or a conversation is closed via the API.",
            "An existing conversation has received notification from Dialogflow that human intervention is required.",
            "An existing conversation has received a new message, either from API or telephony. It is configured in ConversationProfile.new_message_event_notification_config",
            "Unrecoverable error during a telephone call. In general non-recoverable errors only occur if something was misconfigured in the ConversationProfile corresponding to the call. After a non-recoverable error, Dialogflow may stop responding. We don't fire this event: * in an API call because we can directly return the error, or, * when we can recover from an error.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationInfo = {
      description = "Represents metadata of a conversation.",
      id = "GoogleCloudDialogflowV2ConversationInfo",
      properties = {
        languageCode = {
          description = "Optional. The language code of the conversation data within this dataset. See https://cloud.google.com/apis/design/standard_fields for more information. Supports all UTF-8 languages.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationModel = {
      description = "Represents a conversation model.",
      id = "GoogleCloudDialogflowV2ConversationModel",
      properties = {
        articleSuggestionModelMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV2ArticleSuggestionModelMetadata",
          description = "Metadata for article suggestion models.",
        },
        createTime = {
          description = "Output only. Creation time of this model.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        datasets = {
          description = "Required. Datasets used to create model.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2InputDataset",
          },
          type = "array",
        },
        displayName = {
          description = "Required. The display name of the model. At most 64 bytes long.",
          type = "string",
        },
        languageCode = {
          description = "Language code for the conversation model. If not specified, the language is en-US. Language at ConversationModel should be set for all non en-us languages. This should be a [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag. Example: \"en-US\".",
          type = "string",
        },
        name = {
          description = "ConversationModel resource name. Format: `projects//conversationModels/`",
          type = "string",
        },
        smartReplyModelMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV2SmartReplyModelMetadata",
          description = "Metadata for smart reply models.",
        },
        state = {
          description = "Output only. State of the model. A model can only serve prediction requests after it gets deployed.",
          enum = {
            "STATE_UNSPECIFIED",
            "CREATING",
            "UNDEPLOYED",
            "DEPLOYING",
            "DEPLOYED",
            "UNDEPLOYING",
            "DELETING",
            "FAILED",
            "PENDING",
          },
          enumDescriptions = {
            "Should not be used, an un-set enum has this value by default.",
            "Model being created.",
            "Model is not deployed but ready to deploy.",
            "Model is deploying.",
            "Model is deployed and ready to use.",
            "Model is undeploying.",
            "Model is deleting.",
            "Model is in error state. Not ready to deploy and use.",
            "Model is being created but the training has not started, The model may remain in this state until there is enough capacity to start training.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationModelEvaluation = {
      description = "Represents evaluation result of a conversation model.",
      id = "GoogleCloudDialogflowV2ConversationModelEvaluation",
      properties = {
        createTime = {
          description = "Output only. Creation time of this model.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Optional. The display name of the model evaluation. At most 64 bytes long.",
          type = "string",
        },
        evaluationConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2EvaluationConfig",
          description = "Optional. The configuration of the evaluation task.",
        },
        name = {
          description = "The resource name of the evaluation. Format: `projects//conversationModels//evaluations/`",
          type = "string",
        },
        rawHumanEvalTemplateCsv = {
          description = "Output only. Human eval template in csv format. It tooks real-world conversations provided through input dataset, generates example suggestions for customer to verify quality of the model. For Smart Reply, the generated csv file contains columns of Context, (Suggestions,Q1,Q2)*3, Actual reply. Context contains at most 10 latest messages in the conversation prior to the current suggestion. Q1: \"Would you send it as the next message of agent?\" Evaluated based on whether the suggest is appropriate to be sent by agent in current context. Q2: \"Does the suggestion move the conversation closer to resolution?\" Evaluated based on whether the suggestion provide solutions, or answers customer's question or collect information from customer to resolve the customer's issue. Actual reply column contains the actual agent reply sent in the context.",
          readOnly = true,
          type = "string",
        },
        smartReplyMetrics = {
          ["$ref"] = "GoogleCloudDialogflowV2SmartReplyMetrics",
          description = "Output only. Only available when model is for smart reply.",
          readOnly = true,
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationPhoneNumber = {
      description = "Represents a phone number for telephony integration. It allows for connecting a particular conversation over telephony.",
      id = "GoogleCloudDialogflowV2ConversationPhoneNumber",
      properties = {
        phoneNumber = {
          description = "Output only. The phone number to connect to this conversation.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ConversationProfile = {
      description = "Defines the services to connect to incoming Dialogflow conversations.",
      id = "GoogleCloudDialogflowV2ConversationProfile",
      properties = {
        automatedAgentConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2AutomatedAgentConfig",
          description = "Configuration for an automated agent to use with this profile.",
        },
        createTime = {
          description = "Output only. Create time of the conversation profile.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        displayName = {
          description = "Required. Human readable name for this profile. Max length 1024 bytes.",
          type = "string",
        },
        humanAgentAssistantConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfig",
          description = "Configuration for agent assistance to use with this profile.",
        },
        humanAgentHandoffConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentHandoffConfig",
          description = "Configuration for connecting to a live agent. Currently, this feature is not general available, please contact Google to get access.",
        },
        languageCode = {
          description = "Language code for the conversation profile. If not specified, the language is en-US. Language at ConversationProfile should be set for all non en-US languages. This should be a [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag. Example: \"en-US\".",
          type = "string",
        },
        loggingConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2LoggingConfig",
          description = "Configuration for logging conversation lifecycle events.",
        },
        name = {
          description = "The unique identifier of this conversation profile. Format: `projects//locations//conversationProfiles/`.",
          type = "string",
        },
        newMessageEventNotificationConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2NotificationConfig",
          description = "Configuration for publishing new message events. Event will be sent in format of ConversationEvent",
        },
        notificationConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2NotificationConfig",
          description = "Configuration for publishing conversation lifecycle events.",
        },
        securitySettings = {
          description = "Name of the CX SecuritySettings reference for the agent. Format: `projects//locations//securitySettings/`.",
          type = "string",
        },
        sttConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2SpeechToTextConfig",
          description = "Settings for speech transcription.",
        },
        timeZone = {
          description = "The time zone of this conversational profile from the [time zone database](https://www.iana.org/time-zones), e.g., America/New_York, Europe/Paris. Defaults to America/New_York.",
          type = "string",
        },
        updateTime = {
          description = "Output only. Update time of the conversation profile.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2CreateConversationDatasetOperationMetadata = {
      description = "Metadata for ConversationDatasets.",
      id = "GoogleCloudDialogflowV2CreateConversationDatasetOperationMetadata",
      properties = {
        conversationDataset = {
          description = "The resource name of the conversation dataset that will be created. Format: `projects//locations//conversationDatasets/`",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2CreateConversationModelEvaluationOperationMetadata = {
      description = "Metadata for a ConversationModels.CreateConversationModelEvaluation operation.",
      id = "GoogleCloudDialogflowV2CreateConversationModelEvaluationOperationMetadata",
      properties = {
        conversationModel = {
          description = "The resource name of the conversation model. Format: `projects//locations//conversationModels/`",
          type = "string",
        },
        conversationModelEvaluation = {
          description = "The resource name of the conversation model. Format: `projects//locations//conversationModels//evaluations/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp when the request to create conversation model was submitted. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        state = {
          description = "State of CreateConversationModel operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "INITIALIZING",
            "RUNNING",
            "CANCELLED",
            "SUCCEEDED",
            "FAILED",
          },
          enumDescriptions = {
            "Operation status not specified.",
            "The operation is being prepared.",
            "The operation is running.",
            "The operation is cancelled.",
            "The operation has succeeded.",
            "The operation has failed.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2CreateConversationModelEvaluationRequest = {
      description = "The request message for ConversationModels.CreateConversationModelEvaluation",
      id = "GoogleCloudDialogflowV2CreateConversationModelEvaluationRequest",
      properties = {
        conversationModelEvaluation = {
          ["$ref"] = "GoogleCloudDialogflowV2ConversationModelEvaluation",
          description = "Required. The conversation model evaluation to be created.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2CreateConversationModelOperationMetadata = {
      description = "Metadata for a ConversationModels.CreateConversationModel operation.",
      id = "GoogleCloudDialogflowV2CreateConversationModelOperationMetadata",
      properties = {
        conversationModel = {
          description = "The resource name of the conversation model. Format: `projects//conversationModels/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp when the request to create conversation model is submitted. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        state = {
          description = "State of CreateConversationModel operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "PENDING",
            "SUCCEEDED",
            "FAILED",
            "CANCELLED",
            "CANCELLING",
            "TRAINING",
          },
          enumDescriptions = {
            "Invalid.",
            "Request is submitted, but training has not started yet. The model may remain in this state until there is enough capacity to start training.",
            "The training has succeeded.",
            "The training has succeeded.",
            "The training has been cancelled.",
            "The training is in cancelling state.",
            "Custom model is training.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2DeleteConversationDatasetOperationMetadata = {
      description = "Metadata for ConversationDatasets.",
      id = "GoogleCloudDialogflowV2DeleteConversationDatasetOperationMetadata",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowV2DeleteConversationModelOperationMetadata = {
      description = "Metadata for a ConversationModels.DeleteConversationModel operation.",
      id = "GoogleCloudDialogflowV2DeleteConversationModelOperationMetadata",
      properties = {
        conversationModel = {
          description = "The resource name of the conversation model. Format: `projects//conversationModels/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp when delete conversation model request was created. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2DeployConversationModelOperationMetadata = {
      description = "Metadata for a ConversationModels.DeployConversationModel operation.",
      id = "GoogleCloudDialogflowV2DeployConversationModelOperationMetadata",
      properties = {
        conversationModel = {
          description = "The resource name of the conversation model. Format: `projects//conversationModels/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp when request to deploy conversation model was submitted. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2DeployConversationModelRequest = {
      description = "The request message for ConversationModels.DeployConversationModel",
      id = "GoogleCloudDialogflowV2DeployConversationModelRequest",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowV2DetectIntentRequest = {
      description = "The request to detect user's intent.",
      id = "GoogleCloudDialogflowV2DetectIntentRequest",
      properties = {
        inputAudio = {
          description = "The natural language speech audio to be processed. This field should be populated iff `query_input` is set to an input audio config. A single request can contain up to 1 minute of speech audio data.",
          format = "byte",
          type = "string",
        },
        outputAudioConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2OutputAudioConfig",
          description = "Instructs the speech synthesizer how to generate the output audio. If this field is not set and agent-level speech synthesizer is not configured, no output audio is generated.",
        },
        outputAudioConfigMask = {
          description = "Mask for output_audio_config indicating which settings in this request-level config should override speech synthesizer settings defined at agent-level. If unspecified or empty, output_audio_config replaces the agent-level config in its entirety.",
          format = "google-fieldmask",
          type = "string",
        },
        queryInput = {
          ["$ref"] = "GoogleCloudDialogflowV2QueryInput",
          description = "Required. The input specification. It can be set to: 1. an audio config which instructs the speech recognizer how to process the speech audio, 2. a conversational query in the form of text, or 3. an event that specifies which intent to trigger.",
        },
        queryParams = {
          ["$ref"] = "GoogleCloudDialogflowV2QueryParameters",
          description = "The parameters of this query.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2DetectIntentResponse = {
      description = "The message returned from the DetectIntent method.",
      id = "GoogleCloudDialogflowV2DetectIntentResponse",
      properties = {
        outputAudio = {
          description = "The audio data bytes encoded as specified in the request. Note: The output audio is generated based on the values of default platform text responses found in the `query_result.fulfillment_messages` field. If multiple default text responses exist, they will be concatenated when generating audio. If no default platform text responses exist, the generated audio content will be empty. In some scenarios, multiple output audio fields may be present in the response structure. In these cases, only the top-most-level audio output has content.",
          format = "byte",
          type = "string",
        },
        outputAudioConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2OutputAudioConfig",
          description = "The config used by the speech synthesizer to generate the output audio.",
        },
        queryResult = {
          ["$ref"] = "GoogleCloudDialogflowV2QueryResult",
          description = "The selected results of the conversational query or event processing. See `alternative_query_results` for additional potential results.",
        },
        responseId = {
          description = "The unique identifier of the response. It can be used to locate a response in the training example set or for reporting issues.",
          type = "string",
        },
        webhookStatus = {
          ["$ref"] = "GoogleRpcStatus",
          description = "Specifies the status of the webhook request.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Document = {
      description = "A knowledge document to be used by a KnowledgeBase. For more information, see the [knowledge base guide](https://cloud.google.com/dialogflow/docs/how/knowledge-bases). Note: The `projects.agent.knowledgeBases.documents` resource is deprecated; only use `projects.knowledgeBases.documents`.",
      id = "GoogleCloudDialogflowV2Document",
      properties = {
        contentUri = {
          description = "The URI where the file content is located. For documents stored in Google Cloud Storage, these URIs must have the form `gs:///`. NOTE: External URLs must correspond to public webpages, i.e., they must be indexed by Google Search. In particular, URLs for showing documents in Google Cloud Storage (i.e. the URL in your browser) are not supported. Instead use the `gs://` format URI described above.",
          type = "string",
        },
        displayName = {
          description = "Required. The display name of the document. The name must be 1024 bytes or less; otherwise, the creation request fails.",
          type = "string",
        },
        enableAutoReload = {
          description = "Optional. If true, we try to automatically reload the document every day (at a time picked by the system). If false or unspecified, we don't try to automatically reload the document. Currently you can only enable automatic reload for documents sourced from a public url, see `source` field for the source types. Reload status can be tracked in `latest_reload_status`. If a reload fails, we will keep the document unchanged. If a reload fails with internal errors, the system will try to reload the document on the next day. If a reload fails with non-retriable errors (e.g. PERMISION_DENIED), the system will not try to reload the document anymore. You need to manually reload the document successfully by calling `ReloadDocument` and clear the errors.",
          type = "boolean",
        },
        knowledgeTypes = {
          description = "Required. The knowledge type of document content.",
          items = {
            enum = {
              "KNOWLEDGE_TYPE_UNSPECIFIED",
              "FAQ",
              "EXTRACTIVE_QA",
              "ARTICLE_SUGGESTION",
              "AGENT_FACING_SMART_REPLY",
            },
            enumDescriptions = {
              "The type is unspecified or arbitrary.",
              "The document content contains question and answer pairs as either HTML or CSV. Typical FAQ HTML formats are parsed accurately, but unusual formats may fail to be parsed. CSV must have questions in the first column and answers in the second, with no header. Because of this explicit format, they are always parsed accurately.",
              "Documents for which unstructured text is extracted and used for question answering.",
              "The entire document content as a whole can be used for query results. Only for Contact Center Solutions on Dialogflow.",
              "The document contains agent-facing Smart Reply entries.",
            },
            type = "string",
          },
          type = "array",
        },
        latestReloadStatus = {
          ["$ref"] = "GoogleCloudDialogflowV2DocumentReloadStatus",
          description = "Output only. The time and status of the latest reload. This reload may have been triggered automatically or manually and may not have succeeded.",
          readOnly = true,
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "Optional. Metadata for the document. The metadata supports arbitrary key-value pairs. Suggested use cases include storing a document's title, an external URL distinct from the document's content_uri, etc. The max size of a `key` or a `value` of the metadata is 1024 bytes.",
          type = "object",
        },
        mimeType = {
          description = "Required. The MIME type of this document.",
          type = "string",
        },
        name = {
          description = "Optional. The document resource name. The name must be empty when creating a document. Format: `projects//locations//knowledgeBases//documents/`.",
          type = "string",
        },
        rawContent = {
          description = "The raw content of the document. This field is only permitted for EXTRACTIVE_QA and FAQ knowledge types.",
          format = "byte",
          type = "string",
        },
        state = {
          description = "Output only. The current state of the document.",
          enum = {
            "STATE_UNSPECIFIED",
            "CREATING",
            "ACTIVE",
            "UPDATING",
            "RELOADING",
            "DELETING",
          },
          enumDescriptions = {
            "The document state is unspecified.",
            "The document creation is in progress.",
            "The document is active and ready to use.",
            "The document updation is in progress.",
            "The document is reloading.",
            "The document deletion is in progress.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2DocumentReloadStatus = {
      description = "The status of a reload attempt.",
      id = "GoogleCloudDialogflowV2DocumentReloadStatus",
      properties = {
        status = {
          ["$ref"] = "GoogleRpcStatus",
          description = "The status of a reload attempt or the initial load.",
        },
        time = {
          description = "The time of a reload attempt. This reload may have been triggered automatically or manually and may not have succeeded.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2DtmfParameters = {
      description = "The message in the response that indicates the parameters of DTMF.",
      id = "GoogleCloudDialogflowV2DtmfParameters",
      properties = {
        acceptsDtmfInput = {
          description = "Indicates whether DTMF input can be handled in the next request.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EntityType = {
      description = "Each intent parameter has a type, called the entity type, which dictates exactly how data from an end-user expression is extracted. Dialogflow provides predefined system entities that can match many common types of data. For example, there are system entities for matching dates, times, colors, email addresses, and so on. You can also create your own custom entities for matching custom data. For example, you could define a vegetable entity that can match the types of vegetables available for purchase with a grocery store agent. For more information, see the [Entity guide](https://cloud.google.com/dialogflow/docs/entities-overview).",
      id = "GoogleCloudDialogflowV2EntityType",
      properties = {
        autoExpansionMode = {
          description = "Optional. Indicates whether the entity type can be automatically expanded.",
          enum = {
            "AUTO_EXPANSION_MODE_UNSPECIFIED",
            "AUTO_EXPANSION_MODE_DEFAULT",
          },
          enumDescriptions = {
            "Auto expansion disabled for the entity.",
            "Allows an agent to recognize values that have not been explicitly listed in the entity.",
          },
          type = "string",
        },
        displayName = {
          description = "Required. The name of the entity type.",
          type = "string",
        },
        enableFuzzyExtraction = {
          description = "Optional. Enables fuzzy entity extraction during classification.",
          type = "boolean",
        },
        entities = {
          description = "Optional. The collection of entity entries associated with the entity type.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityTypeEntity",
          },
          type = "array",
        },
        kind = {
          description = "Required. Indicates the kind of entity type.",
          enum = {
            "KIND_UNSPECIFIED",
            "KIND_MAP",
            "KIND_LIST",
            "KIND_REGEXP",
          },
          enumDescriptions = {
            "Not specified. This value should be never used.",
            "Map entity types allow mapping of a group of synonyms to a reference value.",
            "List entity types contain a set of entries that do not map to reference values. However, list entity types can contain references to other entity types (with or without aliases).",
            "Regexp entity types allow to specify regular expressions in entries values.",
          },
          type = "string",
        },
        name = {
          description = "The unique identifier of the entity type. Required for EntityTypes.UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Format: `projects//agent/entityTypes/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EntityTypeBatch = {
      description = "This message is a wrapper around a collection of entity types.",
      id = "GoogleCloudDialogflowV2EntityTypeBatch",
      properties = {
        entityTypes = {
          description = "A collection of entity types.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityType",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EntityTypeEntity = {
      description = "An **entity entry** for an associated entity type.",
      id = "GoogleCloudDialogflowV2EntityTypeEntity",
      properties = {
        synonyms = {
          description = "Required. A collection of value synonyms. For example, if the entity type is *vegetable*, and `value` is *scallions*, a synonym could be *green onions*. For `KIND_LIST` entity types: * This collection must contain exactly one synonym equal to `value`.",
          items = {
            type = "string",
          },
          type = "array",
        },
        value = {
          description = "Required. The primary value associated with this entity entry. For example, if the entity type is *vegetable*, the value could be *scallions*. For `KIND_MAP` entity types: * A reference value to be used in place of synonyms. For `KIND_LIST` entity types: * A string that can contain references to other entity types (with or without aliases).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Environment = {
      description = "You can create multiple versions of your agent and publish them to separate environments. When you edit an agent, you are editing the draft agent. At any point, you can save the draft agent as an agent version, which is an immutable snapshot of your agent. When you save the draft agent, it is published to the default environment. When you create agent versions, you can publish them to custom environments. You can create a variety of custom environments for: - testing - development - production - etc. For more information, see the [versions and environments guide](https://cloud.google.com/dialogflow/docs/agents-versions).",
      id = "GoogleCloudDialogflowV2Environment",
      properties = {
        agentVersion = {
          description = "Optional. The agent version loaded into this environment. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
          type = "string",
        },
        description = {
          description = "Optional. The developer-provided description for this environment. The maximum length is 500 characters. If exceeded, the request is rejected.",
          type = "string",
        },
        fulfillment = {
          ["$ref"] = "GoogleCloudDialogflowV2Fulfillment",
          description = "Optional. The fulfillment settings to use for this environment.",
        },
        name = {
          description = "Output only. The unique identifier of this agent environment. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
          readOnly = true,
          type = "string",
        },
        state = {
          description = "Output only. The state of this environment. This field is read-only, i.e., it cannot be set by create and update methods.",
          enum = {
            "STATE_UNSPECIFIED",
            "STOPPED",
            "LOADING",
            "RUNNING",
          },
          enumDescriptions = {
            "Not specified. This value is not used.",
            "Stopped.",
            "Loading.",
            "Running.",
          },
          readOnly = true,
          type = "string",
        },
        textToSpeechSettings = {
          ["$ref"] = "GoogleCloudDialogflowV2TextToSpeechSettings",
          description = "Optional. Text to speech settings for this environment.",
        },
        updateTime = {
          description = "Output only. The last update time of this environment. This field is read-only, i.e., it cannot be set by create and update methods.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EnvironmentHistory = {
      description = "The response message for Environments.GetEnvironmentHistory.",
      id = "GoogleCloudDialogflowV2EnvironmentHistory",
      properties = {
        entries = {
          description = "Output only. The list of agent environments. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EnvironmentHistoryEntry",
          },
          readOnly = true,
          type = "array",
        },
        nextPageToken = {
          description = "Output only. Token to retrieve the next page of results, or empty if there are no more results in the list.",
          readOnly = true,
          type = "string",
        },
        parent = {
          description = "Output only. The name of the environment this history is for. Supported formats: - `projects//agent/environments/` - `projects//locations//agent/environments/` The environment ID for the default environment is `-`.",
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EnvironmentHistoryEntry = {
      description = "Represents an environment history entry.",
      id = "GoogleCloudDialogflowV2EnvironmentHistoryEntry",
      properties = {
        agentVersion = {
          description = "The agent version loaded into this environment history entry.",
          type = "string",
        },
        createTime = {
          description = "The creation time of this environment history entry.",
          format = "google-datetime",
          type = "string",
        },
        description = {
          description = "The developer-provided description for this environment history entry.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EvaluationConfig = {
      description = "The configuration for model evaluation.",
      id = "GoogleCloudDialogflowV2EvaluationConfig",
      properties = {
        datasets = {
          description = "Required. Datasets used for evaluation.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2InputDataset",
          },
          type = "array",
        },
        smartComposeConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2EvaluationConfigSmartComposeConfig",
          description = "Configuration for smart compose model evalution.",
        },
        smartReplyConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2EvaluationConfigSmartReplyConfig",
          description = "Configuration for smart reply model evalution.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EvaluationConfigSmartComposeConfig = {
      description = "Smart compose specific configuration for evaluation job.",
      id = "GoogleCloudDialogflowV2EvaluationConfigSmartComposeConfig",
      properties = {
        allowlistDocument = {
          description = "The allowlist document resource name. Format: `projects//knowledgeBases//documents/`. Only used for smart compose model.",
          type = "string",
        },
        maxResultCount = {
          description = "Required. The model to be evaluated can return multiple results with confidence score on each query. These results will be sorted by the descending order of the scores and we only keep the first max_result_count results as the final results to evaluate.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EvaluationConfigSmartReplyConfig = {
      description = "Smart reply specific configuration for evaluation job.",
      id = "GoogleCloudDialogflowV2EvaluationConfigSmartReplyConfig",
      properties = {
        allowlistDocument = {
          description = "The allowlist document resource name. Format: `projects//knowledgeBases//documents/`. Only used for smart reply model.",
          type = "string",
        },
        maxResultCount = {
          description = "Required. The model to be evaluated can return multiple results with confidence score on each query. These results will be sorted by the descending order of the scores and we only keep the first max_result_count results as the final results to evaluate.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2EventInput = {
      description = "Events allow for matching intents by event name instead of the natural language input. For instance, input `` can trigger a personalized welcome response. The parameter `name` may be used by the agent in the response: `\"Hello #welcome_event.name! What can I do for you today?\"`.",
      id = "GoogleCloudDialogflowV2EventInput",
      properties = {
        languageCode = {
          description = "Required. The language of this query. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language. This field is ignored when used in the context of a WebhookResponse.followup_event_input field, because the language was already defined in the originating detect intent request.",
          type = "string",
        },
        name = {
          description = "Required. The unique identifier of the event.",
          type = "string",
        },
        parameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "The collection of parameters associated with the event. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: - MapKey type: string - MapKey value: parameter name - MapValue type: - If parameter's entity type is a composite entity: map - Else: depending on parameter value type, could be one of string, number, boolean, null, list or map - MapValue value: - If parameter's entity type is a composite entity: map from composite entity property names to property values - Else: parameter value",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ExportAgentRequest = {
      description = "The request message for Agents.ExportAgent.",
      id = "GoogleCloudDialogflowV2ExportAgentRequest",
      properties = {
        agentUri = {
          description = "Required. The [Google Cloud Storage](https://cloud.google.com/storage/docs/) URI to export the agent to. The format of this URI must be `gs:///`. If left unspecified, the serialized agent is returned inline. Dialogflow performs a write operation for the Cloud Storage object on the caller's behalf, so your request authentication must have write permissions for the object. For more information, see [Dialogflow access control](https://cloud.google.com/dialogflow/cx/docs/concept/access-control#storage).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ExportAgentResponse = {
      description = "The response message for Agents.ExportAgent.",
      id = "GoogleCloudDialogflowV2ExportAgentResponse",
      properties = {
        agentContent = {
          description = "Zip compressed raw byte content for agent.",
          format = "byte",
          type = "string",
        },
        agentUri = {
          description = "The URI to a file containing the exported agent. This field is populated only if `agent_uri` is specified in `ExportAgentRequest`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ExportDocumentRequest = {
      description = "Request message for Documents.ExportDocument.",
      id = "GoogleCloudDialogflowV2ExportDocumentRequest",
      properties = {
        exportFullContent = {
          description = "When enabled, export the full content of the document including empirical probability.",
          type = "boolean",
        },
        gcsDestination = {
          ["$ref"] = "GoogleCloudDialogflowV2GcsDestination",
          description = "Cloud Storage file path to export the document.",
        },
        smartMessagingPartialUpdate = {
          description = "When enabled, export the smart messaging allowlist document for partial update.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ExportOperationMetadata = {
      description = "Metadata related to the Export Data Operations (e.g. ExportDocument).",
      id = "GoogleCloudDialogflowV2ExportOperationMetadata",
      properties = {
        exportedGcsDestination = {
          ["$ref"] = "GoogleCloudDialogflowV2GcsDestination",
          description = "Cloud Storage file path of the exported data.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2FaqAnswer = {
      description = "Represents answer from \"frequently asked questions\".",
      id = "GoogleCloudDialogflowV2FaqAnswer",
      properties = {
        answer = {
          description = "The piece of text from the `source` knowledge base document.",
          type = "string",
        },
        answerRecord = {
          description = "The name of answer record, in the format of \"projects//locations//answerRecords/\"",
          type = "string",
        },
        confidence = {
          description = "The system's confidence score that this Knowledge answer is a good match for this conversational query, range from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "A map that contains metadata about the answer and the document from which it originates.",
          type = "object",
        },
        question = {
          description = "The corresponding FAQ question.",
          type = "string",
        },
        source = {
          description = "Indicates which Knowledge Document this answer was extracted from. Format: `projects//locations//agent/knowledgeBases//documents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Fulfillment = {
      description = "By default, your agent responds to a matched intent with a static response. As an alternative, you can provide a more dynamic response by using fulfillment. When you enable fulfillment for an intent, Dialogflow responds to that intent by calling a service that you define. For example, if an end-user wants to schedule a haircut on Friday, your service can check your database and respond to the end-user with availability information for Friday. For more information, see the [fulfillment guide](https://cloud.google.com/dialogflow/docs/fulfillment-overview).",
      id = "GoogleCloudDialogflowV2Fulfillment",
      properties = {
        displayName = {
          description = "Optional. The human-readable name of the fulfillment, unique within the agent. This field is not used for Fulfillment in an Environment.",
          type = "string",
        },
        enabled = {
          description = "Optional. Whether fulfillment is enabled.",
          type = "boolean",
        },
        features = {
          description = "Optional. The field defines whether the fulfillment is enabled for certain features.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2FulfillmentFeature",
          },
          type = "array",
        },
        genericWebService = {
          ["$ref"] = "GoogleCloudDialogflowV2FulfillmentGenericWebService",
          description = "Configuration for a generic web service.",
        },
        name = {
          description = "Required. The unique identifier of the fulfillment. Supported formats: - `projects//agent/fulfillment` - `projects//locations//agent/fulfillment` This field is not used for Fulfillment in an Environment.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2FulfillmentFeature = {
      description = "Whether fulfillment is enabled for the specific feature.",
      id = "GoogleCloudDialogflowV2FulfillmentFeature",
      properties = {
        type = {
          description = "The type of the feature that enabled for fulfillment.",
          enum = {
            "TYPE_UNSPECIFIED",
            "SMALLTALK",
          },
          enumDescriptions = {
            "Feature type not specified.",
            "Fulfillment is enabled for SmallTalk.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2FulfillmentGenericWebService = {
      description = "Represents configuration for a generic web service. Dialogflow supports two mechanisms for authentications: - Basic authentication with username and password. - Authentication with additional authentication headers. More information could be found at: https://cloud.google.com/dialogflow/docs/fulfillment-configure.",
      id = "GoogleCloudDialogflowV2FulfillmentGenericWebService",
      properties = {
        isCloudFunction = {
          description = "Optional. Indicates if generic web service is created through Cloud Functions integration. Defaults to false. is_cloud_function is deprecated. Cloud functions can be configured by its uri as a regular web service now.",
          type = "boolean",
        },
        password = {
          description = "Optional. The password for HTTP Basic authentication.",
          type = "string",
        },
        requestHeaders = {
          additionalProperties = {
            type = "string",
          },
          description = "Optional. The HTTP request headers to send together with fulfillment requests.",
          type = "object",
        },
        uri = {
          description = "Required. The fulfillment URI for receiving POST requests. It must use https protocol.",
          type = "string",
        },
        username = {
          description = "Optional. The user name for HTTP Basic authentication.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2GcsDestination = {
      description = "Google Cloud Storage location for the output.",
      id = "GoogleCloudDialogflowV2GcsDestination",
      properties = {
        uri = {
          description = "The Google Cloud Storage URIs for the output. A URI is of the form: gs://bucket/object-prefix-or-name Whether a prefix or name is used depends on the use case. The requesting user must have \"write-permission\" to the bucket.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2GcsSources = {
      description = "Google Cloud Storage location for the inputs.",
      id = "GoogleCloudDialogflowV2GcsSources",
      properties = {
        uris = {
          description = "Required. Google Cloud Storage URIs for the inputs. A URI is of the form: gs://bucket/object-prefix-or-name Whether a prefix or name is used depends on the use case.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfig = {
      description = "Defines the Human Agent Assist to connect to a conversation.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfig",
      properties = {
        endUserSuggestionConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig",
          description = "Configuration for agent assistance of end user participant. Currently, this feature is not general available, please contact Google to get access.",
        },
        humanAgentSuggestionConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig",
          description = "Configuration for agent assistance of human agent participant.",
        },
        messageAnalysisConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigMessageAnalysisConfig",
          description = "Configuration for message analysis.",
        },
        notificationConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2NotificationConfig",
          description = "Pub/Sub topic on which to publish new agent assistant events.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationModelConfig = {
      description = "Custom conversation models used in agent assist feature. Supported feature: ARTICLE_SUGGESTION, SMART_COMPOSE, SMART_REPLY, CONVERSATION_SUMMARIZATION.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationModelConfig",
      properties = {
        model = {
          description = "Conversation model resource name. Format: `projects//conversationModels/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationProcessConfig = {
      description = "Config to process conversation.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationProcessConfig",
      properties = {
        recentSentencesCount = {
          description = "Number of recent non-small-talk sentences to use as context for article and FAQ suggestion",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigMessageAnalysisConfig = {
      description = "Configuration for analyses to run on each conversation message.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigMessageAnalysisConfig",
      properties = {
        enableEntityExtraction = {
          description = "Enable entity extraction in conversation messages on [agent assist stage](https://cloud.google.com/dialogflow/priv/docs/contact-center/basics#stages). If unspecified, defaults to false. Currently, this feature is not general available, please contact Google to get access.",
          type = "boolean",
        },
        enableSentimentAnalysis = {
          description = "Enable sentiment analysis in conversation messages on [agent assist stage](https://cloud.google.com/dialogflow/priv/docs/contact-center/basics#stages). If unspecified, defaults to false. Sentiment analysis inspects user input and identifies the prevailing subjective opinion, especially to determine a user's attitude as positive, negative, or neutral: https://cloud.google.com/natural-language/docs/basics#sentiment_analysis For Participants.StreamingAnalyzeContent method, result will be in StreamingAnalyzeContentResponse.message.SentimentAnalysisResult. For Participants.AnalyzeContent method, result will be in AnalyzeContentResponse.message.SentimentAnalysisResult For Conversations.ListMessages method, result will be in ListMessagesResponse.messages.SentimentAnalysisResult If Pub/Sub notification is configured, result will be in ConversationEvent.new_message_payload.SentimentAnalysisResult.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig = {
      description = "Detail human agent assistant config.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionConfig",
      properties = {
        featureConfigs = {
          description = "Configuration of different suggestion features. One feature can have only one config.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig",
          },
          type = "array",
        },
        groupSuggestionResponses = {
          description = "If `group_suggestion_responses` is false, and there are multiple `feature_configs` in `event based suggestion` or StreamingAnalyzeContent, we will try to deliver suggestions to customers as soon as we get new suggestion. Different type of suggestions based on the same context will be in separate Pub/Sub event or `StreamingAnalyzeContentResponse`. If `group_suggestion_responses` set to true. All the suggestions to the same participant based on the same context will be grouped into a single Pub/Sub event or StreamingAnalyzeContentResponse.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig = {
      description = "Config for suggestion features.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig",
      properties = {
        conversationModelConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationModelConfig",
          description = "Configs of custom conversation model.",
        },
        conversationProcessConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigConversationProcessConfig",
          description = "Configs for processing conversation.",
        },
        enableEventBasedSuggestion = {
          description = "Automatically iterates all participants and tries to compile suggestions. Supported features: ARTICLE_SUGGESTION, FAQ, DIALOGFLOW_ASSIST.",
          type = "boolean",
        },
        queryConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfig",
          description = "Configs of query.",
        },
        suggestionFeature = {
          ["$ref"] = "GoogleCloudDialogflowV2SuggestionFeature",
          description = "The suggestion feature.",
        },
        suggestionTriggerSettings = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionTriggerSettings",
          description = "Settings of suggestion trigger. Currently, only ARTICLE_SUGGESTION and FAQ will use this field.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfig = {
      description = "Config for suggestion query.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfig",
      properties = {
        confidenceThreshold = {
          description = "Confidence threshold of query result. Agent Assist gives each suggestion a score in the range [0.0, 1.0], based on the relevance between the suggestion and the current conversation context. A score of 0.0 has no relevance, while a score of 1.0 has high relevance. Only suggestions with a score greater than or equal to the value of this field are included in the results. For a baseline model (the default), the recommended value is in the range [0.05, 0.1]. For a custom model, there is no recommended value. Tune this value by starting from a very low value and slowly increasing until you have desired results. If this field is not set, it defaults to 0.0, which means that all suggestions are returned. Supported features: ARTICLE_SUGGESTION, FAQ, SMART_REPLY, SMART_COMPOSE.",
          format = "float",
          type = "number",
        },
        contextFilterSettings = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigContextFilterSettings",
          description = "Determines how recent conversation context is filtered when generating suggestions. If unspecified, no messages will be dropped.",
        },
        dialogflowQuerySource = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigDialogflowQuerySource",
          description = "Query from Dialogflow agent. It is used by DIALOGFLOW_ASSIST.",
        },
        documentQuerySource = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigDocumentQuerySource",
          description = "Query from knowledge base document. It is used by: SMART_REPLY, SMART_COMPOSE.",
        },
        knowledgeBaseQuerySource = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigKnowledgeBaseQuerySource",
          description = "Query from knowledgebase. It is used by: ARTICLE_SUGGESTION, FAQ.",
        },
        maxResults = {
          description = "Maximum number of results to return. Currently, if unset, defaults to 10. And the max number is 20.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigContextFilterSettings = {
      description = "Settings that determine how to filter recent conversation context when generating suggestions.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigContextFilterSettings",
      properties = {
        dropHandoffMessages = {
          description = "If set to true, the last message from virtual agent (hand off message) and the message before it (trigger message of hand off) are dropped.",
          type = "boolean",
        },
        dropIvrMessages = {
          description = "If set to true, all messages from ivr stage are dropped.",
          type = "boolean",
        },
        dropVirtualAgentMessages = {
          description = "If set to true, all messages from virtual agent are dropped.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigDialogflowQuerySource = {
      description = "Dialogflow source setting. Supported feature: DIALOGFLOW_ASSIST.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigDialogflowQuerySource",
      properties = {
        agent = {
          description = "Required. The name of a Dialogflow virtual agent used for end user side intent detection and suggestion. Format: `projects//locations//agent`. When multiple agents are allowed in the same Dialogflow project.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigDocumentQuerySource = {
      description = "Document source settings. Supported features: SMART_REPLY, SMART_COMPOSE.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigDocumentQuerySource",
      properties = {
        documents = {
          description = "Required. Knowledge documents to query from. Format: `projects//locations//knowledgeBases//documents/`. Currently, at most 5 documents are supported.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigKnowledgeBaseQuerySource = {
      description = "Knowledge base source settings. Supported features: ARTICLE_SUGGESTION, FAQ.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionQueryConfigKnowledgeBaseQuerySource",
      properties = {
        knowledgeBases = {
          description = "Required. Knowledge bases to query. Format: `projects//locations//knowledgeBases/`. Currently, at most 5 knowledge bases are supported.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionTriggerSettings = {
      description = "Settings of suggestion trigger.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionTriggerSettings",
      properties = {
        noSmalltalk = {
          description = "Do not trigger if last utterance is small talk.",
          type = "boolean",
        },
        onlyEndUser = {
          description = "Only trigger suggestion if participant role of last utterance is END_USER.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentAssistantEvent = {
      description = "Represents a notification sent to Cloud Pub/Sub subscribers for human agent assistant events in a specific conversation.",
      id = "GoogleCloudDialogflowV2HumanAgentAssistantEvent",
      properties = {
        conversation = {
          description = "The conversation this notification refers to. Format: `projects//conversations/`.",
          type = "string",
        },
        participant = {
          description = "The participant that the suggestion is compiled for. Format: `projects//conversations//participants/`. It will not be set in legacy workflow.",
          type = "string",
        },
        suggestionResults = {
          description = "The suggestion results payload that this notification refers to.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SuggestionResult",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentHandoffConfig = {
      description = "Defines the hand off to a live agent, typically on which external agent service provider to connect to a conversation. Currently, this feature is not general available, please contact Google to get access.",
      id = "GoogleCloudDialogflowV2HumanAgentHandoffConfig",
      properties = {
        livePersonConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentHandoffConfigLivePersonConfig",
          description = "Uses LivePerson (https://www.liveperson.com).",
        },
        salesforceLiveAgentConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentHandoffConfigSalesforceLiveAgentConfig",
          description = "Uses Salesforce Live Agent.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentHandoffConfigLivePersonConfig = {
      description = "Configuration specific to LivePerson (https://www.liveperson.com).",
      id = "GoogleCloudDialogflowV2HumanAgentHandoffConfigLivePersonConfig",
      properties = {
        accountNumber = {
          description = "Required. Account number of the LivePerson account to connect. This is the account number you input at the login page.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2HumanAgentHandoffConfigSalesforceLiveAgentConfig = {
      description = "Configuration specific to Salesforce Live Agent.",
      id = "GoogleCloudDialogflowV2HumanAgentHandoffConfigSalesforceLiveAgentConfig",
      properties = {
        buttonId = {
          description = "Required. Live Agent chat button ID.",
          type = "string",
        },
        deploymentId = {
          description = "Required. Live Agent deployment ID.",
          type = "string",
        },
        endpointDomain = {
          description = "Required. Domain of the Live Agent endpoint for this agent. You can find the endpoint URL in the `Live Agent settings` page. For example if URL has the form https://d.la4-c2-phx.salesforceliveagent.com/..., you should fill in d.la4-c2-phx.salesforceliveagent.com.",
          type = "string",
        },
        organizationId = {
          description = "Required. The organization ID of the Salesforce account.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportAgentRequest = {
      description = "The request message for Agents.ImportAgent.",
      id = "GoogleCloudDialogflowV2ImportAgentRequest",
      properties = {
        agentContent = {
          description = "Zip compressed raw byte content for agent.",
          format = "byte",
          type = "string",
        },
        agentUri = {
          description = "The URI to a Google Cloud Storage file containing the agent to import. Note: The URI must start with \"gs://\". Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see [Dialogflow access control](https://cloud.google.com/dialogflow/cx/docs/concept/access-control#storage).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportConversationDataOperationMetadata = {
      description = "Metadata for a ConversationDatasets.ImportConversationData operation.",
      id = "GoogleCloudDialogflowV2ImportConversationDataOperationMetadata",
      properties = {
        conversationDataset = {
          description = "The resource name of the imported conversation dataset. Format: `projects//locations//conversationDatasets/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp when import conversation data request was created. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        partialFailures = {
          description = "Partial failures are failures that don't fail the whole long running operation, e.g. single files that couldn't be read.",
          items = {
            ["$ref"] = "GoogleRpcStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportConversationDataOperationResponse = {
      description = "Response used for ConversationDatasets.ImportConversationData long running operation.",
      id = "GoogleCloudDialogflowV2ImportConversationDataOperationResponse",
      properties = {
        conversationDataset = {
          description = "The resource name of the imported conversation dataset. Format: `projects//locations//conversationDatasets/`",
          type = "string",
        },
        importCount = {
          description = "Number of conversations imported successfully.",
          format = "int32",
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportConversationDataRequest = {
      description = "The request message for ConversationDatasets.ImportConversationData.",
      id = "GoogleCloudDialogflowV2ImportConversationDataRequest",
      properties = {
        inputConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2InputConfig",
          description = "Required. Configuration describing where to import data from.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportDocumentTemplate = {
      description = "The template used for importing documents.",
      id = "GoogleCloudDialogflowV2ImportDocumentTemplate",
      properties = {
        knowledgeTypes = {
          description = "Required. The knowledge type of document content.",
          items = {
            enum = {
              "KNOWLEDGE_TYPE_UNSPECIFIED",
              "FAQ",
              "EXTRACTIVE_QA",
              "ARTICLE_SUGGESTION",
              "AGENT_FACING_SMART_REPLY",
            },
            enumDescriptions = {
              "The type is unspecified or arbitrary.",
              "The document content contains question and answer pairs as either HTML or CSV. Typical FAQ HTML formats are parsed accurately, but unusual formats may fail to be parsed. CSV must have questions in the first column and answers in the second, with no header. Because of this explicit format, they are always parsed accurately.",
              "Documents for which unstructured text is extracted and used for question answering.",
              "The entire document content as a whole can be used for query results. Only for Contact Center Solutions on Dialogflow.",
              "The document contains agent-facing Smart Reply entries.",
            },
            type = "string",
          },
          type = "array",
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "Metadata for the document. The metadata supports arbitrary key-value pairs. Suggested use cases include storing a document's title, an external URL distinct from the document's content_uri, etc. The max size of a `key` or a `value` of the metadata is 1024 bytes.",
          type = "object",
        },
        mimeType = {
          description = "Required. The MIME type of the document.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportDocumentsRequest = {
      description = "Request message for Documents.ImportDocuments.",
      id = "GoogleCloudDialogflowV2ImportDocumentsRequest",
      properties = {
        documentTemplate = {
          ["$ref"] = "GoogleCloudDialogflowV2ImportDocumentTemplate",
          description = "Required. Document template used for importing all the documents.",
        },
        gcsSource = {
          ["$ref"] = "GoogleCloudDialogflowV2GcsSources",
          description = "The Google Cloud Storage location for the documents. The path can include a wildcard. These URIs may have the forms `gs:///`. `gs:////*.`.",
        },
        importGcsCustomMetadata = {
          description = "Whether to import custom metadata from Google Cloud Storage. Only valid when the document source is Google Cloud Storage URI.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ImportDocumentsResponse = {
      description = "Response message for Documents.ImportDocuments.",
      id = "GoogleCloudDialogflowV2ImportDocumentsResponse",
      properties = {
        warnings = {
          description = "Includes details about skipped documents or any other warnings.",
          items = {
            ["$ref"] = "GoogleRpcStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2InputAudioConfig = {
      description = "Instructs the speech recognizer how to process the audio content.",
      id = "GoogleCloudDialogflowV2InputAudioConfig",
      properties = {
        audioEncoding = {
          description = "Required. Audio encoding of the audio content to process.",
          enum = {
            "AUDIO_ENCODING_UNSPECIFIED",
            "AUDIO_ENCODING_LINEAR_16",
            "AUDIO_ENCODING_FLAC",
            "AUDIO_ENCODING_MULAW",
            "AUDIO_ENCODING_AMR",
            "AUDIO_ENCODING_AMR_WB",
            "AUDIO_ENCODING_OGG_OPUS",
            "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE",
          },
          enumDescriptions = {
            "Not specified.",
            "Uncompressed 16-bit signed little-endian samples (Linear PCM).",
            "[`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio Codec) is the recommended encoding because it is lossless (therefore recognition is not compromised) and requires only about half the bandwidth of `LINEAR16`. `FLAC` stream encoding supports 16-bit and 24-bit samples, however, not all fields in `STREAMINFO` are supported.",
            "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.",
            "Adaptive Multi-Rate Narrowband codec. `sample_rate_hertz` must be 8000.",
            "Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.",
            "Opus encoded audio frames in Ogg container ([OggOpus](https://wiki.xiph.org/OggOpus)). `sample_rate_hertz` must be 16000.",
            "Although the use of lossy encodings is not recommended, if a very low bitrate encoding is required, `OGG_OPUS` is highly preferred over Speex encoding. The [Speex](https://speex.org/) encoding supported by Dialogflow API has a header byte in each block, as in MIME type `audio/x-speex-with-header-byte`. It is a variant of the RTP Speex encoding defined in [RFC 5574](https://tools.ietf.org/html/rfc5574). The stream is a sequence of blocks, one block per RTP packet. Each block starts with a byte containing the length of the block, in bytes, followed by one or more frames of Speex data, padded to an integral number of bytes (octets) as specified in RFC 5574. In other words, each RTP header is replaced with a single byte containing the block length. Only Speex wideband is supported. `sample_rate_hertz` must be 16000.",
          },
          type = "string",
        },
        disableNoSpeechRecognizedEvent = {
          description = "Only used in Participants.AnalyzeContent and Participants.StreamingAnalyzeContent. If `false` and recognition doesn't return any result, trigger `NO_SPEECH_RECOGNIZED` event to Dialogflow agent.",
          type = "boolean",
        },
        enableWordInfo = {
          description = "If `true`, Dialogflow returns SpeechWordInfo in StreamingRecognitionResult with information about the recognized speech words, e.g. start and end time offsets. If false or unspecified, Speech doesn't return any word-level information.",
          type = "boolean",
        },
        languageCode = {
          description = "Required. The language of the supplied audio. Dialogflow does not do translations. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.",
          type = "string",
        },
        model = {
          description = "Which Speech model to select for the given request. Select the model best suited to your domain to get best results. If a model is not explicitly specified, then we auto-select a model based on the parameters in the InputAudioConfig. If enhanced speech model is enabled for the agent and an enhanced version of the specified model for the language does not exist, then the speech is recognized using the standard version of the specified model. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics#select-model) for more details.",
          type = "string",
        },
        modelVariant = {
          description = "Which variant of the Speech model to use.",
          enum = {
            "SPEECH_MODEL_VARIANT_UNSPECIFIED",
            "USE_BEST_AVAILABLE",
            "USE_STANDARD",
            "USE_ENHANCED",
          },
          enumDescriptions = {
            "No model variant specified. In this case Dialogflow defaults to USE_BEST_AVAILABLE.",
            "Use the best available variant of the Speech model that the caller is eligible for. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible for enhanced models.",
            "Use standard model variant even if an enhanced model is available. See the [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) for details about enhanced models.",
            "Use an enhanced model variant: * If an enhanced variant does not exist for the given model and request language, Dialogflow falls back to the standard variant. The [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) describes which models have enhanced variants. * If the API caller isn't eligible for enhanced models, Dialogflow returns an error. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible.",
          },
          type = "string",
        },
        phraseHints = {
          description = "A list of strings containing words and phrases that the speech recognizer should recognize with higher likelihood. See [the Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints) for more details. This field is deprecated. Please use [speech_contexts]() instead. If you specify both [phrase_hints]() and [speech_contexts](), Dialogflow will treat the [phrase_hints]() as a single additional [SpeechContext]().",
          items = {
            type = "string",
          },
          type = "array",
        },
        sampleRateHertz = {
          description = "Required. Sample rate (in Hertz) of the audio content sent in the query. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics) for more details.",
          format = "int32",
          type = "integer",
        },
        singleUtterance = {
          description = "If `false` (default), recognition does not cease until the client closes the stream. If `true`, the recognizer will detect a single spoken utterance in input audio. Recognition ceases when it detects the audio's voice has stopped or paused. In this case, once a detected intent is received, the client should close the stream and start a new request with a new stream as needed. Note: This setting is relevant only for streaming methods. Note: When specified, InputAudioConfig.single_utterance takes precedence over StreamingDetectIntentRequest.single_utterance.",
          type = "boolean",
        },
        speechContexts = {
          description = "Context information to assist speech recognition. See [the Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints) for more details.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SpeechContext",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2InputConfig = {
      description = "Represents the configuration of importing a set of conversation files in Google Cloud Storage.",
      id = "GoogleCloudDialogflowV2InputConfig",
      properties = {
        gcsSource = {
          ["$ref"] = "GoogleCloudDialogflowV2GcsSources",
          description = "The Cloud Storage URI has the form gs:////agent*.json. Wildcards are allowed and will be expanded into all matched JSON files, which will be read as one conversation per file.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2InputDataset = {
      description = "InputDataset used to create model or do evaluation. NextID:5",
      id = "GoogleCloudDialogflowV2InputDataset",
      properties = {
        dataset = {
          description = "Required. ConversationDataset resource name. Format: `projects//locations//conversationDatasets/`",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Intent = {
      description = "An intent categorizes an end-user's intention for one conversation turn. For each agent, you define many intents, where your combined intents can handle a complete conversation. When an end-user writes or says something, referred to as an end-user expression or end-user input, Dialogflow matches the end-user input to the best intent in your agent. Matching an intent is also known as intent classification. For more information, see the [intent guide](https://cloud.google.com/dialogflow/docs/intents-overview).",
      id = "GoogleCloudDialogflowV2Intent",
      properties = {
        action = {
          description = "Optional. The name of the action associated with the intent. Note: The action name must not contain whitespaces.",
          type = "string",
        },
        defaultResponsePlatforms = {
          description = "Optional. The list of platforms for which the first responses will be copied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform).",
          items = {
            enum = {
              "PLATFORM_UNSPECIFIED",
              "FACEBOOK",
              "SLACK",
              "TELEGRAM",
              "KIK",
              "SKYPE",
              "LINE",
              "VIBER",
              "ACTIONS_ON_GOOGLE",
              "GOOGLE_HANGOUTS",
            },
            enumDescriptions = {
              "Default platform.",
              "Facebook.",
              "Slack.",
              "Telegram.",
              "Kik.",
              "Skype.",
              "Line.",
              "Viber.",
              "Google Assistant See [Dialogflow webhook format](https://developers.google.com/assistant/actions/build/json/dialogflow-webhook-json)",
              "Google Hangouts.",
            },
            type = "string",
          },
          type = "array",
        },
        displayName = {
          description = "Required. The name of this intent.",
          type = "string",
        },
        endInteraction = {
          description = "Optional. Indicates that this intent ends an interaction. Some integrations (e.g., Actions on Google or Dialogflow phone gateway) use this information to close interaction with an end user. Default is false.",
          type = "boolean",
        },
        events = {
          description = "Optional. The collection of event names that trigger the intent. If the collection of input contexts is not empty, all of the contexts must be present in the active user session for an event to trigger this intent. Event names are limited to 150 characters.",
          items = {
            type = "string",
          },
          type = "array",
        },
        followupIntentInfo = {
          description = "Output only. Read-only. Information about all followup intents that have this intent as a direct or indirect parent. We populate this field only in the output.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentFollowupIntentInfo",
          },
          readOnly = true,
          type = "array",
        },
        inputContextNames = {
          description = "Optional. The list of context names required for this intent to be triggered. Format: `projects//agent/sessions/-/contexts/`.",
          items = {
            type = "string",
          },
          type = "array",
        },
        isFallback = {
          description = "Optional. Indicates whether this is a fallback intent.",
          type = "boolean",
        },
        liveAgentHandoff = {
          description = "Optional. Indicates that a live agent should be brought in to handle the interaction with the user. In most cases, when you set this flag to true, you would also want to set end_interaction to true as well. Default is false.",
          type = "boolean",
        },
        messages = {
          description = "Optional. The collection of rich messages corresponding to the `Response` field in the Dialogflow console.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessage",
          },
          type = "array",
        },
        mlDisabled = {
          description = "Optional. Indicates whether Machine Learning is disabled for the intent. Note: If `ml_disabled` setting is set to true, then this intent is not taken into account during inference in `ML ONLY` match mode. Also, auto-markup in the UI is turned off.",
          type = "boolean",
        },
        name = {
          description = "Optional. The unique identifier of this intent. Required for Intents.UpdateIntent and Intents.BatchUpdateIntents methods. Format: `projects//agent/intents/`.",
          type = "string",
        },
        outputContexts = {
          description = "Optional. The collection of contexts that are activated when the intent is matched. Context messages in this collection should not set the parameters field. Setting the `lifespan_count` to 0 will reset the context when the intent is matched. Format: `projects//agent/sessions/-/contexts/`.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Context",
          },
          type = "array",
        },
        parameters = {
          description = "Optional. The collection of parameters associated with the intent.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentParameter",
          },
          type = "array",
        },
        parentFollowupIntentName = {
          description = "Read-only after creation. The unique identifier of the parent intent in the chain of followup intents. You can set this field when creating an intent, for example with CreateIntent or BatchUpdateIntents, in order to make this intent a followup intent. It identifies the parent followup intent. Format: `projects//agent/intents/`.",
          type = "string",
        },
        priority = {
          description = "Optional. The priority of this intent. Higher numbers represent higher priorities. - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds to the `Normal` priority in the console. - If the supplied value is negative, the intent is ignored in runtime detect intent requests.",
          format = "int32",
          type = "integer",
        },
        resetContexts = {
          description = "Optional. Indicates whether to delete all contexts in the current session when this intent is matched.",
          type = "boolean",
        },
        rootFollowupIntentName = {
          description = "Output only. Read-only. The unique identifier of the root intent in the chain of followup intents. It identifies the correct followup intents chain for this intent. We populate this field only in the output. Format: `projects//agent/intents/`.",
          readOnly = true,
          type = "string",
        },
        trainingPhrases = {
          description = "Optional. The collection of examples that the agent is trained on.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentTrainingPhrase",
          },
          type = "array",
        },
        webhookState = {
          description = "Optional. Indicates whether webhooks are enabled for the intent.",
          enum = {
            "WEBHOOK_STATE_UNSPECIFIED",
            "WEBHOOK_STATE_ENABLED",
            "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING",
          },
          enumDescriptions = {
            "Webhook is disabled in the agent and in the intent.",
            "Webhook is enabled in the agent and in the intent.",
            "Webhook is enabled in the agent and in the intent. Also, each slot filling prompt is forwarded to the webhook.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentBatch = {
      description = "This message is a wrapper around a collection of intents.",
      id = "GoogleCloudDialogflowV2IntentBatch",
      properties = {
        intents = {
          description = "A collection of intents.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Intent",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentFollowupIntentInfo = {
      description = "Represents a single followup intent in the chain.",
      id = "GoogleCloudDialogflowV2IntentFollowupIntentInfo",
      properties = {
        followupIntentName = {
          description = "The unique identifier of the followup intent. Format: `projects//agent/intents/`.",
          type = "string",
        },
        parentFollowupIntentName = {
          description = "The unique identifier of the followup intent's parent. Format: `projects//agent/intents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessage = {
      description = "A rich response message. Corresponds to the intent `Response` field in the Dialogflow console. For more information, see [Rich response messages](https://cloud.google.com/dialogflow/docs/intents-rich-messages).",
      id = "GoogleCloudDialogflowV2IntentMessage",
      properties = {
        basicCard = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBasicCard",
          description = "The basic card response for Actions on Google.",
        },
        browseCarouselCard = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard",
          description = "Browse carousel card for Actions on Google.",
        },
        card = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageCard",
          description = "The card response.",
        },
        carouselSelect = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageCarouselSelect",
          description = "The carousel card response for Actions on Google.",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "The image response.",
        },
        linkOutSuggestion = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion",
          description = "The link out suggestion chip for Actions on Google.",
        },
        listSelect = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageListSelect",
          description = "The list card response for Actions on Google.",
        },
        mediaContent = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageMediaContent",
          description = "The media content card for Actions on Google.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "A custom platform-specific response.",
          type = "object",
        },
        platform = {
          description = "Optional. The platform that this message is intended for.",
          enum = {
            "PLATFORM_UNSPECIFIED",
            "FACEBOOK",
            "SLACK",
            "TELEGRAM",
            "KIK",
            "SKYPE",
            "LINE",
            "VIBER",
            "ACTIONS_ON_GOOGLE",
            "GOOGLE_HANGOUTS",
          },
          enumDescriptions = {
            "Default platform.",
            "Facebook.",
            "Slack.",
            "Telegram.",
            "Kik.",
            "Skype.",
            "Line.",
            "Viber.",
            "Google Assistant See [Dialogflow webhook format](https://developers.google.com/assistant/actions/build/json/dialogflow-webhook-json)",
            "Google Hangouts.",
          },
          type = "string",
        },
        quickReplies = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageQuickReplies",
          description = "The quick replies response.",
        },
        simpleResponses = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageSimpleResponses",
          description = "The voice and text-only responses for Actions on Google.",
        },
        suggestions = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageSuggestions",
          description = "The suggestion chips for Actions on Google.",
        },
        tableCard = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageTableCard",
          description = "Table card for Actions on Google.",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageText",
          description = "The text response.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageBasicCard = {
      description = "The basic card message. Useful for displaying information.",
      id = "GoogleCloudDialogflowV2IntentMessageBasicCard",
      properties = {
        buttons = {
          description = "Optional. The collection of card buttons.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBasicCardButton",
          },
          type = "array",
        },
        formattedText = {
          description = "Required, unless image is present. The body text of the card.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. The image for the card.",
        },
        subtitle = {
          description = "Optional. The subtitle of the card.",
          type = "string",
        },
        title = {
          description = "Optional. The title of the card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageBasicCardButton = {
      description = "The button object that appears at the bottom of a card.",
      id = "GoogleCloudDialogflowV2IntentMessageBasicCardButton",
      properties = {
        openUriAction = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction",
          description = "Required. Action to take when a user taps on the button.",
        },
        title = {
          description = "Required. The title of the button.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction = {
      description = "Opens the given URI.",
      id = "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction",
      properties = {
        uri = {
          description = "Required. The HTTP or HTTPS scheme URI.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard = {
      description = "Browse Carousel Card for Actions on Google. https://developers.google.com/actions/assistant/responses#browsing_carousel",
      id = "GoogleCloudDialogflowV2IntentMessageBrowseCarouselCard",
      properties = {
        imageDisplayOptions = {
          description = "Optional. Settings for displaying the image. Applies to every image in items.",
          enum = {
            "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED",
            "GRAY",
            "WHITE",
            "CROPPED",
            "BLURRED_BACKGROUND",
          },
          enumDescriptions = {
            "Fill the gaps between the image and the image container with gray bars.",
            "Fill the gaps between the image and the image container with gray bars.",
            "Fill the gaps between the image and the image container with white bars.",
            "Image is scaled such that the image width and height match or exceed the container dimensions. This may crop the top and bottom of the image if the scaled image height is greater than the container height, or crop the left and right of the image if the scaled image width is greater than the container width. This is similar to \"Zoom Mode\" on a widescreen TV when playing a 4:3 video.",
            "Pad the gaps between image and image frame with a blurred copy of the same image.",
          },
          type = "string",
        },
        items = {
          description = "Required. List of items in the Browse Carousel Card. Minimum of two items, maximum of ten.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem = {
      description = "Browsing carousel tile",
      id = "GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItem",
      properties = {
        description = {
          description = "Optional. Description of the carousel item. Maximum of four lines of text.",
          type = "string",
        },
        footer = {
          description = "Optional. Text that appears at the bottom of the Browse Carousel Card. Maximum of one line of text.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. Hero image for the carousel item.",
        },
        openUriAction = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction",
          description = "Required. Action to present to the user.",
        },
        title = {
          description = "Required. Title of the carousel item. Maximum of two lines of text.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction = {
      description = "Actions on Google action to open a given url.",
      id = "GoogleCloudDialogflowV2IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction",
      properties = {
        url = {
          description = "Required. URL",
          type = "string",
        },
        urlTypeHint = {
          description = "Optional. Specifies the type of viewer that is used when opening the URL. Defaults to opening via web browser.",
          enum = {
            "URL_TYPE_HINT_UNSPECIFIED",
            "AMP_ACTION",
            "AMP_CONTENT",
          },
          enumDescriptions = {
            "Unspecified",
            "Url would be an amp action",
            "URL that points directly to AMP content, or to a canonical URL which refers to AMP content via .",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageCard = {
      description = "The card response message.",
      id = "GoogleCloudDialogflowV2IntentMessageCard",
      properties = {
        buttons = {
          description = "Optional. The collection of card buttons.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageCardButton",
          },
          type = "array",
        },
        imageUri = {
          description = "Optional. The public URI to an image file for the card.",
          type = "string",
        },
        subtitle = {
          description = "Optional. The subtitle of the card.",
          type = "string",
        },
        title = {
          description = "Optional. The title of the card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageCardButton = {
      description = "Contains information about a button.",
      id = "GoogleCloudDialogflowV2IntentMessageCardButton",
      properties = {
        postback = {
          description = "Optional. The text to send back to the Dialogflow API or a URI to open.",
          type = "string",
        },
        text = {
          description = "Optional. The text to show on the button.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageCarouselSelect = {
      description = "The card for presenting a carousel of options to select from.",
      id = "GoogleCloudDialogflowV2IntentMessageCarouselSelect",
      properties = {
        items = {
          description = "Required. Carousel items.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageCarouselSelectItem = {
      description = "An item in the carousel.",
      id = "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem",
      properties = {
        description = {
          description = "Optional. The body text of the card.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. The image to display.",
        },
        info = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageSelectItemInfo",
          description = "Required. Additional info about the option item.",
        },
        title = {
          description = "Required. Title of the carousel item.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageColumnProperties = {
      description = "Column properties for TableCard.",
      id = "GoogleCloudDialogflowV2IntentMessageColumnProperties",
      properties = {
        header = {
          description = "Required. Column heading.",
          type = "string",
        },
        horizontalAlignment = {
          description = "Optional. Defines text alignment for all cells in this column.",
          enum = {
            "HORIZONTAL_ALIGNMENT_UNSPECIFIED",
            "LEADING",
            "CENTER",
            "TRAILING",
          },
          enumDescriptions = {
            "Text is aligned to the leading edge of the column.",
            "Text is aligned to the leading edge of the column.",
            "Text is centered in the column.",
            "Text is aligned to the trailing edge of the column.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageImage = {
      description = "The image response message.",
      id = "GoogleCloudDialogflowV2IntentMessageImage",
      properties = {
        accessibilityText = {
          description = "Optional. A text description of the image to be used for accessibility, e.g., screen readers.",
          type = "string",
        },
        imageUri = {
          description = "Optional. The public URI to an image file.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion = {
      description = "The suggestion chip message that allows the user to jump out to the app or website associated with this agent.",
      id = "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion",
      properties = {
        destinationName = {
          description = "Required. The name of the app or site this chip is linking to.",
          type = "string",
        },
        uri = {
          description = "Required. The URI of the app or site to open when the user taps the suggestion chip.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageListSelect = {
      description = "The card for presenting a list of options to select from.",
      id = "GoogleCloudDialogflowV2IntentMessageListSelect",
      properties = {
        items = {
          description = "Required. List items.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageListSelectItem",
          },
          type = "array",
        },
        subtitle = {
          description = "Optional. Subtitle of the list.",
          type = "string",
        },
        title = {
          description = "Optional. The overall title of the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageListSelectItem = {
      description = "An item in the list.",
      id = "GoogleCloudDialogflowV2IntentMessageListSelectItem",
      properties = {
        description = {
          description = "Optional. The main text describing the item.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. The image to display.",
        },
        info = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageSelectItemInfo",
          description = "Required. Additional information about this option.",
        },
        title = {
          description = "Required. The title of the list item.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageMediaContent = {
      description = "The media content card for Actions on Google.",
      id = "GoogleCloudDialogflowV2IntentMessageMediaContent",
      properties = {
        mediaObjects = {
          description = "Required. List of media objects.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageMediaContentResponseMediaObject",
          },
          type = "array",
        },
        mediaType = {
          description = "Optional. What type of media is the content (ie \"audio\").",
          enum = {
            "RESPONSE_MEDIA_TYPE_UNSPECIFIED",
            "AUDIO",
          },
          enumDescriptions = {
            "Unspecified.",
            "Response media type is audio.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageMediaContentResponseMediaObject = {
      description = "Response media object for media content card.",
      id = "GoogleCloudDialogflowV2IntentMessageMediaContentResponseMediaObject",
      properties = {
        contentUrl = {
          description = "Required. Url where the media is stored.",
          type = "string",
        },
        description = {
          description = "Optional. Description of media card.",
          type = "string",
        },
        icon = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. Icon to display above media content.",
        },
        largeImage = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. Image to display above media content.",
        },
        name = {
          description = "Required. Name of media card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageQuickReplies = {
      description = "The quick replies response message.",
      id = "GoogleCloudDialogflowV2IntentMessageQuickReplies",
      properties = {
        quickReplies = {
          description = "Optional. The collection of quick replies.",
          items = {
            type = "string",
          },
          type = "array",
        },
        title = {
          description = "Optional. The title of the collection of quick replies.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageSelectItemInfo = {
      description = "Additional info about the select item for when it is triggered in a dialog.",
      id = "GoogleCloudDialogflowV2IntentMessageSelectItemInfo",
      properties = {
        key = {
          description = "Required. A unique key that will be sent back to the agent if this response is given.",
          type = "string",
        },
        synonyms = {
          description = "Optional. A list of synonyms that can also be used to trigger this item in dialog.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageSimpleResponse = {
      description = "The simple response message containing speech or text.",
      id = "GoogleCloudDialogflowV2IntentMessageSimpleResponse",
      properties = {
        displayText = {
          description = "Optional. The text to display.",
          type = "string",
        },
        ssml = {
          description = "One of text_to_speech or ssml must be provided. Structured spoken response to the user in the SSML format. Mutually exclusive with text_to_speech.",
          type = "string",
        },
        textToSpeech = {
          description = "One of text_to_speech or ssml must be provided. The plain text of the speech output. Mutually exclusive with ssml.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageSimpleResponses = {
      description = "The collection of simple response candidates. This message in `QueryResult.fulfillment_messages` and `WebhookResponse.fulfillment_messages` should contain only one `SimpleResponse`.",
      id = "GoogleCloudDialogflowV2IntentMessageSimpleResponses",
      properties = {
        simpleResponses = {
          description = "Required. The list of simple responses.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageSimpleResponse",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageSuggestion = {
      description = "The suggestion chip message that the user can tap to quickly post a reply to the conversation.",
      id = "GoogleCloudDialogflowV2IntentMessageSuggestion",
      properties = {
        title = {
          description = "Required. The text shown the in the suggestion chip.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageSuggestions = {
      description = "The collection of suggestions.",
      id = "GoogleCloudDialogflowV2IntentMessageSuggestions",
      properties = {
        suggestions = {
          description = "Required. The list of suggested replies.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageSuggestion",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageTableCard = {
      description = "Table card for Actions on Google.",
      id = "GoogleCloudDialogflowV2IntentMessageTableCard",
      properties = {
        buttons = {
          description = "Optional. List of buttons for the card.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageBasicCardButton",
          },
          type = "array",
        },
        columnProperties = {
          description = "Optional. Display properties for the columns in this table.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageColumnProperties",
          },
          type = "array",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2IntentMessageImage",
          description = "Optional. Image which should be displayed on the card.",
        },
        rows = {
          description = "Optional. Rows in this table of data.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageTableCardRow",
          },
          type = "array",
        },
        subtitle = {
          description = "Optional. Subtitle to the title.",
          type = "string",
        },
        title = {
          description = "Required. Title of the card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageTableCardCell = {
      description = "Cell of TableCardRow.",
      id = "GoogleCloudDialogflowV2IntentMessageTableCardCell",
      properties = {
        text = {
          description = "Required. Text in this cell.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageTableCardRow = {
      description = "Row of TableCard.",
      id = "GoogleCloudDialogflowV2IntentMessageTableCardRow",
      properties = {
        cells = {
          description = "Optional. List of cells that make up this row.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessageTableCardCell",
          },
          type = "array",
        },
        dividerAfter = {
          description = "Optional. Whether to add a visual divider after this row.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentMessageText = {
      description = "The text response message.",
      id = "GoogleCloudDialogflowV2IntentMessageText",
      properties = {
        text = {
          description = "Optional. The collection of the agent's responses.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentParameter = {
      description = "Represents intent parameters.",
      id = "GoogleCloudDialogflowV2IntentParameter",
      properties = {
        defaultValue = {
          description = "Optional. The default value to use when the `value` yields an empty result. Default values can be extracted from contexts by using the following syntax: `#context_name.parameter_name`.",
          type = "string",
        },
        displayName = {
          description = "Required. The name of the parameter.",
          type = "string",
        },
        entityTypeDisplayName = {
          description = "Optional. The name of the entity type, prefixed with `@`, that describes values of the parameter. If the parameter is required, this must be provided.",
          type = "string",
        },
        isList = {
          description = "Optional. Indicates whether the parameter represents a list of values.",
          type = "boolean",
        },
        mandatory = {
          description = "Optional. Indicates whether the parameter is required. That is, whether the intent cannot be completed without collecting the parameter value.",
          type = "boolean",
        },
        name = {
          description = "The unique identifier of this parameter.",
          type = "string",
        },
        prompts = {
          description = "Optional. The collection of prompts that the agent can present to the user in order to collect a value for the parameter.",
          items = {
            type = "string",
          },
          type = "array",
        },
        value = {
          description = "Optional. The definition of the parameter value. It can be: - a constant string, - a parameter value defined as `$parameter_name`, - an original parameter value defined as `$parameter_name.original`, - a parameter value from some context defined as `#context_name.parameter_name`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentTrainingPhrase = {
      description = "Represents an example that the agent is trained on.",
      id = "GoogleCloudDialogflowV2IntentTrainingPhrase",
      properties = {
        name = {
          description = "Output only. The unique identifier of this training phrase.",
          type = "string",
        },
        parts = {
          description = "Required. The ordered list of training phrase parts. The parts are concatenated in order to form the training phrase. Note: The API does not automatically annotate training phrases like the Dialogflow Console does. Note: Do not forget to include whitespace at part boundaries, so the training phrase is well formatted when the parts are concatenated. If the training phrase does not need to be annotated with parameters, you just need a single part with only the Part.text field set. If you want to annotate the training phrase, you must create multiple parts, where the fields of each part are populated in one of two ways: - `Part.text` is set to a part of the phrase that has no parameters. - `Part.text` is set to a part of the phrase that you want to annotate, and the `entity_type`, `alias`, and `user_defined` fields are all set.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentTrainingPhrasePart",
          },
          type = "array",
        },
        timesAddedCount = {
          description = "Optional. Indicates how many times this example was added to the intent. Each time a developer adds an existing sample by editing an intent or training, this counter is increased.",
          format = "int32",
          type = "integer",
        },
        type = {
          description = "Required. The type of the training phrase.",
          enum = {
            "TYPE_UNSPECIFIED",
            "EXAMPLE",
            "TEMPLATE",
          },
          enumDescriptions = {
            "Not specified. This value should never be used.",
            "Examples do not contain @-prefixed entity type names, but example parts can be annotated with entity types.",
            "Templates are not annotated with entity types, but they can contain @-prefixed entity type names as substrings. Template mode has been deprecated. Example mode is the only supported way to create new training phrases. If you have existing training phrases that you've created in template mode, those will continue to work.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2IntentTrainingPhrasePart = {
      description = "Represents a part of a training phrase.",
      id = "GoogleCloudDialogflowV2IntentTrainingPhrasePart",
      properties = {
        alias = {
          description = "Optional. The parameter name for the value extracted from the annotated part of the example. This field is required for annotated parts of the training phrase.",
          type = "string",
        },
        entityType = {
          description = "Optional. The entity type name prefixed with `@`. This field is required for annotated parts of the training phrase.",
          type = "string",
        },
        text = {
          description = "Required. The text for this part.",
          type = "string",
        },
        userDefined = {
          description = "Optional. Indicates whether the text was manually annotated. This field is set to true when the Dialogflow Console is used to manually annotate the part. When creating an annotated part with the API, you must set this to true.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2KnowledgeBase = {
      description = "A knowledge base represents a collection of knowledge documents that you provide to Dialogflow. Your knowledge documents contain information that may be useful during conversations with end-users. Some Dialogflow features use knowledge bases when looking for a response to an end-user input. For more information, see the [knowledge base guide](https://cloud.google.com/dialogflow/docs/how/knowledge-bases). Note: The `projects.agent.knowledgeBases` resource is deprecated; only use `projects.knowledgeBases`.",
      id = "GoogleCloudDialogflowV2KnowledgeBase",
      properties = {
        displayName = {
          description = "Required. The display name of the knowledge base. The name must be 1024 bytes or less; otherwise, the creation request fails.",
          type = "string",
        },
        languageCode = {
          description = "Language which represents the KnowledgeBase. When the KnowledgeBase is created/updated, expect this to be present for non en-us languages. When unspecified, the default language code en-us applies.",
          type = "string",
        },
        name = {
          description = "The knowledge base resource name. The name must be empty when creating a knowledge base. Format: `projects//locations//knowledgeBases/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2KnowledgeOperationMetadata = {
      description = "Metadata in google::longrunning::Operation for Knowledge operations.",
      id = "GoogleCloudDialogflowV2KnowledgeOperationMetadata",
      properties = {
        exportOperationMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV2ExportOperationMetadata",
          description = "Metadata for the Export Data Operation such as the destination of export.",
        },
        knowledgeBase = {
          description = "The name of the knowledge base interacted with during the operation.",
          type = "string",
        },
        state = {
          description = "Output only. The current state of this operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "PENDING",
            "RUNNING",
            "DONE",
          },
          enumDescriptions = {
            "State unspecified.",
            "The operation has been created.",
            "The operation is currently running.",
            "The operation is done, either cancelled or completed.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListAnswerRecordsResponse = {
      description = "Response message for AnswerRecords.ListAnswerRecords.",
      id = "GoogleCloudDialogflowV2ListAnswerRecordsResponse",
      properties = {
        answerRecords = {
          description = "The list of answer records.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2AnswerRecord",
          },
          type = "array",
        },
        nextPageToken = {
          description = "A token to retrieve next page of results. Or empty if there are no more results. Pass this value in the ListAnswerRecordsRequest.page_token field in the subsequent call to `ListAnswerRecords` method to retrieve the next page of results.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListContextsResponse = {
      description = "The response message for Contexts.ListContexts.",
      id = "GoogleCloudDialogflowV2ListContextsResponse",
      properties = {
        contexts = {
          description = "The list of contexts. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Context",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListConversationDatasetsResponse = {
      description = "The response message for ConversationDatasets.ListConversationDatasets.",
      id = "GoogleCloudDialogflowV2ListConversationDatasetsResponse",
      properties = {
        conversationDatasets = {
          description = "The list of datasets to return.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2ConversationDataset",
          },
          type = "array",
        },
        nextPageToken = {
          description = "The token to use to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListConversationModelEvaluationsResponse = {
      description = "The response message for ConversationModels.ListConversationModelEvaluations",
      id = "GoogleCloudDialogflowV2ListConversationModelEvaluationsResponse",
      properties = {
        conversationModelEvaluations = {
          description = "The list of evaluations to return.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2ConversationModelEvaluation",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListConversationModelsResponse = {
      description = "The response message for ConversationModels.ListConversationModels",
      id = "GoogleCloudDialogflowV2ListConversationModelsResponse",
      properties = {
        conversationModels = {
          description = "The list of models to return.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2ConversationModel",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListConversationProfilesResponse = {
      description = "The response message for ConversationProfiles.ListConversationProfiles.",
      id = "GoogleCloudDialogflowV2ListConversationProfilesResponse",
      properties = {
        conversationProfiles = {
          description = "The list of project conversation profiles. There is a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2ConversationProfile",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListConversationsResponse = {
      description = "The response message for Conversations.ListConversations.",
      id = "GoogleCloudDialogflowV2ListConversationsResponse",
      properties = {
        conversations = {
          description = "The list of conversations. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Conversation",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListDocumentsResponse = {
      description = "Response message for Documents.ListDocuments.",
      id = "GoogleCloudDialogflowV2ListDocumentsResponse",
      properties = {
        documents = {
          description = "The list of documents.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Document",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListEntityTypesResponse = {
      description = "The response message for EntityTypes.ListEntityTypes.",
      id = "GoogleCloudDialogflowV2ListEntityTypesResponse",
      properties = {
        entityTypes = {
          description = "The list of agent entity types. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityType",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListEnvironmentsResponse = {
      description = "The response message for Environments.ListEnvironments.",
      id = "GoogleCloudDialogflowV2ListEnvironmentsResponse",
      properties = {
        environments = {
          description = "The list of agent environments. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Environment",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListIntentsResponse = {
      description = "The response message for Intents.ListIntents.",
      id = "GoogleCloudDialogflowV2ListIntentsResponse",
      properties = {
        intents = {
          description = "The list of agent intents. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Intent",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListKnowledgeBasesResponse = {
      description = "Response message for KnowledgeBases.ListKnowledgeBases.",
      id = "GoogleCloudDialogflowV2ListKnowledgeBasesResponse",
      properties = {
        knowledgeBases = {
          description = "The list of knowledge bases.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2KnowledgeBase",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListMessagesResponse = {
      description = "The response message for Conversations.ListMessages.",
      id = "GoogleCloudDialogflowV2ListMessagesResponse",
      properties = {
        messages = {
          description = "The list of messages. There will be a maximum number of items returned based on the page_size field in the request. `messages` is sorted by `create_time` in descending order.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Message",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListParticipantsResponse = {
      description = "The response message for Participants.ListParticipants.",
      id = "GoogleCloudDialogflowV2ListParticipantsResponse",
      properties = {
        nextPageToken = {
          description = "Token to retrieve the next page of results or empty if there are no more results in the list.",
          type = "string",
        },
        participants = {
          description = "The list of participants. There is a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Participant",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListSessionEntityTypesResponse = {
      description = "The response message for SessionEntityTypes.ListSessionEntityTypes.",
      id = "GoogleCloudDialogflowV2ListSessionEntityTypesResponse",
      properties = {
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
        sessionEntityTypes = {
          description = "The list of session entity types. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ListVersionsResponse = {
      description = "The response message for Versions.ListVersions.",
      id = "GoogleCloudDialogflowV2ListVersionsResponse",
      properties = {
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
        versions = {
          description = "The list of agent versions. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Version",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2LoggingConfig = {
      description = "Defines logging behavior for conversation lifecycle events.",
      id = "GoogleCloudDialogflowV2LoggingConfig",
      properties = {
        enableStackdriverLogging = {
          description = "Whether to log conversation events like CONVERSATION_STARTED to Stackdriver in the conversation project as JSON format ConversationEvent protos.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Message = {
      description = "Represents a message posted into a conversation.",
      id = "GoogleCloudDialogflowV2Message",
      properties = {
        content = {
          description = "Required. The message content.",
          type = "string",
        },
        createTime = {
          description = "Output only. The time when the message was created in Contact Center AI.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        languageCode = {
          description = "Optional. The message language. This should be a [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag. Example: \"en-US\".",
          type = "string",
        },
        messageAnnotation = {
          ["$ref"] = "GoogleCloudDialogflowV2MessageAnnotation",
          description = "Output only. The annotation for the message.",
          readOnly = true,
        },
        name = {
          description = "Optional. The unique identifier of the message. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
        participant = {
          description = "Output only. The participant that sends this message.",
          readOnly = true,
          type = "string",
        },
        participantRole = {
          description = "Output only. The role of the participant.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          readOnly = true,
          type = "string",
        },
        sendTime = {
          description = "Optional. The time when the message was sent.",
          format = "google-datetime",
          type = "string",
        },
        sentimentAnalysis = {
          ["$ref"] = "GoogleCloudDialogflowV2SentimentAnalysisResult",
          description = "Output only. The sentiment analysis result for the message.",
          readOnly = true,
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2MessageAnnotation = {
      description = "Represents the result of annotation for the message.",
      id = "GoogleCloudDialogflowV2MessageAnnotation",
      properties = {
        containEntities = {
          description = "Indicates whether the text message contains entities.",
          type = "boolean",
        },
        parts = {
          description = "The collection of annotated message parts ordered by their position in the message. You can recover the annotated message by concatenating [AnnotatedMessagePart.text].",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2AnnotatedMessagePart",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2NotificationConfig = {
      description = "Defines notification behavior.",
      id = "GoogleCloudDialogflowV2NotificationConfig",
      properties = {
        messageFormat = {
          description = "Format of message.",
          enum = {
            "MESSAGE_FORMAT_UNSPECIFIED",
            "PROTO",
            "JSON",
          },
          enumDescriptions = {
            "If it is unspecified, PROTO will be used.",
            "Pub/Sub message will be serialized proto.",
            "Pub/Sub message will be json.",
          },
          type = "string",
        },
        topic = {
          description = "Name of the Pub/Sub topic to publish conversation events like CONVERSATION_STARTED as serialized ConversationEvent protos. For telephony integration to receive notification, make sure either this topic is in the same project as the conversation or you grant `service-@gcp-sa-dialogflow.iam.gserviceaccount.com` the `Dialogflow Service Agent` role in the topic project. For chat integration to receive notification, make sure API caller has been granted the `Dialogflow Service Agent` role for the topic. Format: `projects//locations//topics/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2OriginalDetectIntentRequest = {
      description = "Represents the contents of the original request that was passed to the `[Streaming]DetectIntent` call.",
      id = "GoogleCloudDialogflowV2OriginalDetectIntentRequest",
      properties = {
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Optional. This field is set to the value of the `QueryParameters.payload` field passed in the request. Some integrations that query a Dialogflow agent may provide additional information in the payload. In particular, for the Dialogflow Phone Gateway integration, this field has the form: { \"telephony\": { \"caller_id\": \"+18558363987\" } } Note: The caller ID field (`caller_id`) will be redacted for Trial Edition agents and populated with the caller ID in [E.164 format](https://en.wikipedia.org/wiki/E.164) for Essentials Edition agents.",
          type = "object",
        },
        source = {
          description = "The source of this request, e.g., `google`, `facebook`, `slack`. It is set by Dialogflow-owned servers.",
          type = "string",
        },
        version = {
          description = "Optional. The version of the protocol used for this request. This field is AoG-specific.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2OutputAudio = {
      description = "Represents the natural language speech audio to be played to the end user.",
      id = "GoogleCloudDialogflowV2OutputAudio",
      properties = {
        audio = {
          description = "The natural language speech audio.",
          format = "byte",
          type = "string",
        },
        config = {
          ["$ref"] = "GoogleCloudDialogflowV2OutputAudioConfig",
          description = "Instructs the speech synthesizer how to generate the speech audio.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2OutputAudioConfig = {
      description = "Instructs the speech synthesizer on how to generate the output audio content. If this audio config is supplied in a request, it overrides all existing text-to-speech settings applied to the agent.",
      id = "GoogleCloudDialogflowV2OutputAudioConfig",
      properties = {
        audioEncoding = {
          description = "Required. Audio encoding of the synthesized audio content.",
          enum = {
            "OUTPUT_AUDIO_ENCODING_UNSPECIFIED",
            "OUTPUT_AUDIO_ENCODING_LINEAR_16",
            "OUTPUT_AUDIO_ENCODING_MP3",
            "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS",
            "OUTPUT_AUDIO_ENCODING_OGG_OPUS",
            "OUTPUT_AUDIO_ENCODING_MULAW",
          },
          enumDescriptions = {
            "Not specified.",
            "Uncompressed 16-bit signed little-endian samples (Linear PCM). Audio content returned as LINEAR16 also contains a WAV header.",
            "MP3 audio at 32kbps.",
            "MP3 audio at 64kbps.",
            "Opus encoded audio wrapped in an ogg container. The result will be a file which can be played natively on Android, and in browsers (at least Chrome and Firefox). The quality of the encoding is considerably higher than MP3 while using approximately the same bitrate.",
            "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.",
          },
          type = "string",
        },
        sampleRateHertz = {
          description = "The synthesis sample rate (in hertz) for this audio. If not provided, then the synthesizer will use the default sample rate based on the audio encoding. If this is different from the voice's natural sample rate, then the synthesizer will honor this request by converting to the desired sample rate (which might result in worse audio quality).",
          format = "int32",
          type = "integer",
        },
        synthesizeSpeechConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2SynthesizeSpeechConfig",
          description = "Configuration of how speech should be synthesized.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Participant = {
      description = "Represents a conversation participant (human agent, virtual agent, end-user).",
      id = "GoogleCloudDialogflowV2Participant",
      properties = {
        documentsMetadataFilters = {
          additionalProperties = {
            type = "string",
          },
          description = "Optional. Key-value filters on the metadata of documents returned by article suggestion. If specified, article suggestion only returns suggested documents that match all filters in their Document.metadata. Multiple values for a metadata key should be concatenated by comma. For example, filters to match all documents that have 'US' or 'CA' in their market metadata values and 'agent' in their user metadata values will be ``` documents_metadata_filters { key: \"market\" value: \"US,CA\" } documents_metadata_filters { key: \"user\" value: \"agent\" } ```",
          type = "object",
        },
        name = {
          description = "Optional. The unique identifier of this participant. Format: `projects//locations//conversations//participants/`.",
          type = "string",
        },
        obfuscatedExternalUserId = {
          description = "Optional. Obfuscated user id that should be associated with the created participant. You can specify a user id as follows: 1. If you set this field in CreateParticipantRequest or UpdateParticipantRequest, Dialogflow adds the obfuscated user id with the participant. 2. If you set this field in AnalyzeContent or StreamingAnalyzeContent, Dialogflow will update Participant.obfuscated_external_user_id. Dialogflow returns an error if you try to add a user id for a non-END_USER participant. Dialogflow uses this user id for billing and measurement purposes. For example, Dialogflow determines whether a user in one conversation returned in a later conversation. Note: * Please never pass raw user ids to Dialogflow. Always obfuscate your user id first. * Dialogflow only accepts a UTF-8 encoded string, e.g., a hex digest of a hash function like SHA-512. * The length of the user id must be <= 256 characters.",
          type = "string",
        },
        role = {
          description = "Immutable. The role this participant plays in the conversation. This field must be set during participant creation and is then immutable.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        sipRecordingMediaLabel = {
          description = "Optional. Label applied to streams representing this participant in SIPREC XML metadata and SDP. This is used to assign transcriptions from that media stream to this participant. This field can be updated.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2QueryInput = {
      description = "Represents the query input. It can contain either: 1. An audio config which instructs the speech recognizer how to process the speech audio. 2. A conversational query in the form of text,. 3. An event that specifies which intent to trigger.",
      id = "GoogleCloudDialogflowV2QueryInput",
      properties = {
        audioConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2InputAudioConfig",
          description = "Instructs the speech recognizer how to process the speech audio.",
        },
        event = {
          ["$ref"] = "GoogleCloudDialogflowV2EventInput",
          description = "The event to be processed.",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowV2TextInput",
          description = "The natural language text to be processed. Text length must not exceed 256 character for virtual agent interactions.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2QueryParameters = {
      description = "Represents the parameters of the conversational query.",
      id = "GoogleCloudDialogflowV2QueryParameters",
      properties = {
        contexts = {
          description = "The collection of contexts to be activated before this query is executed.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Context",
          },
          type = "array",
        },
        geoLocation = {
          ["$ref"] = "GoogleTypeLatLng",
          description = "The geo location of this conversational query.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "This field can be used to pass custom data to your webhook. Arbitrary JSON objects are supported. If supplied, the value is used to populate the `WebhookRequest.original_detect_intent_request.payload` field sent to your webhook.",
          type = "object",
        },
        resetContexts = {
          description = "Specifies whether to delete all contexts in the current session before the new ones are activated.",
          type = "boolean",
        },
        sentimentAnalysisRequestConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2SentimentAnalysisRequestConfig",
          description = "Configures the type of sentiment analysis to perform. If not provided, sentiment analysis is not performed.",
        },
        sessionEntityTypes = {
          description = "Additional session entity types to replace or extend developer entity types with. The entity synonyms apply to all languages and persist for the session of this query.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
          },
          type = "array",
        },
        timeZone = {
          description = "The time zone of this conversational query from the [time zone database](https://www.iana.org/time-zones), e.g., America/New_York, Europe/Paris. If not provided, the time zone specified in agent settings is used.",
          type = "string",
        },
        webhookHeaders = {
          additionalProperties = {
            type = "string",
          },
          description = "This field can be used to pass HTTP headers for a webhook call. These headers will be sent to webhook along with the headers that have been configured through the Dialogflow web console. The headers defined within this field will overwrite the headers configured through the Dialogflow console if there is a conflict. Header names are case-insensitive. Google's specified headers are not allowed. Including: \"Host\", \"Content-Length\", \"Connection\", \"From\", \"User-Agent\", \"Accept-Encoding\", \"If-Modified-Since\", \"If-None-Match\", \"X-Forwarded-For\", etc.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2QueryResult = {
      description = "Represents the result of conversational query or event processing.",
      id = "GoogleCloudDialogflowV2QueryResult",
      properties = {
        action = {
          description = "The action name from the matched intent.",
          type = "string",
        },
        allRequiredParamsPresent = {
          description = "This field is set to: - `false` if the matched intent has required parameters and not all of the required parameter values have been collected. - `true` if all required parameter values have been collected, or if the matched intent doesn't contain any required parameters.",
          type = "boolean",
        },
        cancelsSlotFilling = {
          description = "Indicates whether the conversational query triggers a cancellation for slot filling. For more information, see the [cancel slot filling documentation](https://cloud.google.com/dialogflow/es/docs/intents-actions-parameters#cancel).",
          type = "boolean",
        },
        diagnosticInfo = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Free-form diagnostic information for the associated detect intent request. The fields of this data can change without notice, so you should not write code that depends on its structure. The data may contain: - webhook call latency - webhook errors",
          type = "object",
        },
        fulfillmentMessages = {
          description = "The collection of rich messages to present to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessage",
          },
          type = "array",
        },
        fulfillmentText = {
          description = "The text to be pronounced to the user or shown on the screen. Note: This is a legacy field, `fulfillment_messages` should be preferred.",
          type = "string",
        },
        intent = {
          ["$ref"] = "GoogleCloudDialogflowV2Intent",
          description = "The intent that matched the conversational query. Some, not all fields are filled in this message, including but not limited to: `name`, `display_name`, `end_interaction` and `is_fallback`.",
        },
        intentDetectionConfidence = {
          description = "The intent detection confidence. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). This value is for informational purpose only and is only used to help match the best intent within the classification threshold. This value may change for the same end-user expression at any time due to a model retraining or change in implementation. If there are `multiple knowledge_answers` messages, this value is set to the greatest `knowledgeAnswers.match_confidence` value in the list.",
          format = "float",
          type = "number",
        },
        languageCode = {
          description = "The language that was triggered during intent detection. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes.",
          type = "string",
        },
        outputContexts = {
          description = "The collection of output contexts. If applicable, `output_contexts.parameters` contains entries with name `.original` containing the original parameter values before the query.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Context",
          },
          type = "array",
        },
        parameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "The collection of extracted parameters. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: - MapKey type: string - MapKey value: parameter name - MapValue type: - If parameter's entity type is a composite entity: map - Else: depending on parameter value type, could be one of string, number, boolean, null, list or map - MapValue value: - If parameter's entity type is a composite entity: map from composite entity property names to property values - Else: parameter value",
          type = "object",
        },
        queryText = {
          description = "The original conversational query text: - If natural language text was provided as input, `query_text` contains a copy of the input. - If natural language speech audio was provided as input, `query_text` contains the speech recognition result. If speech recognizer produced multiple alternatives, a particular one is picked. - If automatic spell correction is enabled, `query_text` will contain the corrected user input.",
          type = "string",
        },
        sentimentAnalysisResult = {
          ["$ref"] = "GoogleCloudDialogflowV2SentimentAnalysisResult",
          description = "The sentiment analysis result, which depends on the `sentiment_analysis_request_config` specified in the request.",
        },
        speechRecognitionConfidence = {
          description = "The Speech recognition confidence between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. The default of 0.0 is a sentinel value indicating that confidence was not set. This field is not guaranteed to be accurate or set. In particular this field isn't set for StreamingDetectIntent since the streaming endpoint has separate confidence estimates per portion of the audio in StreamingRecognitionResult.",
          format = "float",
          type = "number",
        },
        webhookPayload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "If the query was fulfilled by a webhook call, this field is set to the value of the `payload` field returned in the webhook response.",
          type = "object",
        },
        webhookSource = {
          description = "If the query was fulfilled by a webhook call, this field is set to the value of the `source` field returned in the webhook response.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ReloadDocumentRequest = {
      description = "Request message for Documents.ReloadDocument.",
      id = "GoogleCloudDialogflowV2ReloadDocumentRequest",
      properties = {
        contentUri = {
          description = "Optional. The path of gcs source file for reloading document content. For now, only gcs uri is supported. For documents stored in Google Cloud Storage, these URIs must have the form `gs:///`.",
          type = "string",
        },
        importGcsCustomMetadata = {
          description = "Optional. Whether to import custom metadata from Google Cloud Storage. Only valid when the document source is Google Cloud Storage URI.",
          type = "boolean",
        },
        smartMessagingPartialUpdate = {
          description = "Optional. When enabled, the reload request is to apply partial update to the smart messaging allowlist.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2RestoreAgentRequest = {
      description = "The request message for Agents.RestoreAgent.",
      id = "GoogleCloudDialogflowV2RestoreAgentRequest",
      properties = {
        agentContent = {
          description = "Zip compressed raw byte content for agent.",
          format = "byte",
          type = "string",
        },
        agentUri = {
          description = "The URI to a Google Cloud Storage file containing the agent to restore. Note: The URI must start with \"gs://\". Dialogflow performs a read operation for the Cloud Storage object on the caller's behalf, so your request authentication must have read permissions for the object. For more information, see [Dialogflow access control](https://cloud.google.com/dialogflow/cx/docs/concept/access-control#storage).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SearchAgentsResponse = {
      description = "The response message for Agents.SearchAgents.",
      id = "GoogleCloudDialogflowV2SearchAgentsResponse",
      properties = {
        agents = {
          description = "The list of agents. There will be a maximum number of items returned based on the page_size field in the request.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Agent",
          },
          type = "array",
        },
        nextPageToken = {
          description = "Token to retrieve the next page of results, or empty if there are no more results in the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Sentiment = {
      description = "The sentiment, such as positive/negative feeling or association, for a unit of analysis, such as the query text. See: https://cloud.google.com/natural-language/docs/basics#interpreting_sentiment_analysis_values for how to interpret the result.",
      id = "GoogleCloudDialogflowV2Sentiment",
      properties = {
        magnitude = {
          description = "A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).",
          format = "float",
          type = "number",
        },
        score = {
          description = "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SentimentAnalysisRequestConfig = {
      description = "Configures the types of sentiment analysis to perform.",
      id = "GoogleCloudDialogflowV2SentimentAnalysisRequestConfig",
      properties = {
        analyzeQueryTextSentiment = {
          description = "Instructs the service to perform sentiment analysis on `query_text`. If not provided, sentiment analysis is not performed on `query_text`.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SentimentAnalysisResult = {
      description = "The result of sentiment analysis. Sentiment analysis inspects user input and identifies the prevailing subjective opinion, especially to determine a user's attitude as positive, negative, or neutral. For Participants.DetectIntent, it needs to be configured in DetectIntentRequest.query_params. For Participants.StreamingDetectIntent, it needs to be configured in StreamingDetectIntentRequest.query_params. And for Participants.AnalyzeContent and Participants.StreamingAnalyzeContent, it needs to be configured in ConversationProfile.human_agent_assistant_config",
      id = "GoogleCloudDialogflowV2SentimentAnalysisResult",
      properties = {
        queryTextSentiment = {
          ["$ref"] = "GoogleCloudDialogflowV2Sentiment",
          description = "The sentiment analysis result for `query_text`.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SessionEntityType = {
      description = "A session represents a conversation between a Dialogflow agent and an end-user. You can create special entities, called session entities, during a session. Session entities can extend or replace custom entity types and only exist during the session that they were created for. All session data, including session entities, is stored by Dialogflow for 20 minutes. For more information, see the [session entity guide](https://cloud.google.com/dialogflow/docs/entities-session).",
      id = "GoogleCloudDialogflowV2SessionEntityType",
      properties = {
        entities = {
          description = "Required. The collection of entities associated with this session entity type.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2EntityTypeEntity",
          },
          type = "array",
        },
        entityOverrideMode = {
          description = "Required. Indicates whether the additional data should override or supplement the custom entity type definition.",
          enum = {
            "ENTITY_OVERRIDE_MODE_UNSPECIFIED",
            "ENTITY_OVERRIDE_MODE_OVERRIDE",
            "ENTITY_OVERRIDE_MODE_SUPPLEMENT",
          },
          enumDescriptions = {
            "Not specified. This value should be never used.",
            "The collection of session entities overrides the collection of entities in the corresponding custom entity type.",
            "The collection of session entities extends the collection of entities in the corresponding custom entity type. Note: Even in this override mode calls to `ListSessionEntityTypes`, `GetSessionEntityType`, `CreateSessionEntityType` and `UpdateSessionEntityType` only return the additional entities added in this session entity type. If you want to get the supplemented list, please call EntityTypes.GetEntityType on the custom entity type and merge.",
          },
          type = "string",
        },
        name = {
          description = "Required. The unique identifier of this session entity type. Format: `projects//agent/sessions//entityTypes/`, or `projects//agent/environments//users//sessions//entityTypes/`. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. `` must be the display name of an existing entity type in the same agent that will be overridden or supplemented.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SetSuggestionFeatureConfigOperationMetadata = {
      description = "Metadata for a ConversationProfile.SetSuggestionFeatureConfig operation.",
      id = "GoogleCloudDialogflowV2SetSuggestionFeatureConfigOperationMetadata",
      properties = {
        conversationProfile = {
          description = "The resource name of the conversation profile. Format: `projects//locations//conversationProfiles/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp whe the request was created. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        participantRole = {
          description = "Required. The participant role to add or update the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        suggestionFeatureType = {
          description = "Required. The type of the suggestion feature to add or update.",
          enum = {
            "TYPE_UNSPECIFIED",
            "ARTICLE_SUGGESTION",
            "FAQ",
            "SMART_REPLY",
          },
          enumDescriptions = {
            "Unspecified feature type.",
            "Run article suggestion model for chat.",
            "Run FAQ model for chat.",
            "Run smart reply model for chat.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SetSuggestionFeatureConfigRequest = {
      description = "The request message for ConversationProfiles.SetSuggestionFeature.",
      id = "GoogleCloudDialogflowV2SetSuggestionFeatureConfigRequest",
      properties = {
        participantRole = {
          description = "Required. The participant role to add or update the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        suggestionFeatureConfig = {
          ["$ref"] = "GoogleCloudDialogflowV2HumanAgentAssistantConfigSuggestionFeatureConfig",
          description = "Required. The suggestion feature config to add or update.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SmartReplyAnswer = {
      description = "Represents a smart reply answer.",
      id = "GoogleCloudDialogflowV2SmartReplyAnswer",
      properties = {
        answerRecord = {
          description = "The name of answer record, in the format of \"projects//locations//answerRecords/\"",
          type = "string",
        },
        confidence = {
          description = "Smart reply confidence. The system's confidence score that this reply is a good match for this conversation, as a value from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        reply = {
          description = "The content of the reply.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SmartReplyMetrics = {
      description = "The evaluation metrics for smart reply model.",
      id = "GoogleCloudDialogflowV2SmartReplyMetrics",
      properties = {
        allowlistCoverage = {
          description = "Percentage of target participant messages in the evaluation dataset for which similar messages have appeared at least once in the allowlist. Should be [0, 1].",
          format = "float",
          type = "number",
        },
        conversationCount = {
          description = "Total number of conversations used to generate this metric.",
          format = "int64",
          type = "string",
        },
        topNMetrics = {
          description = "Metrics of top n smart replies, sorted by TopNMetric.n.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SmartReplyMetricsTopNMetrics",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SmartReplyMetricsTopNMetrics = {
      description = "Evaluation metrics when retrieving `n` smart replies with the model.",
      id = "GoogleCloudDialogflowV2SmartReplyMetricsTopNMetrics",
      properties = {
        n = {
          description = "Number of retrieved smart replies. For example, when `n` is 3, this evaluation contains metrics for when Dialogflow retrieves 3 smart replies with the model.",
          format = "int32",
          type = "integer",
        },
        recall = {
          description = "Defined as `number of queries whose top n smart replies have at least one similar (token match similarity above the defined threshold) reply as the real reply` divided by `number of queries with at least one smart reply`. Value ranges from 0.0 to 1.0 inclusive.",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SmartReplyModelMetadata = {
      description = "Metadata for smart reply models.",
      id = "GoogleCloudDialogflowV2SmartReplyModelMetadata",
      properties = {
        trainingModelType = {
          description = "Optional. Type of the smart reply model. If not provided, model_type is used.",
          enum = {
            "MODEL_TYPE_UNSPECIFIED",
            "SMART_REPLY_DUAL_ENCODER_MODEL",
            "SMART_REPLY_BERT_MODEL",
          },
          enumDescriptions = {
            "ModelType unspecified.",
            "ModelType smart reply dual encoder model.",
            "ModelType smart reply bert model.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SpeechContext = {
      description = "Hints for the speech recognizer to help with recognition in a specific conversation state.",
      id = "GoogleCloudDialogflowV2SpeechContext",
      properties = {
        boost = {
          description = "Optional. Boost for this context compared to other contexts: * If the boost is positive, Dialogflow will increase the probability that the phrases in this context are recognized over similar sounding phrases. * If the boost is unspecified or non-positive, Dialogflow will not apply any boost. Dialogflow recommends that you use boosts in the range (0, 20] and that you find a value that fits your use case with binary search.",
          format = "float",
          type = "number",
        },
        phrases = {
          description = "Optional. A list of strings containing words and phrases that the speech recognizer should recognize with higher likelihood. This list can be used to: * improve accuracy for words and phrases you expect the user to say, e.g. typical commands for your Dialogflow agent * add additional words to the speech recognizer vocabulary * ... See the [Cloud Speech documentation](https://cloud.google.com/speech-to-text/quotas) for usage limits.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SpeechToTextConfig = {
      description = "Configures speech transcription for ConversationProfile.",
      id = "GoogleCloudDialogflowV2SpeechToTextConfig",
      properties = {
        model = {
          description = "Which Speech model to select. Select the model best suited to your domain to get best results. If a model is not explicitly specified, then a default model is used. Refer to [Cloud Speech API documentation](https://cloud.google.com/speech-to-text/docs/basics#select-model) for more details.",
          type = "string",
        },
        speechModelVariant = {
          description = "The speech model used in speech to text. `SPEECH_MODEL_VARIANT_UNSPECIFIED`, `USE_BEST_AVAILABLE` will be treated as `USE_ENHANCED`. It can be overridden in AnalyzeContentRequest and StreamingAnalyzeContentRequest request. If enhanced model variant is specified and an enhanced version of the specified model for the language does not exist, then it would emit an error.",
          enum = {
            "SPEECH_MODEL_VARIANT_UNSPECIFIED",
            "USE_BEST_AVAILABLE",
            "USE_STANDARD",
            "USE_ENHANCED",
          },
          enumDescriptions = {
            "No model variant specified. In this case Dialogflow defaults to USE_BEST_AVAILABLE.",
            "Use the best available variant of the Speech model that the caller is eligible for. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible for enhanced models.",
            "Use standard model variant even if an enhanced model is available. See the [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) for details about enhanced models.",
            "Use an enhanced model variant: * If an enhanced variant does not exist for the given model and request language, Dialogflow falls back to the standard variant. The [Cloud Speech documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models) describes which models have enhanced variants. * If the API caller isn't eligible for enhanced models, Dialogflow returns an error. Please see the [Dialogflow docs](https://cloud.google.com/dialogflow/docs/data-logging) for how to make your project eligible.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestArticlesRequest = {
      description = "The request message for Participants.SuggestArticles.",
      id = "GoogleCloudDialogflowV2SuggestArticlesRequest",
      properties = {
        assistQueryParams = {
          ["$ref"] = "GoogleCloudDialogflowV2AssistQueryParameters",
          description = "Parameters for a human assist query.",
        },
        contextSize = {
          description = "Optional. Max number of messages prior to and including latest_message to use as context when compiling the suggestion. By default 20 and at most 50.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "Optional. The name of the latest conversation message to compile suggestion for. If empty, it will be the latest message of the conversation. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestArticlesResponse = {
      description = "The response message for Participants.SuggestArticles.",
      id = "GoogleCloudDialogflowV2SuggestArticlesResponse",
      properties = {
        articleAnswers = {
          description = "Articles ordered by score in descending order.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2ArticleAnswer",
          },
          type = "array",
        },
        contextSize = {
          description = "Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestArticlesRequest.context_size field in the request if there aren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "The name of the latest conversation message used to compile suggestion for. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestConversationSummaryRequest = {
      description = "The request message for Conversations.SuggestConversationSummary.",
      id = "GoogleCloudDialogflowV2SuggestConversationSummaryRequest",
      properties = {
        contextSize = {
          description = "Max number of messages prior to and including [latest_message] to use as context when compiling the suggestion. By default 500 and at most 1000.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "The name of the latest conversation message used as context for compiling suggestion. If empty, the latest message of the conversation will be used. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestConversationSummaryResponse = {
      description = "The response message for Conversations.SuggestConversationSummary.",
      id = "GoogleCloudDialogflowV2SuggestConversationSummaryResponse",
      properties = {
        contextSize = {
          description = "Number of messages prior to and including last_conversation_message used to compile the suggestion. It may be smaller than the SuggestSummaryRequest.context_size field in the request if there weren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "The name of the latest conversation message used as context for compiling suggestion. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
        summary = {
          ["$ref"] = "GoogleCloudDialogflowV2SuggestConversationSummaryResponseSummary",
          description = "Generated summary.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestConversationSummaryResponseSummary = {
      description = "Generated summary for a conversation.",
      id = "GoogleCloudDialogflowV2SuggestConversationSummaryResponseSummary",
      properties = {
        answerRecord = {
          description = "The name of the answer record. Format: \"projects//answerRecords/\"",
          type = "string",
        },
        text = {
          description = "The summary content that is concatenated into one string.",
          type = "string",
        },
        textSections = {
          additionalProperties = {
            type = "string",
          },
          description = "The summary content that is divided into sections. The key is the section's name and the value is the section's content. There is no specific format for the key or value.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestFaqAnswersRequest = {
      description = "The request message for Participants.SuggestFaqAnswers.",
      id = "GoogleCloudDialogflowV2SuggestFaqAnswersRequest",
      properties = {
        assistQueryParams = {
          ["$ref"] = "GoogleCloudDialogflowV2AssistQueryParameters",
          description = "Parameters for a human assist query.",
        },
        contextSize = {
          description = "Optional. Max number of messages prior to and including [latest_message] to use as context when compiling the suggestion. By default 20 and at most 50.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "Optional. The name of the latest conversation message to compile suggestion for. If empty, it will be the latest message of the conversation. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestFaqAnswersResponse = {
      description = "The request message for Participants.SuggestFaqAnswers.",
      id = "GoogleCloudDialogflowV2SuggestFaqAnswersResponse",
      properties = {
        contextSize = {
          description = "Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestFaqAnswersRequest.context_size field in the request if there aren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        faqAnswers = {
          description = "Answers extracted from FAQ documents.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2FaqAnswer",
          },
          type = "array",
        },
        latestMessage = {
          description = "The name of the latest conversation message used to compile suggestion for. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestSmartRepliesRequest = {
      description = "The request message for Participants.SuggestSmartReplies.",
      id = "GoogleCloudDialogflowV2SuggestSmartRepliesRequest",
      properties = {
        contextSize = {
          description = "Max number of messages prior to and including [latest_message] to use as context when compiling the suggestion. By default 20 and at most 50.",
          format = "int32",
          type = "integer",
        },
        currentTextInput = {
          ["$ref"] = "GoogleCloudDialogflowV2TextInput",
          description = "The current natural language text segment to compile suggestion for. This provides a way for user to get follow up smart reply suggestion after a smart reply selection, without sending a text message.",
        },
        latestMessage = {
          description = "The name of the latest conversation message to compile suggestion for. If empty, it will be the latest message of the conversation. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestSmartRepliesResponse = {
      description = "The response message for Participants.SuggestSmartReplies.",
      id = "GoogleCloudDialogflowV2SuggestSmartRepliesResponse",
      properties = {
        contextSize = {
          description = "Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestSmartRepliesRequest.context_size field in the request if there aren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "The name of the latest conversation message used to compile suggestion for. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
        smartReplyAnswers = {
          description = "Output only. Multiple reply options provided by smart reply service. The order is based on the rank of the model prediction. The maximum number of the returned replies is set in SmartReplyConfig.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SmartReplyAnswer",
          },
          readOnly = true,
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestionFeature = {
      description = "The type of Human Agent Assistant API suggestion to perform, and the maximum number of results to return for that type. Multiple `Feature` objects can be specified in the `features` list.",
      id = "GoogleCloudDialogflowV2SuggestionFeature",
      properties = {
        type = {
          description = "Type of Human Agent Assistant API feature to request.",
          enum = {
            "TYPE_UNSPECIFIED",
            "ARTICLE_SUGGESTION",
            "FAQ",
            "SMART_REPLY",
          },
          enumDescriptions = {
            "Unspecified feature type.",
            "Run article suggestion model for chat.",
            "Run FAQ model for chat.",
            "Run smart reply model for chat.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SuggestionResult = {
      description = "One response of different type of suggestion response which is used in the response of Participants.AnalyzeContent and Participants.AnalyzeContent, as well as HumanAgentAssistantEvent.",
      id = "GoogleCloudDialogflowV2SuggestionResult",
      properties = {
        error = {
          ["$ref"] = "GoogleRpcStatus",
          description = "Error status if the request failed.",
        },
        suggestArticlesResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2SuggestArticlesResponse",
          description = "SuggestArticlesResponse if request is for ARTICLE_SUGGESTION.",
        },
        suggestFaqAnswersResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2SuggestFaqAnswersResponse",
          description = "SuggestFaqAnswersResponse if request is for FAQ_ANSWER.",
        },
        suggestSmartRepliesResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2SuggestSmartRepliesResponse",
          description = "SuggestSmartRepliesResponse if request is for SMART_REPLY.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2SynthesizeSpeechConfig = {
      description = "Configuration of how speech should be synthesized.",
      id = "GoogleCloudDialogflowV2SynthesizeSpeechConfig",
      properties = {
        effectsProfileId = {
          description = "Optional. An identifier which selects 'audio effects' profiles that are applied on (post synthesized) text to speech. Effects are applied on top of each other in the order they are given.",
          items = {
            type = "string",
          },
          type = "array",
        },
        pitch = {
          description = "Optional. Speaking pitch, in the range [-20.0, 20.0]. 20 means increase 20 semitones from the original pitch. -20 means decrease 20 semitones from the original pitch.",
          format = "double",
          type = "number",
        },
        speakingRate = {
          description = "Optional. Speaking rate/speed, in the range [0.25, 4.0]. 1.0 is the normal native speed supported by the specific voice. 2.0 is twice as fast, and 0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any other values < 0.25 or > 4.0 will return an error.",
          format = "double",
          type = "number",
        },
        voice = {
          ["$ref"] = "GoogleCloudDialogflowV2VoiceSelectionParams",
          description = "Optional. The desired voice of the synthesized audio.",
        },
        volumeGainDb = {
          description = "Optional. Volume gain (in dB) of the normal native volume supported by the specific voice, in the range [-96.0, 16.0]. If unset, or set to a value of 0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB) will play at approximately half the amplitude of the normal native signal amplitude. A value of +6.0 (dB) will play at approximately twice the amplitude of the normal native signal amplitude. We strongly recommend not to exceed +10 (dB) as there's usually no effective increase in loudness for any value greater than that.",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2TextInput = {
      description = "============================================================================ Auxiliary proto messages. Represents the natural language text to be processed.",
      id = "GoogleCloudDialogflowV2TextInput",
      properties = {
        languageCode = {
          description = "Required. The language of this conversational query. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.",
          type = "string",
        },
        text = {
          description = "Required. The UTF-8 encoded natural language text to be processed. Text length must not exceed 256 characters for virtual agent interactions.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2TextToSpeechSettings = {
      description = "Instructs the speech synthesizer on how to generate the output audio content.",
      id = "GoogleCloudDialogflowV2TextToSpeechSettings",
      properties = {
        enableTextToSpeech = {
          description = "Optional. Indicates whether text to speech is enabled. Even when this field is false, other settings in this proto are still retained.",
          type = "boolean",
        },
        outputAudioEncoding = {
          description = "Required. Audio encoding of the synthesized audio content.",
          enum = {
            "OUTPUT_AUDIO_ENCODING_UNSPECIFIED",
            "OUTPUT_AUDIO_ENCODING_LINEAR_16",
            "OUTPUT_AUDIO_ENCODING_MP3",
            "OUTPUT_AUDIO_ENCODING_MP3_64_KBPS",
            "OUTPUT_AUDIO_ENCODING_OGG_OPUS",
            "OUTPUT_AUDIO_ENCODING_MULAW",
          },
          enumDescriptions = {
            "Not specified.",
            "Uncompressed 16-bit signed little-endian samples (Linear PCM). Audio content returned as LINEAR16 also contains a WAV header.",
            "MP3 audio at 32kbps.",
            "MP3 audio at 64kbps.",
            "Opus encoded audio wrapped in an ogg container. The result will be a file which can be played natively on Android, and in browsers (at least Chrome and Firefox). The quality of the encoding is considerably higher than MP3 while using approximately the same bitrate.",
            "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.",
          },
          type = "string",
        },
        sampleRateHertz = {
          description = "Optional. The synthesis sample rate (in hertz) for this audio. If not provided, then the synthesizer will use the default sample rate based on the audio encoding. If this is different from the voice's natural sample rate, then the synthesizer will honor this request by converting to the desired sample rate (which might result in worse audio quality).",
          format = "int32",
          type = "integer",
        },
        synthesizeSpeechConfigs = {
          additionalProperties = {
            ["$ref"] = "GoogleCloudDialogflowV2SynthesizeSpeechConfig",
          },
          description = "Optional. Configuration of how speech should be synthesized, mapping from language (https://cloud.google.com/dialogflow/docs/reference/language) to SynthesizeSpeechConfig.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2TrainAgentRequest = {
      description = "The request message for Agents.TrainAgent.",
      id = "GoogleCloudDialogflowV2TrainAgentRequest",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata = {
      description = "Metadata for a ConversationModels.UndeployConversationModel operation.",
      id = "GoogleCloudDialogflowV2UndeployConversationModelOperationMetadata",
      properties = {
        conversationModel = {
          description = "The resource name of the conversation model. Format: `projects//conversationModels/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp when the request to undeploy conversation model was submitted. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2UndeployConversationModelRequest = {
      description = "The request message for ConversationModels.UndeployConversationModel",
      id = "GoogleCloudDialogflowV2UndeployConversationModelRequest",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowV2ValidationError = {
      description = "Represents a single validation error.",
      id = "GoogleCloudDialogflowV2ValidationError",
      properties = {
        entries = {
          description = "The names of the entries that the error is associated with. Format: - \"projects//agent\", if the error is associated with the entire agent. - \"projects//agent/intents/\", if the error is associated with certain intents. - \"projects//agent/intents//trainingPhrases/\", if the error is associated with certain intent training phrases. - \"projects//agent/intents//parameters/\", if the error is associated with certain intent parameters. - \"projects//agent/entities/\", if the error is associated with certain entities.",
          items = {
            type = "string",
          },
          type = "array",
        },
        errorMessage = {
          description = "The detailed error message.",
          type = "string",
        },
        severity = {
          description = "The severity of the error.",
          enum = {
            "SEVERITY_UNSPECIFIED",
            "INFO",
            "WARNING",
            "ERROR",
            "CRITICAL",
          },
          enumDescriptions = {
            "Not specified. This value should never be used.",
            "The agent doesn't follow Dialogflow best practices.",
            "The agent may not behave as expected.",
            "The agent may experience partial failures.",
            "The agent may completely fail.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2ValidationResult = {
      description = "Represents the output of agent validation.",
      id = "GoogleCloudDialogflowV2ValidationResult",
      properties = {
        validationErrors = {
          description = "Contains all validation errors.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2ValidationError",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2Version = {
      description = "You can create multiple versions of your agent and publish them to separate environments. When you edit an agent, you are editing the draft agent. At any point, you can save the draft agent as an agent version, which is an immutable snapshot of your agent. When you save the draft agent, it is published to the default environment. When you create agent versions, you can publish them to custom environments. You can create a variety of custom environments for: - testing - development - production - etc. For more information, see the [versions and environments guide](https://cloud.google.com/dialogflow/docs/agents-versions).",
      id = "GoogleCloudDialogflowV2Version",
      properties = {
        createTime = {
          description = "Output only. The creation time of this version. This field is read-only, i.e., it cannot be set by create and update methods.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        description = {
          description = "Optional. The developer-provided description of this version.",
          type = "string",
        },
        name = {
          description = "Output only. The unique identifier of this agent version. Supported formats: - `projects//agent/versions/` - `projects//locations//agent/versions/`",
          readOnly = true,
          type = "string",
        },
        status = {
          description = "Output only. The status of this version. This field is read-only and cannot be set by create and update methods.",
          enum = {
            "VERSION_STATUS_UNSPECIFIED",
            "IN_PROGRESS",
            "READY",
            "FAILED",
          },
          enumDescriptions = {
            "Not specified. This value is not used.",
            "Version is not ready to serve (e.g. training is in progress).",
            "Version is ready to serve.",
            "Version training failed.",
          },
          readOnly = true,
          type = "string",
        },
        versionNumber = {
          description = "Output only. The sequential number of this version. This field is read-only which means it cannot be set by create and update methods.",
          format = "int32",
          readOnly = true,
          type = "integer",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2VoiceSelectionParams = {
      description = "Description of which voice to use for speech synthesis.",
      id = "GoogleCloudDialogflowV2VoiceSelectionParams",
      properties = {
        name = {
          description = "Optional. The name of the voice. If not set, the service will choose a voice based on the other parameters such as language_code and ssml_gender.",
          type = "string",
        },
        ssmlGender = {
          description = "Optional. The preferred gender of the voice. If not set, the service will choose a voice based on the other parameters such as language_code and name. Note that this is only a preference, not requirement. If a voice of the appropriate gender is not available, the synthesizer should substitute a voice with a different gender rather than failing the request.",
          enum = {
            "SSML_VOICE_GENDER_UNSPECIFIED",
            "SSML_VOICE_GENDER_MALE",
            "SSML_VOICE_GENDER_FEMALE",
            "SSML_VOICE_GENDER_NEUTRAL",
          },
          enumDescriptions = {
            "An unspecified gender, which means that the client doesn't care which gender the selected voice will have.",
            "A male voice.",
            "A female voice.",
            "A gender-neutral voice.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2WebhookRequest = {
      description = "The request message for a webhook call.",
      id = "GoogleCloudDialogflowV2WebhookRequest",
      properties = {
        originalDetectIntentRequest = {
          ["$ref"] = "GoogleCloudDialogflowV2OriginalDetectIntentRequest",
          description = "Optional. The contents of the original request that was passed to `[Streaming]DetectIntent` call.",
        },
        queryResult = {
          ["$ref"] = "GoogleCloudDialogflowV2QueryResult",
          description = "The result of the conversational query or event processing. Contains the same value as `[Streaming]DetectIntentResponse.query_result`.",
        },
        responseId = {
          description = "The unique identifier of the response. Contains the same value as `[Streaming]DetectIntentResponse.response_id`.",
          type = "string",
        },
        session = {
          description = "The unique identifier of detectIntent request session. Can be used to identify end-user inside webhook implementation. Format: `projects//agent/sessions/`, or `projects//agent/environments//users//sessions/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2WebhookResponse = {
      description = "The response message for a webhook call. This response is validated by the Dialogflow server. If validation fails, an error will be returned in the QueryResult.diagnostic_info field. Setting JSON fields to an empty value with the wrong type is a common error. To avoid this error: - Use `\"\"` for empty strings - Use `{}` or `null` for empty objects - Use `[]` or `null` for empty arrays For more information, see the [Protocol Buffers Language Guide](https://developers.google.com/protocol-buffers/docs/proto3#json).",
      id = "GoogleCloudDialogflowV2WebhookResponse",
      properties = {
        followupEventInput = {
          ["$ref"] = "GoogleCloudDialogflowV2EventInput",
          description = "Optional. Invokes the supplied events. When this field is set, Dialogflow ignores the `fulfillment_text`, `fulfillment_messages`, and `payload` fields.",
        },
        fulfillmentMessages = {
          description = "Optional. The rich response messages intended for the end-user. When provided, Dialogflow uses this field to populate QueryResult.fulfillment_messages sent to the integration or API caller.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2IntentMessage",
          },
          type = "array",
        },
        fulfillmentText = {
          description = "Optional. The text response message intended for the end-user. It is recommended to use `fulfillment_messages.text.text[0]` instead. When provided, Dialogflow uses this field to populate QueryResult.fulfillment_text sent to the integration or API caller.",
          type = "string",
        },
        outputContexts = {
          description = "Optional. The collection of output contexts that will overwrite currently active contexts for the session and reset their lifespans. When provided, Dialogflow uses this field to populate QueryResult.output_contexts sent to the integration or API caller.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2Context",
          },
          type = "array",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Optional. This field can be used to pass custom data from your webhook to the integration or API caller. Arbitrary JSON objects are supported. When provided, Dialogflow uses this field to populate QueryResult.webhook_payload sent to the integration or API caller. This field is also used by the [Google Assistant integration](https://cloud.google.com/dialogflow/docs/integrations/aog) for rich response messages. See the format definition at [Google Assistant Dialogflow webhook format](https://developers.google.com/assistant/actions/build/json/dialogflow-webhook-json)",
          type = "object",
        },
        sessionEntityTypes = {
          description = "Optional. Additional session entity types to replace or extend developer entity types with. The entity synonyms apply to all languages and persist for the session. Setting this data from a webhook overwrites the session entity types that have been set using `detectIntent`, `streamingDetectIntent` or SessionEntityType management methods.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2SessionEntityType",
          },
          type = "array",
        },
        source = {
          description = "Optional. A custom field used to identify the webhook source. Arbitrary strings are supported. When provided, Dialogflow uses this field to populate QueryResult.webhook_source sent to the integration or API caller.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1AnnotatedMessagePart = {
      description = "Represents a part of a message possibly annotated with an entity. The part can be an entity or purely a part of the message between two entities or message start/end.",
      id = "GoogleCloudDialogflowV2beta1AnnotatedMessagePart",
      properties = {
        entityType = {
          description = "Optional. The [Dialogflow system entity type](https://cloud.google.com/dialogflow/docs/reference/system-entities) of this message part. If this is empty, Dialogflow could not annotate the phrase part with a system entity.",
          type = "string",
        },
        formattedValue = {
          description = "Optional. The [Dialogflow system entity formatted value ](https://cloud.google.com/dialogflow/docs/reference/system-entities) of this message part. For example for a system entity of type `@sys.unit-currency`, this may contain: { \"amount\": 5, \"currency\": \"USD\" } ",
          type = "any",
        },
        text = {
          description = "Required. A part of a message possibly annotated with an entity.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1ArticleAnswer = {
      description = "Represents article answer.",
      id = "GoogleCloudDialogflowV2beta1ArticleAnswer",
      properties = {
        answerRecord = {
          description = "The name of answer record, in the format of \"projects//locations//answerRecords/\"",
          type = "string",
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "A map that contains metadata about the answer and the document from which it originates.",
          type = "object",
        },
        snippets = {
          description = "Output only. Article snippets.",
          items = {
            type = "string",
          },
          type = "array",
        },
        title = {
          description = "The article title.",
          type = "string",
        },
        uri = {
          description = "The article URI.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse = {
      description = "The response message for EntityTypes.BatchUpdateEntityTypes.",
      id = "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse",
      properties = {
        entityTypes = {
          description = "The collection of updated or created entity types.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1EntityType",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse = {
      description = "The response message for Intents.BatchUpdateIntents.",
      id = "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse",
      properties = {
        intents = {
          description = "The collection of updated or created intents.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1Intent",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1ClearSuggestionFeatureConfigOperationMetadata = {
      description = "Metadata for a ConversationProfile.ClearSuggestionFeatureConfig operation.",
      id = "GoogleCloudDialogflowV2beta1ClearSuggestionFeatureConfigOperationMetadata",
      properties = {
        conversationProfile = {
          description = "The resource name of the conversation profile. Format: `projects//locations//conversationProfiles/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp whe the request was created. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        participantRole = {
          description = "Required. The participant role to remove the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        suggestionFeatureType = {
          description = "Required. The type of the suggestion feature to remove.",
          enum = {
            "TYPE_UNSPECIFIED",
            "ARTICLE_SUGGESTION",
            "FAQ",
            "SMART_REPLY",
            "CONVERSATION_SUMMARIZATION",
          },
          enumDescriptions = {
            "Unspecified feature type.",
            "Run article suggestion model for chat.",
            "Run FAQ model.",
            "Run smart reply model for chat.",
            "Run conversation summarization model for chat.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1Context = {
      description = "Dialogflow contexts are similar to natural language context. If a person says to you \"they are orange\", you need context in order to understand what \"they\" is referring to. Similarly, for Dialogflow to handle an end-user expression like that, it needs to be provided with context in order to correctly match an intent. Using contexts, you can control the flow of a conversation. You can configure contexts for an intent by setting input and output contexts, which are identified by string names. When an intent is matched, any configured output contexts for that intent become active. While any contexts are active, Dialogflow is more likely to match intents that are configured with input contexts that correspond to the currently active contexts. For more information about context, see the [Contexts guide](https://cloud.google.com/dialogflow/docs/contexts-overview).",
      id = "GoogleCloudDialogflowV2beta1Context",
      properties = {
        lifespanCount = {
          description = "Optional. The number of conversational query requests after which the context expires. The default is `0`. If set to `0`, the context expires immediately. Contexts expire automatically after 20 minutes if there are no matching queries.",
          format = "int32",
          type = "integer",
        },
        name = {
          description = "Required. The unique identifier of the context. Supported formats: - `projects//agent/sessions//contexts/`, - `projects//locations//agent/sessions//contexts/`, - `projects//agent/environments//users//sessions//contexts/`, - `projects//locations//agent/environments//users//sessions//contexts/`, The `Context ID` is always converted to lowercase, may only contain characters in a-zA-Z0-9_-% and may be at most 250 bytes long. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. The following context names are reserved for internal use by Dialogflow. You should not use these contexts or create contexts with these names: * `__system_counters__` * `*_id_dialog_context` * `*_dialog_params_size`",
          type = "string",
        },
        parameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Optional. The collection of parameters associated with this context. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: - MapKey type: string - MapKey value: parameter name - MapValue type: - If parameter's entity type is a composite entity: map - Else: depending on parameter value type, could be one of string, number, boolean, null, list or map - MapValue value: - If parameter's entity type is a composite entity: map from composite entity property names to property values - Else: parameter value",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1ConversationEvent = {
      description = "Represents a notification sent to Pub/Sub subscribers for conversation lifecycle events.",
      id = "GoogleCloudDialogflowV2beta1ConversationEvent",
      properties = {
        conversation = {
          description = "Required. The unique identifier of the conversation this notification refers to. Format: `projects//conversations/`.",
          type = "string",
        },
        errorStatus = {
          ["$ref"] = "GoogleRpcStatus",
          description = "Optional. More detailed information about an error. Only set for type UNRECOVERABLE_ERROR_IN_PHONE_CALL.",
        },
        newMessagePayload = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1Message",
          description = "Payload of NEW_MESSAGE event.",
        },
        type = {
          description = "Required. The type of the event that this notification refers to.",
          enum = {
            "TYPE_UNSPECIFIED",
            "CONVERSATION_STARTED",
            "CONVERSATION_FINISHED",
            "HUMAN_INTERVENTION_NEEDED",
            "NEW_MESSAGE",
            "UNRECOVERABLE_ERROR",
          },
          enumDescriptions = {
            "Type not set.",
            "A new conversation has been opened. This is fired when a telephone call is answered, or a conversation is created via the API.",
            "An existing conversation has closed. This is fired when a telephone call is terminated, or a conversation is closed via the API.",
            "An existing conversation has received notification from Dialogflow that human intervention is required.",
            "An existing conversation has received a new message, either from API or telephony. It is configured in ConversationProfile.new_message_event_notification_config",
            "Unrecoverable error during a telephone call. In general non-recoverable errors only occur if something was misconfigured in the ConversationProfile corresponding to the call. After a non-recoverable error, Dialogflow may stop responding. We don't fire this event: * in an API call because we can directly return the error, or, * when we can recover from an error.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1EntityType = {
      description = "Each intent parameter has a type, called the entity type, which dictates exactly how data from an end-user expression is extracted. Dialogflow provides predefined system entities that can match many common types of data. For example, there are system entities for matching dates, times, colors, email addresses, and so on. You can also create your own custom entities for matching custom data. For example, you could define a vegetable entity that can match the types of vegetables available for purchase with a grocery store agent. For more information, see the [Entity guide](https://cloud.google.com/dialogflow/docs/entities-overview).",
      id = "GoogleCloudDialogflowV2beta1EntityType",
      properties = {
        autoExpansionMode = {
          description = "Optional. Indicates whether the entity type can be automatically expanded.",
          enum = {
            "AUTO_EXPANSION_MODE_UNSPECIFIED",
            "AUTO_EXPANSION_MODE_DEFAULT",
          },
          enumDescriptions = {
            "Auto expansion disabled for the entity.",
            "Allows an agent to recognize values that have not been explicitly listed in the entity.",
          },
          type = "string",
        },
        displayName = {
          description = "Required. The name of the entity type.",
          type = "string",
        },
        enableFuzzyExtraction = {
          description = "Optional. Enables fuzzy entity extraction during classification.",
          type = "boolean",
        },
        entities = {
          description = "Optional. The collection of entity entries associated with the entity type.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1EntityTypeEntity",
          },
          type = "array",
        },
        kind = {
          description = "Required. Indicates the kind of entity type.",
          enum = {
            "KIND_UNSPECIFIED",
            "KIND_MAP",
            "KIND_LIST",
            "KIND_REGEXP",
          },
          enumDescriptions = {
            "Not specified. This value should be never used.",
            "Map entity types allow mapping of a group of synonyms to a reference value.",
            "List entity types contain a set of entries that do not map to reference values. However, list entity types can contain references to other entity types (with or without aliases).",
            "Regexp entity types allow to specify regular expressions in entries values.",
          },
          type = "string",
        },
        name = {
          description = "The unique identifier of the entity type. Required for EntityTypes.UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Supported formats: - `projects//agent/entityTypes/` - `projects//locations//agent/entityTypes/`",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1EntityTypeEntity = {
      description = "An **entity entry** for an associated entity type.",
      id = "GoogleCloudDialogflowV2beta1EntityTypeEntity",
      properties = {
        synonyms = {
          description = "Required. A collection of value synonyms. For example, if the entity type is *vegetable*, and `value` is *scallions*, a synonym could be *green onions*. For `KIND_LIST` entity types: * This collection must contain exactly one synonym equal to `value`.",
          items = {
            type = "string",
          },
          type = "array",
        },
        value = {
          description = "Required. The primary value associated with this entity entry. For example, if the entity type is *vegetable*, the value could be *scallions*. For `KIND_MAP` entity types: * A reference value to be used in place of synonyms. For `KIND_LIST` entity types: * A string that can contain references to other entity types (with or without aliases).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1EventInput = {
      description = "Events allow for matching intents by event name instead of the natural language input. For instance, input `` can trigger a personalized welcome response. The parameter `name` may be used by the agent in the response: `\"Hello #welcome_event.name! What can I do for you today?\"`.",
      id = "GoogleCloudDialogflowV2beta1EventInput",
      properties = {
        languageCode = {
          description = "Required. The language of this query. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language. This field is ignored when used in the context of a WebhookResponse.followup_event_input field, because the language was already defined in the originating detect intent request.",
          type = "string",
        },
        name = {
          description = "Required. The unique identifier of the event.",
          type = "string",
        },
        parameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "The collection of parameters associated with the event. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: - MapKey type: string - MapKey value: parameter name - MapValue type: - If parameter's entity type is a composite entity: map - Else: depending on parameter value type, could be one of string, number, boolean, null, list or map - MapValue value: - If parameter's entity type is a composite entity: map from composite entity property names to property values - Else: parameter value",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1ExportAgentResponse = {
      description = "The response message for Agents.ExportAgent.",
      id = "GoogleCloudDialogflowV2beta1ExportAgentResponse",
      properties = {
        agentContent = {
          description = "Zip compressed raw byte content for agent.",
          format = "byte",
          type = "string",
        },
        agentUri = {
          description = "The URI to a file containing the exported agent. This field is populated only if `agent_uri` is specified in `ExportAgentRequest`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1ExportOperationMetadata = {
      description = "Metadata related to the Export Data Operations (e.g. ExportDocument).",
      id = "GoogleCloudDialogflowV2beta1ExportOperationMetadata",
      properties = {
        exportedGcsDestination = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1GcsDestination",
          description = "Cloud Storage file path of the exported data.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1FaqAnswer = {
      description = "Represents answer from \"frequently asked questions\".",
      id = "GoogleCloudDialogflowV2beta1FaqAnswer",
      properties = {
        answer = {
          description = "The piece of text from the `source` knowledge base document.",
          type = "string",
        },
        answerRecord = {
          description = "The name of answer record, in the format of \"projects//locations//answerRecords/\"",
          type = "string",
        },
        confidence = {
          description = "The system's confidence score that this Knowledge answer is a good match for this conversational query, range from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        metadata = {
          additionalProperties = {
            type = "string",
          },
          description = "A map that contains metadata about the answer and the document from which it originates.",
          type = "object",
        },
        question = {
          description = "The corresponding FAQ question.",
          type = "string",
        },
        source = {
          description = "Indicates which Knowledge Document this answer was extracted from. Format: `projects//locations//agent/knowledgeBases//documents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1GcsDestination = {
      description = "Google Cloud Storage location for the output.",
      id = "GoogleCloudDialogflowV2beta1GcsDestination",
      properties = {
        uri = {
          description = "Required. The Google Cloud Storage URIs for the output. A URI is of the form: gs://bucket/object-prefix-or-name Whether a prefix or name is used depends on the use case. The requesting user must have \"write-permission\" to the bucket.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1HumanAgentAssistantEvent = {
      description = "Output only. Represents a notification sent to Pub/Sub subscribers for agent assistant events in a specific conversation.",
      id = "GoogleCloudDialogflowV2beta1HumanAgentAssistantEvent",
      properties = {
        conversation = {
          description = "The conversation this notification refers to. Format: `projects//conversations/`.",
          type = "string",
        },
        participant = {
          description = "The participant that the suggestion is compiled for. And This field is used to call Participants.ListSuggestions API. Format: `projects//conversations//participants/`. It will not be set in legacy workflow. HumanAgentAssistantConfig.name for more information.",
          type = "string",
        },
        suggestionResults = {
          description = "The suggestion results payload that this notification refers to. It will only be set when HumanAgentAssistantConfig.SuggestionConfig.group_suggestion_responses sets to true.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1SuggestionResult",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1ImportDocumentsResponse = {
      description = "Response message for Documents.ImportDocuments.",
      id = "GoogleCloudDialogflowV2beta1ImportDocumentsResponse",
      properties = {
        warnings = {
          description = "Includes details about skipped documents or any other warnings.",
          items = {
            ["$ref"] = "GoogleRpcStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1Intent = {
      description = "An intent categorizes an end-user's intention for one conversation turn. For each agent, you define many intents, where your combined intents can handle a complete conversation. When an end-user writes or says something, referred to as an end-user expression or end-user input, Dialogflow matches the end-user input to the best intent in your agent. Matching an intent is also known as intent classification. For more information, see the [intent guide](https://cloud.google.com/dialogflow/docs/intents-overview).",
      id = "GoogleCloudDialogflowV2beta1Intent",
      properties = {
        action = {
          description = "Optional. The name of the action associated with the intent. Note: The action name must not contain whitespaces.",
          type = "string",
        },
        defaultResponsePlatforms = {
          description = "Optional. The list of platforms for which the first responses will be copied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform).",
          items = {
            enum = {
              "PLATFORM_UNSPECIFIED",
              "FACEBOOK",
              "SLACK",
              "TELEGRAM",
              "KIK",
              "SKYPE",
              "LINE",
              "VIBER",
              "ACTIONS_ON_GOOGLE",
              "TELEPHONY",
              "GOOGLE_HANGOUTS",
            },
            enumDescriptions = {
              "Not specified.",
              "Facebook.",
              "Slack.",
              "Telegram.",
              "Kik.",
              "Skype.",
              "Line.",
              "Viber.",
              "Google Assistant See [Dialogflow webhook format](https://developers.google.com/assistant/actions/build/json/dialogflow-webhook-json)",
              "Telephony Gateway.",
              "Google Hangouts.",
            },
            type = "string",
          },
          type = "array",
        },
        displayName = {
          description = "Required. The name of this intent.",
          type = "string",
        },
        endInteraction = {
          description = "Optional. Indicates that this intent ends an interaction. Some integrations (e.g., Actions on Google or Dialogflow phone gateway) use this information to close interaction with an end user. Default is false.",
          type = "boolean",
        },
        events = {
          description = "Optional. The collection of event names that trigger the intent. If the collection of input contexts is not empty, all of the contexts must be present in the active user session for an event to trigger this intent. Event names are limited to 150 characters.",
          items = {
            type = "string",
          },
          type = "array",
        },
        followupIntentInfo = {
          description = "Output only. Information about all followup intents that have this intent as a direct or indirect parent. We populate this field only in the output.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo",
          },
          readOnly = true,
          type = "array",
        },
        inputContextNames = {
          description = "Optional. The list of context names required for this intent to be triggered. Formats: - `projects//agent/sessions/-/contexts/` - `projects//locations//agent/sessions/-/contexts/`",
          items = {
            type = "string",
          },
          type = "array",
        },
        isFallback = {
          description = "Optional. Indicates whether this is a fallback intent.",
          type = "boolean",
        },
        liveAgentHandoff = {
          description = "Optional. Indicates that a live agent should be brought in to handle the interaction with the user. In most cases, when you set this flag to true, you would also want to set end_interaction to true as well. Default is false.",
          type = "boolean",
        },
        messages = {
          description = "Optional. The collection of rich messages corresponding to the `Response` field in the Dialogflow console.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessage",
          },
          type = "array",
        },
        mlDisabled = {
          description = "Optional. Indicates whether Machine Learning is disabled for the intent. Note: If `ml_disabled` setting is set to true, then this intent is not taken into account during inference in `ML ONLY` match mode. Also, auto-markup in the UI is turned off.",
          type = "boolean",
        },
        mlEnabled = {
          description = "Optional. Indicates whether Machine Learning is enabled for the intent. Note: If `ml_enabled` setting is set to false, then this intent is not taken into account during inference in `ML ONLY` match mode. Also, auto-markup in the UI is turned off. DEPRECATED! Please use `ml_disabled` field instead. NOTE: If both `ml_enabled` and `ml_disabled` are either not set or false, then the default value is determined as follows: - Before April 15th, 2018 the default is: ml_enabled = false / ml_disabled = true. - After April 15th, 2018 the default is: ml_enabled = true / ml_disabled = false.",
          type = "boolean",
        },
        name = {
          description = "Optional. The unique identifier of this intent. Required for Intents.UpdateIntent and Intents.BatchUpdateIntents methods. Supported formats: - `projects//agent/intents/` - `projects//locations//agent/intents/`",
          type = "string",
        },
        outputContexts = {
          description = "Optional. The collection of contexts that are activated when the intent is matched. Context messages in this collection should not set the parameters field. Setting the `lifespan_count` to 0 will reset the context when the intent is matched. Format: `projects//agent/sessions/-/contexts/`.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1Context",
          },
          type = "array",
        },
        parameters = {
          description = "Optional. The collection of parameters associated with the intent.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentParameter",
          },
          type = "array",
        },
        parentFollowupIntentName = {
          description = "Optional. The unique identifier of the parent intent in the chain of followup intents. You can set this field when creating an intent, for example with CreateIntent or BatchUpdateIntents, in order to make this intent a followup intent. It identifies the parent followup intent. Format: `projects//agent/intents/`.",
          type = "string",
        },
        priority = {
          description = "Optional. The priority of this intent. Higher numbers represent higher priorities. - If the supplied value is unspecified or 0, the service translates the value to 500,000, which corresponds to the `Normal` priority in the console. - If the supplied value is negative, the intent is ignored in runtime detect intent requests.",
          format = "int32",
          type = "integer",
        },
        resetContexts = {
          description = "Optional. Indicates whether to delete all contexts in the current session when this intent is matched.",
          type = "boolean",
        },
        rootFollowupIntentName = {
          description = "Output only. The unique identifier of the root intent in the chain of followup intents. It identifies the correct followup intents chain for this intent. Format: `projects//agent/intents/`.",
          readOnly = true,
          type = "string",
        },
        trainingPhrases = {
          description = "Optional. The collection of examples that the agent is trained on.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentTrainingPhrase",
          },
          type = "array",
        },
        webhookState = {
          description = "Optional. Indicates whether webhooks are enabled for the intent.",
          enum = {
            "WEBHOOK_STATE_UNSPECIFIED",
            "WEBHOOK_STATE_ENABLED",
            "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING",
          },
          enumDescriptions = {
            "Webhook is disabled in the agent and in the intent.",
            "Webhook is enabled in the agent and in the intent.",
            "Webhook is enabled in the agent and in the intent. Also, each slot filling prompt is forwarded to the webhook.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo = {
      description = "Represents a single followup intent in the chain.",
      id = "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo",
      properties = {
        followupIntentName = {
          description = "The unique identifier of the followup intent. Format: `projects//agent/intents/`.",
          type = "string",
        },
        parentFollowupIntentName = {
          description = "The unique identifier of the followup intent's parent. Format: `projects//agent/intents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessage = {
      description = "Corresponds to the `Response` field in the Dialogflow console.",
      id = "GoogleCloudDialogflowV2beta1IntentMessage",
      properties = {
        basicCard = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBasicCard",
          description = "Displays a basic card for Actions on Google.",
        },
        browseCarouselCard = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCard",
          description = "Browse carousel card for Actions on Google.",
        },
        card = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageCard",
          description = "Displays a card.",
        },
        carouselSelect = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect",
          description = "Displays a carousel card for Actions on Google.",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Displays an image.",
        },
        linkOutSuggestion = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion",
          description = "Displays a link out suggestion chip for Actions on Google.",
        },
        listSelect = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageListSelect",
          description = "Displays a list card for Actions on Google.",
        },
        mediaContent = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageMediaContent",
          description = "The media content card for Actions on Google.",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "A custom platform-specific response.",
          type = "object",
        },
        platform = {
          description = "Optional. The platform that this message is intended for.",
          enum = {
            "PLATFORM_UNSPECIFIED",
            "FACEBOOK",
            "SLACK",
            "TELEGRAM",
            "KIK",
            "SKYPE",
            "LINE",
            "VIBER",
            "ACTIONS_ON_GOOGLE",
            "TELEPHONY",
            "GOOGLE_HANGOUTS",
          },
          enumDescriptions = {
            "Not specified.",
            "Facebook.",
            "Slack.",
            "Telegram.",
            "Kik.",
            "Skype.",
            "Line.",
            "Viber.",
            "Google Assistant See [Dialogflow webhook format](https://developers.google.com/assistant/actions/build/json/dialogflow-webhook-json)",
            "Telephony Gateway.",
            "Google Hangouts.",
          },
          type = "string",
        },
        quickReplies = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies",
          description = "Displays quick replies.",
        },
        rbmCarouselRichCard = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard",
          description = "Rich Business Messaging (RBM) carousel rich card response.",
        },
        rbmStandaloneRichCard = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard",
          description = "Standalone Rich Business Messaging (RBM) rich card response.",
        },
        rbmText = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmText",
          description = "Rich Business Messaging (RBM) text response. RBM allows businesses to send enriched and branded versions of SMS. See https://jibe.google.com/business-messaging.",
        },
        simpleResponses = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses",
          description = "Returns a voice or text-only response for Actions on Google.",
        },
        suggestions = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageSuggestions",
          description = "Displays suggestion chips for Actions on Google.",
        },
        tableCard = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageTableCard",
          description = "Table card for Actions on Google.",
        },
        telephonyPlayAudio = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio",
          description = "Plays audio from a file in Telephony Gateway.",
        },
        telephonySynthesizeSpeech = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech",
          description = "Synthesizes speech in Telephony Gateway.",
        },
        telephonyTransferCall = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall",
          description = "Transfers the call in Telephony Gateway.",
        },
        text = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageText",
          description = "Returns a text response.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageBasicCard = {
      description = "The basic card message. Useful for displaying information.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageBasicCard",
      properties = {
        buttons = {
          description = "Optional. The collection of card buttons.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton",
          },
          type = "array",
        },
        formattedText = {
          description = "Required, unless image is present. The body text of the card.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. The image for the card.",
        },
        subtitle = {
          description = "Optional. The subtitle of the card.",
          type = "string",
        },
        title = {
          description = "Optional. The title of the card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton = {
      description = "The button object that appears at the bottom of a card.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton",
      properties = {
        openUriAction = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction",
          description = "Required. Action to take when a user taps on the button.",
        },
        title = {
          description = "Required. The title of the button.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction = {
      description = "Opens the given URI.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction",
      properties = {
        uri = {
          description = "Required. The HTTP or HTTPS scheme URI.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCard = {
      description = "Browse Carousel Card for Actions on Google. https://developers.google.com/actions/assistant/responses#browsing_carousel",
      id = "GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCard",
      properties = {
        imageDisplayOptions = {
          description = "Optional. Settings for displaying the image. Applies to every image in items.",
          enum = {
            "IMAGE_DISPLAY_OPTIONS_UNSPECIFIED",
            "GRAY",
            "WHITE",
            "CROPPED",
            "BLURRED_BACKGROUND",
          },
          enumDescriptions = {
            "Fill the gaps between the image and the image container with gray bars.",
            "Fill the gaps between the image and the image container with gray bars.",
            "Fill the gaps between the image and the image container with white bars.",
            "Image is scaled such that the image width and height match or exceed the container dimensions. This may crop the top and bottom of the image if the scaled image height is greater than the container height, or crop the left and right of the image if the scaled image width is greater than the container width. This is similar to \"Zoom Mode\" on a widescreen TV when playing a 4:3 video.",
            "Pad the gaps between image and image frame with a blurred copy of the same image.",
          },
          type = "string",
        },
        items = {
          description = "Required. List of items in the Browse Carousel Card. Minimum of two items, maximum of ten.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItem",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItem = {
      description = "Browsing carousel tile",
      id = "GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItem",
      properties = {
        description = {
          description = "Optional. Description of the carousel item. Maximum of four lines of text.",
          type = "string",
        },
        footer = {
          description = "Optional. Text that appears at the bottom of the Browse Carousel Card. Maximum of one line of text.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. Hero image for the carousel item.",
        },
        openUriAction = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction",
          description = "Required. Action to present to the user.",
        },
        title = {
          description = "Required. Title of the carousel item. Maximum of two lines of text.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction = {
      description = "Actions on Google action to open a given url.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageBrowseCarouselCardBrowseCarouselCardItemOpenUrlAction",
      properties = {
        url = {
          description = "Required. URL",
          type = "string",
        },
        urlTypeHint = {
          description = "Optional. Specifies the type of viewer that is used when opening the URL. Defaults to opening via web browser.",
          enum = {
            "URL_TYPE_HINT_UNSPECIFIED",
            "AMP_ACTION",
            "AMP_CONTENT",
          },
          enumDescriptions = {
            "Unspecified",
            "Url would be an amp action",
            "URL that points directly to AMP content, or to a canonical URL which refers to AMP content via .",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageCard = {
      description = "The card response message.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageCard",
      properties = {
        buttons = {
          description = "Optional. The collection of card buttons.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageCardButton",
          },
          type = "array",
        },
        imageUri = {
          description = "Optional. The public URI to an image file for the card.",
          type = "string",
        },
        subtitle = {
          description = "Optional. The subtitle of the card.",
          type = "string",
        },
        title = {
          description = "Optional. The title of the card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageCardButton = {
      description = "Optional. Contains information about a button.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageCardButton",
      properties = {
        postback = {
          description = "Optional. The text to send back to the Dialogflow API or a URI to open.",
          type = "string",
        },
        text = {
          description = "Optional. The text to show on the button.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect = {
      description = "The card for presenting a carousel of options to select from.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect",
      properties = {
        items = {
          description = "Required. Carousel items.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem = {
      description = "An item in the carousel.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem",
      properties = {
        description = {
          description = "Optional. The body text of the card.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. The image to display.",
        },
        info = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo",
          description = "Required. Additional info about the option item.",
        },
        title = {
          description = "Required. Title of the carousel item.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageColumnProperties = {
      description = "Column properties for TableCard.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageColumnProperties",
      properties = {
        header = {
          description = "Required. Column heading.",
          type = "string",
        },
        horizontalAlignment = {
          description = "Optional. Defines text alignment for all cells in this column.",
          enum = {
            "HORIZONTAL_ALIGNMENT_UNSPECIFIED",
            "LEADING",
            "CENTER",
            "TRAILING",
          },
          enumDescriptions = {
            "Text is aligned to the leading edge of the column.",
            "Text is aligned to the leading edge of the column.",
            "Text is centered in the column.",
            "Text is aligned to the trailing edge of the column.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageImage = {
      description = "The image response message.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageImage",
      properties = {
        accessibilityText = {
          description = "A text description of the image to be used for accessibility, e.g., screen readers. Required if image_uri is set for CarouselSelect.",
          type = "string",
        },
        imageUri = {
          description = "Optional. The public URI to an image file.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion = {
      description = "The suggestion chip message that allows the user to jump out to the app or website associated with this agent.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion",
      properties = {
        destinationName = {
          description = "Required. The name of the app or site this chip is linking to.",
          type = "string",
        },
        uri = {
          description = "Required. The URI of the app or site to open when the user taps the suggestion chip.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageListSelect = {
      description = "The card for presenting a list of options to select from.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageListSelect",
      properties = {
        items = {
          description = "Required. List items.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem",
          },
          type = "array",
        },
        subtitle = {
          description = "Optional. Subtitle of the list.",
          type = "string",
        },
        title = {
          description = "Optional. The overall title of the list.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageListSelectItem = {
      description = "An item in the list.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem",
      properties = {
        description = {
          description = "Optional. The main text describing the item.",
          type = "string",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. The image to display.",
        },
        info = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo",
          description = "Required. Additional information about this option.",
        },
        title = {
          description = "Required. The title of the list item.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageMediaContent = {
      description = "The media content card for Actions on Google.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageMediaContent",
      properties = {
        mediaObjects = {
          description = "Required. List of media objects.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageMediaContentResponseMediaObject",
          },
          type = "array",
        },
        mediaType = {
          description = "Optional. What type of media is the content (ie \"audio\").",
          enum = {
            "RESPONSE_MEDIA_TYPE_UNSPECIFIED",
            "AUDIO",
          },
          enumDescriptions = {
            "Unspecified.",
            "Response media type is audio.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageMediaContentResponseMediaObject = {
      description = "Response media object for media content card.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageMediaContentResponseMediaObject",
      properties = {
        contentUrl = {
          description = "Required. Url where the media is stored.",
          type = "string",
        },
        description = {
          description = "Optional. Description of media card.",
          type = "string",
        },
        icon = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. Icon to display above media content.",
        },
        largeImage = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. Image to display above media content.",
        },
        name = {
          description = "Required. Name of media card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageQuickReplies = {
      description = "The quick replies response message.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies",
      properties = {
        quickReplies = {
          description = "Optional. The collection of quick replies.",
          items = {
            type = "string",
          },
          type = "array",
        },
        title = {
          description = "Optional. The title of the collection of quick replies.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent = {
      description = "Rich Business Messaging (RBM) Card content",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent",
      properties = {
        description = {
          description = "Optional. Description of the card (at most 2000 bytes). At least one of the title, description or media must be set.",
          type = "string",
        },
        media = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmCardContentRbmMedia",
          description = "Optional. However at least one of the title, description or media must be set. Media (image, GIF or a video) to include in the card.",
        },
        suggestions = {
          description = "Optional. List of suggestions to include in the card.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestion",
          },
          type = "array",
        },
        title = {
          description = "Optional. Title of the card (at most 200 bytes). At least one of the title, description or media must be set.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmCardContentRbmMedia = {
      description = "Rich Business Messaging (RBM) Media displayed in Cards The following media-types are currently supported: Image Types * image/jpeg * image/jpg' * image/gif * image/png Video Types * video/h263 * video/m4v * video/mp4 * video/mpeg * video/mpeg4 * video/webm",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmCardContentRbmMedia",
      properties = {
        fileUri = {
          description = "Required. Publicly reachable URI of the file. The RBM platform determines the MIME type of the file from the content-type field in the HTTP headers when the platform fetches the file. The content-type field must be present and accurate in the HTTP response from the URL.",
          type = "string",
        },
        height = {
          description = "Required for cards with vertical orientation. The height of the media within a rich card with a vertical layout. For a standalone card with horizontal layout, height is not customizable, and this field is ignored.",
          enum = {
            "HEIGHT_UNSPECIFIED",
            "SHORT",
            "MEDIUM",
            "TALL",
          },
          enumDescriptions = {
            "Not specified.",
            "112 DP.",
            "168 DP.",
            "264 DP. Not available for rich card carousels when the card width is set to small.",
          },
          type = "string",
        },
        thumbnailUri = {
          description = "Optional. Publicly reachable URI of the thumbnail.If you don't provide a thumbnail URI, the RBM platform displays a blank placeholder thumbnail until the user's device downloads the file. Depending on the user's setting, the file may not download automatically and may require the user to tap a download button.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard = {
      description = "Carousel Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. If you want to show a single card with more control over the layout, please use RbmStandaloneCard instead.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmCarouselCard",
      properties = {
        cardContents = {
          description = "Required. The cards in the carousel. A carousel must have at least 2 cards and at most 10.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent",
          },
          type = "array",
        },
        cardWidth = {
          description = "Required. The width of the cards in the carousel.",
          enum = {
            "CARD_WIDTH_UNSPECIFIED",
            "SMALL",
            "MEDIUM",
          },
          enumDescriptions = {
            "Not specified.",
            "120 DP. Note that tall media cannot be used.",
            "232 DP.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard = {
      description = "Standalone Rich Business Messaging (RBM) rich card. Rich cards allow you to respond to users with more vivid content, e.g. with media and suggestions. You can group multiple rich cards into one using RbmCarouselCard but carousel cards will give you less control over the card layout.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmStandaloneCard",
      properties = {
        cardContent = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmCardContent",
          description = "Required. Card content.",
        },
        cardOrientation = {
          description = "Required. Orientation of the card.",
          enum = {
            "CARD_ORIENTATION_UNSPECIFIED",
            "HORIZONTAL",
            "VERTICAL",
          },
          enumDescriptions = {
            "Not specified.",
            "Horizontal layout.",
            "Vertical layout.",
          },
          type = "string",
        },
        thumbnailImageAlignment = {
          description = "Required if orientation is horizontal. Image preview alignment for standalone cards with horizontal layout.",
          enum = {
            "THUMBNAIL_IMAGE_ALIGNMENT_UNSPECIFIED",
            "LEFT",
            "RIGHT",
          },
          enumDescriptions = {
            "Not specified.",
            "Thumbnail preview is left-aligned.",
            "Thumbnail preview is right-aligned.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction = {
      description = "Rich Business Messaging (RBM) suggested client-side action that the user can choose from the card.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction",
      properties = {
        dial = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionDial",
          description = "Suggested client side action: Dial a phone number",
        },
        openUrl = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri",
          description = "Suggested client side action: Open a URI on device",
        },
        postbackData = {
          description = "Opaque payload that the Dialogflow receives in a user event when the user taps the suggested action. This data will be also forwarded to webhook to allow performing custom business logic.",
          type = "string",
        },
        shareLocation = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionShareLocation",
          description = "Suggested client side action: Share user location",
        },
        text = {
          description = "Text to display alongside the action.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionDial = {
      description = "Opens the user's default dialer app with the specified phone number but does not dial automatically.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionDial",
      properties = {
        phoneNumber = {
          description = "Required. The phone number to fill in the default dialer app. This field should be in [E.164](https://en.wikipedia.org/wiki/E.164) format. An example of a correctly formatted phone number: +15556767888.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri = {
      description = "Opens the user's default web browser app to the specified uri If the user has an app installed that is registered as the default handler for the URL, then this app will be opened instead, and its icon will be used in the suggested action UI.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionOpenUri",
      properties = {
        uri = {
          description = "Required. The uri to open on the user device",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionShareLocation = {
      description = "Opens the device's location chooser so the user can pick a location to send back to the agent.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedActionRbmSuggestedActionShareLocation",
      properties = {},
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply = {
      description = "Rich Business Messaging (RBM) suggested reply that the user can click instead of typing in their own response.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply",
      properties = {
        postbackData = {
          description = "Opaque payload that the Dialogflow receives in a user event when the user taps the suggested reply. This data will be also forwarded to webhook to allow performing custom business logic.",
          type = "string",
        },
        text = {
          description = "Suggested reply text.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestion = {
      description = "Rich Business Messaging (RBM) suggestion. Suggestions allow user to easily select/click a predefined response or perform an action (like opening a web uri).",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestion",
      properties = {
        action = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedAction",
          description = "Predefined client side actions that user can choose",
        },
        reply = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestedReply",
          description = "Predefined replies for user to select instead of typing",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageRbmText = {
      description = "Rich Business Messaging (RBM) text response with suggestions.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageRbmText",
      properties = {
        rbmSuggestion = {
          description = "Optional. One or more suggestions to show to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageRbmSuggestion",
          },
          type = "array",
        },
        text = {
          description = "Required. Text sent and displayed to the user.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo = {
      description = "Additional info about the select item for when it is triggered in a dialog.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo",
      properties = {
        key = {
          description = "Required. A unique key that will be sent back to the agent if this response is given.",
          type = "string",
        },
        synonyms = {
          description = "Optional. A list of synonyms that can also be used to trigger this item in dialog.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse = {
      description = "The simple response message containing speech or text.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse",
      properties = {
        displayText = {
          description = "Optional. The text to display.",
          type = "string",
        },
        ssml = {
          description = "One of text_to_speech or ssml must be provided. Structured spoken response to the user in the SSML format. Mutually exclusive with text_to_speech.",
          type = "string",
        },
        textToSpeech = {
          description = "One of text_to_speech or ssml must be provided. The plain text of the speech output. Mutually exclusive with ssml.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses = {
      description = "The collection of simple response candidates. This message in `QueryResult.fulfillment_messages` and `WebhookResponse.fulfillment_messages` should contain only one `SimpleResponse`.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses",
      properties = {
        simpleResponses = {
          description = "Required. The list of simple responses.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageSuggestion = {
      description = "The suggestion chip message that the user can tap to quickly post a reply to the conversation.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageSuggestion",
      properties = {
        title = {
          description = "Required. The text shown the in the suggestion chip.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageSuggestions = {
      description = "The collection of suggestions.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageSuggestions",
      properties = {
        suggestions = {
          description = "Required. The list of suggested replies.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageSuggestion",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageTableCard = {
      description = "Table card for Actions on Google.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageTableCard",
      properties = {
        buttons = {
          description = "Optional. List of buttons for the card.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton",
          },
          type = "array",
        },
        columnProperties = {
          description = "Optional. Display properties for the columns in this table.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageColumnProperties",
          },
          type = "array",
        },
        image = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageImage",
          description = "Optional. Image which should be displayed on the card.",
        },
        rows = {
          description = "Optional. Rows in this table of data.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageTableCardRow",
          },
          type = "array",
        },
        subtitle = {
          description = "Optional. Subtitle to the title.",
          type = "string",
        },
        title = {
          description = "Required. Title of the card.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageTableCardCell = {
      description = "Cell of TableCardRow.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageTableCardCell",
      properties = {
        text = {
          description = "Required. Text in this cell.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageTableCardRow = {
      description = "Row of TableCard.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageTableCardRow",
      properties = {
        cells = {
          description = "Optional. List of cells that make up this row.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessageTableCardCell",
          },
          type = "array",
        },
        dividerAfter = {
          description = "Optional. Whether to add a visual divider after this row.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio = {
      description = "Plays audio from a file in Telephony Gateway.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio",
      properties = {
        audioUri = {
          description = "Required. URI to a Google Cloud Storage object containing the audio to play, e.g., \"gs://bucket/object\". The object must contain a single channel (mono) of linear PCM audio (2 bytes / sample) at 8kHz. This object must be readable by the `service-@gcp-sa-dialogflow.iam.gserviceaccount.com` service account where is the number of the Telephony Gateway project (usually the same as the Dialogflow agent project). If the Google Cloud Storage bucket is in the Telephony Gateway project, this permission is added by default when enabling the Dialogflow V2 API. For audio from other sources, consider using the `TelephonySynthesizeSpeech` message with SSML.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech = {
      description = "Synthesizes speech and plays back the synthesized audio to the caller in Telephony Gateway. Telephony Gateway takes the synthesizer settings from `DetectIntentResponse.output_audio_config` which can either be set at request-level or can come from the agent-level synthesizer config.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech",
      properties = {
        ssml = {
          description = "The SSML to be synthesized. For more information, see [SSML](https://developers.google.com/actions/reference/ssml).",
          type = "string",
        },
        text = {
          description = "The raw text to be synthesized.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall = {
      description = "Transfers the call in Telephony Gateway.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall",
      properties = {
        phoneNumber = {
          description = "Required. The phone number to transfer the call to in [E.164 format](https://en.wikipedia.org/wiki/E.164). We currently only allow transferring to US numbers (+1xxxyyyzzzz).",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentMessageText = {
      description = "The text response message.",
      id = "GoogleCloudDialogflowV2beta1IntentMessageText",
      properties = {
        text = {
          description = "Optional. The collection of the agent's responses.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentParameter = {
      description = "Represents intent parameters.",
      id = "GoogleCloudDialogflowV2beta1IntentParameter",
      properties = {
        defaultValue = {
          description = "Optional. The default value to use when the `value` yields an empty result. Default values can be extracted from contexts by using the following syntax: `#context_name.parameter_name`.",
          type = "string",
        },
        displayName = {
          description = "Required. The name of the parameter.",
          type = "string",
        },
        entityTypeDisplayName = {
          description = "Optional. The name of the entity type, prefixed with `@`, that describes values of the parameter. If the parameter is required, this must be provided.",
          type = "string",
        },
        isList = {
          description = "Optional. Indicates whether the parameter represents a list of values.",
          type = "boolean",
        },
        mandatory = {
          description = "Optional. Indicates whether the parameter is required. That is, whether the intent cannot be completed without collecting the parameter value.",
          type = "boolean",
        },
        name = {
          description = "The unique identifier of this parameter.",
          type = "string",
        },
        prompts = {
          description = "Optional. The collection of prompts that the agent can present to the user in order to collect a value for the parameter.",
          items = {
            type = "string",
          },
          type = "array",
        },
        value = {
          description = "Optional. The definition of the parameter value. It can be: - a constant string, - a parameter value defined as `$parameter_name`, - an original parameter value defined as `$parameter_name.original`, - a parameter value from some context defined as `#context_name.parameter_name`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentTrainingPhrase = {
      description = "Represents an example that the agent is trained on.",
      id = "GoogleCloudDialogflowV2beta1IntentTrainingPhrase",
      properties = {
        name = {
          description = "Output only. The unique identifier of this training phrase.",
          type = "string",
        },
        parts = {
          description = "Required. The ordered list of training phrase parts. The parts are concatenated in order to form the training phrase. Note: The API does not automatically annotate training phrases like the Dialogflow Console does. Note: Do not forget to include whitespace at part boundaries, so the training phrase is well formatted when the parts are concatenated. If the training phrase does not need to be annotated with parameters, you just need a single part with only the Part.text field set. If you want to annotate the training phrase, you must create multiple parts, where the fields of each part are populated in one of two ways: - `Part.text` is set to a part of the phrase that has no parameters. - `Part.text` is set to a part of the phrase that you want to annotate, and the `entity_type`, `alias`, and `user_defined` fields are all set.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart",
          },
          type = "array",
        },
        timesAddedCount = {
          description = "Optional. Indicates how many times this example was added to the intent. Each time a developer adds an existing sample by editing an intent or training, this counter is increased.",
          format = "int32",
          type = "integer",
        },
        type = {
          description = "Required. The type of the training phrase.",
          enum = {
            "TYPE_UNSPECIFIED",
            "EXAMPLE",
            "TEMPLATE",
          },
          enumDescriptions = {
            "Not specified. This value should never be used.",
            "Examples do not contain @-prefixed entity type names, but example parts can be annotated with entity types.",
            "Templates are not annotated with entity types, but they can contain @-prefixed entity type names as substrings. Note: Template mode has been deprecated. Example mode is the only supported way to create new training phrases. If you have existing training phrases in template mode, they will be removed during training and it can cause a drop in agent performance.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart = {
      description = "Represents a part of a training phrase.",
      id = "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart",
      properties = {
        alias = {
          description = "Optional. The parameter name for the value extracted from the annotated part of the example. This field is required for annotated parts of the training phrase.",
          type = "string",
        },
        entityType = {
          description = "Optional. The entity type name prefixed with `@`. This field is required for annotated parts of the training phrase.",
          type = "string",
        },
        text = {
          description = "Required. The text for this part.",
          type = "string",
        },
        userDefined = {
          description = "Optional. Indicates whether the text was manually annotated. This field is set to true when the Dialogflow Console is used to manually annotate the part. When creating an annotated part with the API, you must set this to true.",
          type = "boolean",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1KnowledgeAnswers = {
      description = "Represents the result of querying a Knowledge base.",
      id = "GoogleCloudDialogflowV2beta1KnowledgeAnswers",
      properties = {
        answers = {
          description = "A list of answers from Knowledge Connector.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer = {
      description = "An answer from Knowledge Connector.",
      id = "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer",
      properties = {
        answer = {
          description = "The piece of text from the `source` knowledge base document that answers this conversational query.",
          type = "string",
        },
        faqQuestion = {
          description = "The corresponding FAQ question if the answer was extracted from a FAQ Document, empty otherwise.",
          type = "string",
        },
        matchConfidence = {
          description = "The system's confidence score that this Knowledge answer is a good match for this conversational query. The range is from 0.0 (completely uncertain) to 1.0 (completely certain). Note: The confidence score is likely to vary somewhat (possibly even for identical requests), as the underlying model is under constant improvement. It may be deprecated in the future. We recommend using `match_confidence_level` which should be generally more stable.",
          format = "float",
          type = "number",
        },
        matchConfidenceLevel = {
          description = "The system's confidence level that this knowledge answer is a good match for this conversational query. NOTE: The confidence level for a given `` pair may change without notice, as it depends on models that are constantly being improved. However, it will change less frequently than the confidence score below, and should be preferred for referencing the quality of an answer.",
          enum = {
            "MATCH_CONFIDENCE_LEVEL_UNSPECIFIED",
            "LOW",
            "MEDIUM",
            "HIGH",
          },
          enumDescriptions = {
            "Not specified.",
            "Indicates that the confidence is low.",
            "Indicates our confidence is medium.",
            "Indicates our confidence is high.",
          },
          type = "string",
        },
        source = {
          description = "Indicates which Knowledge Document this answer was extracted from. Format: `projects//knowledgeBases//documents/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata = {
      description = "Metadata in google::longrunning::Operation for Knowledge operations.",
      id = "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata",
      properties = {
        exportOperationMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1ExportOperationMetadata",
          description = "Metadata for the Export Data Operation such as the destination of export.",
        },
        knowledgeBase = {
          description = "The name of the knowledge base interacted with during the operation.",
          type = "string",
        },
        state = {
          description = "Required. Output only. The current state of this operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "PENDING",
            "RUNNING",
            "DONE",
          },
          enumDescriptions = {
            "State unspecified.",
            "The operation has been created.",
            "The operation is currently running.",
            "The operation is done, either cancelled or completed.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1Message = {
      description = "Represents a message posted into a conversation.",
      id = "GoogleCloudDialogflowV2beta1Message",
      properties = {
        content = {
          description = "Required. The message content.",
          type = "string",
        },
        createTime = {
          description = "Output only. The time when the message was created in Contact Center AI.",
          format = "google-datetime",
          readOnly = true,
          type = "string",
        },
        languageCode = {
          description = "Optional. The message language. This should be a [BCP-47](https://www.rfc-editor.org/rfc/bcp/bcp47.txt) language tag. Example: \"en-US\".",
          type = "string",
        },
        messageAnnotation = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1MessageAnnotation",
          description = "Output only. The annotation for the message.",
          readOnly = true,
        },
        name = {
          description = "Optional. The unique identifier of the message. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
        participant = {
          description = "Output only. The participant that sends this message.",
          readOnly = true,
          type = "string",
        },
        participantRole = {
          description = "Output only. The role of the participant.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          readOnly = true,
          type = "string",
        },
        sendTime = {
          description = "Optional. The time when the message was sent.",
          format = "google-datetime",
          type = "string",
        },
        sentimentAnalysis = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1SentimentAnalysisResult",
          description = "Output only. The sentiment analysis result for the message.",
          readOnly = true,
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1MessageAnnotation = {
      description = "Represents the result of annotation for the message.",
      id = "GoogleCloudDialogflowV2beta1MessageAnnotation",
      properties = {
        containEntities = {
          description = "Required. Indicates whether the text message contains entities.",
          type = "boolean",
        },
        parts = {
          description = "Optional. The collection of annotated message parts ordered by their position in the message. You can recover the annotated message by concatenating [AnnotatedMessagePart.text].",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1AnnotatedMessagePart",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest = {
      description = "Represents the contents of the original request that was passed to the `[Streaming]DetectIntent` call.",
      id = "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest",
      properties = {
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Optional. This field is set to the value of the `QueryParameters.payload` field passed in the request. Some integrations that query a Dialogflow agent may provide additional information in the payload. In particular, for the Dialogflow Phone Gateway integration, this field has the form: { \"telephony\": { \"caller_id\": \"+18558363987\" } } Note: The caller ID field (`caller_id`) will be redacted for Trial Edition agents and populated with the caller ID in [E.164 format](https://en.wikipedia.org/wiki/E.164) for Essentials Edition agents.",
          type = "object",
        },
        source = {
          description = "The source of this request, e.g., `google`, `facebook`, `slack`. It is set by Dialogflow-owned servers.",
          type = "string",
        },
        version = {
          description = "Optional. The version of the protocol used for this request. This field is AoG-specific.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1QueryResult = {
      description = "Represents the result of conversational query or event processing.",
      id = "GoogleCloudDialogflowV2beta1QueryResult",
      properties = {
        action = {
          description = "The action name from the matched intent.",
          type = "string",
        },
        allRequiredParamsPresent = {
          description = "This field is set to: - `false` if the matched intent has required parameters and not all of the required parameter values have been collected. - `true` if all required parameter values have been collected, or if the matched intent doesn't contain any required parameters.",
          type = "boolean",
        },
        cancelsSlotFilling = {
          description = "Indicates whether the conversational query triggers a cancellation for slot filling. For more information, see the [cancel slot filling documentation](https://cloud.google.com/dialogflow/es/docs/intents-actions-parameters#cancel).",
          type = "boolean",
        },
        diagnosticInfo = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Free-form diagnostic information for the associated detect intent request. The fields of this data can change without notice, so you should not write code that depends on its structure. The data may contain: - webhook call latency - webhook errors",
          type = "object",
        },
        fulfillmentMessages = {
          description = "The collection of rich messages to present to the user.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessage",
          },
          type = "array",
        },
        fulfillmentText = {
          description = "The text to be pronounced to the user or shown on the screen. Note: This is a legacy field, `fulfillment_messages` should be preferred.",
          type = "string",
        },
        intent = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1Intent",
          description = "The intent that matched the conversational query. Some, not all fields are filled in this message, including but not limited to: `name`, `display_name`, `end_interaction` and `is_fallback`.",
        },
        intentDetectionConfidence = {
          description = "The intent detection confidence. Values range from 0.0 (completely uncertain) to 1.0 (completely certain). This value is for informational purpose only and is only used to help match the best intent within the classification threshold. This value may change for the same end-user expression at any time due to a model retraining or change in implementation. If there are `multiple knowledge_answers` messages, this value is set to the greatest `knowledgeAnswers.match_confidence` value in the list.",
          format = "float",
          type = "number",
        },
        knowledgeAnswers = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1KnowledgeAnswers",
          description = "The result from Knowledge Connector (if any), ordered by decreasing `KnowledgeAnswers.match_confidence`.",
        },
        languageCode = {
          description = "The language that was triggered during intent detection. See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes.",
          type = "string",
        },
        outputContexts = {
          description = "The collection of output contexts. If applicable, `output_contexts.parameters` contains entries with name `.original` containing the original parameter values before the query.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1Context",
          },
          type = "array",
        },
        parameters = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "The collection of extracted parameters. Depending on your protocol or client library language, this is a map, associative array, symbol table, dictionary, or JSON object composed of a collection of (MapKey, MapValue) pairs: - MapKey type: string - MapKey value: parameter name - MapValue type: - If parameter's entity type is a composite entity: map - Else: depending on parameter value type, could be one of string, number, boolean, null, list or map - MapValue value: - If parameter's entity type is a composite entity: map from composite entity property names to property values - Else: parameter value",
          type = "object",
        },
        queryText = {
          description = "The original conversational query text: - If natural language text was provided as input, `query_text` contains a copy of the input. - If natural language speech audio was provided as input, `query_text` contains the speech recognition result. If speech recognizer produced multiple alternatives, a particular one is picked. - If automatic spell correction is enabled, `query_text` will contain the corrected user input.",
          type = "string",
        },
        sentimentAnalysisResult = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1SentimentAnalysisResult",
          description = "The sentiment analysis result, which depends on the `sentiment_analysis_request_config` specified in the request.",
        },
        speechRecognitionConfidence = {
          description = "The Speech recognition confidence between 0.0 and 1.0. A higher number indicates an estimated greater likelihood that the recognized words are correct. The default of 0.0 is a sentinel value indicating that confidence was not set. This field is not guaranteed to be accurate or set. In particular this field isn't set for StreamingDetectIntent since the streaming endpoint has separate confidence estimates per portion of the audio in StreamingRecognitionResult.",
          format = "float",
          type = "number",
        },
        webhookPayload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "If the query was fulfilled by a webhook call, this field is set to the value of the `payload` field returned in the webhook response.",
          type = "object",
        },
        webhookSource = {
          description = "If the query was fulfilled by a webhook call, this field is set to the value of the `source` field returned in the webhook response.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1Sentiment = {
      description = "The sentiment, such as positive/negative feeling or association, for a unit of analysis, such as the query text. See: https://cloud.google.com/natural-language/docs/basics#interpreting_sentiment_analysis_values for how to interpret the result.",
      id = "GoogleCloudDialogflowV2beta1Sentiment",
      properties = {
        magnitude = {
          description = "A non-negative number in the [0, +inf) range, which represents the absolute magnitude of sentiment, regardless of score (positive or negative).",
          format = "float",
          type = "number",
        },
        score = {
          description = "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive sentiment).",
          format = "float",
          type = "number",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SentimentAnalysisResult = {
      description = "The result of sentiment analysis. Sentiment analysis inspects user input and identifies the prevailing subjective opinion, especially to determine a user's attitude as positive, negative, or neutral. For Participants.DetectIntent, it needs to be configured in DetectIntentRequest.query_params. For Participants.StreamingDetectIntent, it needs to be configured in StreamingDetectIntentRequest.query_params. And for Participants.AnalyzeContent and Participants.StreamingAnalyzeContent, it needs to be configured in ConversationProfile.human_agent_assistant_config",
      id = "GoogleCloudDialogflowV2beta1SentimentAnalysisResult",
      properties = {
        queryTextSentiment = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1Sentiment",
          description = "The sentiment analysis result for `query_text`.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SessionEntityType = {
      description = "A session represents a conversation between a Dialogflow agent and an end-user. You can create special entities, called session entities, during a session. Session entities can extend or replace custom entity types and only exist during the session that they were created for. All session data, including session entities, is stored by Dialogflow for 20 minutes. For more information, see the [session entity guide](https://cloud.google.com/dialogflow/docs/entities-session).",
      id = "GoogleCloudDialogflowV2beta1SessionEntityType",
      properties = {
        entities = {
          description = "Required. The collection of entities associated with this session entity type.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1EntityTypeEntity",
          },
          type = "array",
        },
        entityOverrideMode = {
          description = "Required. Indicates whether the additional data should override or supplement the custom entity type definition.",
          enum = {
            "ENTITY_OVERRIDE_MODE_UNSPECIFIED",
            "ENTITY_OVERRIDE_MODE_OVERRIDE",
            "ENTITY_OVERRIDE_MODE_SUPPLEMENT",
          },
          enumDescriptions = {
            "Not specified. This value should be never used.",
            "The collection of session entities overrides the collection of entities in the corresponding custom entity type.",
            "The collection of session entities extends the collection of entities in the corresponding custom entity type. Note: Even in this override mode calls to `ListSessionEntityTypes`, `GetSessionEntityType`, `CreateSessionEntityType` and `UpdateSessionEntityType` only return the additional entities added in this session entity type. If you want to get the supplemented list, please call EntityTypes.GetEntityType on the custom entity type and merge.",
          },
          type = "string",
        },
        name = {
          description = "Required. The unique identifier of this session entity type. Supported formats: - `projects//agent/sessions//entityTypes/` - `projects//locations//agent/sessions//entityTypes/` - `projects//agent/environments//users//sessions//entityTypes/` - `projects//locations//agent/environments/ /users//sessions//entityTypes/` If `Location ID` is not specified we assume default 'us' location. If `Environment ID` is not specified, we assume default 'draft' environment. If `User ID` is not specified, we assume default '-' user. `` must be the display name of an existing entity type in the same agent that will be overridden or supplemented.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SetSuggestionFeatureConfigOperationMetadata = {
      description = "Metadata for a ConversationProfile.SetSuggestionFeatureConfig operation.",
      id = "GoogleCloudDialogflowV2beta1SetSuggestionFeatureConfigOperationMetadata",
      properties = {
        conversationProfile = {
          description = "The resource name of the conversation profile. Format: `projects//locations//conversationProfiles/`",
          type = "string",
        },
        createTime = {
          description = "Timestamp whe the request was created. The time is measured on server side.",
          format = "google-datetime",
          type = "string",
        },
        participantRole = {
          description = "Required. The participant role to add or update the suggestion feature config. Only HUMAN_AGENT or END_USER can be used.",
          enum = {
            "ROLE_UNSPECIFIED",
            "HUMAN_AGENT",
            "AUTOMATED_AGENT",
            "END_USER",
          },
          enumDescriptions = {
            "Participant role not set.",
            "Participant is a human agent.",
            "Participant is an automated agent, such as a Dialogflow agent.",
            "Participant is an end user that has called or chatted with Dialogflow services.",
          },
          type = "string",
        },
        suggestionFeatureType = {
          description = "Required. The type of the suggestion feature to add or update.",
          enum = {
            "TYPE_UNSPECIFIED",
            "ARTICLE_SUGGESTION",
            "FAQ",
            "SMART_REPLY",
            "CONVERSATION_SUMMARIZATION",
          },
          enumDescriptions = {
            "Unspecified feature type.",
            "Run article suggestion model for chat.",
            "Run FAQ model.",
            "Run smart reply model for chat.",
            "Run conversation summarization model for chat.",
          },
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SmartReplyAnswer = {
      description = "Represents a smart reply answer.",
      id = "GoogleCloudDialogflowV2beta1SmartReplyAnswer",
      properties = {
        answerRecord = {
          description = "The name of answer record, in the format of \"projects//locations//answerRecords/\"",
          type = "string",
        },
        confidence = {
          description = "Smart reply confidence. The system's confidence score that this reply is a good match for this conversation, as a value from 0.0 (completely uncertain) to 1.0 (completely certain).",
          format = "float",
          type = "number",
        },
        reply = {
          description = "The content of the reply.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SuggestArticlesResponse = {
      description = "The response message for Participants.SuggestArticles.",
      id = "GoogleCloudDialogflowV2beta1SuggestArticlesResponse",
      properties = {
        articleAnswers = {
          description = "Output only. Articles ordered by score in descending order.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1ArticleAnswer",
          },
          type = "array",
        },
        contextSize = {
          description = "Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestArticlesResponse.context_size field in the request if there aren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "The name of the latest conversation message used to compile suggestion for. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SuggestFaqAnswersResponse = {
      description = "The request message for Participants.SuggestFaqAnswers.",
      id = "GoogleCloudDialogflowV2beta1SuggestFaqAnswersResponse",
      properties = {
        contextSize = {
          description = "Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestFaqAnswersRequest.context_size field in the request if there aren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        faqAnswers = {
          description = "Output only. Answers extracted from FAQ documents.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1FaqAnswer",
          },
          type = "array",
        },
        latestMessage = {
          description = "The name of the latest conversation message used to compile suggestion for. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse = {
      description = "The response message for Participants.SuggestSmartReplies.",
      id = "GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse",
      properties = {
        contextSize = {
          description = "Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestSmartRepliesRequest.context_size field in the request if there aren't that many messages in the conversation.",
          format = "int32",
          type = "integer",
        },
        latestMessage = {
          description = "The name of the latest conversation message used to compile suggestion for. Format: `projects//locations//conversations//messages/`.",
          type = "string",
        },
        smartReplyAnswers = {
          description = "Output only. Multiple reply options provided by smart reply service. The order is based on the rank of the model prediction. The maximum number of the returned replies is set in SmartReplyConfig.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1SmartReplyAnswer",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1SuggestionResult = {
      description = "One response of different type of suggestion response which is used in the response of Participants.AnalyzeContent and Participants.AnalyzeContent, as well as HumanAgentAssistantEvent.",
      id = "GoogleCloudDialogflowV2beta1SuggestionResult",
      properties = {
        error = {
          ["$ref"] = "GoogleRpcStatus",
          description = "Error status if the request failed.",
        },
        suggestArticlesResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1SuggestArticlesResponse",
          description = "SuggestArticlesResponse if request is for ARTICLE_SUGGESTION.",
        },
        suggestFaqAnswersResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1SuggestFaqAnswersResponse",
          description = "SuggestFaqAnswersResponse if request is for FAQ_ANSWER.",
        },
        suggestSmartRepliesResponse = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1SuggestSmartRepliesResponse",
          description = "SuggestSmartRepliesResponse if request is for SMART_REPLY.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1WebhookRequest = {
      description = "The request message for a webhook call.",
      id = "GoogleCloudDialogflowV2beta1WebhookRequest",
      properties = {
        alternativeQueryResults = {
          description = "Alternative query results from KnowledgeService.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1QueryResult",
          },
          type = "array",
        },
        originalDetectIntentRequest = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest",
          description = "Optional. The contents of the original request that was passed to `[Streaming]DetectIntent` call.",
        },
        queryResult = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1QueryResult",
          description = "The result of the conversational query or event processing. Contains the same value as `[Streaming]DetectIntentResponse.query_result`.",
        },
        responseId = {
          description = "The unique identifier of the response. Contains the same value as `[Streaming]DetectIntentResponse.response_id`.",
          type = "string",
        },
        session = {
          description = "The unique identifier of detectIntent request session. Can be used to identify end-user inside webhook implementation. Supported formats: - `projects//agent/sessions/, - `projects//locations//agent/sessions/`, - `projects//agent/environments//users//sessions/`, - `projects//locations//agent/environments//users//sessions/`,",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV2beta1WebhookResponse = {
      description = "The response message for a webhook call. This response is validated by the Dialogflow server. If validation fails, an error will be returned in the QueryResult.diagnostic_info field. Setting JSON fields to an empty value with the wrong type is a common error. To avoid this error: - Use `\"\"` for empty strings - Use `{}` or `null` for empty objects - Use `[]` or `null` for empty arrays For more information, see the [Protocol Buffers Language Guide](https://developers.google.com/protocol-buffers/docs/proto3#json).",
      id = "GoogleCloudDialogflowV2beta1WebhookResponse",
      properties = {
        endInteraction = {
          description = "Optional. Indicates that this intent ends an interaction. Some integrations (e.g., Actions on Google or Dialogflow phone gateway) use this information to close interaction with an end user. Default is false.",
          type = "boolean",
        },
        followupEventInput = {
          ["$ref"] = "GoogleCloudDialogflowV2beta1EventInput",
          description = "Optional. Invokes the supplied events. When this field is set, Dialogflow ignores the `fulfillment_text`, `fulfillment_messages`, and `payload` fields.",
        },
        fulfillmentMessages = {
          description = "Optional. The rich response messages intended for the end-user. When provided, Dialogflow uses this field to populate QueryResult.fulfillment_messages sent to the integration or API caller.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1IntentMessage",
          },
          type = "array",
        },
        fulfillmentText = {
          description = "Optional. The text response message intended for the end-user. It is recommended to use `fulfillment_messages.text.text[0]` instead. When provided, Dialogflow uses this field to populate QueryResult.fulfillment_text sent to the integration or API caller.",
          type = "string",
        },
        liveAgentHandoff = {
          description = "Indicates that a live agent should be brought in to handle the interaction with the user. In most cases, when you set this flag to true, you would also want to set end_interaction to true as well. Default is false.",
          type = "boolean",
        },
        outputContexts = {
          description = "Optional. The collection of output contexts that will overwrite currently active contexts for the session and reset their lifespans. When provided, Dialogflow uses this field to populate QueryResult.output_contexts sent to the integration or API caller.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1Context",
          },
          type = "array",
        },
        payload = {
          additionalProperties = {
            description = "Properties of the object.",
            type = "any",
          },
          description = "Optional. This field can be used to pass custom data from your webhook to the integration or API caller. Arbitrary JSON objects are supported. When provided, Dialogflow uses this field to populate QueryResult.webhook_payload sent to the integration or API caller. This field is also used by the [Google Assistant integration](https://cloud.google.com/dialogflow/docs/integrations/aog) for rich response messages. See the format definition at [Google Assistant Dialogflow webhook format](https://developers.google.com/assistant/actions/build/json/dialogflow-webhook-json)",
          type = "object",
        },
        sessionEntityTypes = {
          description = "Optional. Additional session entity types to replace or extend developer entity types with. The entity synonyms apply to all languages and persist for the session. Setting this data from a webhook overwrites the session entity types that have been set using `detectIntent`, `streamingDetectIntent` or SessionEntityType management methods.",
          items = {
            ["$ref"] = "GoogleCloudDialogflowV2beta1SessionEntityType",
          },
          type = "array",
        },
        source = {
          description = "Optional. A custom field used to identify the webhook source. Arbitrary strings are supported. When provided, Dialogflow uses this field to populate QueryResult.webhook_source sent to the integration or API caller.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1ConversationSignals = {
      description = "This message is used to hold all the Conversation Signals data, which will be converted to JSON and exported to BigQuery.",
      id = "GoogleCloudDialogflowV3alpha1ConversationSignals",
      properties = {
        turnSignals = {
          ["$ref"] = "GoogleCloudDialogflowV3alpha1TurnSignals",
          description = "Required. Turn signals for the current turn.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1CreateDocumentOperationMetadata = {
      description = "Metadata for CreateDocument operation.",
      id = "GoogleCloudDialogflowV3alpha1CreateDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1DeleteDocumentOperationMetadata = {
      description = "Metadata for DeleteDocument operation.",
      id = "GoogleCloudDialogflowV3alpha1DeleteDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata = {
      description = "Metadata in google::longrunning::Operation for Knowledge operations.",
      id = "GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata",
      properties = {
        state = {
          description = "Required. Output only. The current state of this operation.",
          enum = {
            "STATE_UNSPECIFIED",
            "PENDING",
            "RUNNING",
            "DONE",
          },
          enumDescriptions = {
            "State unspecified.",
            "The operation has been created.",
            "The operation is currently running.",
            "The operation is done, either cancelled or completed.",
          },
          readOnly = true,
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1ImportDocumentsOperationMetadata = {
      description = "Metadata for ImportDocuments operation.",
      id = "GoogleCloudDialogflowV3alpha1ImportDocumentsOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1ImportDocumentsResponse = {
      description = "Response message for Documents.ImportDocuments.",
      id = "GoogleCloudDialogflowV3alpha1ImportDocumentsResponse",
      properties = {
        warnings = {
          description = "Includes details about skipped documents or any other warnings.",
          items = {
            ["$ref"] = "GoogleRpcStatus",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1ReloadDocumentOperationMetadata = {
      description = "Metadata for ReloadDocument operation.",
      id = "GoogleCloudDialogflowV3alpha1ReloadDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1TurnSignals = {
      description = "Collection of all signals that were extracted for a single turn of the conversation.",
      id = "GoogleCloudDialogflowV3alpha1TurnSignals",
      properties = {
        agentEscalated = {
          description = "Whether agent responded with LiveAgentHandoff fulfillment.",
          type = "boolean",
        },
        dtmfUsed = {
          description = "Whether user was using DTMF input.",
          type = "boolean",
        },
        failureReasons = {
          description = "Failure reasons of the turn.",
          items = {
            enum = {
              "FAILURE_REASON_UNSPECIFIED",
              "FAILED_INTENT",
              "FAILED_WEBHOOK",
            },
            enumDescriptions = {
              "Failure reason is not assigned.",
              "Whether NLU failed to recognize user intent.",
              "Whether webhook failed during the turn.",
            },
            type = "string",
          },
          type = "array",
        },
        noMatch = {
          description = "Whether NLU predicted NO_MATCH.",
          type = "boolean",
        },
        noUserInput = {
          description = "Whether user provided no input.",
          type = "boolean",
        },
        reachedEndPage = {
          description = "Whether turn resulted in End Session page.",
          type = "boolean",
        },
        triggeredAbandonmentEvent = {
          description = "Whether agent has triggered the event corresponding to user abandoning the conversation.",
          type = "boolean",
        },
        userEscalated = {
          description = "Whether user was specifically asking for a live agent.",
          type = "boolean",
        },
        webhookStatuses = {
          description = "Human-readable statuses of the webhooks triggered during this turn.",
          items = {
            type = "string",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleCloudDialogflowV3alpha1UpdateDocumentOperationMetadata = {
      description = "Metadata for UpdateDocument operation.",
      id = "GoogleCloudDialogflowV3alpha1UpdateDocumentOperationMetadata",
      properties = {
        genericMetadata = {
          ["$ref"] = "GoogleCloudDialogflowV3alpha1GenericKnowledgeOperationMetadata",
          description = "The generic information of the operation.",
        },
      },
      type = "object",
    },
    GoogleCloudLocationListLocationsResponse = {
      description = "The response message for Locations.ListLocations.",
      id = "GoogleCloudLocationListLocationsResponse",
      properties = {
        locations = {
          description = "A list of locations that matches the specified filter in the request.",
          items = {
            ["$ref"] = "GoogleCloudLocationLocation",
          },
          type = "array",
        },
        nextPageToken = {
          description = "The standard List next-page token.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleCloudLocationLocation = {
      description = "A resource that represents Google Cloud Platform location.",
      id = "GoogleCloudLocationLocation",
      properties = {
        displayName = {
          description = "The friendly name for this location, typically a nearby city name. For example, \"Tokyo\".",
          type = "string",
        },
        labels = {
          additionalProperties = {
            type = "string",
          },
          description = "Cross-service attributes for the location. For example {\"cloud.googleapis.com/region\": \"us-east1\"}",
          type = "object",
        },
        locationId = {
          description = "The canonical id for this location. For example: `\"us-east1\"`.",
          type = "string",
        },
        metadata = {
          additionalProperties = {
            description = "Properties of the object. Contains field @type with type URL.",
            type = "any",
          },
          description = "Service-specific metadata. For example the available capacity at the given location.",
          type = "object",
        },
        name = {
          description = "Resource name for the location, which may vary between implementations. For example: `\"projects/example-project/locations/us-east1\"`",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleLongrunningListOperationsResponse = {
      description = "The response message for Operations.ListOperations.",
      id = "GoogleLongrunningListOperationsResponse",
      properties = {
        nextPageToken = {
          description = "The standard List next-page token.",
          type = "string",
        },
        operations = {
          description = "A list of operations that matches the specified filter in the request.",
          items = {
            ["$ref"] = "GoogleLongrunningOperation",
          },
          type = "array",
        },
      },
      type = "object",
    },
    GoogleLongrunningOperation = {
      description = "This resource represents a long-running operation that is the result of a network API call.",
      id = "GoogleLongrunningOperation",
      properties = {
        done = {
          description = "If the value is `false`, it means the operation is still in progress. If `true`, the operation is completed, and either `error` or `response` is available.",
          type = "boolean",
        },
        error = {
          ["$ref"] = "GoogleRpcStatus",
          description = "The error result of the operation in case of failure or cancellation.",
        },
        metadata = {
          additionalProperties = {
            description = "Properties of the object. Contains field @type with type URL.",
            type = "any",
          },
          description = "Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.",
          type = "object",
        },
        name = {
          description = "The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should be a resource name ending with `operations/{unique_id}`.",
          type = "string",
        },
        response = {
          additionalProperties = {
            description = "Properties of the object. Contains field @type with type URL.",
            type = "any",
          },
          description = "The normal response of the operation in case of success. If the original method returns no data on success, such as `Delete`, the response is `google.protobuf.Empty`. If the original method is standard `Get`/`Create`/`Update`, the response should be the resource. For other methods, the response should have the type `XxxResponse`, where `Xxx` is the original method name. For example, if the original method name is `TakeSnapshot()`, the inferred response type is `TakeSnapshotResponse`.",
          type = "object",
        },
      },
      type = "object",
    },
    GoogleProtobufEmpty = {
      description = "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance: service Foo { rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty); }",
      id = "GoogleProtobufEmpty",
      properties = {},
      type = "object",
    },
    GoogleRpcStatus = {
      description = "The `Status` type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by [gRPC](https://github.com/grpc). Each `Status` message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the [API Design Guide](https://cloud.google.com/apis/design/errors).",
      id = "GoogleRpcStatus",
      properties = {
        code = {
          description = "The status code, which should be an enum value of google.rpc.Code.",
          format = "int32",
          type = "integer",
        },
        details = {
          description = "A list of messages that carry the error details. There is a common set of message types for APIs to use.",
          items = {
            additionalProperties = {
              description = "Properties of the object. Contains field @type with type URL.",
              type = "any",
            },
            type = "object",
          },
          type = "array",
        },
        message = {
          description = "A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client.",
          type = "string",
        },
      },
      type = "object",
    },
    GoogleTypeLatLng = {
      description = "An object that represents a latitude/longitude pair. This is expressed as a pair of doubles to represent degrees latitude and degrees longitude. Unless specified otherwise, this object must conform to the WGS84 standard. Values must be within normalized ranges.",
      id = "GoogleTypeLatLng",
      properties = {
        latitude = {
          description = "The latitude in degrees. It must be in the range [-90.0, +90.0].",
          format = "double",
          type = "number",
        },
        longitude = {
          description = "The longitude in degrees. It must be in the range [-180.0, +180.0].",
          format = "double",
          type = "number",
        },
      },
      type = "object",
    },
  },
  servicePath = "",
  title = "Dialogflow API",
  version = "v2",
  version_module = true,
}
